{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Language Models\n",
    "\n",
    "Models investigating the effect of spoken frequency, and concretneess, controlling for using word norms, including orthographic frequency norms and prescence of speech. </br>\n"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "name": "stderr",
     "output_type": "stream",
     "text": [
      "/home/alejandro/anaconda3/lib/python3.7/site-packages/nilearn/datasets/__init__.py:89: FutureWarning: Fetchers from the nilearn.datasets module will be updated in version 0.9 to return python strings instead of bytes and Pandas dataframes instead of Numpy arrays.\n",
      "  \"Numpy arrays.\", FutureWarning)\n"
     ]
    }
   ],
   "source": [
    "from create import create_models\n",
    "from pyns import Neuroscout\n",
    "from matplotlib import pyplot as plt\n",
    "from pathlib import Path\n",
    "import sys\n",
    "sys.path.append(\"..\") \n",
    "from utils import dump_collection, load_collection\n",
    "\n",
    "%matplotlib inline"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {},
   "outputs": [],
   "source": [
    "api = Neuroscout()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Define predictors and confounds"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {},
   "outputs": [],
   "source": [
    "predictors = [\n",
    "    'subtlexusfrequency_Lg10WF', 'speech', 'massiveauditorylexicaldecision_PhonLev', 'text_length', \n",
    "    'massiveauditorylexicaldecision_NumSylls', 'massiveauditorylexicaldecision_NumPhones', \n",
    "    'massiveauditorylexicaldecision_Duration', 'concreteness_Conc.M'\n",
    "]\n",
    "transform_variables = list(set(predictors) - set(['speech']))\n",
    "datasets = api.datasets.get() # Get all Neuroscout datasets"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {},
   "outputs": [],
   "source": [
    "confounds = ['a_comp_cor_00', 'a_comp_cor_01', 'a_comp_cor_02', 'a_comp_cor_03', 'a_comp_cor_04', 'a_comp_cor_05', 'trans_x', 'trans_y', 'trans_z', 'rot_x', 'rot_y', 'rot_z']"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 6,
   "metadata": {},
   "outputs": [],
   "source": [
    "filename = Path('models') / 'lexical_variables.json'\n",
    "language_models = load_collection(filename) # Load instead of re-running"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Create models"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 7,
   "metadata": {},
   "outputs": [],
   "source": [
    "transformations = [\n",
    "    {\"Name\": \"Scale\", \"Demean\": True, \"Rescale\": True, \"ReplaceNA\": \"after\", \"Input\": [p],\"Output\": [p]} \n",
    "    for p in transform_variables\n",
    "    ]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 15,
   "metadata": {},
   "outputs": [],
   "source": [
    "name = name = '+'.join(predictors)\n",
    "language_models = {}\n",
    "# language_models[name] = create_models(name=name,\n",
    "#     predictors=predictors, confounds=confounds, datasets=datasets, transformations=transformations)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 14,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "\n",
       "<div id=\"altair-viz-1\"></div>\n",
       "<script type=\"text/javascript\">\n",
       "  (function(spec, embedOpt){\n",
       "    const outputDiv = document.getElementById(\"altair-viz-1\");\n",
       "    const paths = {\n",
       "      \"vega\": \"https://cdn.jsdelivr.net/npm//vega@5?noext\",\n",
       "      \"vega-lib\": \"https://cdn.jsdelivr.net/npm//vega-lib?noext\",\n",
       "      \"vega-lite\": \"https://cdn.jsdelivr.net/npm//vega-lite@4.0.0?noext\",\n",
       "      \"vega-embed\": \"https://cdn.jsdelivr.net/npm//vega-embed@6?noext\",\n",
       "    };\n",
       "\n",
       "    function loadScript(lib) {\n",
       "      return new Promise(function(resolve, reject) {\n",
       "        var s = document.createElement('script');\n",
       "        s.src = paths[lib];\n",
       "        s.async = true;\n",
       "        s.onload = () => resolve(paths[lib]);\n",
       "        s.onerror = () => reject(`Error loading script: ${paths[lib]}`);\n",
       "        document.getElementsByTagName(\"head\")[0].appendChild(s);\n",
       "      });\n",
       "    }\n",
       "\n",
       "    function showError(err) {\n",
       "      outputDiv.innerHTML = `<div class=\"error\" style=\"color:red;\">${err}</div>`;\n",
       "      throw err;\n",
       "    }\n",
       "\n",
       "    function displayChart(vegaEmbed) {\n",
       "      vegaEmbed(outputDiv, spec, embedOpt)\n",
       "        .catch(err => showError(`Javascript Error: ${err.message}<br>This usually means there's a typo in your chart specification. See the javascript console for the full traceback.`));\n",
       "    }\n",
       "\n",
       "    if(typeof define === \"function\" && define.amd) {\n",
       "      requirejs.config({paths});\n",
       "      require([\"vega-embed\"], displayChart, err => showError(`Error loading script: ${err.message}`));\n",
       "    } else if (typeof vegaEmbed === \"function\") {\n",
       "      displayChart(vegaEmbed);\n",
       "    } else {\n",
       "      loadScript(\"vega\")\n",
       "        .then(() => loadScript(\"vega-lite\"))\n",
       "        .then(() => loadScript(\"vega-embed\"))\n",
       "        .catch(showError)\n",
       "        .then(() => displayChart(vegaEmbed));\n",
       "    }\n",
       "  })({\"$schema\": \"https://vega.github.io/schema/vega-lite/v4.8.1.json\", \"config\": {\"scale\": {\"bandPaddingInner\": 0.0}, \"view\": {\"continuousHeight\": 300, \"continuousWidth\": 400}}, \"data\": {\"name\": \"data-b471e2eef2329ad842eafa26fe0b515a\"}, \"datasets\": {\"data-b471e2eef2329ad842eafa26fe0b515a\": [{\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 0, \"value\": -4.109397845668746e-12}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 1, \"value\": 1.0165519568969086e-11}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 2, \"value\": -2.448056131907903e-11}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 3, \"value\": 5.707381890184913e-11}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 4, \"value\": -1.2760983380615576e-10}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 5, \"value\": 2.6899029494022947e-10}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 6, \"value\": -5.160082967562063e-10}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 7, \"value\": 8.209181103912882e-10}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 8, \"value\": -6.910202519509775e-10}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 9, \"value\": -2.1174862331684515e-09}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 10, \"value\": 1.5900901580317783e-08}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 11, \"value\": -6.838650843051768e-08}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 12, \"value\": 2.4667393429463194e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 13, \"value\": -8.127288524831545e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 14, \"value\": 2.528539180240452e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 15, \"value\": -7.542859997432457e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 16, \"value\": 2.178970447555816e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 17, \"value\": -6.13503592478346e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 18, \"value\": 0.00016899483492723312}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 19, \"value\": -0.00044730103472488913}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 20, \"value\": 0.0011076522792162233}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 21, \"value\": -0.002495765912618743}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 22, \"value\": 0.039708620184422366}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 23, \"value\": 0.14014077011826992}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 24, \"value\": 0.09582722289457853}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 25, \"value\": -0.0020016904034831488}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 26, \"value\": -0.03923196353705078}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 27, \"value\": -0.3769980816651683}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 28, \"value\": -0.6828315666336859}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 29, \"value\": -0.5934651638543804}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 30, \"value\": -0.2890657421374448}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 31, \"value\": -0.05282858085900367}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 32, \"value\": 0.02421104622639359}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 33, \"value\": -0.048868436618823036}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 34, \"value\": -0.0398618769734428}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 35, \"value\": 0.021804710049315952}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 36, \"value\": 0.0249424483921322}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 37, \"value\": 0.01908365928985856}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 38, \"value\": 0.011617663300774766}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 39, \"value\": 0.005297359147361266}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 40, \"value\": 0.0022448487700504065}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 41, \"value\": -0.00044172406228563217}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 42, \"value\": 0.0016405121404624065}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 43, \"value\": -0.022320414841517013}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 44, \"value\": -0.14015177703591633}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 45, \"value\": -0.19825472921959503}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 46, \"value\": -0.13281370211231922}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 47, \"value\": 0.10227251181454121}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 48, \"value\": 0.12809029813511794}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 49, \"value\": 0.07833559954931102}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 50, \"value\": 0.016987135225080788}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 51, \"value\": -0.11362653598109694}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 52, \"value\": -0.23936812493845466}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 53, \"value\": -0.23867294294471847}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 54, \"value\": -0.6477033735081357}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 55, \"value\": -0.9933071097502623}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 56, \"value\": -0.6541387803316108}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 57, \"value\": -0.2500531945209582}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 58, \"value\": 0.07682710204498688}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 59, \"value\": 0.030397193694417332}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 60, \"value\": -0.2406371163055198}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 61, \"value\": -0.13190272797963856}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 62, \"value\": -0.13551188257901634}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 63, \"value\": -0.19287922210390215}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 64, \"value\": -0.07496678576788313}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 65, \"value\": -0.03545071586545113}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 66, \"value\": -0.054158871136541484}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 67, \"value\": -0.07563384557376726}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 68, \"value\": 0.019800061992961183}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 69, \"value\": -0.011112702971624455}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 70, \"value\": -0.1335649339502985}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 71, \"value\": -0.0985151313035579}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 72, \"value\": -0.028116807015565994}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 73, \"value\": -0.02275518357386311}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 74, \"value\": -0.13602856971666066}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 75, \"value\": -0.2121768263986654}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 76, \"value\": -0.08081477450246433}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 77, \"value\": -0.0190042411458232}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 78, \"value\": -0.10586035669455021}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 79, \"value\": -0.31867674815692254}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 80, \"value\": -0.23100848062053006}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 81, \"value\": -0.10573407638861601}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 82, \"value\": -0.025616448610307544}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 83, \"value\": -0.29910827247631244}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 84, \"value\": -0.4991996912628184}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 85, \"value\": -0.24212977570815983}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 86, \"value\": -0.04942190886612664}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 87, \"value\": 0.030925880047192354}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 88, \"value\": 0.06117721851021032}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 89, \"value\": 0.09442872742733656}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 90, \"value\": 0.07042851658724227}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 91, \"value\": 0.027102976817283846}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 92, \"value\": 0.005477420194717746}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 93, \"value\": 0.004451024740753798}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 94, \"value\": 0.02479995918485197}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 95, \"value\": 0.03200144191641424}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 96, \"value\": -0.09954837022186853}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 97, \"value\": -0.25365711292757304}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 98, \"value\": -0.30328401753557566}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 99, \"value\": -0.17038242311672594}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 100, \"value\": 0.05404247293752339}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 101, \"value\": 0.05418836766839165}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 102, \"value\": 0.059417483854866546}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 103, \"value\": 0.1887389332715646}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 104, \"value\": 0.14901307287779655}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 105, \"value\": 0.1384835502622617}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 106, \"value\": 0.16867220920730072}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 107, \"value\": 0.007021307387467967}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 108, \"value\": -0.07063508996170371}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 109, \"value\": -0.09348491620299389}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 110, \"value\": -0.05166224560640487}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 111, \"value\": -0.01184844817874598}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 112, \"value\": 0.02408293618896826}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 113, \"value\": 0.054562775618766116}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 114, \"value\": 0.030497704638975866}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 115, \"value\": 0.004563120939774435}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 116, \"value\": 0.009091455125508867}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 117, \"value\": -0.10195326777060332}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 118, \"value\": -0.339625076678022}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 119, \"value\": -0.251577203499023}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 120, \"value\": -0.08402490298502452}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 121, \"value\": -0.0011719346725550157}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 122, \"value\": 0.028827995296035816}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 123, \"value\": 0.02882610042137895}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 124, \"value\": 0.01875712138539776}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 125, \"value\": 0.009674324671773782}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 126, \"value\": 0.0034041998008748865}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 127, \"value\": 0.0023543180386189056}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 128, \"value\": -0.007412374100011982}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 129, \"value\": -0.09546195653197607}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 130, \"value\": -0.1274885409094314}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 131, \"value\": -0.22816122517634857}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 132, \"value\": -0.19216888266536952}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 133, \"value\": -0.05448563211515188}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 134, \"value\": 0.005867104262054369}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 135, \"value\": 0.024971244779893303}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 136, \"value\": 0.02282981143989456}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 137, \"value\": 0.014538528394514366}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 138, \"value\": 0.00711459752833281}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 139, \"value\": 0.0028692181828984704}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 140, \"value\": 0.000968165676488328}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 141, \"value\": 0.0002849808376361836}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 142, \"value\": 3.9635784577854266e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 143, \"value\": 3.8445813641452006e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 144, \"value\": -0.00015302555379845576}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 145, \"value\": 0.0004333645636714602}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 146, \"value\": -0.001135793195754897}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 147, \"value\": 0.002746074997599381}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 148, \"value\": -0.03398842762966013}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 149, \"value\": -0.08772382859683443}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 150, \"value\": -0.05553943870128294}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 151, \"value\": -0.016126014409296223}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 152, \"value\": 0.0018532032322801629}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 153, \"value\": 0.007698275058777448}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 154, \"value\": 0.006931228610527484}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 155, \"value\": 0.004346063222231446}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 156, \"value\": 0.00199329764970897}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 157, \"value\": 0.0015333970281470664}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 158, \"value\": 0.006464630243657788}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 159, \"value\": 0.006554983397844347}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 160, \"value\": 0.0025424360426284207}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 161, \"value\": 0.0003529112186999237}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 162, \"value\": -0.0005350734719388503}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 163, \"value\": -0.0006500240722494316}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 164, \"value\": -0.0004667974530253849}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 165, \"value\": -0.00024397941379200158}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 166, \"value\": -0.00011327688072325757}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 167, \"value\": -2.17164874520006e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 168, \"value\": -5.062019730401252e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 169, \"value\": 8.001280018429821e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 170, \"value\": -0.00016536472707640482}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 171, \"value\": 0.0002829268393739387}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 172, \"value\": -0.00037813247703877615}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 173, \"value\": 0.0011780190184060948}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 174, \"value\": -0.0025184826095849227}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 175, \"value\": -0.2170479723971221}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 176, \"value\": -0.297230584704486}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 177, \"value\": -0.15413201067145424}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 178, \"value\": -0.18506755908356168}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 179, \"value\": -0.32153462297175744}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 180, \"value\": -0.24019865044039668}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 181, \"value\": 0.008030018966057349}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 182, \"value\": 0.16151890847973563}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 183, \"value\": 0.1174805022152256}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 184, \"value\": 0.05405814803046381}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 185, \"value\": 0.015261702999530391}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 186, \"value\": -0.0027853017560263106}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 187, \"value\": -0.006863749455423187}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 188, \"value\": -0.005084671705461785}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 189, \"value\": -0.00259738992039533}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 190, \"value\": -0.0011048063344804232}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 191, \"value\": -0.00040035825726296204}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 192, \"value\": -0.00011531345495867257}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 193, \"value\": -5.521821899353856e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 194, \"value\": 8.481187247638906e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 195, \"value\": -8.040524403681103e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 196, \"value\": 1.2950546003928934e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 197, \"value\": -2.294483368195548e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 198, \"value\": 3.5842548948934366e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 199, \"value\": -2.3073478163029817e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 200, \"value\": -9.767422336025288e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 201, \"value\": -1.098500340724275e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 202, \"value\": 0.001954770259501562}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 203, \"value\": 0.03142525221655283}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 204, \"value\": 0.07799673047347627}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 205, \"value\": 0.0694950128095379}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 206, \"value\": 0.027507509394533735}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 207, \"value\": 0.002445367673857718}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 208, \"value\": -0.006936841702529209}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 209, \"value\": -0.007772161758144177}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 210, \"value\": -0.00538488881967122}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 211, \"value\": -0.002834576128590505}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 212, \"value\": -0.001217380230467558}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 213, \"value\": -0.00044485742522603873}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 214, \"value\": -0.00014037511433061207}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 215, \"value\": -3.072059684683161e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 216, \"value\": -1.5556671349321828e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 217, \"value\": -1.7038152573733355e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 218, \"value\": 6.598913229603706e-09}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 219, \"value\": 1.6560268241387183e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 220, \"value\": -4.993290441494475e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 221, \"value\": 1.3319420413624374e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 222, \"value\": -3.4528707005298687e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 223, \"value\": 8.756616860284538e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 224, \"value\": -2.1693705917648562e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 225, \"value\": 5.233810199338172e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 226, \"value\": -0.00012216795273793768}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 227, \"value\": 0.00026976789153362304}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 228, \"value\": -0.0005610125481197981}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 229, \"value\": 0.0013489221560319571}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 230, \"value\": -0.012746326113446357}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 231, \"value\": -0.10815853217761476}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 232, \"value\": -0.11222697909952106}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 233, \"value\": -0.04376237875808323}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 234, \"value\": -0.0060128236818890665}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 235, \"value\": 0.009365243639439717}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 236, \"value\": 0.011308800242561045}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 237, \"value\": 0.00808180684019156}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 238, \"value\": 0.00427693956843811}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 239, \"value\": 0.0018377561673368929}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 240, \"value\": 0.0006657384708635342}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 241, \"value\": 0.00021345280299945273}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 242, \"value\": 4.9078480626493296e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 243, \"value\": -5.468832150964505e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 244, \"value\": 4.972066665780682e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 245, \"value\": -8.545190127848443e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 246, \"value\": 1.725051638067425e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 247, \"value\": -3.318511606089689e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 248, \"value\": 5.2133112070326615e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 249, \"value\": -4.646442359052685e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 250, \"value\": 5.089120339923723e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 251, \"value\": -0.004711812401691588}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 252, \"value\": -0.07148830179390989}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 253, \"value\": -0.09948022343228634}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 254, \"value\": -0.04668305808519371}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 255, \"value\": -0.001856498522110059}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 256, \"value\": 0.0137176915039512}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 257, \"value\": 0.01242831058961081}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 258, \"value\": 0.007485333378819612}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 259, \"value\": 0.008085137855459229}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 260, \"value\": 0.040960356110265314}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 261, \"value\": 0.1062824454930177}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 262, \"value\": -0.014405693651358464}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 263, \"value\": -0.30394366359394787}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 264, \"value\": -0.24395899701099844}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 265, \"value\": -0.18273450578357558}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 266, \"value\": -0.25469311044442156}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 267, \"value\": -0.1428317752300044}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 268, \"value\": -0.025426511676638244}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 269, \"value\": 0.020728956447562764}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 270, \"value\": 0.030403392497686317}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 271, \"value\": 0.023807272553902595}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 272, \"value\": 0.01407132134959894}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 273, \"value\": 0.006595450609600957}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 274, \"value\": 0.0026678877039894525}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 275, \"value\": 0.0006101054746707868}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 276, \"value\": 0.0009065082580387485}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 277, \"value\": -0.0015304119149249186}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 278, \"value\": 0.0036458301211181473}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 279, \"value\": -0.049437118709839675}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 280, \"value\": -0.18118274890242092}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 281, \"value\": -0.12949057129995944}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 282, \"value\": -0.019895361948395043}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 283, \"value\": 0.013003388765939724}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 284, \"value\": 0.019387932183204816}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 285, \"value\": 0.014948054145148241}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 286, \"value\": 0.007980165715733713}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 287, \"value\": 0.0038119089024723158}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 288, \"value\": -0.00023165944914788636}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 289, \"value\": 0.003698879124672985}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 290, \"value\": -0.0239085246019553}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 291, \"value\": -0.10113614571375693}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 292, \"value\": -0.19823247342739145}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 293, \"value\": -0.5603945751877947}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 294, \"value\": -0.6083330777233317}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 295, \"value\": -0.2577953119579485}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 296, \"value\": -0.052119642601831356}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 297, \"value\": 0.00857654360088255}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 298, \"value\": 0.038880445775916754}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 299, \"value\": -0.06258546305804279}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 300, \"value\": -0.18599653952656467}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 301, \"value\": -0.32180552839381515}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 302, \"value\": -0.3598055139872028}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 303, \"value\": -0.44531564526925344}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 304, \"value\": -0.5417629332488363}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 305, \"value\": -0.291298225759181}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 306, \"value\": -0.05208711572702247}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 307, \"value\": 0.044685233242364494}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 308, \"value\": 0.06425665991663122}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 309, \"value\": 0.04957701801734333}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 310, \"value\": 0.028722841322361498}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 311, \"value\": 0.013335606591968781}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 312, \"value\": 0.00516810656856018}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 313, \"value\": 0.0018058537023367069}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 314, \"value\": 0.00026799539621548966}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 315, \"value\": 0.0011402819561108987}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 316, \"value\": 0.003409458896852454}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 317, \"value\": 0.006669703051139658}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 318, \"value\": -0.0040722678959692156}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 319, \"value\": 0.05515723537514045}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 320, \"value\": 0.1301586651491396}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 321, \"value\": -0.15059478542824922}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 322, \"value\": -0.2679945877568591}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 323, \"value\": -0.14169797137619855}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 324, \"value\": -0.02040136527818273}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 325, \"value\": 0.041834543973805406}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 326, \"value\": 0.040077417855033805}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 327, \"value\": 0.023466571355329577}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 328, \"value\": 0.009537988578552493}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 329, \"value\": 0.001956765062391158}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 330, \"value\": -0.0006613686458553648}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 331, \"value\": -0.0008629882388655659}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 332, \"value\": -0.0005382914568480621}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 333, \"value\": -0.0002770799169962599}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 334, \"value\": -9.234808046347049e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 335, \"value\": -2.788730481266448e-05}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 336, \"value\": -1.3474690653309387e-06}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 337, \"value\": -1.07435743003424e-07}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 338, \"value\": 2.9836931626217174e-08}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 339, \"value\": -7.300994159205922e-10}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 340, \"value\": -4.097191808294016e-09}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 341, \"value\": 3.2283932680925986e-09}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 342, \"value\": -2.2427884887344926e-09}, {\"regressor\": \"subtlexusfrequency_Lg10WF\", \"scan_number\": 343, \"value\": 3.414745163669446e-09}, {\"regressor\": \"speech\", \"scan_number\": 0, \"value\": -1.0684583019994886e-11}, {\"regressor\": \"speech\", \"scan_number\": 1, \"value\": 2.5693617580919756e-11}, {\"regressor\": \"speech\", \"scan_number\": 2, \"value\": -5.979680681198903e-11}, {\"regressor\": \"speech\", \"scan_number\": 3, \"value\": 1.3338877305635765e-10}, {\"regressor\": \"speech\", \"scan_number\": 4, \"value\": -2.8022060632261785e-10}, {\"regressor\": \"speech\", \"scan_number\": 5, \"value\": 5.344394051415119e-10}, {\"regressor\": \"speech\", \"scan_number\": 6, \"value\": -8.390105763777365e-10}, {\"regressor\": \"speech\", \"scan_number\": 7, \"value\": 6.57207126817412e-10}, {\"regressor\": \"speech\", \"scan_number\": 8, \"value\": 2.420096094365525e-09}, {\"regressor\": \"speech\", \"scan_number\": 9, \"value\": -1.7246295747736564e-08}, {\"regressor\": \"speech\", \"scan_number\": 10, \"value\": 7.330778423197561e-08}, {\"regressor\": \"speech\", \"scan_number\": 11, \"value\": -2.630144807581415e-07}, {\"regressor\": \"speech\", \"scan_number\": 12, \"value\": 8.638236607048261e-07}, {\"regressor\": \"speech\", \"scan_number\": 13, \"value\": -2.6816932683768566e-06}, {\"regressor\": \"speech\", \"scan_number\": 14, \"value\": 7.994644517131878e-06}, {\"regressor\": \"speech\", \"scan_number\": 15, \"value\": -2.3069127776085894e-05}, {\"regressor\": \"speech\", \"scan_number\": 16, \"value\": 6.482056220848158e-05}, {\"regressor\": \"speech\", \"scan_number\": 17, \"value\": -0.00017808234498772015}, {\"regressor\": \"speech\", \"scan_number\": 18, \"value\": 0.00047937594911470234}, {\"regressor\": \"speech\", \"scan_number\": 19, \"value\": -0.0012432222573333606}, {\"regressor\": \"speech\", \"scan_number\": 20, \"value\": 0.0030388680612826423}, {\"regressor\": \"speech\", \"scan_number\": 21, \"value\": -0.0069610862970906125}, {\"regressor\": \"speech\", \"scan_number\": 22, \"value\": 0.09863062316633346}, {\"regressor\": \"speech\", \"scan_number\": 23, \"value\": 0.37419508029857346}, {\"regressor\": \"speech\", \"scan_number\": 24, \"value\": 0.3530710053051453}, {\"regressor\": \"speech\", \"scan_number\": 25, \"value\": 0.3138369661315664}, {\"regressor\": \"speech\", \"scan_number\": 26, \"value\": 0.4830595459746612}, {\"regressor\": \"speech\", \"scan_number\": 27, \"value\": 0.6568433430427812}, {\"regressor\": \"speech\", \"scan_number\": 28, \"value\": 0.7719928416326672}, {\"regressor\": \"speech\", \"scan_number\": 29, \"value\": 0.6976356643446495}, {\"regressor\": \"speech\", \"scan_number\": 30, \"value\": 0.3415315409686615}, {\"regressor\": \"speech\", \"scan_number\": 31, \"value\": 0.04378462755421298}, {\"regressor\": \"speech\", \"scan_number\": 32, \"value\": 0.036956371612567235}, {\"regressor\": \"speech\", \"scan_number\": 33, \"value\": 0.19300211666066558}, {\"regressor\": \"speech\", \"scan_number\": 34, \"value\": 0.2589604791870276}, {\"regressor\": \"speech\", \"scan_number\": 35, \"value\": 0.15434920686051484}, {\"regressor\": \"speech\", \"scan_number\": 36, \"value\": 0.030278051925034785}, {\"regressor\": \"speech\", \"scan_number\": 37, \"value\": -0.0248542561173991}, {\"regressor\": \"speech\", \"scan_number\": 38, \"value\": -0.03693675126671677}, {\"regressor\": \"speech\", \"scan_number\": 39, \"value\": -0.028962381382643124}, {\"regressor\": \"speech\", \"scan_number\": 40, \"value\": -0.01692777865840792}, {\"regressor\": \"speech\", \"scan_number\": 41, \"value\": -0.008387179771939823}, {\"regressor\": \"speech\", \"scan_number\": 42, \"value\": -0.0007033458029946774}, {\"regressor\": \"speech\", \"scan_number\": 43, \"value\": 0.037790041633798184}, {\"regressor\": \"speech\", \"scan_number\": 44, \"value\": 0.3514239115284566}, {\"regressor\": \"speech\", \"scan_number\": 45, \"value\": 0.7244670390510258}, {\"regressor\": \"speech\", \"scan_number\": 46, \"value\": 0.8620188634768038}, {\"regressor\": \"speech\", \"scan_number\": 47, \"value\": 0.9217223563780929}, {\"regressor\": \"speech\", \"scan_number\": 48, \"value\": 0.7905089376858926}, {\"regressor\": \"speech\", \"scan_number\": 49, \"value\": 0.5767381749861751}, {\"regressor\": \"speech\", \"scan_number\": 50, \"value\": 0.3927633084724246}, {\"regressor\": \"speech\", \"scan_number\": 51, \"value\": 0.3297174943277519}, {\"regressor\": \"speech\", \"scan_number\": 52, \"value\": 0.4036830953048165}, {\"regressor\": \"speech\", \"scan_number\": 53, \"value\": 0.44726356987452237}, {\"regressor\": \"speech\", \"scan_number\": 54, \"value\": 0.6252977655995193}, {\"regressor\": \"speech\", \"scan_number\": 55, \"value\": 0.7061562919048202}, {\"regressor\": \"speech\", \"scan_number\": 56, \"value\": 0.6647900020781548}, {\"regressor\": \"speech\", \"scan_number\": 57, \"value\": 0.445451075905805}, {\"regressor\": \"speech\", \"scan_number\": 58, \"value\": 0.3493371988372386}, {\"regressor\": \"speech\", \"scan_number\": 59, \"value\": 0.5561881563399128}, {\"regressor\": \"speech\", \"scan_number\": 60, \"value\": 0.6632161315772875}, {\"regressor\": \"speech\", \"scan_number\": 61, \"value\": 0.6989342320217835}, {\"regressor\": \"speech\", \"scan_number\": 62, \"value\": 0.7058533115248221}, {\"regressor\": \"speech\", \"scan_number\": 63, \"value\": 0.5393904636155253}, {\"regressor\": \"speech\", \"scan_number\": 64, \"value\": 0.24342563697184535}, {\"regressor\": \"speech\", \"scan_number\": 65, \"value\": 0.14989435684725555}, {\"regressor\": \"speech\", \"scan_number\": 66, \"value\": 0.19471641365260794}, {\"regressor\": \"speech\", \"scan_number\": 67, \"value\": 0.38040455667002304}, {\"regressor\": \"speech\", \"scan_number\": 68, \"value\": 0.3688290831843148}, {\"regressor\": \"speech\", \"scan_number\": 69, \"value\": 0.2411142605782271}, {\"regressor\": \"speech\", \"scan_number\": 70, \"value\": 0.3893112862626239}, {\"regressor\": \"speech\", \"scan_number\": 71, \"value\": 0.2860976323912725}, {\"regressor\": \"speech\", \"scan_number\": 72, \"value\": 0.0695336304820746}, {\"regressor\": \"speech\", \"scan_number\": 73, \"value\": -0.015856792010559388}, {\"regressor\": \"speech\", \"scan_number\": 74, \"value\": 0.04764849282641108}, {\"regressor\": \"speech\", \"scan_number\": 75, \"value\": 0.19218279207748035}, {\"regressor\": \"speech\", \"scan_number\": 76, \"value\": 0.41300322998493355}, {\"regressor\": \"speech\", \"scan_number\": 77, \"value\": 0.5312154600626816}, {\"regressor\": \"speech\", \"scan_number\": 78, \"value\": 0.3993784760370823}, {\"regressor\": \"speech\", \"scan_number\": 79, \"value\": 0.4664934894279309}, {\"regressor\": \"speech\", \"scan_number\": 80, \"value\": 0.5276915486645071}, {\"regressor\": \"speech\", \"scan_number\": 81, \"value\": 0.595052886935703}, {\"regressor\": \"speech\", \"scan_number\": 82, \"value\": 0.5969400324042994}, {\"regressor\": \"speech\", \"scan_number\": 83, \"value\": 0.46777022462336304}, {\"regressor\": \"speech\", \"scan_number\": 84, \"value\": 0.2874293511482393}, {\"regressor\": \"speech\", \"scan_number\": 85, \"value\": 0.05587267173054591}, {\"regressor\": \"speech\", \"scan_number\": 86, \"value\": -0.052641365689805826}, {\"regressor\": \"speech\", \"scan_number\": 87, \"value\": -0.07540258852973881}, {\"regressor\": \"speech\", \"scan_number\": 88, \"value\": -0.03859468995393894}, {\"regressor\": \"speech\", \"scan_number\": 89, \"value\": 0.06192392433931755}, {\"regressor\": \"speech\", \"scan_number\": 90, \"value\": 0.0658389867286007}, {\"regressor\": \"speech\", \"scan_number\": 91, \"value\": 0.025154512474822876}, {\"regressor\": \"speech\", \"scan_number\": 92, \"value\": -0.005720786527222464}, {\"regressor\": \"speech\", \"scan_number\": 93, \"value\": 0.07935724928372757}, {\"regressor\": \"speech\", \"scan_number\": 94, \"value\": 0.3429853820723887}, {\"regressor\": \"speech\", \"scan_number\": 95, \"value\": 0.5189969039851675}, {\"regressor\": \"speech\", \"scan_number\": 96, \"value\": 0.4131674101615592}, {\"regressor\": \"speech\", \"scan_number\": 97, \"value\": 0.21396651387046772}, {\"regressor\": \"speech\", \"scan_number\": 98, \"value\": 0.12359238629187984}, {\"regressor\": \"speech\", \"scan_number\": 99, \"value\": 0.11189404289988618}, {\"regressor\": \"speech\", \"scan_number\": 100, \"value\": 0.36104649848577647}, {\"regressor\": \"speech\", \"scan_number\": 101, \"value\": 0.6531941003285859}, {\"regressor\": \"speech\", \"scan_number\": 102, \"value\": 0.7640093214194469}, {\"regressor\": \"speech\", \"scan_number\": 103, \"value\": 0.6625965286155263}, {\"regressor\": \"speech\", \"scan_number\": 104, \"value\": 0.36655161460054536}, {\"regressor\": \"speech\", \"scan_number\": 105, \"value\": 0.2775243306431406}, {\"regressor\": \"speech\", \"scan_number\": 106, \"value\": 0.5673485436238643}, {\"regressor\": \"speech\", \"scan_number\": 107, \"value\": 0.5942272720908096}, {\"regressor\": \"speech\", \"scan_number\": 108, \"value\": 0.2673736241613257}, {\"regressor\": \"speech\", \"scan_number\": 109, \"value\": 0.13675865408579035}, {\"regressor\": \"speech\", \"scan_number\": 110, \"value\": 0.21584913698622712}, {\"regressor\": \"speech\", \"scan_number\": 111, \"value\": 0.42252121422302524}, {\"regressor\": \"speech\", \"scan_number\": 112, \"value\": 0.500192683235886}, {\"regressor\": \"speech\", \"scan_number\": 113, \"value\": 0.2830791809440386}, {\"regressor\": \"speech\", \"scan_number\": 114, \"value\": 0.0572428333897908}, {\"regressor\": \"speech\", \"scan_number\": 115, \"value\": -0.04052574365363888}, {\"regressor\": \"speech\", \"scan_number\": 116, \"value\": -0.06627274912115073}, {\"regressor\": \"speech\", \"scan_number\": 117, \"value\": -0.0017653281593170767}, {\"regressor\": \"speech\", \"scan_number\": 118, \"value\": 0.3288039583898579}, {\"regressor\": \"speech\", \"scan_number\": 119, \"value\": 0.4111753585974239}, {\"regressor\": \"speech\", \"scan_number\": 120, \"value\": 0.18540374271108157}, {\"regressor\": \"speech\", \"scan_number\": 121, \"value\": 0.03325711913198085}, {\"regressor\": \"speech\", \"scan_number\": 122, \"value\": -0.030337747118020956}, {\"regressor\": \"speech\", \"scan_number\": 123, \"value\": -0.04203536946183784}, {\"regressor\": \"speech\", \"scan_number\": 124, \"value\": -0.03155636707948126}, {\"regressor\": \"speech\", \"scan_number\": 125, \"value\": -0.017367737369332198}, {\"regressor\": \"speech\", \"scan_number\": 126, \"value\": -0.007885704326456187}, {\"regressor\": \"speech\", \"scan_number\": 127, \"value\": -0.002526149983286786}, {\"regressor\": \"speech\", \"scan_number\": 128, \"value\": 0.00040765886614705326}, {\"regressor\": \"speech\", \"scan_number\": 129, \"value\": 0.05773719764743274}, {\"regressor\": \"speech\", \"scan_number\": 130, \"value\": 0.20879868383038203}, {\"regressor\": \"speech\", \"scan_number\": 131, \"value\": 0.4140976016264684}, {\"regressor\": \"speech\", \"scan_number\": 132, \"value\": 0.5347942504584856}, {\"regressor\": \"speech\", \"scan_number\": 133, \"value\": 0.3181237612122181}, {\"regressor\": \"speech\", \"scan_number\": 134, \"value\": 0.076413606172445}, {\"regressor\": \"speech\", \"scan_number\": 135, \"value\": -0.029107083448246106}, {\"regressor\": \"speech\", \"scan_number\": 136, \"value\": -0.05641438100885989}, {\"regressor\": \"speech\", \"scan_number\": 137, \"value\": -0.04621162803124773}, {\"regressor\": \"speech\", \"scan_number\": 138, \"value\": -0.027570779155646794}, {\"regressor\": \"speech\", \"scan_number\": 139, \"value\": -0.013035173029412372}, {\"regressor\": \"speech\", \"scan_number\": 140, \"value\": -0.005168811823023764}, {\"regressor\": \"speech\", \"scan_number\": 141, \"value\": -0.0017466328729947712}, {\"regressor\": \"speech\", \"scan_number\": 142, \"value\": -0.000486050752988717}, {\"regressor\": \"speech\", \"scan_number\": 143, \"value\": -9.43173126947688e-05}, {\"regressor\": \"speech\", \"scan_number\": 144, \"value\": 7.063033033282035e-05}, {\"regressor\": \"speech\", \"scan_number\": 145, \"value\": -0.00017861609871413096}, {\"regressor\": \"speech\", \"scan_number\": 146, \"value\": 0.0004612702870830466}, {\"regressor\": \"speech\", \"scan_number\": 147, \"value\": -0.001112778253471362}, {\"regressor\": \"speech\", \"scan_number\": 148, \"value\": 0.013769435297916584}, {\"regressor\": \"speech\", \"scan_number\": 149, \"value\": 0.035541877631002694}, {\"regressor\": \"speech\", \"scan_number\": 150, \"value\": 0.0224952677815086}, {\"regressor\": \"speech\", \"scan_number\": 151, \"value\": 0.0065496597768982074}, {\"regressor\": \"speech\", \"scan_number\": 152, \"value\": -0.0007968940389507869}, {\"regressor\": \"speech\", \"scan_number\": 153, \"value\": -0.002992440361521676}, {\"regressor\": \"speech\", \"scan_number\": 154, \"value\": -0.0031418436720597057}, {\"regressor\": \"speech\", \"scan_number\": 155, \"value\": -0.0009320795961477914}, {\"regressor\": \"speech\", \"scan_number\": 156, \"value\": -0.0026939198097701523}, {\"regressor\": \"speech\", \"scan_number\": 157, \"value\": 0.026319526598295555}, {\"regressor\": \"speech\", \"scan_number\": 158, \"value\": 0.09001894481837393}, {\"regressor\": \"speech\", \"scan_number\": 159, \"value\": 0.07198029863648914}, {\"regressor\": \"speech\", \"scan_number\": 160, \"value\": 0.024860417108079118}, {\"regressor\": \"speech\", \"scan_number\": 161, \"value\": 0.0009081148497714353}, {\"regressor\": \"speech\", \"scan_number\": 162, \"value\": -0.007894889836087155}, {\"regressor\": \"speech\", \"scan_number\": 163, \"value\": -0.008109343503265549}, {\"regressor\": \"speech\", \"scan_number\": 164, \"value\": -0.005400252463273595}, {\"regressor\": \"speech\", \"scan_number\": 165, \"value\": -0.002730306004403706}, {\"regressor\": \"speech\", \"scan_number\": 166, \"value\": -0.0011345653917956774}, {\"regressor\": \"speech\", \"scan_number\": 167, \"value\": -0.0004038158885142577}, {\"regressor\": \"speech\", \"scan_number\": 168, \"value\": -0.00011622009185472098}, {\"regressor\": \"speech\", \"scan_number\": 169, \"value\": -5.0943648094052156e-05}, {\"regressor\": \"speech\", \"scan_number\": 170, \"value\": 8.778534897893085e-05}, {\"regressor\": \"speech\", \"scan_number\": 171, \"value\": -0.00023069321797982486}, {\"regressor\": \"speech\", \"scan_number\": 172, \"value\": 0.0004347728263624166}, {\"regressor\": \"speech\", \"scan_number\": 173, \"value\": 0.002303383939443534}, {\"regressor\": \"speech\", \"scan_number\": 174, \"value\": 0.10210882205113249}, {\"regressor\": \"speech\", \"scan_number\": 175, \"value\": 0.4414801438630491}, {\"regressor\": \"speech\", \"scan_number\": 176, \"value\": 0.6588807471900152}, {\"regressor\": \"speech\", \"scan_number\": 177, \"value\": 0.40843200223574494}, {\"regressor\": \"speech\", \"scan_number\": 178, \"value\": 0.2817763440031651}, {\"regressor\": \"speech\", \"scan_number\": 179, \"value\": 0.46621763741507616}, {\"regressor\": \"speech\", \"scan_number\": 180, \"value\": 0.5951842602461193}, {\"regressor\": \"speech\", \"scan_number\": 181, \"value\": 0.6281383582121446}, {\"regressor\": \"speech\", \"scan_number\": 182, \"value\": 0.44222843591027394}, {\"regressor\": \"speech\", \"scan_number\": 183, \"value\": 0.1315588732443813}, {\"regressor\": \"speech\", \"scan_number\": 184, \"value\": -0.03550724241982569}, {\"regressor\": \"speech\", \"scan_number\": 185, \"value\": -0.08059809415171838}, {\"regressor\": \"speech\", \"scan_number\": 186, \"value\": -0.06993755430422112}, {\"regressor\": \"speech\", \"scan_number\": 187, \"value\": -0.04380322122565809}, {\"regressor\": \"speech\", \"scan_number\": 188, \"value\": -0.021989814527983167}, {\"regressor\": \"speech\", \"scan_number\": 189, \"value\": -0.009212185231154559}, {\"regressor\": \"speech\", \"scan_number\": 190, \"value\": -0.0032616463460911215}, {\"regressor\": \"speech\", \"scan_number\": 191, \"value\": -0.0009758669049971204}, {\"regressor\": \"speech\", \"scan_number\": 192, \"value\": -0.0002194480863061805}, {\"regressor\": \"speech\", \"scan_number\": 193, \"value\": -7.90637631167021e-06}, {\"regressor\": \"speech\", \"scan_number\": 194, \"value\": 7.948233974440332e-07}, {\"regressor\": \"speech\", \"scan_number\": 195, \"value\": -1.0940136048907513e-06}, {\"regressor\": \"speech\", \"scan_number\": 196, \"value\": 2.1692527471991742e-06}, {\"regressor\": \"speech\", \"scan_number\": 197, \"value\": -4.1915327022801314e-06}, {\"regressor\": \"speech\", \"scan_number\": 198, \"value\": 7.1577579881440845e-06}, {\"regressor\": \"speech\", \"scan_number\": 199, \"value\": -6.6626002771065555e-06}, {\"regressor\": \"speech\", \"scan_number\": 200, \"value\": -8.693755171753652e-06}, {\"regressor\": \"speech\", \"scan_number\": 201, \"value\": -5.898147924994314e-05}, {\"regressor\": \"speech\", \"scan_number\": 202, \"value\": 0.004973637141037839}, {\"regressor\": \"speech\", \"scan_number\": 203, \"value\": 0.0719558686529285}, {\"regressor\": \"speech\", \"scan_number\": 204, \"value\": 0.18815324473968195}, {\"regressor\": \"speech\", \"scan_number\": 205, \"value\": 0.17351997856477824}, {\"regressor\": \"speech\", \"scan_number\": 206, \"value\": 0.06993310508393345}, {\"regressor\": \"speech\", \"scan_number\": 207, \"value\": 0.007156740290471996}, {\"regressor\": \"speech\", \"scan_number\": 208, \"value\": -0.01667389086399168}, {\"regressor\": \"speech\", \"scan_number\": 209, \"value\": -0.019130150536802264}, {\"regressor\": \"speech\", \"scan_number\": 210, \"value\": -0.013386205448497819}, {\"regressor\": \"speech\", \"scan_number\": 211, \"value\": -0.007092060408164415}, {\"regressor\": \"speech\", \"scan_number\": 212, \"value\": -0.0030597557415062517}, {\"regressor\": \"speech\", \"scan_number\": 213, \"value\": -0.001121893193371019}, {\"regressor\": \"speech\", \"scan_number\": 214, \"value\": -0.0003554641846736026}, {\"regressor\": \"speech\", \"scan_number\": 215, \"value\": -7.976698912086428e-05}, {\"regressor\": \"speech\", \"scan_number\": 216, \"value\": -3.7548605985162183e-07}, {\"regressor\": \"speech\", \"scan_number\": 217, \"value\": -5.12425014920844e-07}, {\"regressor\": \"speech\", \"scan_number\": 218, \"value\": 2.1538991993434097e-07}, {\"regressor\": \"speech\", \"scan_number\": 219, \"value\": -1.2592250669199174e-07}, {\"regressor\": \"speech\", \"scan_number\": 220, \"value\": 2.1262715005790026e-07}, {\"regressor\": \"speech\", \"scan_number\": 221, \"value\": -5.390877257090892e-07}, {\"regressor\": \"speech\", \"scan_number\": 222, \"value\": 1.3970195255076484e-06}, {\"regressor\": \"speech\", \"scan_number\": 223, \"value\": -3.546295335219871e-06}, {\"regressor\": \"speech\", \"scan_number\": 224, \"value\": 8.788160626410255e-06}, {\"regressor\": \"speech\", \"scan_number\": 225, \"value\": -2.120364997081411e-05}, {\"regressor\": \"speech\", \"scan_number\": 226, \"value\": 4.9494363552957145e-05}, {\"regressor\": \"speech\", \"scan_number\": 227, \"value\": -0.00010929236716042088}, {\"regressor\": \"speech\", \"scan_number\": 228, \"value\": 0.0002272858350076759}, {\"regressor\": \"speech\", \"scan_number\": 229, \"value\": -0.0005464956744336507}, {\"regressor\": \"speech\", \"scan_number\": 230, \"value\": 0.0051639838410755794}, {\"regressor\": \"speech\", \"scan_number\": 231, \"value\": 0.043818815563092035}, {\"regressor\": \"speech\", \"scan_number\": 232, \"value\": 0.045467086083760856}, {\"regressor\": \"speech\", \"scan_number\": 233, \"value\": 0.01772967494495175}, {\"regressor\": \"speech\", \"scan_number\": 234, \"value\": 0.002436005328497339}, {\"regressor\": \"speech\", \"scan_number\": 235, \"value\": -0.0037941872264638187}, {\"regressor\": \"speech\", \"scan_number\": 236, \"value\": -0.004581596237870706}, {\"regressor\": \"speech\", \"scan_number\": 237, \"value\": -0.003274210143694739}, {\"regressor\": \"speech\", \"scan_number\": 238, \"value\": -0.0017327761194580625}, {\"regressor\": \"speech\", \"scan_number\": 239, \"value\": -0.0007444344039225306}, {\"regressor\": \"speech\", \"scan_number\": 240, \"value\": -0.00026999924746823464}, {\"regressor\": \"speech\", \"scan_number\": 241, \"value\": -8.571910918866626e-05}, {\"regressor\": \"speech\", \"scan_number\": 242, \"value\": -2.185681430941174e-05}, {\"regressor\": \"speech\", \"scan_number\": 243, \"value\": 7.243140877601413e-06}, {\"regressor\": \"speech\", \"scan_number\": 244, \"value\": -1.452274651024157e-05}, {\"regressor\": \"speech\", \"scan_number\": 245, \"value\": 3.378897998790778e-05}, {\"regressor\": \"speech\", \"scan_number\": 246, \"value\": -7.830999638675897e-05}, {\"regressor\": \"speech\", \"scan_number\": 247, \"value\": 0.00017460514139856824}, {\"regressor\": \"speech\", \"scan_number\": 248, \"value\": -0.00035983659149528183}, {\"regressor\": \"speech\", \"scan_number\": 249, \"value\": 0.0006698264725231032}, {\"regressor\": \"speech\", \"scan_number\": 250, \"value\": -0.0015271898244007746}, {\"regressor\": \"speech\", \"scan_number\": 251, \"value\": 0.02200251603787361}, {\"regressor\": \"speech\", \"scan_number\": 252, \"value\": 0.21864784951163052}, {\"regressor\": \"speech\", \"scan_number\": 253, \"value\": 0.2600463531673598}, {\"regressor\": \"speech\", \"scan_number\": 254, \"value\": 0.11949217267348339}, {\"regressor\": \"speech\", \"scan_number\": 255, \"value\": 0.05236319577052509}, {\"regressor\": \"speech\", \"scan_number\": 256, \"value\": 0.010978405712982465}, {\"regressor\": \"speech\", \"scan_number\": 257, \"value\": -0.015135778946197472}, {\"regressor\": \"speech\", \"scan_number\": 258, \"value\": -0.01717688782413885}, {\"regressor\": \"speech\", \"scan_number\": 259, \"value\": -0.0032672926642468903}, {\"regressor\": \"speech\", \"scan_number\": 260, \"value\": 0.12022291220728368}, {\"regressor\": \"speech\", \"scan_number\": 261, \"value\": 0.24737032699807895}, {\"regressor\": \"speech\", \"scan_number\": 262, \"value\": 0.2038976663096657}, {\"regressor\": \"speech\", \"scan_number\": 263, \"value\": 0.33357776028134295}, {\"regressor\": \"speech\", \"scan_number\": 264, \"value\": 0.37271799228024466}, {\"regressor\": \"speech\", \"scan_number\": 265, \"value\": 0.27007747151484923}, {\"regressor\": \"speech\", \"scan_number\": 266, \"value\": 0.22642025873727328}, {\"regressor\": \"speech\", \"scan_number\": 267, \"value\": 0.17318025561851166}, {\"regressor\": \"speech\", \"scan_number\": 268, \"value\": 0.08633455878778946}, {\"regressor\": \"speech\", \"scan_number\": 269, \"value\": 0.0005574053010902506}, {\"regressor\": \"speech\", \"scan_number\": 270, \"value\": -0.029763456089588573}, {\"regressor\": \"speech\", \"scan_number\": 271, \"value\": -0.031223770638253896}, {\"regressor\": \"speech\", \"scan_number\": 272, \"value\": -0.02208074874688019}, {\"regressor\": \"speech\", \"scan_number\": 273, \"value\": -0.012387469678488328}, {\"regressor\": \"speech\", \"scan_number\": 274, \"value\": -0.00583915935529111}, {\"regressor\": \"speech\", \"scan_number\": 275, \"value\": -0.0019656366566041914}, {\"regressor\": \"speech\", \"scan_number\": 276, \"value\": -0.0014236373582036785}, {\"regressor\": \"speech\", \"scan_number\": 277, \"value\": 0.0014210268897604653}, {\"regressor\": \"speech\", \"scan_number\": 278, \"value\": -0.003811780953513643}, {\"regressor\": \"speech\", \"scan_number\": 279, \"value\": 0.07244603959396674}, {\"regressor\": \"speech\", \"scan_number\": 280, \"value\": 0.34760780875688163}, {\"regressor\": \"speech\", \"scan_number\": 281, \"value\": 0.5278490960005103}, {\"regressor\": \"speech\", \"scan_number\": 282, \"value\": 0.35911975838689925}, {\"regressor\": \"speech\", \"scan_number\": 283, \"value\": 0.11149256097419283}, {\"regressor\": \"speech\", \"scan_number\": 284, \"value\": -0.012796662453413103}, {\"regressor\": \"speech\", \"scan_number\": 285, \"value\": -0.05140234015813337}, {\"regressor\": \"speech\", \"scan_number\": 286, \"value\": -0.04647034998390255}, {\"regressor\": \"speech\", \"scan_number\": 287, \"value\": -0.030056149691791538}, {\"regressor\": \"speech\", \"scan_number\": 288, \"value\": -0.012783295711963162}, {\"regressor\": \"speech\", \"scan_number\": 289, \"value\": -0.007017402866343381}, {\"regressor\": \"speech\", \"scan_number\": 290, \"value\": 0.12034735821221411}, {\"regressor\": \"speech\", \"scan_number\": 291, \"value\": 0.4055419065574123}, {\"regressor\": \"speech\", \"scan_number\": 292, \"value\": 0.6354976071617832}, {\"regressor\": \"speech\", \"scan_number\": 293, \"value\": 0.8020360970538972}, {\"regressor\": \"speech\", \"scan_number\": 294, \"value\": 0.5830254522411964}, {\"regressor\": \"speech\", \"scan_number\": 295, \"value\": 0.18326270934217978}, {\"regressor\": \"speech\", \"scan_number\": 296, \"value\": -0.013310747049174308}, {\"regressor\": \"speech\", \"scan_number\": 297, \"value\": -0.054214408910420175}, {\"regressor\": \"speech\", \"scan_number\": 298, \"value\": -0.06469900680550765}, {\"regressor\": \"speech\", \"scan_number\": 299, \"value\": 0.10009568038090035}, {\"regressor\": \"speech\", \"scan_number\": 300, \"value\": 0.3578743911899497}, {\"regressor\": \"speech\", \"scan_number\": 301, \"value\": 0.42405932961298654}, {\"regressor\": \"speech\", \"scan_number\": 302, \"value\": 0.5812436603915444}, {\"regressor\": \"speech\", \"scan_number\": 303, \"value\": 0.7172422368107432}, {\"regressor\": \"speech\", \"scan_number\": 304, \"value\": 0.7099065672152467}, {\"regressor\": \"speech\", \"scan_number\": 305, \"value\": 0.3940783072143437}, {\"regressor\": \"speech\", \"scan_number\": 306, \"value\": 0.06927201699254926}, {\"regressor\": \"speech\", \"scan_number\": 307, \"value\": -0.06470094721447467}, {\"regressor\": \"speech\", \"scan_number\": 308, \"value\": -0.09040816074538396}, {\"regressor\": \"speech\", \"scan_number\": 309, \"value\": -0.06915918480308661}, {\"regressor\": \"speech\", \"scan_number\": 310, \"value\": -0.04032118956260185}, {\"regressor\": \"speech\", \"scan_number\": 311, \"value\": -0.018389467724368693}, {\"regressor\": \"speech\", \"scan_number\": 312, \"value\": -0.008477035236067387}, {\"regressor\": \"speech\", \"scan_number\": 313, \"value\": 0.0002044789934418606}, {\"regressor\": \"speech\", \"scan_number\": 314, \"value\": -0.00730401828581237}, {\"regressor\": \"speech\", \"scan_number\": 315, \"value\": 0.07375784677874256}, {\"regressor\": \"speech\", \"scan_number\": 316, \"value\": 0.2287788494709757}, {\"regressor\": \"speech\", \"scan_number\": 317, \"value\": 0.1651967904820613}, {\"regressor\": \"speech\", \"scan_number\": 318, \"value\": 0.048063219268722875}, {\"regressor\": \"speech\", \"scan_number\": 319, \"value\": 0.0812372915894442}, {\"regressor\": \"speech\", \"scan_number\": 320, \"value\": 0.3449217999070603}, {\"regressor\": \"speech\", \"scan_number\": 321, \"value\": 0.5323986446090239}, {\"regressor\": \"speech\", \"scan_number\": 322, \"value\": 0.5611250202616057}, {\"regressor\": \"speech\", \"scan_number\": 323, \"value\": 0.613295220663045}, {\"regressor\": \"speech\", \"scan_number\": 324, \"value\": 0.57805732468815}, {\"regressor\": \"speech\", \"scan_number\": 325, \"value\": 0.3585383369502152}, {\"regressor\": \"speech\", \"scan_number\": 326, \"value\": 0.09255422053688223}, {\"regressor\": \"speech\", \"scan_number\": 327, \"value\": -0.04375206131420488}, {\"regressor\": \"speech\", \"scan_number\": 328, \"value\": -0.07574735894562286}, {\"regressor\": \"speech\", \"scan_number\": 329, \"value\": -0.06254287808229565}, {\"regressor\": \"speech\", \"scan_number\": 330, \"value\": -0.038309570379053005}, {\"regressor\": \"speech\", \"scan_number\": 331, \"value\": -0.01896877639727393}, {\"regressor\": \"speech\", \"scan_number\": 332, \"value\": -0.007839417042504175}, {\"regressor\": \"speech\", \"scan_number\": 333, \"value\": -0.00278511171412889}, {\"regressor\": \"speech\", \"scan_number\": 334, \"value\": -0.0008307925140160709}, {\"regressor\": \"speech\", \"scan_number\": 335, \"value\": -0.00017950995120804666}, {\"regressor\": \"speech\", \"scan_number\": 336, \"value\": -1.1525747199326623e-05}, {\"regressor\": \"speech\", \"scan_number\": 337, \"value\": 8.396682818455393e-07}, {\"regressor\": \"speech\", \"scan_number\": 338, \"value\": -2.8705528264119295e-07}, {\"regressor\": \"speech\", \"scan_number\": 339, \"value\": 1.375485904833803e-07}, {\"regressor\": \"speech\", \"scan_number\": 340, \"value\": -6.533945794787999e-08}, {\"regressor\": \"speech\", \"scan_number\": 341, \"value\": 2.9091260884508162e-08}, {\"regressor\": \"speech\", \"scan_number\": 342, \"value\": -1.3372968649237423e-08}, {\"regressor\": \"speech\", \"scan_number\": 343, \"value\": 9.823340659753434e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 0, \"value\": 6.079232241084597e-12}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 1, \"value\": -1.5121179585920977e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 2, \"value\": 3.664832719809422e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 3, \"value\": -8.611828982277052e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 4, \"value\": 1.9457456944085943e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 5, \"value\": -4.1646614053836324e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 6, \"value\": 8.198391979409229e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 7, \"value\": -1.3804255564312225e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 8, \"value\": 1.4961198599798364e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 9, \"value\": 1.8131330548512204e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 10, \"value\": -1.9930925975856058e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 11, \"value\": 9.159234509668807e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 12, \"value\": -3.399175069327246e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 13, \"value\": 1.1384160229315938e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 14, \"value\": -3.580980164262128e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 15, \"value\": 1.0770066658904742e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 16, \"value\": -3.1317188723626006e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 17, \"value\": 8.866284181199514e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 18, \"value\": -0.00024537106124897646}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 19, \"value\": 0.0006535930063778373}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 20, \"value\": -0.0016401267625249772}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 21, \"value\": 0.00386392368818218}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 22, \"value\": -0.052279186808091675}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 23, \"value\": -0.17712708407575065}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 24, \"value\": -0.13134645692823102}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 25, \"value\": -0.03430586032665849}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 26, \"value\": 0.08083520637100573}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 27, \"value\": 0.6892941594437195}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 28, \"value\": 1.2269118932340195}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 29, \"value\": 0.9411498715884774}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 30, \"value\": 0.31560343443925076}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 31, \"value\": -0.011221817464537355}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 32, \"value\": -0.11582230574176784}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 33, \"value\": -0.10899761584545656}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 34, \"value\": -0.06531809212053773}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 35, \"value\": -0.034778366812195774}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 36, \"value\": -0.015235660082295955}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 37, \"value\": -0.005951637826326091}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 38, \"value\": -0.0022042650528337417}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 39, \"value\": -0.0006459441208690023}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 40, \"value\": -0.00012132951990243884}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 41, \"value\": -0.00027821634435690537}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 42, \"value\": 0.0008151377491929571}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 43, \"value\": 0.0007435231543420503}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 44, \"value\": 0.08325286891865515}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 45, \"value\": 0.0538710392149156}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 46, \"value\": -0.08584518911566205}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 47, \"value\": -0.0033842833617061295}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 48, \"value\": 0.39292969797952304}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 49, \"value\": 0.46696439412136703}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 50, \"value\": 0.5313097716418184}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 51, \"value\": 0.2728250352169571}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 52, \"value\": -0.06972606172735821}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 53, \"value\": -0.15482908475814758}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 54, \"value\": 0.3450504071197635}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 55, \"value\": 1.1499798674841573}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 56, \"value\": 0.9345820299167196}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 57, \"value\": 0.3766529217621371}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 58, \"value\": -0.05779494725872045}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 59, \"value\": -0.25442533258404265}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 60, \"value\": -0.2799835395590647}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 61, \"value\": -0.2780142202902485}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 62, \"value\": -0.25588197402563767}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 63, \"value\": -0.17309916758498134}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 64, \"value\": -0.06252550478128067}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 65, \"value\": 0.01207175041349454}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 66, \"value\": 0.02846753973518526}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 67, \"value\": 0.008393079570266852}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 68, \"value\": 0.01177430007517229}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 69, \"value\": -0.0033767933939654713}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 70, \"value\": -0.05318368384689989}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 71, \"value\": -0.04216758050292083}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 72, \"value\": -0.013362218994251369}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 73, \"value\": 0.00021288524321413403}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 74, \"value\": 0.001731733629186871}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 75, \"value\": -0.031006377530439534}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 76, \"value\": -0.12051618867783663}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 77, \"value\": -0.18888537776586656}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 78, \"value\": 0.002473978160147175}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 79, \"value\": 0.47776622629728444}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 80, \"value\": 0.39118508224276927}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 81, \"value\": 0.26946104550448746}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 82, \"value\": 0.2683312756630751}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 83, \"value\": 0.08951872700264024}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 84, \"value\": -0.009888353557606146}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 85, \"value\": -0.038396552784016144}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 86, \"value\": -0.0357830249068066}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 87, \"value\": -0.023225536890065596}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 88, \"value\": -0.015124686489968016}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 89, \"value\": -0.019835691379174934}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 90, \"value\": -0.014264127264314422}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 91, \"value\": -0.005700931666919062}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 92, \"value\": 0.0011038249691604348}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 93, \"value\": -0.016596227438708356}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 94, \"value\": 0.017024003052324065}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 95, \"value\": 0.056121053593576616}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 96, \"value\": 0.020390632062172485}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 97, \"value\": 0.0013044214332064274}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 98, \"value\": -0.002520856602332652}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 99, \"value\": -0.022572035108563274}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 100, \"value\": -0.12963781940581626}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 101, \"value\": -0.11151506244230369}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 102, \"value\": -0.015218471768906781}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 103, \"value\": -0.03858486520905367}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 104, \"value\": -0.03529583347742929}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 105, \"value\": 0.011611108787521328}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 106, \"value\": 0.0020320270867251796}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 107, \"value\": -0.018275964938100252}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 108, \"value\": -0.011783665155981038}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 109, \"value\": -0.0021372304030668116}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 110, \"value\": -0.016657679853110244}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 111, \"value\": -0.08132529080680315}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 112, \"value\": -0.09104915869266773}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 113, \"value\": -0.05410090707480744}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 114, \"value\": -0.014466702558888874}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 115, \"value\": 0.004232391022377175}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 116, \"value\": 0.011029970728065627}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 117, \"value\": 0.0033073690904463185}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 118, \"value\": 0.021575251212770017}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 119, \"value\": 0.06866136373024465}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 120, \"value\": 0.04585120296502212}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 121, \"value\": 0.01414954172812509}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 122, \"value\": -0.0004595781454186632}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 123, \"value\": -0.005570388822828733}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 124, \"value\": -0.005306719394510276}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 125, \"value\": -0.0033502484083399653}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 126, \"value\": -0.0017408656459185065}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 127, \"value\": -0.0003471384399512779}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 128, \"value\": -0.001096472457947229}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 129, \"value\": 0.0020973915005692116}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 130, \"value\": -0.03906270219594122}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 131, \"value\": -0.08151717448215721}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 132, \"value\": -0.055314231234395966}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 133, \"value\": -0.019927518025086233}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 134, \"value\": 0.00019867249205756765}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 135, \"value\": 0.007023085633550647}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 136, \"value\": 0.006936256523954134}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 137, \"value\": 0.004517239322704696}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 138, \"value\": 0.0022844206819172667}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 139, \"value\": 0.0009556791210842362}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 140, \"value\": 0.0003427626978171743}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 141, \"value\": 0.00010738040654975212}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 142, \"value\": 1.7313648029996175e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 143, \"value\": 1.4713318000426461e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 144, \"value\": -1.0856793772949579e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 145, \"value\": 1.188617524875145e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 146, \"value\": 2.8497697953830514e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 147, \"value\": -3.5247729386600562e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 148, \"value\": 2.283964428647811e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 149, \"value\": -1.208448847886297e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 150, \"value\": 5.781389785227177e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 151, \"value\": -2.603514176091904e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 152, \"value\": 1.1308800908270909e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 153, \"value\": -4.93547521275403e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 154, \"value\": 2.487071486037782e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 155, \"value\": -1.9521297024135986e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 156, \"value\": 2.410142916781378e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 157, \"value\": -2.786708738812409e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 158, \"value\": -7.429136758076323e-12}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 159, \"value\": 2.2738893810765404e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 160, \"value\": -1.1348927851941659e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 161, \"value\": 4.346580622217399e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 162, \"value\": -1.480818972350261e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 163, \"value\": 4.7100312283508126e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 164, \"value\": -1.4295217881956357e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 165, \"value\": 4.1881592299810505e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 166, \"value\": -1.1923985481368092e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 167, \"value\": 3.312224103358369e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 168, \"value\": -8.998820011826329e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 169, \"value\": 2.395643835230471e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 170, \"value\": -6.252127852821295e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 171, \"value\": 0.0001563642226132367}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 172, \"value\": -0.00036864937343861936}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 173, \"value\": 0.0007947851375975399}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 174, \"value\": -0.015148795178492484}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 175, \"value\": -0.0827825450486432}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 176, \"value\": -0.1363837757619445}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 177, \"value\": -0.10168790080026072}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 178, \"value\": -0.04734545172368677}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 179, \"value\": 0.010994038300685812}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 180, \"value\": 0.0025130353105025124}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 181, \"value\": -0.07428619998359896}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 182, \"value\": -0.05896413016963226}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 183, \"value\": -0.01759364849886905}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 184, \"value\": 0.0012106286562840278}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 185, \"value\": 0.007938559437364877}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 186, \"value\": 0.007587128702166482}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 187, \"value\": 0.004899324230797409}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 188, \"value\": 0.0024059137188695194}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 189, \"value\": 0.0009774036095956395}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 190, \"value\": 0.0003355812932238632}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 191, \"value\": 0.00010785932513211966}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 192, \"value\": 1.4010718757696383e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 193, \"value\": -3.392300826551712e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 194, \"value\": 1.6446602996781367e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 195, \"value\": -2.365963087324507e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 196, \"value\": 5.191171989352065e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 197, \"value\": -1.2311759275411524e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 198, \"value\": 2.8802163481526242e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 199, \"value\": -6.45643550033835e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 200, \"value\": 0.00013513179694759947}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 201, \"value\": -0.00028282446688092627}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 202, \"value\": 0.0014588873146873025}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 203, \"value\": 0.0032313848096272614}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 204, \"value\": -0.0455068947920797}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 205, \"value\": -0.06542857313926988}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 206, \"value\": -0.03146181721463819}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 207, \"value\": -0.00707496172082803}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 208, \"value\": 0.0035811363330291307}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 209, \"value\": 0.006043370005226089}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 210, \"value\": 0.004773110747985547}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 211, \"value\": 0.0027097284064585246}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 212, \"value\": 0.0012233177793795455}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 213, \"value\": 0.00046284647489128753}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 214, \"value\": 0.00015368363130820257}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 215, \"value\": 4.102935588008976e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 216, \"value\": 2.51065126471044e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 217, \"value\": 2.5137847587177064e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 218, \"value\": -8.538646970365689e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 219, \"value\": 1.722787583804523e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 220, \"value\": 3.903664814312522e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 221, \"value\": -2.680331021513054e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 222, \"value\": 1.9445565998717455e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 223, \"value\": -1.0728876473492922e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 224, \"value\": 5.252804490630372e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 225, \"value\": -2.398269979494894e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 226, \"value\": 1.0438020640438745e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 227, \"value\": -4.3745662566017463e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 228, \"value\": 1.7662572488231797e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 229, \"value\": -6.845566796747453e-12}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 230, \"value\": 3.0845610908424076e-12}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 231, \"value\": -4.716479765024218e-12}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 232, \"value\": 1.7391867682998026e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 233, \"value\": -6.350121595563384e-11}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 234, \"value\": 2.1273780744509026e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 235, \"value\": -6.700394916927789e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 236, \"value\": 2.019370747567682e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 237, \"value\": -5.883624515059928e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 238, \"value\": 1.667338699678655e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 239, \"value\": -4.612551541027157e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 240, \"value\": 1.2482982796411627e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 241, \"value\": -3.30824032662845e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 242, \"value\": 8.586587056855473e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 243, \"value\": -2.1808647584342857e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 244, \"value\": 5.407690846187208e-06}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 245, \"value\": -1.3059932980970817e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 246, \"value\": 3.056572207749527e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 247, \"value\": -6.862554881022607e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 248, \"value\": 0.00014290764874906888}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 249, \"value\": -0.0002709983326291348}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 250, \"value\": 0.0006225138271002716}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 251, \"value\": -0.008277483894254046}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 252, \"value\": -0.08132997138527678}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 253, \"value\": -0.09589200145740275}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 254, \"value\": -0.041414862823745985}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 255, \"value\": -0.005963274963417198}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 256, \"value\": 0.00814887952675974}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 257, \"value\": 0.01009409744483168}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 258, \"value\": 0.006581533049785909}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 259, \"value\": 0.006246731699503288}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 260, \"value\": -0.0003070478458111828}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 261, \"value\": -0.015318483061238576}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 262, \"value\": -0.017470870165069274}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 263, \"value\": -0.058661903276294766}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 264, \"value\": -0.0627710598124}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 265, \"value\": -0.0636088176617342}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 266, \"value\": -0.0711850732176299}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 267, \"value\": -0.022310802356798626}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 268, \"value\": 0.007869048216943309}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 269, \"value\": 0.01209471190665323}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 270, \"value\": 0.009534060972457552}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 271, \"value\": 0.005498246122870112}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 272, \"value\": 0.0024332025063591653}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 273, \"value\": 0.0007422626675457266}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 274, \"value\": 0.0002595785424858313}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 275, \"value\": -0.00024795066218487853}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 276, \"value\": 0.0006096900319842069}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 277, \"value\": -0.0015000370974765948}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 278, \"value\": 0.0035362293437214104}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 279, \"value\": -0.05262951917617377}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 280, \"value\": -0.260149993924493}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 281, \"value\": -0.3262274321891632}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 282, \"value\": -0.18408582796156855}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 283, \"value\": -0.04721879759869381}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 284, \"value\": 0.0164924401689512}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 285, \"value\": 0.03222225243387616}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 286, \"value\": 0.027802972571418096}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 287, \"value\": 0.013572528904044359}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 288, \"value\": 0.013086815461670197}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 289, \"value\": -0.011636402586293258}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 290, \"value\": 0.0911097784408844}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 291, \"value\": 0.3828390574767676}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 292, \"value\": 0.288463637852305}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 293, \"value\": 0.9685292825269259}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 294, \"value\": 1.2393406810395482}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 295, \"value\": 0.5525575054513046}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 296, \"value\": 0.09415504954348416}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 297, \"value\": -0.09341292951347276}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 298, \"value\": -0.12613547486503643}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 299, \"value\": -0.12156945190887385}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 300, \"value\": -0.1118822207265297}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 301, \"value\": -0.0711739114328514}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 302, \"value\": -0.12072252594968945}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 303, \"value\": -0.3126552134567014}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 304, \"value\": -0.531369646704187}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 305, \"value\": -0.3768195314807876}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 306, \"value\": -0.11487147010628462}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 307, \"value\": 0.01218449182761055}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 308, \"value\": 0.052784821578044074}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 309, \"value\": 0.04834939830722192}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 310, \"value\": 0.030662284226180513}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 311, \"value\": 0.015122410010076363}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 312, \"value\": 0.00619218007422216}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 313, \"value\": 0.0021550659668206737}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 314, \"value\": 0.0006839986298881621}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 315, \"value\": 0.00043253233434319664}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 316, \"value\": 0.0051036964150443}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 317, \"value\": 0.0015538888909487228}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 318, \"value\": 0.007178542937000739}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 319, \"value\": -0.035234773709689186}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 320, \"value\": 0.07646284419653356}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 321, \"value\": 0.43333630126763817}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 322, \"value\": 0.4038136313758869}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 323, \"value\": 0.11604288663774619}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 324, \"value\": -0.03535570283950818}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 325, \"value\": -0.04916531809563931}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 326, \"value\": -0.039703574536622946}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 327, \"value\": -0.023509667180157276}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 328, \"value\": -0.010438920567580133}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 329, \"value\": -0.0036171067738356255}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 330, \"value\": -0.0011369893825694977}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 331, \"value\": -0.0004004389731770999}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 332, \"value\": -9.031926954173358e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 333, \"value\": 5.427970256253635e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 334, \"value\": -1.1574367214761994e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 335, \"value\": -1.5300015682776576e-05}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 336, \"value\": -7.744788414324821e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 337, \"value\": -2.9718735638557736e-07}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 338, \"value\": 9.932994700287029e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 339, \"value\": -2.935314421069036e-08}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 340, \"value\": 7.895075582854395e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 341, \"value\": -1.6657699866474356e-09}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 342, \"value\": -2.3204277260712077e-10}, {\"regressor\": \"massiveauditorylexicaldecision_PhonLev\", \"scan_number\": 343, \"value\": 2.4965193887742635e-09}, {\"regressor\": \"text_length\", \"scan_number\": 0, \"value\": -7.245908068785487e-12}, {\"regressor\": \"text_length\", \"scan_number\": 1, \"value\": 1.8342933677686543e-11}, {\"regressor\": \"text_length\", \"scan_number\": 2, \"value\": -4.535359222067882e-11}, {\"regressor\": \"text_length\", \"scan_number\": 3, \"value\": 1.091560533920649e-10}, {\"regressor\": \"text_length\", \"scan_number\": 4, \"value\": -2.5429137039116726e-10}, {\"regressor\": \"text_length\", \"scan_number\": 5, \"value\": 5.679593402286082e-10}, {\"regressor\": \"text_length\", \"scan_number\": 6, \"value\": -1.1952632814807747e-09}, {\"regressor\": \"text_length\", \"scan_number\": 7, \"value\": 2.2862958796549223e-09}, {\"regressor\": \"text_length\", \"scan_number\": 8, \"value\": -3.612870167729952e-09}, {\"regressor\": \"text_length\", \"scan_number\": 9, \"value\": 2.9331334776687126e-09}, {\"regressor\": \"text_length\", \"scan_number\": 10, \"value\": 9.886582465044674e-09}, {\"regressor\": \"text_length\", \"scan_number\": 11, \"value\": -7.219925600273922e-08}, {\"regressor\": \"text_length\", \"scan_number\": 12, \"value\": 3.086267267847004e-07}, {\"regressor\": \"text_length\", \"scan_number\": 13, \"value\": -1.11019283363751e-06}, {\"regressor\": \"text_length\", \"scan_number\": 14, \"value\": 3.6519381724502786e-06}, {\"regressor\": \"text_length\", \"scan_number\": 15, \"value\": -1.1336975639778029e-05}, {\"regressor\": \"text_length\", \"scan_number\": 16, \"value\": 3.3783998114870083e-05}, {\"regressor\": \"text_length\", \"scan_number\": 17, \"value\": -9.75977336803547e-05}, {\"regressor\": \"text_length\", \"scan_number\": 18, \"value\": 0.0002748916011535839}, {\"regressor\": \"text_length\", \"scan_number\": 19, \"value\": -0.0007473428791826785}, {\"regressor\": \"text_length\", \"scan_number\": 20, \"value\": 0.001924470586943603}, {\"regressor\": \"text_length\", \"scan_number\": 21, \"value\": -0.0046480297923371825}, {\"regressor\": \"text_length\", \"scan_number\": 22, \"value\": 0.04846350353933733}, {\"regressor\": \"text_length\", \"scan_number\": 23, \"value\": 0.11303305532993428}, {\"regressor\": \"text_length\", \"scan_number\": 24, \"value\": 0.06305712472453838}, {\"regressor\": \"text_length\", \"scan_number\": 25, \"value\": 0.15974333576279387}, {\"regressor\": \"text_length\", \"scan_number\": 26, \"value\": 0.23345558405690817}, {\"regressor\": \"text_length\", \"scan_number\": 27, \"value\": 0.5464879848348493}, {\"regressor\": \"text_length\", \"scan_number\": 28, \"value\": 0.8559445142109721}, {\"regressor\": \"text_length\", \"scan_number\": 29, \"value\": 0.6511889025232728}, {\"regressor\": \"text_length\", \"scan_number\": 30, \"value\": 0.21636340992036274}, {\"regressor\": \"text_length\", \"scan_number\": 31, \"value\": -0.015620771066808302}, {\"regressor\": \"text_length\", \"scan_number\": 32, \"value\": -0.08199939013471234}, {\"regressor\": \"text_length\", \"scan_number\": 33, \"value\": -0.029348881933085092}, {\"regressor\": \"text_length\", \"scan_number\": 34, \"value\": -0.017321927412652302}, {\"regressor\": \"text_length\", \"scan_number\": 35, \"value\": -0.036391783792787444}, {\"regressor\": \"text_length\", \"scan_number\": 36, \"value\": -0.02206237440754055}, {\"regressor\": \"text_length\", \"scan_number\": 37, \"value\": -0.011652352359823122}, {\"regressor\": \"text_length\", \"scan_number\": 38, \"value\": -0.005086460732841038}, {\"regressor\": \"text_length\", \"scan_number\": 39, \"value\": -0.0015092058225549823}, {\"regressor\": \"text_length\", \"scan_number\": 40, \"value\": 0.0002037403867828146}, {\"regressor\": \"text_length\", \"scan_number\": 41, \"value\": -0.0003936798609052896}, {\"regressor\": \"text_length\", \"scan_number\": 42, \"value\": 0.003249480262524771}, {\"regressor\": \"text_length\", \"scan_number\": 43, \"value\": 0.01661954897211117}, {\"regressor\": \"text_length\", \"scan_number\": 44, \"value\": 0.21982510694407728}, {\"regressor\": \"text_length\", \"scan_number\": 45, \"value\": 0.3530609501456585}, {\"regressor\": \"text_length\", \"scan_number\": 46, \"value\": 0.23384498472002097}, {\"regressor\": \"text_length\", \"scan_number\": 47, \"value\": 0.09046830696692043}, {\"regressor\": \"text_length\", \"scan_number\": 48, \"value\": 0.2334258977563372}, {\"regressor\": \"text_length\", \"scan_number\": 49, \"value\": 0.3167998647680637}, {\"regressor\": \"text_length\", \"scan_number\": 50, \"value\": 0.2914266822188139}, {\"regressor\": \"text_length\", \"scan_number\": 51, \"value\": 0.22597389021231107}, {\"regressor\": \"text_length\", \"scan_number\": 52, \"value\": 0.17959199009287355}, {\"regressor\": \"text_length\", \"scan_number\": 53, \"value\": 0.18673300893096947}, {\"regressor\": \"text_length\", \"scan_number\": 54, \"value\": 0.854450817162591}, {\"regressor\": \"text_length\", \"scan_number\": 55, \"value\": 1.427755525208883}, {\"regressor\": \"text_length\", \"scan_number\": 56, \"value\": 1.0626841450378994}, {\"regressor\": \"text_length\", \"scan_number\": 57, \"value\": 0.556442148259476}, {\"regressor\": \"text_length\", \"scan_number\": 58, \"value\": -0.04233889851648243}, {\"regressor\": \"text_length\", \"scan_number\": 59, \"value\": -0.2760079500616906}, {\"regressor\": \"text_length\", \"scan_number\": 60, \"value\": -0.14764249622209996}, {\"regressor\": \"text_length\", \"scan_number\": 61, \"value\": -0.08348290934865706}, {\"regressor\": \"text_length\", \"scan_number\": 62, \"value\": 0.008114538557168578}, {\"regressor\": \"text_length\", \"scan_number\": 63, \"value\": -0.013707080774606627}, {\"regressor\": \"text_length\", \"scan_number\": 64, \"value\": 0.01870644109532666}, {\"regressor\": \"text_length\", \"scan_number\": 65, \"value\": 0.1006295718398675}, {\"regressor\": \"text_length\", \"scan_number\": 66, \"value\": 0.18337357782339347}, {\"regressor\": \"text_length\", \"scan_number\": 67, \"value\": 0.20630876323358596}, {\"regressor\": \"text_length\", \"scan_number\": 68, \"value\": 0.0658729525124241}, {\"regressor\": \"text_length\", \"scan_number\": 69, \"value\": 0.05560775179184924}, {\"regressor\": \"text_length\", \"scan_number\": 70, \"value\": 0.13955070919649232}, {\"regressor\": \"text_length\", \"scan_number\": 71, \"value\": 0.07554185571226141}, {\"regressor\": \"text_length\", \"scan_number\": 72, \"value\": 0.008254490430533449}, {\"regressor\": \"text_length\", \"scan_number\": 73, \"value\": 0.007972959282150395}, {\"regressor\": \"text_length\", \"scan_number\": 74, \"value\": 0.041792569690046265}, {\"regressor\": \"text_length\", \"scan_number\": 75, \"value\": -0.02445487689853451}, {\"regressor\": \"text_length\", \"scan_number\": 76, \"value\": -0.09826799274054078}, {\"regressor\": \"text_length\", \"scan_number\": 77, \"value\": -0.048701172588833476}, {\"regressor\": \"text_length\", \"scan_number\": 78, \"value\": 0.23549017445610523}, {\"regressor\": \"text_length\", \"scan_number\": 79, \"value\": 0.8908185700434591}, {\"regressor\": \"text_length\", \"scan_number\": 80, \"value\": 0.7652474166590401}, {\"regressor\": \"text_length\", \"scan_number\": 81, \"value\": 0.40458508905990553}, {\"regressor\": \"text_length\", \"scan_number\": 82, \"value\": 0.2733729577021473}, {\"regressor\": \"text_length\", \"scan_number\": 83, \"value\": 0.231406678611047}, {\"regressor\": \"text_length\", \"scan_number\": 84, \"value\": 0.19293322001916316}, {\"regressor\": \"text_length\", \"scan_number\": 85, \"value\": 0.045643354603258496}, {\"regressor\": \"text_length\", \"scan_number\": 86, \"value\": -0.02856129036005217}, {\"regressor\": \"text_length\", \"scan_number\": 87, \"value\": -0.0432152411442174}, {\"regressor\": \"text_length\", \"scan_number\": 88, \"value\": -0.056378088701542865}, {\"regressor\": \"text_length\", \"scan_number\": 89, \"value\": -0.11817753804115952}, {\"regressor\": \"text_length\", \"scan_number\": 90, \"value\": -0.09439695913066581}, {\"regressor\": \"text_length\", \"scan_number\": 91, \"value\": -0.03394864543754757}, {\"regressor\": \"text_length\", \"scan_number\": 92, \"value\": -0.0044483836435876035}, {\"regressor\": \"text_length\", \"scan_number\": 93, \"value\": 0.01794466142295132}, {\"regressor\": \"text_length\", \"scan_number\": 94, \"value\": 0.12176170306674479}, {\"regressor\": \"text_length\", \"scan_number\": 95, \"value\": 0.1958090692488767}, {\"regressor\": \"text_length\", \"scan_number\": 96, \"value\": 0.24890364459908718}, {\"regressor\": \"text_length\", \"scan_number\": 97, \"value\": 0.18222576732818416}, {\"regressor\": \"text_length\", \"scan_number\": 98, \"value\": 0.04743629984626421}, {\"regressor\": \"text_length\", \"scan_number\": 99, \"value\": -0.036600335139165434}, {\"regressor\": \"text_length\", \"scan_number\": 100, \"value\": -0.1161692766938425}, {\"regressor\": \"text_length\", \"scan_number\": 101, \"value\": 0.029549490575344277}, {\"regressor\": \"text_length\", \"scan_number\": 102, \"value\": 0.11582026693631395}, {\"regressor\": \"text_length\", \"scan_number\": 103, \"value\": 0.0073437691450313775}, {\"regressor\": \"text_length\", \"scan_number\": 104, \"value\": -0.025219138746147268}, {\"regressor\": \"text_length\", \"scan_number\": 105, \"value\": -0.08559959846747639}, {\"regressor\": \"text_length\", \"scan_number\": 106, \"value\": -0.009277242644583242}, {\"regressor\": \"text_length\", \"scan_number\": 107, \"value\": 0.21364153036897549}, {\"regressor\": \"text_length\", \"scan_number\": 108, \"value\": 0.16494685119222324}, {\"regressor\": \"text_length\", \"scan_number\": 109, \"value\": -0.0007694176345862521}, {\"regressor\": \"text_length\", \"scan_number\": 110, \"value\": 0.015201475783179017}, {\"regressor\": \"text_length\", \"scan_number\": 111, \"value\": 0.2155021609495974}, {\"regressor\": \"text_length\", \"scan_number\": 112, \"value\": 0.24706742169269552}, {\"regressor\": \"text_length\", \"scan_number\": 113, \"value\": 0.09737584605875739}, {\"regressor\": \"text_length\", \"scan_number\": 114, \"value\": 0.010356779847994487}, {\"regressor\": \"text_length\", \"scan_number\": 115, \"value\": -0.022519392714902848}, {\"regressor\": \"text_length\", \"scan_number\": 116, \"value\": -0.0255452594402708}, {\"regressor\": \"text_length\", \"scan_number\": 117, \"value\": -0.018051052528455305}, {\"regressor\": \"text_length\", \"scan_number\": 118, \"value\": 0.04340107749936147}, {\"regressor\": \"text_length\", \"scan_number\": 119, \"value\": 0.10002423310493827}, {\"regressor\": \"text_length\", \"scan_number\": 120, \"value\": 0.05851534727963022}, {\"regressor\": \"text_length\", \"scan_number\": 121, \"value\": 0.015457185198298194}, {\"regressor\": \"text_length\", \"scan_number\": 122, \"value\": -0.0038013347713516457}, {\"regressor\": \"text_length\", \"scan_number\": 123, \"value\": -0.009429847980054432}, {\"regressor\": \"text_length\", \"scan_number\": 124, \"value\": -0.008043663586980452}, {\"regressor\": \"text_length\", \"scan_number\": 125, \"value\": -0.004879906726274535}, {\"regressor\": \"text_length\", \"scan_number\": 126, \"value\": -0.002206835123377205}, {\"regressor\": \"text_length\", \"scan_number\": 127, \"value\": -0.0010201039251562178}, {\"regressor\": \"text_length\", \"scan_number\": 128, \"value\": 0.00022580517420236275}, {\"regressor\": \"text_length\", \"scan_number\": 129, \"value\": -0.0010834568663935867}, {\"regressor\": \"text_length\", \"scan_number\": 130, \"value\": -0.0258929127394879}, {\"regressor\": \"text_length\", \"scan_number\": 131, \"value\": 0.048713969063053995}, {\"regressor\": \"text_length\", \"scan_number\": 132, \"value\": 0.19087984645076916}, {\"regressor\": \"text_length\", \"scan_number\": 133, \"value\": 0.14616916353034995}, {\"regressor\": \"text_length\", \"scan_number\": 134, \"value\": 0.04964330715786815}, {\"regressor\": \"text_length\", \"scan_number\": 135, \"value\": 0.001607353742052332}, {\"regressor\": \"text_length\", \"scan_number\": 136, \"value\": -0.016092512872415775}, {\"regressor\": \"text_length\", \"scan_number\": 137, \"value\": -0.01638940174726143}, {\"regressor\": \"text_length\", \"scan_number\": 138, \"value\": -0.010820144271413989}, {\"regressor\": \"text_length\", \"scan_number\": 139, \"value\": -0.0054162083571262535}, {\"regressor\": \"text_length\", \"scan_number\": 140, \"value\": -0.002231371644510298}, {\"regressor\": \"text_length\", \"scan_number\": 141, \"value\": -0.0007848670730443535}, {\"regressor\": \"text_length\", \"scan_number\": 142, \"value\": -0.00024431061012352275}, {\"regressor\": \"text_length\", \"scan_number\": 143, \"value\": -4.067026998521126e-05}, {\"regressor\": \"text_length\", \"scan_number\": 144, \"value\": 1.0843032759835261e-05}, {\"regressor\": \"text_length\", \"scan_number\": 145, \"value\": -1.993326520355782e-05}, {\"regressor\": \"text_length\", \"scan_number\": 146, \"value\": 4.877623333919601e-05}, {\"regressor\": \"text_length\", \"scan_number\": 147, \"value\": -0.00011664466607949735}, {\"regressor\": \"text_length\", \"scan_number\": 148, \"value\": 0.0014408473920483598}, {\"regressor\": \"text_length\", \"scan_number\": 149, \"value\": 0.0037197380664269913}, {\"regressor\": \"text_length\", \"scan_number\": 150, \"value\": 0.002351611732268068}, {\"regressor\": \"text_length\", \"scan_number\": 151, \"value\": 0.0006937150769371873}, {\"regressor\": \"text_length\", \"scan_number\": 152, \"value\": -0.00011059572052218388}, {\"regressor\": \"text_length\", \"scan_number\": 153, \"value\": -0.000228875496124821}, {\"regressor\": \"text_length\", \"scan_number\": 154, \"value\": -0.0005751860963233873}, {\"regressor\": \"text_length\", \"scan_number\": 155, \"value\": 0.0005638513816797029}, {\"regressor\": \"text_length\", \"scan_number\": 156, \"value\": -0.0017593158024835813}, {\"regressor\": \"text_length\", \"scan_number\": 157, \"value\": 0.026576823442603335}, {\"regressor\": \"text_length\", \"scan_number\": 158, \"value\": 0.062029708821771695}, {\"regressor\": \"text_length\", \"scan_number\": 159, \"value\": 0.03828710218745472}, {\"regressor\": \"text_length\", \"scan_number\": 160, \"value\": 0.01100481197292256}, {\"regressor\": \"text_length\", \"scan_number\": 161, \"value\": -0.0015298418151220667}, {\"regressor\": \"text_length\", \"scan_number\": 162, \"value\": -0.005480521659397871}, {\"regressor\": \"text_length\", \"scan_number\": 163, \"value\": -0.004889564070208137}, {\"regressor\": \"text_length\", \"scan_number\": 164, \"value\": -0.0030143684464685634}, {\"regressor\": \"text_length\", \"scan_number\": 165, \"value\": -0.0014404331556495532}, {\"regressor\": \"text_length\", \"scan_number\": 166, \"value\": -0.0005717634264165828}, {\"regressor\": \"text_length\", \"scan_number\": 167, \"value\": -0.00019607695113685666}, {\"regressor\": \"text_length\", \"scan_number\": 168, \"value\": -5.913052335141873e-05}, {\"regressor\": \"text_length\", \"scan_number\": 169, \"value\": 5.05479149390259e-06}, {\"regressor\": \"text_length\", \"scan_number\": 170, \"value\": -5.281458569794585e-05}, {\"regressor\": \"text_length\", \"scan_number\": 171, \"value\": 0.00020918325511635046}, {\"regressor\": \"text_length\", \"scan_number\": 172, \"value\": -0.0007805131840211888}, {\"regressor\": \"text_length\", \"scan_number\": 173, \"value\": 0.004672496931074958}, {\"regressor\": \"text_length\", \"scan_number\": 174, \"value\": 0.031255855693852065}, {\"regressor\": \"text_length\", \"scan_number\": 175, \"value\": 0.20285936455189815}, {\"regressor\": \"text_length\", \"scan_number\": 176, \"value\": 0.2698043939003314}, {\"regressor\": \"text_length\", \"scan_number\": 177, \"value\": 0.13310083569087922}, {\"regressor\": \"text_length\", \"scan_number\": 178, \"value\": 0.18617693961759968}, {\"regressor\": \"text_length\", \"scan_number\": 179, \"value\": 0.328665311114877}, {\"regressor\": \"text_length\", \"scan_number\": 180, \"value\": 0.175076704171267}, {\"regressor\": \"text_length\", \"scan_number\": 181, \"value\": -0.045516697175552616}, {\"regressor\": \"text_length\", \"scan_number\": 182, \"value\": -0.1331906406380241}, {\"regressor\": \"text_length\", \"scan_number\": 183, \"value\": -0.09744138781743858}, {\"regressor\": \"text_length\", \"scan_number\": 184, \"value\": -0.043379424819244054}, {\"regressor\": \"text_length\", \"scan_number\": 185, \"value\": -0.011446972297165346}, {\"regressor\": \"text_length\", \"scan_number\": 186, \"value\": 0.002913048361195227}, {\"regressor\": \"text_length\", \"scan_number\": 187, \"value\": 0.005721510435364655}, {\"regressor\": \"text_length\", \"scan_number\": 188, \"value\": 0.004107124431074363}, {\"regressor\": \"text_length\", \"scan_number\": 189, \"value\": 0.0020724371499976826}, {\"regressor\": \"text_length\", \"scan_number\": 190, \"value\": 0.0008907327012361545}, {\"regressor\": \"text_length\", \"scan_number\": 191, \"value\": 0.0003189155315259298}, {\"regressor\": \"text_length\", \"scan_number\": 192, \"value\": 7.971316551416834e-05}, {\"regressor\": \"text_length\", \"scan_number\": 193, \"value\": 9.661627665357675e-06}, {\"regressor\": \"text_length\", \"scan_number\": 194, \"value\": -2.488774828315062e-06}, {\"regressor\": \"text_length\", \"scan_number\": 195, \"value\": 2.6685993452667893e-06}, {\"regressor\": \"text_length\", \"scan_number\": 196, \"value\": -5.357615184463522e-06}, {\"regressor\": \"text_length\", \"scan_number\": 197, \"value\": 1.2413246027698447e-05}, {\"regressor\": \"text_length\", \"scan_number\": 198, \"value\": -2.8700335406453736e-05}, {\"regressor\": \"text_length\", \"scan_number\": 199, \"value\": 6.307467857901463e-05}, {\"regressor\": \"text_length\", \"scan_number\": 200, \"value\": -0.00012999961276459915}, {\"regressor\": \"text_length\", \"scan_number\": 201, \"value\": 0.00030496424856219564}, {\"regressor\": \"text_length\", \"scan_number\": 202, \"value\": -0.0028657367749899995}, {\"regressor\": \"text_length\", \"scan_number\": 203, \"value\": -0.02315419246108181}, {\"regressor\": \"text_length\", \"scan_number\": 204, \"value\": -0.016460710400130057}, {\"regressor\": \"text_length\", \"scan_number\": 205, \"value\": 0.0017538170184184325}, {\"regressor\": \"text_length\", \"scan_number\": 206, \"value\": 0.0041813988797137665}, {\"regressor\": \"text_length\", \"scan_number\": 207, \"value\": 0.0032414620586358016}, {\"regressor\": \"text_length\", \"scan_number\": 208, \"value\": 0.0018198395177919928}, {\"regressor\": \"text_length\", \"scan_number\": 209, \"value\": 0.0006946811727744872}, {\"regressor\": \"text_length\", \"scan_number\": 210, \"value\": 9.377957295313758e-05}, {\"regressor\": \"text_length\", \"scan_number\": 211, \"value\": -7.611076628179626e-05}, {\"regressor\": \"text_length\", \"scan_number\": 212, \"value\": -7.042776970707661e-05}, {\"regressor\": \"text_length\", \"scan_number\": 213, \"value\": -3.525826550117625e-05}, {\"regressor\": \"text_length\", \"scan_number\": 214, \"value\": -1.647814606036952e-05}, {\"regressor\": \"text_length\", \"scan_number\": 215, \"value\": -8.14761960763592e-06}, {\"regressor\": \"text_length\", \"scan_number\": 216, \"value\": 1.5627068263572218e-07}, {\"regressor\": \"text_length\", \"scan_number\": 217, \"value\": -1.2619612663676788e-07}, {\"regressor\": \"text_length\", \"scan_number\": 218, \"value\": 4.437051749485572e-08}, {\"regressor\": \"text_length\", \"scan_number\": 219, \"value\": -1.8702219657179328e-08}, {\"regressor\": \"text_length\", \"scan_number\": 220, \"value\": 2.33070692014162e-08}, {\"regressor\": \"text_length\", \"scan_number\": 221, \"value\": -5.641520389742774e-08}, {\"regressor\": \"text_length\", \"scan_number\": 222, \"value\": 1.4603891741614606e-07}, {\"regressor\": \"text_length\", \"scan_number\": 223, \"value\": -3.7098130276978446e-07}, {\"regressor\": \"text_length\", \"scan_number\": 224, \"value\": 9.195526754271395e-07}, {\"regressor\": \"text_length\", \"scan_number\": 225, \"value\": -2.2187724931170493e-06}, {\"regressor\": \"text_length\", \"scan_number\": 226, \"value\": 5.179200727947458e-06}, {\"regressor\": \"text_length\", \"scan_number\": 227, \"value\": -1.1436622436161434e-05}, {\"regressor\": \"text_length\", \"scan_number\": 228, \"value\": 2.3783759756365584e-05}, {\"regressor\": \"text_length\", \"scan_number\": 229, \"value\": -5.7186683185872374e-05}, {\"regressor\": \"text_length\", \"scan_number\": 230, \"value\": 0.0005403722788572742}, {\"regressor\": \"text_length\", \"scan_number\": 231, \"value\": 0.004585311250032492}, {\"regressor\": \"text_length\", \"scan_number\": 232, \"value\": 0.004757790440866297}, {\"regressor\": \"text_length\", \"scan_number\": 233, \"value\": 0.001855277824035915}, {\"regressor\": \"text_length\", \"scan_number\": 234, \"value\": 0.0002549098211072761}, {\"regressor\": \"text_length\", \"scan_number\": 235, \"value\": -0.00039703356522180093}, {\"regressor\": \"text_length\", \"scan_number\": 236, \"value\": -0.0004794290422520128}, {\"regressor\": \"text_length\", \"scan_number\": 237, \"value\": -0.000342623636319273}, {\"regressor\": \"text_length\", \"scan_number\": 238, \"value\": -0.00018131649786605228}, {\"regressor\": \"text_length\", \"scan_number\": 239, \"value\": -7.791434358642281e-05}, {\"regressor\": \"text_length\", \"scan_number\": 240, \"value\": -2.821454728351261e-05}, {\"regressor\": \"text_length\", \"scan_number\": 241, \"value\": -9.069375768301685e-06}, {\"regressor\": \"text_length\", \"scan_number\": 242, \"value\": -2.037984661972542e-06}, {\"regressor\": \"text_length\", \"scan_number\": 243, \"value\": 1.4963112741140486e-07}, {\"regressor\": \"text_length\", \"scan_number\": 244, \"value\": -7.848321404927254e-08}, {\"regressor\": \"text_length\", \"scan_number\": 245, \"value\": 2.4396910801786835e-07}, {\"regressor\": \"text_length\", \"scan_number\": 246, \"value\": -1.035073559743459e-06}, {\"regressor\": \"text_length\", \"scan_number\": 247, \"value\": 3.8303674148447396e-06}, {\"regressor\": \"text_length\", \"scan_number\": 248, \"value\": -1.3003643268817894e-05}, {\"regressor\": \"text_length\", \"scan_number\": 249, \"value\": 4.056046067681161e-05}, {\"regressor\": \"text_length\", \"scan_number\": 250, \"value\": -0.00010726723642142703}, {\"regressor\": \"text_length\", \"scan_number\": 251, \"value\": -0.00010937849130209805}, {\"regressor\": \"text_length\", \"scan_number\": 252, \"value\": -0.0076133943217997005}, {\"regressor\": \"text_length\", \"scan_number\": 253, \"value\": -0.014597166884690755}, {\"regressor\": \"text_length\", \"scan_number\": 254, \"value\": -0.009118861150078535}, {\"regressor\": \"text_length\", \"scan_number\": 255, \"value\": -0.0070235841319975754}, {\"regressor\": \"text_length\", \"scan_number\": 256, \"value\": -0.003813757289543415}, {\"regressor\": \"text_length\", \"scan_number\": 257, \"value\": -0.0008762672820452696}, {\"regressor\": \"text_length\", \"scan_number\": 258, \"value\": 0.002284260757806306}, {\"regressor\": \"text_length\", \"scan_number\": 259, \"value\": -0.011251602906877748}, {\"regressor\": \"text_length\", \"scan_number\": 260, \"value\": -0.026465645319844255}, {\"regressor\": \"text_length\", \"scan_number\": 261, \"value\": -0.015932227834376474}, {\"regressor\": \"text_length\", \"scan_number\": 262, \"value\": -0.004030513661670909}, {\"regressor\": \"text_length\", \"scan_number\": 263, \"value\": 0.0020169837377116548}, {\"regressor\": \"text_length\", \"scan_number\": 264, \"value\": 0.005039409299004285}, {\"regressor\": \"text_length\", \"scan_number\": 265, \"value\": 0.04858324317707985}, {\"regressor\": \"text_length\", \"scan_number\": 266, \"value\": 0.08906233977111733}, {\"regressor\": \"text_length\", \"scan_number\": 267, \"value\": 0.07450825336546744}, {\"regressor\": \"text_length\", \"scan_number\": 268, \"value\": 0.03565027869203886}, {\"regressor\": \"text_length\", \"scan_number\": 269, \"value\": 0.004572977810578637}, {\"regressor\": \"text_length\", \"scan_number\": 270, \"value\": -0.007149961962710596}, {\"regressor\": \"text_length\", \"scan_number\": 271, \"value\": -0.00881419763541136}, {\"regressor\": \"text_length\", \"scan_number\": 272, \"value\": -0.0063303508000345}, {\"regressor\": \"text_length\", \"scan_number\": 273, \"value\": -0.003457526209321067}, {\"regressor\": \"text_length\", \"scan_number\": 274, \"value\": -0.0015911020881399214}, {\"regressor\": \"text_length\", \"scan_number\": 275, \"value\": -0.0004587752524053393}, {\"regressor\": \"text_length\", \"scan_number\": 276, \"value\": -0.00055309153580664}, {\"regressor\": \"text_length\", \"scan_number\": 277, \"value\": 0.0008949736548568813}, {\"regressor\": \"text_length\", \"scan_number\": 278, \"value\": -0.002080879946346872}, {\"regressor\": \"text_length\", \"scan_number\": 279, \"value\": 0.0368034250368526}, {\"regressor\": \"text_length\", \"scan_number\": 280, \"value\": 0.10765601656987557}, {\"regressor\": \"text_length\", \"scan_number\": 281, \"value\": 0.08833550846552914}, {\"regressor\": \"text_length\", \"scan_number\": 282, \"value\": 0.028345035324550818}, {\"regressor\": \"text_length\", \"scan_number\": 283, \"value\": -0.0013102812185213494}, {\"regressor\": \"text_length\", \"scan_number\": 284, \"value\": -0.010268468940958855}, {\"regressor\": \"text_length\", \"scan_number\": 285, \"value\": -0.010321924642074303}, {\"regressor\": \"text_length\", \"scan_number\": 286, \"value\": -0.005655023773853398}, {\"regressor\": \"text_length\", \"scan_number\": 287, \"value\": -0.004995041895492962}, {\"regressor\": \"text_length\", \"scan_number\": 288, \"value\": 0.0032030345541173965}, {\"regressor\": \"text_length\", \"scan_number\": 289, \"value\": -0.012187639439963741}, {\"regressor\": \"text_length\", \"scan_number\": 290, \"value\": 0.07524776593762562}, {\"regressor\": \"text_length\", \"scan_number\": 291, \"value\": 0.3337325816032038}, {\"regressor\": \"text_length\", \"scan_number\": 292, \"value\": 0.2913910132327322}, {\"regressor\": \"text_length\", \"scan_number\": 293, \"value\": 0.9339797088621525}, {\"regressor\": \"text_length\", \"scan_number\": 294, \"value\": 1.1798836181691532}, {\"regressor\": \"text_length\", \"scan_number\": 295, \"value\": 0.5250553329325125}, {\"regressor\": \"text_length\", \"scan_number\": 296, \"value\": 0.09496685898891198}, {\"regressor\": \"text_length\", \"scan_number\": 297, \"value\": -0.06779582745125996}, {\"regressor\": \"text_length\", \"scan_number\": 298, \"value\": -0.1134483889563946}, {\"regressor\": \"text_length\", \"scan_number\": 299, \"value\": 0.008730683421067177}, {\"regressor\": \"text_length\", \"scan_number\": 300, \"value\": 0.20236865306086685}, {\"regressor\": \"text_length\", \"scan_number\": 301, \"value\": 0.14860721569075552}, {\"regressor\": \"text_length\", \"scan_number\": 302, \"value\": 0.009352966830046194}, {\"regressor\": \"text_length\", \"scan_number\": 303, \"value\": 0.06640889436683992}, {\"regressor\": \"text_length\", \"scan_number\": 304, \"value\": 0.243720172338002}, {\"regressor\": \"text_length\", \"scan_number\": 305, \"value\": 0.18537972381048692}, {\"regressor\": \"text_length\", \"scan_number\": 306, \"value\": 0.05836828383883895}, {\"regressor\": \"text_length\", \"scan_number\": 307, \"value\": -0.0037455668246528353}, {\"regressor\": \"text_length\", \"scan_number\": 308, \"value\": -0.025226694894014128}, {\"regressor\": \"text_length\", \"scan_number\": 309, \"value\": -0.02408419251323915}, {\"regressor\": \"text_length\", \"scan_number\": 310, \"value\": -0.01583797500811749}, {\"regressor\": \"text_length\", \"scan_number\": 311, \"value\": -0.007369794827029571}, {\"regressor\": \"text_length\", \"scan_number\": 312, \"value\": -0.004364418675672941}, {\"regressor\": \"text_length\", \"scan_number\": 313, \"value\": 0.0018166087546104223}, {\"regressor\": \"text_length\", \"scan_number\": 314, \"value\": -0.0075585913876306315}, {\"regressor\": \"text_length\", \"scan_number\": 315, \"value\": 0.08377911424210711}, {\"regressor\": \"text_length\", \"scan_number\": 316, \"value\": 0.25106183604408744}, {\"regressor\": \"text_length\", \"scan_number\": 317, \"value\": 0.17009240600232212}, {\"regressor\": \"text_length\", \"scan_number\": 318, \"value\": 0.05867057785605251}, {\"regressor\": \"text_length\", \"scan_number\": 319, \"value\": -0.05489357809379778}, {\"regressor\": \"text_length\", \"scan_number\": 320, \"value\": -0.1468549776746739}, {\"regressor\": \"text_length\", \"scan_number\": 321, \"value\": 0.20205935790715238}, {\"regressor\": \"text_length\", \"scan_number\": 322, \"value\": 0.5053833124720334}, {\"regressor\": \"text_length\", \"scan_number\": 323, \"value\": 0.3979092444098786}, {\"regressor\": \"text_length\", \"scan_number\": 324, \"value\": 0.22946557291339523}, {\"regressor\": \"text_length\", \"scan_number\": 325, \"value\": 0.07418015427213179}, {\"regressor\": \"text_length\", \"scan_number\": 326, \"value\": -0.028821617933634087}, {\"regressor\": \"text_length\", \"scan_number\": 327, \"value\": -0.04834025570837911}, {\"regressor\": \"text_length\", \"scan_number\": 328, \"value\": -0.03860905645260459}, {\"regressor\": \"text_length\", \"scan_number\": 329, \"value\": -0.022687484729793338}, {\"regressor\": \"text_length\", \"scan_number\": 330, \"value\": -0.010841316807064764}, {\"regressor\": \"text_length\", \"scan_number\": 331, \"value\": -0.004304329894862071}, {\"regressor\": \"text_length\", \"scan_number\": 332, \"value\": -0.0014220488224328126}, {\"regressor\": \"text_length\", \"scan_number\": 333, \"value\": -0.0003359576260814582}, {\"regressor\": \"text_length\", \"scan_number\": 334, \"value\": -5.744557808841076e-05}, {\"regressor\": \"text_length\", \"scan_number\": 335, \"value\": -6.666912078448564e-07}, {\"regressor\": \"text_length\", \"scan_number\": 336, \"value\": 1.0524916434279462e-05}, {\"regressor\": \"text_length\", \"scan_number\": 337, \"value\": -1.6782992071974197e-06}, {\"regressor\": \"text_length\", \"scan_number\": 338, \"value\": 5.962823263853385e-07}, {\"regressor\": \"text_length\", \"scan_number\": 339, \"value\": -2.0908416635812298e-07}, {\"regressor\": \"text_length\", \"scan_number\": 340, \"value\": 6.913739328899432e-08}, {\"regressor\": \"text_length\", \"scan_number\": 341, \"value\": -2.116942649835306e-08}, {\"regressor\": \"text_length\", \"scan_number\": 342, \"value\": 4.579915461527863e-09}, {\"regressor\": \"text_length\", \"scan_number\": 343, \"value\": 8.62505695605406e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 0, \"value\": 3.931963397211308e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 1, \"value\": -9.50686248704132e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 2, \"value\": 2.227478953395517e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 3, \"value\": -5.013637823347668e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 4, \"value\": 1.0672681085760789e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 5, \"value\": -2.0820503949443357e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 6, \"value\": 3.438920914077445e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 7, \"value\": -3.45109953153008e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 8, \"value\": -5.95855478595252e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 9, \"value\": 5.52602938361079e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 10, \"value\": -2.474320557241042e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 11, \"value\": 9.083434651351326e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 12, \"value\": -3.023401825949841e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 13, \"value\": 9.471300099991182e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 14, \"value\": -2.8427755895055287e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 15, \"value\": 8.247843426016732e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 16, \"value\": -2.3283327228315934e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 17, \"value\": 6.423758432481896e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 18, \"value\": -0.00017362621146989915}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 19, \"value\": 0.0004518770333940762}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 20, \"value\": -0.001105225407655921}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 21, \"value\": 0.002525940048101418}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 22, \"value\": -0.03674924108358129}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 23, \"value\": -0.13172954618971028}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 24, \"value\": -0.06199230652910805}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 25, \"value\": 0.031187484230176872}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 26, \"value\": 0.06378307110443913}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 27, \"value\": 0.7129118612448925}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 28, \"value\": 1.2029875121631326}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 29, \"value\": 0.8851501379476466}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 30, \"value\": 0.31782912233112837}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 31, \"value\": -0.005123087533856588}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 32, \"value\": -0.15043877049344817}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 33, \"value\": -0.12912017880975332}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 34, \"value\": -0.06996580750338792}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 35, \"value\": -0.05049841248422836}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 36, \"value\": -0.020907085302690864}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 37, \"value\": -0.0060901418701869115}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 38, \"value\": -0.0002880393401476286}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 39, \"value\": 0.0011045323903183378}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 40, \"value\": 0.0017558801753609274}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 41, \"value\": -0.0009882568860276088}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 42, \"value\": 0.004945366205640527}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 43, \"value\": -0.005745548364086844}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 44, \"value\": 0.27689462899129147}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 45, \"value\": 0.6108220468264098}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 46, \"value\": 0.33790580854263375}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 47, \"value\": 0.0341985918665752}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 48, \"value\": 0.2265646728009239}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 49, \"value\": 0.3091936083172388}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 50, \"value\": 0.4261534428933237}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 51, \"value\": 0.28407261586592064}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 52, \"value\": 0.06284183165945126}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 53, \"value\": -0.01609770093634653}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 54, \"value\": 0.8265531615745653}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 55, \"value\": 1.7518597045755964}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 56, \"value\": 1.1728923194172103}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 57, \"value\": 0.42121537385323915}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 58, \"value\": -0.03816940279018803}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 59, \"value\": -0.17099148077296655}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 60, \"value\": -0.20485018873721228}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 61, \"value\": -0.24524071230503433}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 62, \"value\": -0.18021460544222348}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 63, \"value\": -0.13327454887716778}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 64, \"value\": -0.06862012611828394}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 65, \"value\": -0.03555219674354485}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 66, \"value\": -0.03401508548166467}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 67, \"value\": -0.08031518494991567}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 68, \"value\": -0.1004453451487609}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 69, \"value\": -0.0217265628883831}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 70, \"value\": -0.014913396321892963}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 71, \"value\": -0.03449451203839782}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 72, \"value\": -0.010709973313665069}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 73, \"value\": 0.0015939828195908451}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 74, \"value\": 0.0004520002968825205}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 75, \"value\": -0.0492869559336289}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 76, \"value\": -0.0795830375033777}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 77, \"value\": 0.048102389084839915}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 78, \"value\": 0.22426096364367826}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 79, \"value\": 0.46369780907082486}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 80, \"value\": 0.320554626398088}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 81, \"value\": 0.16610242597873479}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 82, \"value\": 0.0929812543103731}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 83, \"value\": -0.017067997637673266}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 84, \"value\": -0.04008303940140508}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 85, \"value\": -0.033726390268924294}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 86, \"value\": -0.02125478032318886}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 87, \"value\": -0.009763213337206643}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 88, \"value\": -0.011319426907168665}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 89, \"value\": -0.03724343628480422}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 90, \"value\": -0.03153122573303996}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 91, \"value\": -0.011517806034978682}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 92, \"value\": 0.00020696983814315448}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 93, \"value\": -0.014989145087675059}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 94, \"value\": 0.06618314030857335}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 95, \"value\": 0.04152411911309892}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 96, \"value\": -0.036302809068292856}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 97, \"value\": -0.02634546329641108}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 98, \"value\": -0.010560142218590973}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 99, \"value\": -0.024388932897788512}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 100, \"value\": -0.11331292154867154}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 101, \"value\": -0.14922041801453698}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 102, \"value\": -0.15962370180233126}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 103, \"value\": -0.13054364315888034}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 104, \"value\": -0.01288977009876313}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 105, \"value\": 0.02370311015597004}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 106, \"value\": 0.14568048195337896}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 107, \"value\": 0.33625929743996563}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 108, \"value\": 0.2240702240252135}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 109, \"value\": 0.08273089782886126}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 110, \"value\": 0.006274073845682229}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 111, \"value\": 0.07372187157176634}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 112, \"value\": 0.15530658707070016}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 113, \"value\": 0.05574379784244452}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 114, \"value\": 0.0017119598727883202}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 115, \"value\": -0.01635452765986202}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 116, \"value\": -0.01637883711303962}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 117, \"value\": -0.01726531690440041}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 118, \"value\": -0.005671924208467571}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 119, \"value\": 0.042569702605445285}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 120, \"value\": 0.035212510124529674}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 121, \"value\": 0.011969447753274014}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 122, \"value\": 0.0008128268037684578}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 123, \"value\": -0.003592679148395666}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 124, \"value\": -0.003822905242474285}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 125, \"value\": -0.0025837026993836797}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 126, \"value\": -0.0012604310086336845}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 127, \"value\": -0.0006284140845792067}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 128, \"value\": 0.00011801494264401024}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 129, \"value\": -0.004970121933916838}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 130, \"value\": -0.0023983519762494}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 131, \"value\": 0.1196983529016805}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 132, \"value\": 0.35035158336012245}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 133, \"value\": 0.2756721475605629}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 134, \"value\": 0.09229543013819554}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 135, \"value\": 0.0016244914905849208}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 136, \"value\": -0.031283359875395364}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 137, \"value\": -0.031383737405417306}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 138, \"value\": -0.02069948308169792}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 139, \"value\": -0.010389185687524415}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 140, \"value\": -0.004298236168504298}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 141, \"value\": -0.0015130050921568642}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 142, \"value\": -0.0004660881183037388}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 143, \"value\": -8.311035690909673e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 144, \"value\": 9.14866155033889e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 145, \"value\": -3.2167719386937313e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 146, \"value\": 1.2288531922669465e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 147, \"value\": -4.565567159353694e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 148, \"value\": 1.6330973890114525e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 149, \"value\": -5.692003688320442e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 150, \"value\": 1.9261307385227062e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 151, \"value\": -6.2786975255915345e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 152, \"value\": 1.9496711283542024e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 153, \"value\": -5.762597536648649e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 154, \"value\": 1.9576660395014437e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 155, \"value\": -1.855900348357581e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 156, \"value\": 4.437172171416522e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 157, \"value\": -1.1977448864287694e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 158, \"value\": 3.1732504334580335e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 159, \"value\": -8.215460645894722e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 160, \"value\": 2.0800664167146898e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 161, \"value\": -5.1429059510424224e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 162, \"value\": 1.2376442797594883e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 163, \"value\": -2.88264298523018e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 164, \"value\": 6.436150876752177e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 165, \"value\": -1.3536623849248308e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 166, \"value\": 2.5862483176290106e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 167, \"value\": -4.074935762025509e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 168, \"value\": 3.2543513421516096e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 169, \"value\": 1.1425148891845523e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 170, \"value\": -8.246115609240247e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 171, \"value\": 0.0003550439207649644}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 172, \"value\": -0.0012719382738769164}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 173, \"value\": 0.004480679510910006}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 174, \"value\": 0.0038835939097956297}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 175, \"value\": 0.22016351316521224}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 176, \"value\": 0.3151501341166936}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 177, \"value\": 0.12001891892989568}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 178, \"value\": 0.04337449117910536}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 179, \"value\": 0.17008857094768523}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 180, \"value\": 0.22142580708072246}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 181, \"value\": 0.058300856987077675}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 182, \"value\": -0.07386755098168454}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 183, \"value\": -0.06956922497993077}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 184, \"value\": -0.03908792875995775}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 185, \"value\": -0.016292042774202573}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 186, \"value\": -0.003008657186109809}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 187, \"value\": 0.001856158035653602}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 188, \"value\": 0.0021531714099023293}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 189, \"value\": 0.0012584623391312028}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 190, \"value\": 0.0005693802585205067}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 191, \"value\": 0.00023722572368865588}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 192, \"value\": 7.273225436019963e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 193, \"value\": 3.9629514499535935e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 194, \"value\": -2.0949699138526667e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 195, \"value\": -6.268010377796481e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 196, \"value\": 2.1009163968082484e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 197, \"value\": -5.699776650002863e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 198, \"value\": 1.4687863642156239e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 199, \"value\": -3.695059406768645e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 200, \"value\": 8.83765682395071e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 201, \"value\": -0.0001863705101368979}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 202, \"value\": 4.349772329228808e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 203, \"value\": -0.012866369509608228}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 204, \"value\": -0.05641360218658607}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 205, \"value\": -0.05963049742565013}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 206, \"value\": -0.025522569973435306}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 207, \"value\": -0.003901519474570068}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 208, \"value\": 0.00481120514527045}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 209, \"value\": 0.006151345031471006}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 210, \"value\": 0.004481485011651479}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 211, \"value\": 0.002428880963437914}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 212, \"value\": 0.0010640783972057533}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 213, \"value\": 0.00039396756602987575}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 214, \"value\": 0.000127387571617352}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 215, \"value\": 3.039769399246839e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 216, \"value\": -3.972838064155265e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 217, \"value\": 2.5498167090795234e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 218, \"value\": -9.37416692831046e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 219, \"value\": 2.6619327073498637e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 220, \"value\": -5.703763013131758e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 221, \"value\": 5.124050651458011e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 222, \"value\": 4.2776983127848366e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 223, \"value\": -3.9386554428430737e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 224, \"value\": 2.338372134312819e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 225, \"value\": -1.1874588631454297e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 226, \"value\": 5.5422890096313746e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 227, \"value\": -2.4413112338566242e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 228, \"value\": 1.0210696367031247e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 229, \"value\": -4.060643847676109e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 230, \"value\": 2.1399062011708763e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 231, \"value\": -4.537434584530861e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 232, \"value\": 1.7619130516571444e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 233, \"value\": -6.391315587884239e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 234, \"value\": 2.126268520089919e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 235, \"value\": -6.66304515910331e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 236, \"value\": 2.000561279941456e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 237, \"value\": -5.811266672721239e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 238, \"value\": 1.6426289806041288e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 239, \"value\": -4.533830007955031e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 240, \"value\": 1.224377590284613e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 241, \"value\": -3.238092971237986e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 242, \"value\": 8.386719054816279e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 243, \"value\": -2.1253108740443787e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 244, \"value\": 5.256827698184481e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 245, \"value\": -1.2658731600228357e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 246, \"value\": 2.9520695936567023e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 247, \"value\": -6.59619902309287e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 248, \"value\": 0.00013625802916340644}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 249, \"value\": -0.0002546507415870884}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 250, \"value\": 0.0005813866105990441}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 251, \"value\": -0.008264683976062233}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 252, \"value\": -0.08185697915205009}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 253, \"value\": -0.09754605385074396}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 254, \"value\": -0.04366355014363039}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 255, \"value\": -0.01327009979558682}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 256, \"value\": 0.001639581165738998}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 257, \"value\": 0.007731372741225997}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 258, \"value\": 0.006690035513312284}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 259, \"value\": 0.002714802948306446}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 260, \"value\": -0.025241076239248064}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 261, \"value\": -0.06212120436860913}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 262, \"value\": -0.046945330319792596}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 263, \"value\": -0.05799691704217506}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 264, \"value\": -0.0618978545792717}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 265, \"value\": -0.04062715616453941}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 266, \"value\": -0.029802142320130547}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 267, \"value\": -0.025204722656030666}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 268, \"value\": -0.016115227707217045}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 269, \"value\": -0.0017382145154966467}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 270, \"value\": 0.004021097732758776}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 271, \"value\": 0.004844618124895924}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 272, \"value\": 0.0036532302143160444}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 273, \"value\": 0.0021404198997978206}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 274, \"value\": 0.0010759611334294112}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 275, \"value\": 0.00031344866940976647}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 276, \"value\": 0.00039324648782271634}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 277, \"value\": -0.0005444708134091811}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 278, \"value\": 0.0014244671690926212}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 279, \"value\": -0.020802354736991845}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 280, \"value\": -0.10914598308961193}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 281, \"value\": -0.15023314981092892}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 282, \"value\": -0.096587344777792}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 283, \"value\": -0.029399739911989065}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 284, \"value\": 0.004879590015013663}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 285, \"value\": 0.01428913214860143}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 286, \"value\": 0.01420515996398243}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 287, \"value\": 0.00521604560727714}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 288, \"value\": 0.011007856611453726}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 289, \"value\": -0.015763093508447575}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 290, \"value\": 0.15190914758155336}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 291, \"value\": 0.5282956747744562}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 292, \"value\": 0.3836740822539424}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 293, \"value\": 0.917687672831134}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 294, \"value\": 1.113672981457774}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 295, \"value\": 0.47870404029147184}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 296, \"value\": 0.06863513650944111}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 297, \"value\": -0.09503089241565592}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 298, \"value\": -0.11470360000386606}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 299, \"value\": -0.08686148651427666}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 300, \"value\": -0.1084824869965518}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 301, \"value\": -0.1145269808297034}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 302, \"value\": -0.07401329418292232}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 303, \"value\": -0.02127822718817684}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 304, \"value\": -0.11983159992626642}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 305, \"value\": -0.11256872873493551}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 306, \"value\": -0.038769025217968114}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 307, \"value\": -0.0015162095733220115}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 308, \"value\": 0.012544589247606529}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 309, \"value\": 0.013158418361094394}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 310, \"value\": 0.009043065120165441}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 311, \"value\": 0.0046674108329307065}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 312, \"value\": 0.0019976473282493604}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 313, \"value\": 0.0006558801350525314}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 314, \"value\": 0.00035463239257010155}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 315, \"value\": -0.0007298232184565764}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 316, \"value\": -0.00375930671798945}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 317, \"value\": -0.0049185264813577205}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 318, \"value\": 0.0008321199642261282}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 319, \"value\": -0.033523377941589286}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 320, \"value\": -0.09044235134177717}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 321, \"value\": 0.02766859123936324}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 322, \"value\": 0.37491056158291325}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 323, \"value\": 0.4787449317271937}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 324, \"value\": 0.26645178703629757}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 325, \"value\": 0.07447082056727676}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 326, \"value\": -0.01953128632234399}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 327, \"value\": -0.045353100209517515}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 328, \"value\": -0.03804107270224441}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 329, \"value\": -0.02272408015372034}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 330, \"value\": -0.010786478109983047}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 331, \"value\": -0.004309585981501798}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 332, \"value\": -0.0014837315181181418}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 333, \"value\": -0.0004096252164965281}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 334, \"value\": -5.133352941807937e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 335, \"value\": -2.5738018590625033e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 336, \"value\": 2.4875160513522897e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 337, \"value\": 2.7089835238364073e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 338, \"value\": -1.124100168733965e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 339, \"value\": 4.809279551126205e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 340, \"value\": -2.0454118623801534e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 341, \"value\": 8.518561051717361e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 342, \"value\": -3.6046450220853514e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumSylls\", \"scan_number\": 343, \"value\": 1.9178889475318055e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 0, \"value\": 6.257602600415185e-14}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 1, \"value\": -4.2338764511983293e-13}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 2, \"value\": 1.7769671709573325e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 3, \"value\": -6.3368371941481405e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 4, \"value\": 2.0734591340578305e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 5, \"value\": -6.420030387005148e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 6, \"value\": 1.910104587682536e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 7, \"value\": -5.507801077858824e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 8, \"value\": 1.5470702076543807e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 9, \"value\": -4.245962591006176e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 10, \"value\": 1.1405526555329133e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 11, \"value\": -3.000720094120727e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 12, \"value\": 7.730673214075682e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 13, \"value\": -1.948044809383618e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 14, \"value\": 4.790584929719381e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 15, \"value\": -1.1450159457592759e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 16, \"value\": 2.6440236372062725e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 17, \"value\": -5.828107693831659e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 18, \"value\": 1.1953341337069289e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 19, \"value\": -2.2989189259766987e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 20, \"value\": 4.7346151746524204e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 21, \"value\": -0.0002007521755941305}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 22, \"value\": -0.005524166425456413}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 23, \"value\": -0.022020049738156907}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 24, \"value\": -0.019034303371138234}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 25, \"value\": 0.05131266975746639}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 26, \"value\": 0.12701999046832663}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 27, \"value\": 0.560652777424063}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 28, \"value\": 0.9911728556620647}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 29, \"value\": 0.8410912742049372}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 30, \"value\": 0.3398342864016999}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 31, \"value\": 0.023796886190793756}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 32, \"value\": -0.08782748367694543}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 33, \"value\": -0.04418681533937122}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 34, \"value\": -0.032363411465131296}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 35, \"value\": -0.048244330285037}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 36, \"value\": -0.02777513749531045}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 37, \"value\": -0.013825752999336006}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 38, \"value\": -0.00561467164632737}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 39, \"value\": -0.001473498231009227}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 40, \"value\": 0.00034743503867407295}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 41, \"value\": -0.0001606355219000377}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 42, \"value\": 0.001934323934885423}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 43, \"value\": -0.0009683350185851247}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 44, \"value\": 0.1509038717619211}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 45, \"value\": 0.3369779719569524}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 46, \"value\": 0.26849625288689705}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 47, \"value\": 0.14108210880488914}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 48, \"value\": 0.3402553474809711}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 49, \"value\": 0.3542934194271469}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 50, \"value\": 0.39508703588873806}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 51, \"value\": 0.3053643478669703}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 52, \"value\": 0.11299153145024673}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 53, \"value\": 0.03814839131464444}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 54, \"value\": 0.7589008720576614}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 55, \"value\": 1.4699638535516}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 56, \"value\": 1.05315766527236}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 57, \"value\": 0.4686216020847967}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 58, \"value\": -0.029636047380778276}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 59, \"value\": -0.2296616290047669}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 60, \"value\": -0.24586089103815192}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 61, \"value\": -0.20220238131547383}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 62, \"value\": -0.040339057023798634}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 63, \"value\": 0.041130303938861815}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 64, \"value\": 0.036845121913500305}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 65, \"value\": 0.009457763970166365}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 66, \"value\": -0.007570447006556655}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 67, \"value\": -0.034789538603617165}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 68, \"value\": -0.07501820204897168}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 69, \"value\": 0.015072613216024617}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 70, \"value\": 0.13948671670115803}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 71, \"value\": 0.09194960207517558}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 72, \"value\": 0.029496819478164196}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 73, \"value\": 0.0005429687874976079}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 74, \"value\": -0.011279204902449788}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 75, \"value\": -0.026513410377525352}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 76, \"value\": -0.04357807663047579}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 77, \"value\": 0.003776971628864375}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 78, \"value\": 0.2488340541395267}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 79, \"value\": 0.7816363482444314}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 80, \"value\": 0.6783087987956231}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 81, \"value\": 0.5194232851380178}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 82, \"value\": 0.4295128745083545}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 83, \"value\": 0.12735821403674613}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 84, \"value\": -0.032152992091599324}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 85, \"value\": -0.07348343260960369}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 86, \"value\": -0.06482695615006491}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 87, \"value\": -0.03943347346977915}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 88, \"value\": -0.03374532136051627}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 89, \"value\": -0.07489483944950359}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 90, \"value\": -0.060713613234145876}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 91, \"value\": -0.021494983803713445}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 92, \"value\": -0.001341772001500006}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 93, \"value\": 0.009211213985582204}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 94, \"value\": 0.10938299539275442}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 95, \"value\": 0.1718001054606539}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 96, \"value\": 0.09733327239041334}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 97, \"value\": 0.026631689100310687}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 98, \"value\": -0.006215967314129164}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 99, \"value\": -0.015530058643401103}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 100, \"value\": -0.003332560364832147}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 101, \"value\": 0.1095957706974082}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 102, \"value\": 0.13682245459602926}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 103, \"value\": -0.0070060645207934355}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 104, \"value\": -0.048176843985604414}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 105, \"value\": -0.09578307765630624}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 106, \"value\": -0.01283301760638747}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 107, \"value\": 0.20520348909843683}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 108, \"value\": 0.16905892198298875}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 109, \"value\": 0.06941664766315477}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 110, \"value\": 0.03815588155273984}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 111, \"value\": 0.21401509897701115}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 112, \"value\": 0.2905997684409696}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 113, \"value\": 0.12153965936895246}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 114, \"value\": 0.01663640895765175}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 115, \"value\": -0.024972200310526226}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 116, \"value\": -0.028131892545020205}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 117, \"value\": -0.03046506565834895}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 118, \"value\": 0.02158805397781668}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 119, \"value\": 0.11858854140525027}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 120, \"value\": 0.081051590766891}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 121, \"value\": 0.02470607189151781}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 122, \"value\": -0.0014297226406707422}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 123, \"value\": -0.010482632777999063}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 124, \"value\": -0.009872239750586606}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 125, \"value\": -0.006284399420036534}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 126, \"value\": -0.002997582558908583}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 127, \"value\": -0.001338414981209806}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 128, \"value\": -0.00010474385493077305}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 129, \"value\": -0.003918115702072373}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 130, \"value\": 0.001906717677793344}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 131, \"value\": 0.09604694829665034}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 132, \"value\": 0.22777217602827665}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 133, \"value\": 0.16351556469146042}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 134, \"value\": 0.05148565998210007}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 135, \"value\": -0.0022341633227986545}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 136, \"value\": -0.020624934913846916}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 137, \"value\": -0.019578381712623997}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 138, \"value\": -0.012553424904344995}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 139, \"value\": -0.006183792508210223}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 140, \"value\": -0.0025228020114831506}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 141, \"value\": -0.0008787322016808839}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 142, \"value\": -0.00026561292568552864}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 143, \"value\": -4.204617536691711e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 144, \"value\": 4.8228892122293395e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 145, \"value\": -1.7046428142255975e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 146, \"value\": 6.655491652046612e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 147, \"value\": -2.5409901090450396e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 148, \"value\": 9.361972086595101e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 149, \"value\": -3.3715029731626045e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 150, \"value\": 1.1853256645667076e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 151, \"value\": -4.0516305454532315e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 152, \"value\": 1.3401915082121248e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 153, \"value\": -4.33293979343127e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 154, \"value\": 1.6344138170229474e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 155, \"value\": -1.5408331635385538e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 156, \"value\": 3.6696610414211614e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 157, \"value\": -1.0365814506163943e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 158, \"value\": 2.9007932161558995e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 159, \"value\": -7.938272488996672e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 160, \"value\": 2.126453209453703e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 161, \"value\": -5.579440622058307e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 162, \"value\": 1.4335617038926814e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 163, \"value\": -3.602492412260668e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 164, \"value\": 8.833138837731809e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 165, \"value\": -2.104730893326027e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 166, \"value\": 4.840915297440261e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 167, \"value\": -1.0623468882187711e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 168, \"value\": 2.176380281210984e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 169, \"value\": -3.9655766968381626e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 170, \"value\": 5.515596082749392e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 171, \"value\": -7.486328545495689e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 172, \"value\": -0.00031227639171171277}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 173, \"value\": 0.0012085040798019886}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 174, \"value\": 0.003928886151647144}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 175, \"value\": 0.21699011371658786}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 176, \"value\": 0.3307613728723614}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 177, \"value\": 0.1731513413163132}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 178, \"value\": 0.09407408079446422}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 179, \"value\": 0.21984784964562967}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 180, \"value\": 0.21598524851651332}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 181, \"value\": 0.07886814391425552}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 182, \"value\": -0.03625102175172669}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 183, \"value\": -0.05713100155204037}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 184, \"value\": -0.03815058701714815}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 185, \"value\": -0.020055698978950515}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 186, \"value\": -0.007184310282509622}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 187, \"value\": -0.0011783522262347088}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 188, \"value\": 0.0005457463214229754}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 189, \"value\": 0.0005594924437905566}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 190, \"value\": 0.0003245685610134599}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 191, \"value\": 0.00015505266934456527}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 192, \"value\": 4.937909861403895e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 193, \"value\": 8.269956294135815e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 194, \"value\": -1.9361557512323393e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 195, \"value\": 1.2248501038300587e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 196, \"value\": -1.6305669139919794e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 197, \"value\": 3.0772488134190313e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 198, \"value\": -5.923285566732632e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 199, \"value\": 9.623971657751421e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 200, \"value\": -1.0090992625853173e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 201, \"value\": 1.7107313551213992e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 202, \"value\": -0.0008655382805445171}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 203, \"value\": -0.012692002338653717}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 204, \"value\": -0.018163925987063442}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 205, \"value\": -0.008872561957435483}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 206, \"value\": -0.0018295850678613698}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 207, \"value\": 0.00107345405195023}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 208, \"value\": 0.0017298293651865848}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 209, \"value\": 0.0013470683213019693}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 210, \"value\": 0.0007618250990399937}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 211, \"value\": 0.0003415596094171423}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 212, \"value\": 0.0001285733231437903}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 213, \"value\": 4.1968557577673244e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 214, \"value\": 1.1157678967416061e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 215, \"value\": 9.01380859966063e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 216, \"value\": -8.739623708083239e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 217, \"value\": 2.19865299845949e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 218, \"value\": -1.2085940469559844e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 219, \"value\": 6.390925004650835e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 220, \"value\": -3.0307039903494843e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 221, \"value\": 1.3507263119291163e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 222, \"value\": -5.777349464200253e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 223, \"value\": 2.3935524784287077e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 224, \"value\": -9.656299989173335e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 225, \"value\": 3.80593628312895e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 226, \"value\": -1.468961916079119e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 227, \"value\": 5.568906559762941e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 228, \"value\": -2.095081196949104e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 229, \"value\": 7.996865023869968e-13}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 230, \"value\": -2.619208109568219e-13}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 231, \"value\": -3.127401430279575e-13}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 232, \"value\": 2.0713639944450816e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 233, \"value\": -8.170009637096742e-12}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 234, \"value\": 2.810168841630977e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 235, \"value\": -8.98826032920912e-11}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 236, \"value\": 2.738777007383191e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 237, \"value\": -8.048767928198162e-10}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 238, \"value\": 2.297458778926424e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 239, \"value\": -6.396504341232871e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 240, \"value\": 1.7413854772459104e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 241, \"value\": -4.641591001224642e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 242, \"value\": 1.2117357766400257e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 243, \"value\": -3.096474622921197e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 244, \"value\": 7.72960541633658e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 245, \"value\": -1.8812750765545384e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 246, \"value\": 4.445320340259149e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 247, \"value\": -1.0107348252639979e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 248, \"value\": 2.1374489662479342e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 249, \"value\": -4.13355016239947e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 250, \"value\": 9.840398053946416e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 251, \"value\": -0.0014778310758119344}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 252, \"value\": -0.013289571578544362}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 253, \"value\": -0.01587698009655145}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 254, \"value\": -0.008851239369606375}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 255, \"value\": -0.011607389879890172}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 256, \"value\": -0.008455074051231243}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 257, \"value\": -0.002195759406921545}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 258, \"value\": 0.0013130658631112545}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 259, \"value\": -0.0038703512872835092}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 260, \"value\": -0.02281610104754061}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 261, \"value\": -0.022085237339292865}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 262, \"value\": -0.007379968198114581}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 263, \"value\": 0.007263759590274232}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 264, \"value\": 0.003512895645051085}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 265, \"value\": 0.026475904259224046}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 266, \"value\": 0.04613825172556932}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 267, \"value\": 7.657466648250031e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 268, \"value\": -0.02270699206561733}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 269, \"value\": -0.013990126295512367}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 270, \"value\": -0.00620282068639361}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 271, \"value\": -0.0013172240841215158}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 272, \"value\": 0.0007793938088387166}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 273, \"value\": 0.001157390357160432}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 274, \"value\": 0.0007153838359826961}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 275, \"value\": 0.0005085610406356481}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 276, \"value\": -0.00022962635880497634}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 277, \"value\": 0.001018899895958779}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 278, \"value\": -0.0023095882231975954}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 279, \"value\": 0.030365968846345934}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 280, \"value\": 0.09848521656086014}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 281, \"value\": 0.09802964115445754}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 282, \"value\": 0.05251920513898394}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 283, \"value\": 0.01156237436132791}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 284, \"value\": -0.006504469078604726}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 285, \"value\": -0.010906179638244315}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 286, \"value\": -0.007434409983149764}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 287, \"value\": -0.00686875084312782}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 288, \"value\": 0.0027955872148878605}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 289, \"value\": -0.013827193802341153}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 290, \"value\": 0.09226210784808761}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 291, \"value\": 0.39483443314428013}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 292, \"value\": 0.39045010832956367}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 293, \"value\": 1.1084970035290467}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 294, \"value\": 1.3162651358995276}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 295, \"value\": 0.5708292121911831}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 296, \"value\": 0.08592313116417326}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 297, \"value\": -0.10474904904176266}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 298, \"value\": -0.14035564333193692}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 299, \"value\": 0.002327526878771507}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 300, \"value\": 0.17861965361176213}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 301, \"value\": 0.1158015645790158}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 302, \"value\": 0.041506446827700855}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 303, \"value\": 0.15826383926729165}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 304, \"value\": 0.3129329717195225}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 305, \"value\": 0.213734626479562}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 306, \"value\": 0.06105709974517426}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 307, \"value\": -0.010680243544662326}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 308, \"value\": -0.03299031842862613}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 309, \"value\": -0.02945127335726338}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 310, \"value\": -0.018439998460216517}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 311, \"value\": -0.008993588616309065}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 312, \"value\": -0.0035999829093578675}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 313, \"value\": -0.0013781348152671334}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 314, \"value\": -0.00011312464302183471}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 315, \"value\": -0.001569964302025884}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 316, \"value\": -0.006801645766429569}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 317, \"value\": -0.009250570096248672}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 318, \"value\": 0.002284517871334296}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 319, \"value\": -0.024365342632645507}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 320, \"value\": -0.017416261008744674}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 321, \"value\": 0.3334467329065738}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 322, \"value\": 0.5566879952194089}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 323, \"value\": 0.4222620883846284}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 324, \"value\": 0.1609123161867113}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 325, \"value\": -0.008728983948252415}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 326, \"value\": -0.06051371797925529}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 327, \"value\": -0.05563195352104683}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 328, \"value\": -0.03467229465173364}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 329, \"value\": -0.01670712198304807}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 330, \"value\": -0.006367394789347671}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 331, \"value\": -0.001961492155745848}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 332, \"value\": -0.0004294315330704038}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 333, \"value\": 2.6118932267655904e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 334, \"value\": 5.0128765049281655e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 335, \"value\": 2.2862430041600246e-05}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 336, \"value\": 2.4391112509993625e-06}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 337, \"value\": 3.178614161294348e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 338, \"value\": -1.214830045507343e-07}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 339, \"value\": 4.449390297511334e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 340, \"value\": -1.6456002966515785e-08}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 341, \"value\": 6.061759716969916e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 342, \"value\": -2.1070091297088777e-09}, {\"regressor\": \"massiveauditorylexicaldecision_NumPhones\", \"scan_number\": 343, \"value\": -4.2023579720734506e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 0, \"value\": 8.646943699893805e-12}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 1, \"value\": -2.0262331269896517e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 2, \"value\": 4.561544524127852e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 3, \"value\": -9.713473251466403e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 4, \"value\": 1.8960910581093822e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 5, \"value\": -3.1362576237035875e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 6, \"value\": 3.1671135119600427e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 7, \"value\": 5.328929478262706e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 8, \"value\": -4.997992535610781e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 9, \"value\": 2.2419959224723454e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 10, \"value\": -8.236748846223298e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 11, \"value\": 2.742722535929154e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 12, \"value\": -8.594351206678987e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 13, \"value\": 2.58009341932836e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 14, \"value\": -7.493778467509606e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 15, \"value\": 2.1161733592901397e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 16, \"value\": -5.83454698691479e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 17, \"value\": 0.0001575089862751637}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 18, \"value\": -0.0004167475243969751}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 19, \"value\": 0.0010631511686400438}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 20, \"value\": -0.002571854486260685}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 21, \"value\": 0.006106403685880515}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 22, \"value\": -0.0774298092675694}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 23, \"value\": -0.3205195692287089}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 24, \"value\": -0.25885788045351416}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 25, \"value\": 0.06475805495469218}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 26, \"value\": 0.3186290697293235}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 27, \"value\": 0.6203987408108032}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 28, \"value\": 0.7397531328644942}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 29, \"value\": 0.518520555316442}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 30, \"value\": 0.1296465086835973}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 31, \"value\": -0.05307392505175158}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 32, \"value\": -0.08080392625761086}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 33, \"value\": -0.04154102917034829}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 34, \"value\": -0.08485116336248834}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 35, \"value\": -0.0901530941571899}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 36, \"value\": -0.039186569251445785}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 37, \"value\": -0.010226073635269652}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 38, \"value\": 0.0027756422051240935}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 39, \"value\": 0.005784422262538749}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 40, \"value\": 0.005253031997209714}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 41, \"value\": 0.001542563201919052}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 42, \"value\": 0.004210440679434084}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 43, \"value\": -0.004090787798546862}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 44, \"value\": 0.16998701937838154}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 45, \"value\": 0.5120463922460949}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 46, \"value\": 0.4859881090152807}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 47, \"value\": 0.20220731781334356}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 48, \"value\": 0.10223879301431334}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 49, \"value\": 0.0620927142598771}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 50, \"value\": 0.1333971490157709}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 51, \"value\": 0.22086885445347176}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 52, \"value\": 0.15656917511942042}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 53, \"value\": 0.07684149019583233}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 54, \"value\": 0.4631425751139836}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 55, \"value\": 1.0306558977274456}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 56, \"value\": 1.0062396688252762}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 57, \"value\": 0.5848997647490988}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 58, \"value\": 0.10217723703642903}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 59, \"value\": -0.12348438886700705}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 60, \"value\": -0.23096548870555725}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 61, \"value\": -0.14651265551170803}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 62, \"value\": 0.08043701865596731}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 63, \"value\": 0.13729119971186338}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 64, \"value\": 0.06697090899647978}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 65, \"value\": -0.011771392135286047}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 66, \"value\": -0.034101551076270345}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 67, \"value\": -0.0599493880153179}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 68, \"value\": -0.11923024186486166}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 69, \"value\": -0.05389391964790655}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 70, \"value\": 0.11746497406880504}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 71, \"value\": 0.1309842886067086}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 72, \"value\": 0.05530681239901659}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 73, \"value\": 0.014456525588300819}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 74, \"value\": -0.02071270530294644}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 75, \"value\": -0.11878829953094376}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 76, \"value\": -0.07132353423090201}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 77, \"value\": 0.014733744740427669}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 78, \"value\": 0.3283533136969685}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 79, \"value\": 1.1900798057474589}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 80, \"value\": 1.0158155302833558}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 81, \"value\": 0.5971272548825324}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 82, \"value\": 0.41296210137927486}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 83, \"value\": 0.1080933116485057}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 84, \"value\": -0.056362126959717845}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 85, \"value\": -0.09097579332513074}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 86, \"value\": -0.0756399539459585}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 87, \"value\": -0.042318595631713675}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 88, \"value\": -0.05472091114946289}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 89, \"value\": -0.17160743866976347}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 90, \"value\": -0.14391514824947502}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 91, \"value\": -0.052265329954398206}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 92, \"value\": -0.0013327734269333923}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 93, \"value\": -0.033673300177798605}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 94, \"value\": 0.0170168015946093}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 95, \"value\": 0.08893427243060609}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 96, \"value\": 0.04061575417022763}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 97, \"value\": 0.008647752344374763}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 98, \"value\": 0.0030840165908897718}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 99, \"value\": -0.0513197889404111}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 100, \"value\": -0.08769785613554841}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 101, \"value\": 0.12597354902442884}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 102, \"value\": 0.17920411556563964}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 103, \"value\": -0.0069486104382374785}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 104, \"value\": -0.022012361432345896}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 105, \"value\": -0.060906767121062216}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 106, \"value\": -0.08147857709486717}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 107, \"value\": 0.1010191539066336}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 108, \"value\": 0.12569712456515145}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 109, \"value\": 0.02321571327651912}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 110, \"value\": -0.04269001684994124}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 111, \"value\": 0.11510118200920946}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 112, \"value\": 0.20883340416958313}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 113, \"value\": 0.1243920153466573}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 114, \"value\": 0.03805413381164868}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 115, \"value\": -0.0069802943631673345}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 116, \"value\": -0.01734695088982103}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 117, \"value\": -0.02564798933680384}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 118, \"value\": -0.0050062955152176845}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 119, \"value\": 0.06852402378643838}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 120, \"value\": 0.053438603191714194}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 121, \"value\": 0.017611318649006558}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 122, \"value\": 0.0006087664129021527}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 123, \"value\": -0.005948167933786636}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 124, \"value\": -0.006013910634690334}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 125, \"value\": -0.004125925231950698}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 126, \"value\": -0.0016658199521399858}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 127, \"value\": -0.0016728786965719245}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 128, \"value\": 0.0019638196706549646}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 129, \"value\": -0.012757157567691578}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 130, \"value\": -0.014759487601784528}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 131, \"value\": -0.04790592551211587}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 132, \"value\": -0.1818240666461769}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 133, \"value\": -0.1465862802103235}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 134, \"value\": -0.04964364911808056}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 135, \"value\": -0.0015016767518345477}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 136, \"value\": 0.016229915846919154}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 137, \"value\": 0.016554318639657752}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 138, \"value\": 0.011027690374431949}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 139, \"value\": 0.005567760211445361}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 140, \"value\": 0.0023155987313291503}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 141, \"value\": 0.000810713712532926}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 142, \"value\": 0.00025803419768934263}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 143, \"value\": 4.520138869790445e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 144, \"value\": -4.841058814627449e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 145, \"value\": 1.759181102163226e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 146, \"value\": -6.894001078935531e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 147, \"value\": 2.624828271655398e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 148, \"value\": -9.641426662867676e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 149, \"value\": 3.4618175740800966e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 150, \"value\": -1.212982785480955e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 151, \"value\": 4.127788796882724e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 152, \"value\": -1.352359715242303e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 153, \"value\": 4.153942635437545e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 154, \"value\": -1.0083254967805292e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 155, \"value\": -2.6049169141532743e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 156, \"value\": 1.3785256677348655e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 157, \"value\": -3.4910015381165163e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 158, \"value\": 8.213274699607143e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 159, \"value\": -1.8545513810500846e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 160, \"value\": 3.96930291959541e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 161, \"value\": -7.817184807613755e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 162, \"value\": 1.3178796851047021e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 163, \"value\": -1.4359232060129553e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 164, \"value\": -1.6895506352198036e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 165, \"value\": 1.8860306722398634e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 166, \"value\": -8.684555743415161e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 167, \"value\": 3.2251946810477965e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 168, \"value\": -1.080473253852718e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 169, \"value\": 3.402952552423008e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 170, \"value\": -0.00010297055886338951}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 171, \"value\": 0.0002961771369664109}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 172, \"value\": -0.0007715067027121297}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 173, \"value\": 0.0012319309383409525}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 174, \"value\": -0.031071341954167463}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 175, \"value\": -0.05477931057074375}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 176, \"value\": 0.018528859164714043}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 177, \"value\": 0.0315161715788582}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 178, \"value\": 0.12074215698566342}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 179, \"value\": 0.32632916061644907}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 180, \"value\": 0.2586385190472776}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 181, \"value\": 0.15803626923920386}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 182, \"value\": 0.06824594219673609}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 183, \"value\": -0.008184179132353291}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 184, \"value\": -0.028079717688380225}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 185, \"value\": -0.025908233877505824}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 186, \"value\": -0.016581917099743392}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 187, \"value\": -0.008631903582496802}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 188, \"value\": -0.0037057277798837047}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 189, \"value\": -0.0013782257084277339}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 190, \"value\": -0.0003962610870052973}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 191, \"value\": -9.290613118776765e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 192, \"value\": -2.020198670508668e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 193, \"value\": 6.864260079533841e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 194, \"value\": -1.7598984407302522e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 195, \"value\": 2.528803921278869e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 196, \"value\": 9.628332174482293e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 197, \"value\": -3.1874627700760142e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 198, \"value\": 8.661883125126017e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 199, \"value\": -2.2915205064652504e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 200, \"value\": 5.684227419316814e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 201, \"value\": -0.00010645159942907594}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 202, \"value\": -0.000601486586820612}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 203, \"value\": -0.017376505865099923}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 204, \"value\": -0.06246748659902108}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 205, \"value\": -0.06406388608664666}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 206, \"value\": -0.027163455209829587}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 207, \"value\": -0.00386397433802119}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 208, \"value\": 0.005391529393706098}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 209, \"value\": 0.00672241653141834}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 210, \"value\": 0.0048548155210401895}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 211, \"value\": 0.0026205151523821277}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 212, \"value\": 0.001145074447950918}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 213, \"value\": 0.0004235129239786503}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 214, \"value\": 0.0001362544216545964}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 215, \"value\": 3.226437683915845e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 216, \"value\": 9.379296624349268e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 217, \"value\": 2.299992120927685e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 218, \"value\": -8.40773179686417e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 219, \"value\": 2.2412539671869398e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 220, \"value\": -3.889610452647838e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 221, \"value\": -2.39227476399842e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 222, \"value\": 7.306396553592982e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 223, \"value\": -5.131239584812956e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 224, \"value\": 2.7983066091259533e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 225, \"value\": -1.3621085738648593e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 226, \"value\": 6.210387110497311e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 227, \"value\": -2.732260112033639e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 228, \"value\": 1.2189808213849628e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 229, \"value\": -6.32287534152054e-12}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 230, \"value\": 4.4594707454353e-12}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 231, \"value\": -2.425848726913971e-12}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 232, \"value\": -9.13929864591557e-12}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 233, \"value\": 6.106412302130987e-11}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 234, \"value\": -2.5414292342817963e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 235, \"value\": 9.022818891943511e-10}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 236, \"value\": -2.9444493541259106e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 237, \"value\": 9.100250299674512e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 238, \"value\": -2.7038135331542897e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 239, \"value\": 7.787713746863523e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 240, \"value\": -2.185312605453814e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 241, \"value\": 5.992104091219377e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 242, \"value\": -1.608133484130642e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 243, \"value\": 4.226714130868821e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 244, \"value\": -1.0870017359110735e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 245, \"value\": 2.7346866612434116e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 246, \"value\": -6.716257500156961e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 247, \"value\": 0.00016026407724756812}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 248, \"value\": -0.00036501164450849133}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 249, \"value\": 0.00079143618851833}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 250, \"value\": -0.001916955024324269}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 251, \"value\": 0.01592749989199337}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 252, \"value\": 0.11679200832152219}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 253, \"value\": 0.10527935222858609}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 254, \"value\": 0.03143080148488736}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 255, \"value\": -0.01633409861873671}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 256, \"value\": -0.02797513714754602}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 257, \"value\": -0.017185176306961394}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 258, \"value\": -0.008585121530364077}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 259, \"value\": -0.0037527163564280938}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 260, \"value\": -0.04242890519245457}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 261, \"value\": -0.09789672984584596}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 262, \"value\": -0.06930126498432496}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 263, \"value\": -0.019004376070185305}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 264, \"value\": 0.022235080421878644}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 265, \"value\": 0.10132364531595037}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 266, \"value\": 0.1373214751048741}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 267, \"value\": 0.045253063710698836}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 268, \"value\": -0.013180991793569817}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 269, \"value\": -0.018895412777862015}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 270, \"value\": -0.014384586874600324}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 271, \"value\": -0.007633803378707585}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 272, \"value\": -0.0028058266628240144}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 273, \"value\": -0.000401289824426753}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 274, \"value\": 3.388821834211654e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 275, \"value\": 0.0006208417602293335}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 276, \"value\": -0.0010951641630218038}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 277, \"value\": 0.0030832959105329062}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 278, \"value\": -0.007294536568024764}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 279, \"value\": 0.07985073236411977}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 280, \"value\": 0.21704514870567643}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 281, \"value\": 0.07920067599349362}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 282, \"value\": -0.02908563838571225}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 283, \"value\": -0.034067941826532035}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 284, \"value\": -0.024364401738634214}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 285, \"value\": -0.012474971990098454}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 286, \"value\": -0.0035572909172125826}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 287, \"value\": -0.0012202798463638062}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 288, \"value\": 0.0033959938341470825}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 289, \"value\": -0.006886652202679347}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 290, \"value\": 0.03130599739445369}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 291, \"value\": 0.08368963877934554}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 292, \"value\": -0.0025323329676296604}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 293, \"value\": 0.5502058905670991}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 294, \"value\": 0.8165663807091065}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 295, \"value\": 0.3895826273501456}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 296, \"value\": 0.08285004157152545}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 297, \"value\": -0.04139383286862854}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 298, \"value\": -0.08363481885419123}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 299, \"value\": 0.22382836086057223}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 300, \"value\": 0.5347204691894573}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 301, \"value\": 0.29495947451263793}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 302, \"value\": 0.05665707228206162}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 303, \"value\": -0.08818043483074678}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 304, \"value\": -0.25022966129221746}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 305, \"value\": -0.2177006533601356}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 306, \"value\": -0.08928808234786693}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 307, \"value\": -0.01607647003458911}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 308, \"value\": 0.01345649000826595}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 309, \"value\": 0.017839966061682387}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 310, \"value\": 0.012778739244759538}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 311, \"value\": 0.006781605543857365}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 312, \"value\": 0.0029428649115306694}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 313, \"value\": 0.0009233608541281451}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 314, \"value\": 0.0005937467043994248}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 315, \"value\": -0.0021903877224972914}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 316, \"value\": -0.014596731312373693}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 317, \"value\": -0.013835907803999627}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 318, \"value\": -0.004815151881637225}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 319, \"value\": 0.009878099093615112}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 320, \"value\": 0.04946761162138009}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 321, \"value\": 0.1612393214010506}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 322, \"value\": 0.26952136657732517}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 323, \"value\": 0.172166616245559}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 324, \"value\": 0.028856335153214147}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 325, \"value\": -0.03975753765131286}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 326, \"value\": -0.04497098095268328}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 327, \"value\": -0.028140971696618566}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 328, \"value\": -0.013008924779633942}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 329, \"value\": -0.003846538933224123}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 330, \"value\": -0.00018069726435145016}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 331, \"value\": 0.0006140542473099485}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 332, \"value\": 0.00046741347097457826}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 333, \"value\": 0.00025388837597287704}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 334, \"value\": 0.00010637009215333755}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 335, \"value\": 2.739079634018482e-05}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 336, \"value\": 4.399512023744401e-06}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 337, \"value\": -4.710717538608797e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 338, \"value\": 1.7374160091416772e-07}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 339, \"value\": -6.785077914952038e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 340, \"value\": 2.581896265342395e-08}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 341, \"value\": -9.452163796505202e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 342, \"value\": 3.2531972702418787e-09}, {\"regressor\": \"massiveauditorylexicaldecision_Duration\", \"scan_number\": 343, \"value\": 1.510556053346797e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 0, \"value\": -7.706615949992308e-12}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 1, \"value\": 1.876375384933192e-11}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 2, \"value\": -4.4340034339837654e-11}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 3, \"value\": 1.0092107535784054e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 4, \"value\": -2.1830551429366913e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 5, \"value\": 4.3725634258613296e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 6, \"value\": -7.629329051002058e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 7, \"value\": 9.377076811335456e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 8, \"value\": 4.2199130020123227e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 9, \"value\": -8.754218442452266e-09}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 10, \"value\": 4.284240113578453e-08}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 11, \"value\": -1.629627897001602e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 12, \"value\": 5.532341437252351e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 13, \"value\": -1.755795665644843e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 14, \"value\": 5.3205805040390244e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 15, \"value\": -1.5554242643655386e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 16, \"value\": 4.4191062732971444e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 17, \"value\": -0.00012260842694231344}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 18, \"value\": 0.00033304699645865163}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 19, \"value\": -0.0008726381430821024}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 20, \"value\": 0.002164929876888129}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 21, \"value\": -0.0051604638500436515}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 22, \"value\": 0.06380027938645588}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 23, \"value\": 0.22561318766297908}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 24, \"value\": 0.16851341797072156}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 25, \"value\": -0.010071124583329663}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 26, \"value\": -0.13922444223314004}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 27, \"value\": -0.19643664333705838}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 28, \"value\": -0.3003549386975029}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 29, \"value\": -0.11557353133624129}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 30, \"value\": 0.09481551499505825}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 31, \"value\": 0.08451219115438631}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 32, \"value\": 0.07261306013686881}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 33, \"value\": 0.08453474403784218}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 34, \"value\": 0.057228647772507676}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 35, \"value\": 0.016648010319388118}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 36, \"value\": -0.002510193736318451}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 37, \"value\": -0.007862956403408856}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 38, \"value\": -0.007064830115647833}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 39, \"value\": -0.004498501133771625}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 40, \"value\": -0.0022997371680720706}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 41, \"value\": -0.0007343363420588967}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 42, \"value\": -0.00048800040809148795}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 43, \"value\": 0.0011788760262898949}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 44, \"value\": -0.07307882596383217}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 45, \"value\": -0.19072070646365877}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 46, \"value\": -0.03267176433636216}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 47, \"value\": 0.14794945791554026}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 48, \"value\": 0.07733082227482156}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 49, \"value\": -0.03348258514818637}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 50, \"value\": -0.1464651182157442}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 51, \"value\": -0.19289600778379418}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 52, \"value\": -0.2562331156298766}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 53, \"value\": -0.21227078371536798}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 54, \"value\": -0.15480644777982858}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 55, \"value\": -0.060462775084557385}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 56, \"value\": -0.04993343257375864}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 57, \"value\": -0.05929436153072472}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 58, \"value\": -0.08773598045624983}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 59, \"value\": -0.13269372370511656}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 60, \"value\": -0.09181793034547464}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 61, \"value\": -0.0745230824118121}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 62, \"value\": 0.14665804795736234}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 63, \"value\": 0.3822887185450429}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 64, \"value\": 0.25856402224678365}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 65, \"value\": 0.14604228346519285}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 66, \"value\": 0.13104213575286539}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 67, \"value\": 0.18413415211872539}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 68, \"value\": 0.11923819841473451}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 69, \"value\": 0.07391655030287501}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 70, \"value\": 0.09288442041398391}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 71, \"value\": 0.04431578120068514}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 72, \"value\": -1.7206969664710777e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 73, \"value\": -0.013463904499163848}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 74, \"value\": -0.024567684454299323}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 75, \"value\": -0.046416698226318706}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 76, \"value\": -0.09990528862035811}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 77, \"value\": -0.12811408825947584}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 78, \"value\": -0.14770573206027926}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 79, \"value\": -0.2578371068017603}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 80, \"value\": -0.2548829704410047}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 81, \"value\": -0.19873469290051024}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 82, \"value\": -0.08849642031381935}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 83, \"value\": -0.007983092946565535}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 84, \"value\": 0.023751461936809132}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 85, \"value\": 0.02773268236391326}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 86, \"value\": 0.0196458661209806}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 87, \"value\": 0.011677924717131213}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 88, \"value\": 0.0010931150611768912}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 89, \"value\": -0.018938901128368303}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 90, \"value\": -0.017945482367740115}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 91, \"value\": -0.005577328463604985}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 92, \"value\": -0.0023036074639143068}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 93, \"value\": 0.024786803548869668}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 94, \"value\": 0.014075088289316482}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 95, \"value\": 0.00924558575654945}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 96, \"value\": 0.04798342354990708}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 97, \"value\": 0.036984717489413885}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 98, \"value\": 0.01315786873718542}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 99, \"value\": -0.014645442852159175}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 100, \"value\": -0.09932205057530658}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 101, \"value\": -0.11368377280479113}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 102, \"value\": 0.019276701503557283}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 103, \"value\": 0.12403163056523221}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 104, \"value\": 0.12281025715443329}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 105, \"value\": -0.007072959703369876}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 106, \"value\": -0.04079344730115379}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 107, \"value\": 0.010343808909873211}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 108, \"value\": 0.006941203885931015}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 109, \"value\": -0.011201569653733019}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 110, \"value\": -0.057866266618200116}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 111, \"value\": -0.16147480093859135}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 112, \"value\": -0.18734544976143278}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 113, \"value\": -0.10793750186497851}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 114, \"value\": -0.02832650013571146}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 115, \"value\": 0.009516745142681905}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 116, \"value\": 0.020115168685193092}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 117, \"value\": 0.015364101491386886}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 118, \"value\": 0.067287030914861}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 119, \"value\": 0.09993739464446728}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 120, \"value\": 0.05019409658344756}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 121, \"value\": 0.012124886051449003}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 122, \"value\": -0.004463256008534738}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 123, \"value\": -0.008674038337943429}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 124, \"value\": -0.007074183485046163}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 125, \"value\": -0.004001618809421026}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 126, \"value\": -0.0021050640907201417}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 127, \"value\": -2.2565003612619323e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 128, \"value\": -0.002133282901672153}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 129, \"value\": 0.008694181914760799}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 130, \"value\": -0.016468325758674383}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 131, \"value\": -0.0007519350189861215}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 132, \"value\": 0.07522558400877212}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 133, \"value\": 0.052026646643969165}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 134, \"value\": 0.017443471174154616}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 135, \"value\": 0.0006937054935476082}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 136, \"value\": -0.00561520608157389}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 137, \"value\": -0.005765606222671897}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 138, \"value\": -0.0037816558906129637}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 139, \"value\": -0.0018616990825284186}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 140, \"value\": -0.0007558707878372823}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 141, \"value\": -0.0002573280517762465}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 142, \"value\": -8.797737203274021e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 143, \"value\": -6.8467673508780316e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 144, \"value\": 1.0457539207494028e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 145, \"value\": -4.320349028505294e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 146, \"value\": 1.8915697806807125e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 147, \"value\": -3.925390499598809e-08}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 148, \"value\": -1.0873474437227717e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 149, \"value\": 3.713121218430407e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 150, \"value\": -9.758573598978681e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 151, \"value\": 2.4242082298598864e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 152, \"value\": -5.831453701883478e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 153, \"value\": 1.3547955430356942e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 154, \"value\": -2.9718282007723105e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 155, \"value\": 6.12357260494235e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 156, \"value\": -0.0001465242462178738}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 157, \"value\": 0.0014035778866148519}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 158, \"value\": 0.012243817185748861}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 159, \"value\": 0.012808471723779212}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 160, \"value\": 0.00501645734638798}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 161, \"value\": 0.0007012590563680089}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 162, \"value\": -0.0010600247972262296}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 163, \"value\": -0.0012873329014145769}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 164, \"value\": -0.0009221519903439391}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 165, \"value\": -0.0004885416781014913}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 166, \"value\": -0.00021042360281248374}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 167, \"value\": -7.653910402145263e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 168, \"value\": -2.156568484502976e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 169, \"value\": -1.8699806764194216e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 170, \"value\": 4.8847731797232595e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 171, \"value\": -0.0001590562939453489}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 172, \"value\": 0.00046493474388380445}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 173, \"value\": -0.0008995786055721531}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 174, \"value\": 0.018722773538632647}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 175, \"value\": 0.04947541373808951}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 176, \"value\": 0.1449021543053231}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 177, \"value\": 0.17969239729689512}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 178, \"value\": 0.15797920381741923}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 179, \"value\": 0.23054753656223423}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 180, \"value\": 0.18822008953670458}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 181, \"value\": -0.0956314221647582}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 182, \"value\": -0.19457406602541297}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 183, \"value\": -0.1110691965581128}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 184, \"value\": -0.04149796855657061}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 185, \"value\": -0.0038770509160746514}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 186, \"value\": 0.009766671503263675}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 187, \"value\": 0.010225452782230495}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 188, \"value\": 0.006348748402217888}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 189, \"value\": 0.0029750910842946472}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 190, \"value\": 0.001165927539633649}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 191, \"value\": 0.00041677916408220473}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 192, \"value\": 0.0001007947805664194}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 193, \"value\": -5.583161435227917e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 194, \"value\": 3.1753444446204407e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 195, \"value\": 1.5330605598949955e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 196, \"value\": -4.797433407630494e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 197, \"value\": 1.2139592430851931e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 198, \"value\": -2.9225062089253923e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 199, \"value\": 6.710938944852884e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 200, \"value\": -0.00014586185056735017}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 201, \"value\": 0.00034377040605148147}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 202, \"value\": -0.0028676498489908697}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 203, \"value\": -0.016843084347579303}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 204, \"value\": 0.0007411122938095222}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 205, \"value\": 0.017903583543563733}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 206, \"value\": 0.010878522946703047}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 207, \"value\": 0.0040155987249235105}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 208, \"value\": 0.0003223778754059527}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 209, \"value\": -0.0010716882525888833}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 210, \"value\": -0.0011543131940732723}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 211, \"value\": -0.0007424267413589638}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 212, \"value\": -0.0003595017093890762}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 213, \"value\": -0.00014182992396790037}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 214, \"value\": -5.047959900814546e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 215, \"value\": -1.5856214396317264e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 216, \"value\": 8.52924949866441e-09}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 217, \"value\": -1.4757208892227033e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 218, \"value\": 5.002632760308585e-08}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 219, \"value\": -1.2088673067763961e-08}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 220, \"value\": 1.509391573244231e-09}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 221, \"value\": 5.680269115289641e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 222, \"value\": -6.389478094056028e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 223, \"value\": 3.97351435042968e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 224, \"value\": -2.0619708187071444e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 225, \"value\": 9.75993639067231e-11}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 226, \"value\": -4.3664068567904866e-11}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 227, \"value\": 1.891867755326495e-11}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 228, \"value\": -8.323250425434998e-12}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 229, \"value\": 4.356667840583815e-12}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 230, \"value\": -3.5851273705884497e-12}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 231, \"value\": 4.193929689790699e-12}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 232, \"value\": -3.19594678727383e-12}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 233, \"value\": -1.0100650771192725e-11}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 234, \"value\": 7.419968820667355e-11}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 235, \"value\": -3.171668273582621e-10}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 236, \"value\": 1.1406241225962682e-09}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 237, \"value\": -3.751161877103224e-09}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 238, \"value\": 1.1655575678649746e-08}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 239, \"value\": -3.477068127303647e-08}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 240, \"value\": 1.0047859887632223e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 241, \"value\": -2.827510542161347e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 242, \"value\": 7.772792245016539e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 243, \"value\": -2.090956775851078e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 244, \"value\": 5.504348407882321e-06}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 245, \"value\": -1.4192152040979367e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 246, \"value\": 3.581065963845982e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 247, \"value\": -8.818453479746241e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 248, \"value\": 0.0002089641293895041}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 249, \"value\": -0.00047526640841022893}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 250, \"value\": 0.0011730120238571562}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 251, \"value\": -0.009137133634738979}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 252, \"value\": -0.053302916194225364}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 253, \"value\": -0.0396282030059399}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 254, \"value\": -0.008250658738491711}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 255, \"value\": 0.006971246023945469}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 256, \"value\": 0.010548341112607294}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 257, \"value\": 0.005558513170683249}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 258, \"value\": 0.004663902035424314}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 259, \"value\": -0.009724996919248295}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 260, \"value\": 0.0029445231925107683}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 261, \"value\": 0.08386157377899704}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 262, \"value\": 0.07336879497691436}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 263, \"value\": 0.10246131798025873}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 264, \"value\": 0.1506671182619661}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 265, \"value\": 0.12460914463559847}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 266, \"value\": 0.08733307135042023}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 267, \"value\": 0.05285150734325035}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 268, \"value\": 0.02178137349148591}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 269, \"value\": -0.0044056469758993674}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 270, \"value\": -0.012064482818228325}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 271, \"value\": -0.010967731594955595}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 272, \"value\": -0.007267558521307548}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 273, \"value\": -0.003892538307002584}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 274, \"value\": -0.0018762233390076342}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 275, \"value\": -0.00043152655977342797}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 276, \"value\": -0.0008358903343141221}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 277, \"value\": 0.001407811550266472}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 278, \"value\": -0.00350371607792154}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 279, \"value\": 0.04565768964930494}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 280, \"value\": 0.20288230830620116}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 281, \"value\": 0.21466388781031492}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 282, \"value\": 0.1145019298615119}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 283, \"value\": 0.029810780363235947}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 284, \"value\": -0.012245011051615712}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 285, \"value\": -0.021947244524328915}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 286, \"value\": -0.018077388150595158}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 287, \"value\": -0.009918253281330055}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 288, \"value\": -0.006440360992176023}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 289, \"value\": 0.0007662240326997057}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 290, \"value\": -0.03454011239410136}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 291, \"value\": -0.007719605151175283}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 292, \"value\": 0.1279921025016134}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 293, \"value\": 0.005718830679338207}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 294, \"value\": -0.07394044991842975}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 295, \"value\": -0.04244138496344567}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 296, \"value\": -0.017562408617132336}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 297, \"value\": -0.002544290779107909}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 298, \"value\": 0.004781802223250038}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 299, \"value\": 0.04194870785134926}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 300, \"value\": 0.04714692594807975}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 301, \"value\": 0.05430269901263432}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 302, \"value\": 0.02726789450613916}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 303, \"value\": 0.3005786133236545}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 304, \"value\": 0.817461885155593}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 305, \"value\": 0.5995447760161411}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 306, \"value\": 0.19314611561051187}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 307, \"value\": -0.005130254231954773}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 308, \"value\": -0.07405024818760789}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 309, \"value\": -0.0715359915720581}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 310, \"value\": -0.046310850303743246}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 311, \"value\": -0.0229748542966823}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 312, \"value\": -0.009424869385326832}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 313, \"value\": -0.003298093658427032}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 314, \"value\": -0.000993338882813478}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 315, \"value\": 0.0003697767237215539}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 316, \"value\": 0.006049518997414402}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 317, \"value\": 0.003545294881992104}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 318, \"value\": 0.0050493542471086224}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 319, \"value\": -0.03397860373902349}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 320, \"value\": -0.14136900082532197}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 321, \"value\": 0.08034805681020274}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 322, \"value\": 0.11722682539773058}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 323, \"value\": -0.07409815889828206}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 324, \"value\": -0.16046199247561396}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 325, \"value\": -0.13789610459113988}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 326, \"value\": -0.055403222768098}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 327, \"value\": -0.0060728669342176664}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 328, \"value\": 0.013186170386920406}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 329, \"value\": 0.01494849018796523}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 330, \"value\": 0.010258327902580317}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 331, \"value\": 0.0053023167207412675}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 332, \"value\": 0.0022589630962892827}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 333, \"value\": 0.0008558065956523897}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 334, \"value\": 0.0002388103544103009}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 335, \"value\": 5.564258646445612e-05}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 336, \"value\": -8.680444223098236e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 337, \"value\": 6.505968893108937e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 338, \"value\": -2.0983604873438788e-07}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 339, \"value\": 5.299484636572434e-08}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 340, \"value\": -8.053914644543105e-09}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 341, \"value\": -1.899416995258879e-09}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 342, \"value\": 3.82517102522448e-09}, {\"regressor\": \"concreteness_Conc.M\", \"scan_number\": 343, \"value\": -9.68105882562991e-09}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 0, \"value\": 0.0759852221}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 1, \"value\": 0.0811699214}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 2, \"value\": -0.0114877427}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 3, \"value\": -0.1596911397}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 4, \"value\": -0.09659515960000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 5, \"value\": -0.013694121200000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 6, \"value\": 0.08648681119999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 7, \"value\": 0.054780360199999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 8, \"value\": 0.0492883143}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 9, \"value\": 0.032561608}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 10, \"value\": 0.0054773555}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 11, \"value\": -0.0543271896}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 12, \"value\": 0.0042127956}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 13, \"value\": 0.0333046662}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 14, \"value\": -0.054727723799999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 15, \"value\": -0.1025418859}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 16, \"value\": -0.1349382283}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 17, \"value\": 0.0475470304}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 18, \"value\": 0.1061513698}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 19, \"value\": 0.0631297614}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 20, \"value\": -0.043511581900000006}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 21, \"value\": -0.0847844814}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 22, \"value\": -0.0186113981}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 23, \"value\": 0.06673356400000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 24, \"value\": 0.0777066501}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 25, \"value\": -0.055377891799999995}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 26, \"value\": -0.08677873470000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 27, \"value\": 0.00041193379999999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 28, \"value\": 0.09359871}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 29, \"value\": 0.1051766378}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 30, \"value\": -0.0200202746}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 31, \"value\": -0.0438226184}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 32, \"value\": 0.0633970413}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 33, \"value\": 0.0461632308}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 34, \"value\": -0.04972461}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 35, \"value\": 0.0161691323}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 36, \"value\": 0.0176555078}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 37, \"value\": -0.0601493496}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 38, \"value\": -0.0262021271}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 39, \"value\": 0.0194243495}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 40, \"value\": 0.054621658200000006}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 41, \"value\": -0.04748368309999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 42, \"value\": -0.0162218681}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 43, \"value\": 0.08408395949999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 44, \"value\": -0.0092590791}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 45, \"value\": -0.056444343200000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 46, \"value\": -0.0161039203}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 47, \"value\": 0.0445395713}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 48, \"value\": -0.058280778}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 49, \"value\": -0.024012349500000002}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 50, \"value\": 0.12127607259999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 51, \"value\": -0.0302459485}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 52, \"value\": -0.10607926150000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 53, \"value\": 0.0031783106}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 54, \"value\": -0.0032960859999999997}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 55, \"value\": -0.0338723925}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 56, \"value\": 0.0023413062}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 57, \"value\": 0.0174624766}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 58, \"value\": -0.0149839916}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 59, \"value\": 0.0442710905}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 60, \"value\": 0.0194405504}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 61, \"value\": -0.0315736956}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 62, \"value\": 0.0599781313}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 63, \"value\": -0.0003564157}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 64, \"value\": -0.0711408182}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 65, \"value\": 0.0413675871}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 66, \"value\": -0.017661811399999998}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 67, \"value\": -0.060437701399999995}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 68, \"value\": -0.016129203999999998}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 69, \"value\": -0.08517627119999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 70, \"value\": 0.033701483}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 71, \"value\": 0.0011280497}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 72, \"value\": 0.0743691106}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 73, \"value\": 0.020022734099999998}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 74, \"value\": 0.0065729045}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 75, \"value\": 0.036650692400000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 76, \"value\": -0.0799531269}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 77, \"value\": 0.044159614800000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 78, \"value\": -0.0308901674}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 79, \"value\": 0.0956075835}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 80, \"value\": 0.047945892999999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 81, \"value\": -0.0158916936}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 82, \"value\": -0.0183643507}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 83, \"value\": 0.0047178546}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 84, \"value\": 0.060409440599999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 85, \"value\": -0.0582713385}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 86, \"value\": 0.0062473654000000005}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 87, \"value\": -0.0344823309}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 88, \"value\": 0.0852298178}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 89, \"value\": -0.0196875655}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 90, \"value\": -0.0554087784}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 91, \"value\": -0.045464087}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 92, \"value\": 0.06374799190000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 93, \"value\": 0.0520593259}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 94, \"value\": 0.034191402}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 95, \"value\": -0.0768649983}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 96, \"value\": -0.0188319}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 97, \"value\": 0.0195365038}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 98, \"value\": 0.031106962400000007}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 99, \"value\": 0.025458570299999997}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 100, \"value\": 0.0541055742}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 101, \"value\": -0.0182936878}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 102, \"value\": -0.0131216694}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 103, \"value\": 0.0060211654}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 104, \"value\": -0.011311156200000002}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 105, \"value\": 0.0096006562}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 106, \"value\": -0.1250606593}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 107, \"value\": -0.021569670899999997}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 108, \"value\": -0.06727591320000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 109, \"value\": -0.0331159654}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 110, \"value\": -0.07640415440000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 111, \"value\": -0.07223318990000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 112, \"value\": -0.068176029}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 113, \"value\": -0.05787131490000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 114, \"value\": 0.032265571800000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 115, \"value\": -0.056553886}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 116, \"value\": 0.0413954324}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 117, \"value\": 0.1433874643}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 118, \"value\": 0.0994405339}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 119, \"value\": 0.0049680056}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 120, \"value\": -0.035112841400000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 121, \"value\": 0.0472068038}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 122, \"value\": 0.10358552480000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 123, \"value\": 0.09049316119999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 124, \"value\": 0.0908870587}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 125, \"value\": 0.018488700900000002}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 126, \"value\": 0.0066856954}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 127, \"value\": -0.0025380054}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 128, \"value\": 0.026930599500000003}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 129, \"value\": 0.0394329809}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 130, \"value\": -0.0448371396}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 131, \"value\": -0.022296734300000003}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 132, \"value\": 0.0205679811}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 133, \"value\": 0.024727991499999998}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 134, \"value\": -0.0020791814}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 135, \"value\": -0.0331140532}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 136, \"value\": -0.0415083873}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 137, \"value\": 0.0371309389}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 138, \"value\": -0.0092903268}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 139, \"value\": 0.027687867}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 140, \"value\": -0.101727784}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 141, \"value\": -0.1672400483}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 142, \"value\": -0.09111831199999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 143, \"value\": -0.038621595099999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 144, \"value\": 0.014991343700000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 145, \"value\": -0.04621029769999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 146, \"value\": -0.1254083916}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 147, \"value\": -0.08570091310000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 148, \"value\": 0.0276782132}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 149, \"value\": 0.021344421000000002}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 150, \"value\": 0.051283992199999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 151, \"value\": 0.0069351018}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 152, \"value\": 0.033907121299999995}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 153, \"value\": 0.0624907986}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 154, \"value\": 0.1034305837}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 155, \"value\": 0.0761282792}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 156, \"value\": 0.0772682297}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 157, \"value\": 0.1205876016}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 158, \"value\": 0.0011594902999999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 159, \"value\": -0.004502545399999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 160, \"value\": -0.0029005707}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 161, \"value\": 0.030141770099999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 162, \"value\": 0.0248766081}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 163, \"value\": 0.0376163475}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 164, \"value\": -0.0082587604}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 165, \"value\": -0.0229473702}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 166, \"value\": -0.0318465847}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 167, \"value\": -0.027028472}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 168, \"value\": 0.0258460532}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 169, \"value\": 0.038743243999999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 170, \"value\": -0.068170988}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 171, \"value\": -0.0592423825}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 172, \"value\": -0.1043109281}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 173, \"value\": -0.0302854069}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 174, \"value\": 0.0015456822000000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 175, \"value\": -0.0076229647}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 176, \"value\": -0.0283512452}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 177, \"value\": -0.08706501009999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 178, \"value\": -0.0476942511}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 179, \"value\": -0.0015908510000000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 180, \"value\": 0.030621549100000006}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 181, \"value\": -0.0346989813}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 182, \"value\": -0.057254652300000014}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 183, \"value\": 0.0042427322}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 184, \"value\": 0.060411038}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 185, \"value\": 0.072944959}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 186, \"value\": 0.049390904900000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 187, \"value\": -0.0007286936}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 188, \"value\": 0.035507746800000003}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 189, \"value\": 0.04246381849999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 190, \"value\": 0.0663510209}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 191, \"value\": 0.034332069900000005}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 192, \"value\": 0.019009246}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 193, \"value\": -0.037947523}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 194, \"value\": 0.013683907700000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 195, \"value\": -0.0237015335}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 196, \"value\": 0.0248260564}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 197, \"value\": 0.05396369769999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 198, \"value\": -0.00984778}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 199, \"value\": -0.0233413199}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 200, \"value\": -0.0417880224}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 201, \"value\": 0.0118319483}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 202, \"value\": 0.0305718443}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 203, \"value\": 0.032441111200000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 204, \"value\": 0.0366304902}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 205, \"value\": -0.090551748}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 206, \"value\": -0.0801053144}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 207, \"value\": 0.0157505518}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 208, \"value\": -0.0600333067}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 209, \"value\": -0.0523986408}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 210, \"value\": -0.0388004395}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 211, \"value\": 0.052563667800000005}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 212, \"value\": 0.0224095487}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 213, \"value\": -0.04798447}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 214, \"value\": 0.029639005099999997}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 215, \"value\": -0.0055550298}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 216, \"value\": 0.0403166872}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 217, \"value\": 0.0304938839}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 218, \"value\": -0.055535098600000006}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 219, \"value\": -0.0912292313}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 220, \"value\": -0.0074665895}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 221, \"value\": 0.0129466522}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 222, \"value\": 0.0777177716}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 223, \"value\": 0.0627903058}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 224, \"value\": 0.003560616}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 225, \"value\": 0.0052289395}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 226, \"value\": 0.0209789494}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 227, \"value\": 0.0289921127}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 228, \"value\": 0.0132063345}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 229, \"value\": 0.0262016256}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 230, \"value\": 0.0090430396}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 231, \"value\": -0.0476852623}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 232, \"value\": -0.0462429946}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 233, \"value\": 0.010456381899999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 234, \"value\": 0.0022923203}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 235, \"value\": -0.0053223578}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 236, \"value\": 0.045402760599999994}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 237, \"value\": 0.045966188899999996}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 238, \"value\": 0.0321506512}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 239, \"value\": 0.0659261071}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 240, \"value\": -0.10010262210000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 241, \"value\": -0.0475928419}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 242, \"value\": -0.0327379025}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 243, \"value\": -0.0303780627}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 244, \"value\": -0.0236805622}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 245, \"value\": -0.0819779155}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 246, \"value\": -0.09544371759999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 247, \"value\": -0.0729097309}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 248, \"value\": 0.0029969910999999997}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 249, \"value\": 0.051275652000000005}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 250, \"value\": 0.0007866808}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 251, \"value\": -0.0003370146}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 252, \"value\": 0.00817238}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 253, \"value\": 0.066463941}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 254, \"value\": 0.0643226879}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 255, \"value\": 0.08545438679999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 256, \"value\": 0.0574623133}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 257, \"value\": -0.0023360285999999997}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 258, \"value\": 0.0035347053}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 259, \"value\": 0.0260458752}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 260, \"value\": 0.0459135348}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 261, \"value\": 0.023263575699999997}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 262, \"value\": 0.0165896401}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 263, \"value\": -0.0162718563}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 264, \"value\": 0.0450048679}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 265, \"value\": 0.07074274230000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 266, \"value\": 0.0350097788}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 267, \"value\": -0.0246849019}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 268, \"value\": -0.0821739949}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 269, \"value\": -0.059569324800000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 270, \"value\": -0.003037834}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 271, \"value\": -0.0052955486}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 272, \"value\": -0.0657339586}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 273, \"value\": -0.0367219076}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 274, \"value\": -0.0593438133}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 275, \"value\": -0.0780836081}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 276, \"value\": -0.0819298875}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 277, \"value\": -0.063068473}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 278, \"value\": 0.02008128}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 279, \"value\": 0.0633323301}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 280, \"value\": 0.027330546400000003}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 281, \"value\": 0.0255424353}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 282, \"value\": 0.0377285221}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 283, \"value\": 0.0395129463}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 284, \"value\": 0.005385719200000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 285, \"value\": -0.045066325}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 286, \"value\": -0.04659095940000002}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 287, \"value\": 0.0113524592}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 288, \"value\": 0.0638909147}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 289, \"value\": 0.0323121236}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 290, \"value\": -0.031269032}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 291, \"value\": -0.1134400997}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 292, \"value\": -0.0163946683}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 293, \"value\": 0.0883504747}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 294, \"value\": 0.0645178929}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 295, \"value\": -0.0074761935}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 296, \"value\": -0.0697950306}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 297, \"value\": -0.018131258600000002}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 298, \"value\": 0.0402220691}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 299, \"value\": 0.10337993470000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 300, \"value\": 0.012633406399999998}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 301, \"value\": -0.0309037608}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 302, \"value\": 0.0049811487}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 303, \"value\": 0.043272974699999994}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 304, \"value\": 0.048865286900000006}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 305, \"value\": 0.0355450488}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 306, \"value\": -0.0436535662}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 307, \"value\": 0.010598998799999999}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 308, \"value\": 0.0926616003}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 309, \"value\": 0.0793207662}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 310, \"value\": 0.022143389399999998}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 311, \"value\": -0.04347112980000002}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 312, \"value\": -0.0743860078}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 313, \"value\": -0.0753597879}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 314, \"value\": -0.0213396775}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 315, \"value\": 0.0256782313}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 316, \"value\": -0.0191416596}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 317, \"value\": 0.0090880589}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 318, \"value\": 0.034813876800000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 319, \"value\": -0.0075393728}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 320, \"value\": -0.0096553879}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 321, \"value\": -0.0002577839}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 322, \"value\": -0.0220606523}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 323, \"value\": -0.0351127568}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 324, \"value\": -0.033974380400000004}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 325, \"value\": -0.1057746694}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 326, \"value\": -0.0698710958}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 327, \"value\": -0.0939227633}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 328, \"value\": -0.0673020084}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 329, \"value\": 0.0424118604}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 330, \"value\": -0.0696597192}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 331, \"value\": -0.0437303805}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 332, \"value\": 0.023312754900000003}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 333, \"value\": 0.072065125}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 334, \"value\": 0.10880154560000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 335, \"value\": 0.0575517049}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 336, \"value\": -0.0496806549}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 337, \"value\": -0.0240589305}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 338, \"value\": 0.0310577445}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 339, \"value\": 0.1007545714}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 340, \"value\": 0.0545068109}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 341, \"value\": 0.0073476488}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 342, \"value\": -0.010889885600000001}, {\"regressor\": \"a_comp_cor_00\", \"scan_number\": 343, \"value\": 0.011415173899999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 0, \"value\": -0.0748599512}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 1, \"value\": -0.1014908091}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 2, \"value\": -0.0430991628}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 3, \"value\": 0.0922870727}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 4, \"value\": 0.0565262821}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 5, \"value\": -0.024686093399999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 6, \"value\": -0.0821566758}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 7, \"value\": -0.0562050517}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 8, \"value\": -0.045892082599999995}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 9, \"value\": 0.0094437022}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 10, \"value\": 0.0759281706}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 11, \"value\": 0.0669038626}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 12, \"value\": -0.037074311400000004}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 13, \"value\": -0.05916439990000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 14, \"value\": 0.0250900143}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 15, \"value\": 0.0943539868}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 16, \"value\": 0.10443365710000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 17, \"value\": -0.006155694000000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 18, \"value\": -0.059080721399999994}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 19, \"value\": -0.0212707029}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 20, \"value\": 0.0652765513}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 21, \"value\": 0.15369831949999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 22, \"value\": 0.0405192779}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 23, \"value\": -0.0548612807}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 24, \"value\": -0.06941039759999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 25, \"value\": 0.0796804904}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 26, \"value\": 0.12248970070000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 27, \"value\": 0.000530304}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 28, \"value\": -0.1173561681}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 29, \"value\": -0.0547112264}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 30, \"value\": 0.0723467072}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 31, \"value\": 2.05443e-05}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 32, \"value\": -0.09469941890000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 33, \"value\": 0.0157554597}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 34, \"value\": 0.025957105699999997}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 35, \"value\": -0.07228853}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 36, \"value\": -0.039850851}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 37, \"value\": 0.08611517310000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 38, \"value\": -0.0046520618}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 39, \"value\": -0.08523717619999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 40, \"value\": -0.0807927329}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 41, \"value\": 0.0496699504}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 42, \"value\": 0.06597421889999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 43, \"value\": -0.1100644149}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 44, \"value\": -0.0010370378}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 45, \"value\": 0.0468366142}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 46, \"value\": -0.0228541803}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 47, \"value\": -0.0572227197}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 48, \"value\": 0.0875746053}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 49, \"value\": 0.052709763}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 50, \"value\": -0.0928674223}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 51, \"value\": 0.0604317669}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 52, \"value\": 0.0750506029}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 53, \"value\": -0.0603916567}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 54, \"value\": 0.020857403899999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 55, \"value\": 0.0525900067}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 56, \"value\": -0.0876628545}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 57, \"value\": 0.023210881000000003}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 58, \"value\": 0.060207295099999995}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 59, \"value\": -0.0288127586}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 60, \"value\": -0.0344944021}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 61, \"value\": 0.0759735625}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 62, \"value\": -0.09395691800000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 63, \"value\": -0.0377119469}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 64, \"value\": 0.06522479860000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 65, \"value\": -0.0976454226}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 66, \"value\": 0.0393383574}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 67, \"value\": -0.029955978900000006}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 68, \"value\": -0.060005480199999996}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 69, \"value\": 0.0353262561}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 70, \"value\": -0.0801334863}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 71, \"value\": 0.08992389939999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 72, \"value\": -0.0549927163}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 73, \"value\": 0.0252466821}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 74, \"value\": 0.046411093099999995}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 75, \"value\": -0.0023179163000000003}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 76, \"value\": 0.09844548630000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 77, \"value\": -0.035863231}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 78, \"value\": 0.0909334091}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 79, \"value\": -0.057730357999999996}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 80, \"value\": 0.036269245299999996}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 81, \"value\": -0.006019351700000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 82, \"value\": -0.0102005689}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 83, \"value\": 0.0374768952}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 84, \"value\": -0.051049153}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 85, \"value\": 0.0860880183}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 86, \"value\": -0.0308746383}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 87, \"value\": 0.1037427224}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 88, \"value\": -0.0682743752}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 89, \"value\": 0.06351856780000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 90, \"value\": -0.0571514107}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 91, \"value\": 0.1027806385}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 92, \"value\": -0.06610131820000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 93, \"value\": 0.0360501546}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 94, \"value\": -0.09127673789999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 95, \"value\": 0.0471402345}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 96, \"value\": -0.0716885588}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 97, \"value\": 0.011153238700000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 98, \"value\": -0.0418169323}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 99, \"value\": -0.0154855603}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 100, \"value\": -0.049798644100000004}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 101, \"value\": -0.0070054838}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 102, \"value\": -0.0382815744}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 103, \"value\": 0.0050854734}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 104, \"value\": -0.0035741776}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 105, \"value\": -0.0578973813}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 106, \"value\": -0.0009010175}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 107, \"value\": -0.0497079567}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 108, \"value\": 0.0223679806}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 109, \"value\": -0.0679720942}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 110, \"value\": -0.005788431899999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 111, \"value\": -0.052191665400000004}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 112, \"value\": -0.0297113952}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 113, \"value\": -0.0430707538}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 114, \"value\": 0.0299892231}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 115, \"value\": 0.020477869}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 116, \"value\": 0.0407742738}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 117, \"value\": 0.013644711399999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 118, \"value\": 0.0527794005}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 119, \"value\": 0.0691892499}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 120, \"value\": 0.1018268709}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 121, \"value\": 0.0677327297}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 122, \"value\": 0.0522612844}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 123, \"value\": 0.0629306478}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 124, \"value\": 0.0534128091}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 125, \"value\": 0.055703474}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 126, \"value\": 0.0468979911}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 127, \"value\": 0.013228881299999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 128, \"value\": -0.0332039983}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 129, \"value\": -0.0178268171}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 130, \"value\": 0.0485694149}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 131, \"value\": 0.0169098494}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 132, \"value\": 0.0080355945}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 133, \"value\": -0.0351893247}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 134, \"value\": -0.015088852600000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 135, \"value\": -0.0052488029}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 136, \"value\": -0.0341575976}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 137, \"value\": -0.062255510099999994}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 138, \"value\": -0.0295893834}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 139, \"value\": -0.038623117400000004}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 140, \"value\": -0.0702374129}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 141, \"value\": -0.0767225883}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 142, \"value\": -0.0316816192}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 143, \"value\": -0.0719951927}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 144, \"value\": -0.10999659869999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 145, \"value\": -0.10239975050000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 146, \"value\": -0.108826844}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 147, \"value\": -0.0657516291}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 148, \"value\": -0.0833578594}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 149, \"value\": -0.0416218124}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 150, \"value\": -0.051718175400000004}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 151, \"value\": 0.027044516499999997}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 152, \"value\": 0.070282407}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 153, \"value\": 0.11230699429999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 154, \"value\": 0.1376027735}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 155, \"value\": 0.0895897587}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 156, \"value\": 0.1638846144}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 157, \"value\": 0.1388365016}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 158, \"value\": 0.0629778998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 159, \"value\": 0.12793623980000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 160, \"value\": 0.0799952214}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 161, \"value\": 0.0494258089}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 162, \"value\": 0.0344224692}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 163, \"value\": 0.026579456600000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 164, \"value\": 0.0529560404}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 165, \"value\": -0.0178578676}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 166, \"value\": -0.0307892033}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 167, \"value\": -0.0604446268}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 168, \"value\": -0.030887114}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 169, \"value\": -0.020861498}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 170, \"value\": 0.0046504460999999995}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 171, \"value\": -0.030665088599999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 172, \"value\": -0.08640480960000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 173, \"value\": -0.10389741949999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 174, \"value\": -0.08860049060000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 175, \"value\": -0.0858377096}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 176, \"value\": -0.0737108553}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 177, \"value\": -0.0657337229}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 178, \"value\": -0.0417572037}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 179, \"value\": -0.034736136800000005}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 180, \"value\": -0.0245240617}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 181, \"value\": -0.0181408772}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 182, \"value\": -0.0341439606}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 183, \"value\": -0.0154034399}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 184, \"value\": 0.0216663152}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 185, \"value\": 0.0525465385}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 186, \"value\": 0.08637095199999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 187, \"value\": 0.0711904725}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 188, \"value\": 0.0369237676}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 189, \"value\": 0.007896071800000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 190, \"value\": 0.0170730456}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 191, \"value\": 0.0242171136}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 192, \"value\": 0.0667223032}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 193, \"value\": 0.0209008257}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 194, \"value\": 0.010861916000000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 195, \"value\": -0.0039934112}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 196, \"value\": 0.0067661761}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 197, \"value\": 0.030957560099999996}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 198, \"value\": 0.0391600916}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 199, \"value\": -0.0102942022}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 200, \"value\": -0.0452797195}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 201, \"value\": 0.014053730300000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 202, \"value\": 0.0147642595}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 203, \"value\": 0.0050212441}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 204, \"value\": 0.025805636099999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 205, \"value\": -0.0139110728}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 206, \"value\": -0.0260884903}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 207, \"value\": 0.0059796769}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 208, \"value\": -0.0021757587}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 209, \"value\": 0.010782957900000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 210, \"value\": -0.0293931869}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 211, \"value\": -0.0571803797}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 212, \"value\": -0.029743273799999997}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 213, \"value\": -0.0291481465}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 214, \"value\": -0.0170346773}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 215, \"value\": -0.010807401299999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 216, \"value\": 0.0077646604000000015}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 217, \"value\": -0.0027572284}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 218, \"value\": 0.0029585602000000003}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 219, \"value\": -0.0288278912}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 220, \"value\": 0.0656682835}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 221, \"value\": 0.025279256200000003}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 222, \"value\": 0.021743722000000004}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 223, \"value\": 0.0237969608}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 224, \"value\": 0.0099619327}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 225, \"value\": -0.0179032721}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 226, \"value\": -0.0072483756999999985}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 227, \"value\": -0.0160336497}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 228, \"value\": -0.0627112789}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 229, \"value\": -0.0016889848999999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 230, \"value\": -0.0021303103}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 231, \"value\": -0.0191310594}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 232, \"value\": -0.0251145611}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 233, \"value\": 0.0173798007}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 234, \"value\": 0.0043122663}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 235, \"value\": 0.0534852373}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 236, \"value\": 0.0514284979}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 237, \"value\": 0.0258250236}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 238, \"value\": 0.0966807959}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 239, \"value\": 0.060105343600000014}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 240, \"value\": -0.0567188862}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 241, \"value\": -0.039955324}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 242, \"value\": -0.0350040686}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 243, \"value\": -0.0533516201}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 244, \"value\": -0.0734002032}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 245, \"value\": -0.0726942473}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 246, \"value\": -0.0206720773}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 247, \"value\": -0.028106739199999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 248, \"value\": -0.0430400624}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 249, \"value\": -0.0355502404}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 250, \"value\": 0.0104139477}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 251, \"value\": 0.021794191600000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 252, \"value\": 0.0400074459}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 253, \"value\": 0.023760200099999997}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 254, \"value\": 0.011485887299999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 255, \"value\": -0.01874486}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 256, \"value\": 0.0700254307}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 257, \"value\": 0.11198858310000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 258, \"value\": 0.06296842679999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 259, \"value\": 0.0725412805}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 260, \"value\": 0.013173478600000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 261, \"value\": 0.015021026299999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 262, \"value\": 0.0115081333}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 263, \"value\": -0.0034887265000000003}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 264, \"value\": 0.0352496085}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 265, \"value\": 0.0045288943}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 266, \"value\": 0.0124430402}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 267, \"value\": -0.0371750818}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 268, \"value\": -0.0014169134}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 269, \"value\": -0.0115679593}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 270, \"value\": -0.0258748142}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 271, \"value\": -0.049879936}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 272, \"value\": -0.0352266687}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 273, \"value\": -0.0405002211}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 274, \"value\": -0.0820515381}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 275, \"value\": -0.0369596591}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 276, \"value\": -0.015090468700000003}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 277, \"value\": -0.0351423378}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 278, \"value\": -0.0419245653}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 279, \"value\": 0.0390430982}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 280, \"value\": 0.0218867052}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 281, \"value\": -0.0141103626}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 282, \"value\": -0.018800808500000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 283, \"value\": 0.022943764900000004}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 284, \"value\": 0.010477538599999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 285, \"value\": 0.0006217996}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 286, \"value\": 5.079560000000001e-05}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 287, \"value\": -0.008166748599999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 288, \"value\": -0.0223417388}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 289, \"value\": -0.0085510075}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 290, \"value\": 0.013227926899999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 291, \"value\": 0.0129909204}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 292, \"value\": -0.0081854676}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 293, \"value\": -0.029174082999999996}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 294, \"value\": -0.0134582539}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 295, \"value\": 0.0344852773}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 296, \"value\": 0.0189901984}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 297, \"value\": 0.029626315299999997}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 298, \"value\": 0.04815969639999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 299, \"value\": 0.001600083}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 300, \"value\": 0.0240740203}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 301, \"value\": 0.0197482514}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 302, \"value\": 0.031212254300000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 303, \"value\": 0.021669321000000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 304, \"value\": 0.018186008400000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 305, \"value\": 0.0264962519}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 306, \"value\": -0.0057858351}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 307, \"value\": 0.0734898357}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 308, \"value\": 0.0279010739}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 309, \"value\": -0.019666261299999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 310, \"value\": 0.022190701099999998}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 311, \"value\": 0.0072873429}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 312, \"value\": 0.0148952842}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 313, \"value\": 0.0150144431}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 314, \"value\": 0.0063188146}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 315, \"value\": -0.0063944528}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 316, \"value\": 0.0034609340999999997}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 317, \"value\": 0.003215038}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 318, \"value\": -0.016026243}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 319, \"value\": -0.038674859}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 320, \"value\": -0.021703935}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 321, \"value\": -0.0579745054}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 322, \"value\": -0.0965858053}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 323, \"value\": -0.0669582811}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 324, \"value\": -0.09134753279999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 325, \"value\": -0.0820721743}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 326, \"value\": -0.0895085861}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 327, \"value\": -0.12352026390000001}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 328, \"value\": -0.0615794031}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 329, \"value\": 0.056826595}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 330, \"value\": 0.0785638874}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 331, \"value\": 0.0783480174}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 332, \"value\": 0.0542011433}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 333, \"value\": 0.0207567665}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 334, \"value\": 0.0425455562}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 335, \"value\": 0.0353961663}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 336, \"value\": 0.0421579262}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 337, \"value\": 0.0202424467}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 338, \"value\": -0.0021254641}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 339, \"value\": 0.00012082799999999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 340, \"value\": 0.0020350645000000002}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 341, \"value\": 0.0510946428}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 342, \"value\": -0.004679856699999999}, {\"regressor\": \"a_comp_cor_01\", \"scan_number\": 343, \"value\": 0.0176351027}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 0, \"value\": 0.0577938575}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 1, \"value\": 0.0045901252000000005}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 2, \"value\": -0.0397506895}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 3, \"value\": -0.0713378056}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 4, \"value\": 0.058530867699999996}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 5, \"value\": 0.020495046399999998}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 6, \"value\": 0.0007042077}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 7, \"value\": 0.0138890851}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 8, \"value\": -0.0079783801}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 9, \"value\": 0.0047710477}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 10, \"value\": 0.058294182800000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 11, \"value\": -0.00030195119999999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 12, \"value\": 0.0040996331}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 13, \"value\": -0.049279373}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 14, \"value\": -0.0508093888}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 15, \"value\": 0.0182315274}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 16, \"value\": -0.0172114469}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 17, \"value\": 0.0252670087}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 18, \"value\": -0.0021769167000000003}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 19, \"value\": -0.0339970585}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 20, \"value\": -0.0407434018}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 21, \"value\": 0.0001682791}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 22, \"value\": 0.006949626600000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 23, \"value\": -0.0191852673}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 24, \"value\": -0.0651575539}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 25, \"value\": -0.057000370099999996}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 26, \"value\": 0.0276115489}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 27, \"value\": 0.023713793900000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 28, \"value\": 0.0155759114}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 29, \"value\": 0.0010463966}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 30, \"value\": 0.0257516045}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 31, \"value\": 0.0059755309}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 32, \"value\": 0.048176951100000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 33, \"value\": 0.027831789500000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 34, \"value\": 0.024079199}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 35, \"value\": 0.0066345651}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 36, \"value\": -0.0380993659}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 37, \"value\": 0.008086402}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 38, \"value\": 0.0426138183}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 39, \"value\": 0.0069989714}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 40, \"value\": -0.0075610272}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 41, \"value\": -0.0046470926000000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 42, \"value\": 0.067789131}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 43, \"value\": 0.0118699147}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 44, \"value\": -0.010854513100000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 45, \"value\": 0.0039781394}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 46, \"value\": -0.016928931799999998}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 47, \"value\": -0.041032387000000003}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 48, \"value\": 0.0427439042}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 49, \"value\": 0.0789729497}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 50, \"value\": -0.025068605600000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 51, \"value\": -0.0292633887}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 52, \"value\": 0.0128729591}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 53, \"value\": -0.0495036934}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 54, \"value\": -0.0115149139}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 55, \"value\": 0.0153831459}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 56, \"value\": -0.0746954602}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 57, \"value\": -0.0207562652}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 58, \"value\": 0.0424866759}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 59, \"value\": 0.0056226465}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 60, \"value\": -0.0701393065}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 61, \"value\": -0.0008569199}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 62, \"value\": 0.0007437355}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 63, \"value\": -0.068802782}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 64, \"value\": 0.007194085500000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 65, \"value\": 0.0046278018}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 66, \"value\": 0.0047241581}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 67, \"value\": -0.0330276658}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 68, \"value\": -0.0239922597}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 69, \"value\": 0.0122485077}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 70, \"value\": 0.022073250899999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 71, \"value\": 0.027725900699999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 72, \"value\": 0.0052900023999999995}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 73, \"value\": -0.035946939}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 74, \"value\": 0.0080978809}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 75, \"value\": -0.0370089001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 76, \"value\": 0.048022547}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 77, \"value\": 0.007685726199999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 78, \"value\": 0.023448617799999998}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 79, \"value\": 0.0236767173}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 80, \"value\": -0.0054655116}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 81, \"value\": 0.035669593900000005}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 82, \"value\": -0.013817556200000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 83, \"value\": 0.0383642166}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 84, \"value\": -0.026792530499999998}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 85, \"value\": 0.030082711800000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 86, \"value\": -0.0310316068}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 87, \"value\": 0.070045041}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 88, \"value\": 0.0395562144}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 89, \"value\": 0.005160105900000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 90, \"value\": -0.0417104289}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 91, \"value\": -0.0045874005}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 92, \"value\": 0.069836381}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 93, \"value\": 0.055577268}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 94, \"value\": -0.0034479591999999996}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 95, \"value\": -0.0622024007}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 96, \"value\": 0.016434185}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 97, \"value\": -0.045885832599999996}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 98, \"value\": 0.048139008600000005}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 99, \"value\": 0.0226606478}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 100, \"value\": 0.046900465499999995}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 101, \"value\": -0.1007392717}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 102, \"value\": 0.0097292355}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 103, \"value\": -0.08892888}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 104, \"value\": 0.1238342349}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 105, \"value\": -0.1247687249}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 106, \"value\": 0.02947829}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 107, \"value\": -0.09784270880000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 108, \"value\": 0.0397996677}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 109, \"value\": -0.0233945987}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 110, \"value\": -0.0501042479}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 111, \"value\": 0.0062854511}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 112, \"value\": -0.12152164630000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 113, \"value\": 0.0563184088}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 114, \"value\": -0.07147525889999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 115, \"value\": 0.029454334199999998}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 116, \"value\": 0.0440511238}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 117, \"value\": -0.023685070899999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 118, \"value\": 0.1062121674}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 119, \"value\": -0.0767719368}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 120, \"value\": 0.0094909329}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 121, \"value\": 0.0263382287}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 122, \"value\": -0.0397939725}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 123, \"value\": 0.1190690599}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 124, \"value\": -0.048997653099999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 125, \"value\": 0.0552608409}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 126, \"value\": -0.026941725899999998}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 127, \"value\": -0.011478582099999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 128, \"value\": 0.0636987434}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 129, \"value\": -0.07165724379999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 130, \"value\": 0.0476964414}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 131, \"value\": -0.0019272411}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 132, \"value\": -0.0175342336}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 133, \"value\": 0.0801539455}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 134, \"value\": -0.0334891265}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 135, \"value\": 0.0323690907}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 136, \"value\": 0.011850324399999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 137, \"value\": -0.0340629387}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 138, \"value\": 0.09222325599999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 139, \"value\": 0.0255508929}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 140, \"value\": -0.10132137199999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 141, \"value\": -0.0102616861}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 142, \"value\": -0.07289449370000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 143, \"value\": 0.0324037771}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 144, \"value\": 0.11602894230000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 145, \"value\": -0.0705567426}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 146, \"value\": -0.0168888301}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 147, \"value\": 0.0192793215}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 148, \"value\": -0.0267416746}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 149, \"value\": 0.0650985449}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 150, \"value\": 0.049634287}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 151, \"value\": -0.021448446200000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 152, \"value\": 0.024243396299999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 153, \"value\": -0.0187992042}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 154, \"value\": -0.021361999700000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 155, \"value\": 0.0313897436}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 156, \"value\": -0.0339713925}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 157, \"value\": -0.0161382447}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 158, \"value\": 0.013195063600000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 159, \"value\": -0.0668377565}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 160, \"value\": -0.0418903827}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 161, \"value\": 0.0391979277}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 162, \"value\": -0.039871189}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 163, \"value\": -0.061937625}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 164, \"value\": 0.0371759317}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 165, \"value\": -0.0050995939}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 166, \"value\": -0.0688840765}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 167, \"value\": 0.0236824337}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 168, \"value\": 0.037719766200000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 169, \"value\": -0.0632796182}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 170, \"value\": -0.0056790874}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 171, \"value\": 0.030963521600000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 172, \"value\": -0.05038808}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 173, \"value\": -0.035641294500000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 174, \"value\": 0.0881534011}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 175, \"value\": 0.031999150899999995}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 176, \"value\": -0.055110298499999995}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 177, \"value\": -0.0114824649}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 178, \"value\": 0.0440891969}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 179, \"value\": -0.0218038698}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 180, \"value\": -0.0205771572}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 181, \"value\": 0.051711584000000005}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 182, \"value\": 0.0078486518}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 183, \"value\": -0.0661776697}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 184, \"value\": 0.0356548166}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 185, \"value\": 0.11029420109999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 186, \"value\": 0.015344618899999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 187, \"value\": -0.08777957609999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 188, \"value\": -0.0101929154}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 189, \"value\": 0.09968408029999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 190, \"value\": 0.1127117253}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 191, \"value\": -0.0423512675}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 192, \"value\": -0.0289563837}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 193, \"value\": 0.0483166445}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 194, \"value\": 0.1177364792}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 195, \"value\": -0.036632762799999996}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 196, \"value\": -0.0579364141}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 197, \"value\": 0.0216875472}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 198, \"value\": 0.08717994550000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 199, \"value\": 0.0454285782}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 200, \"value\": -0.08407899199999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 201, \"value\": -0.11380214949999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 202, \"value\": 0.0013846796}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 203, \"value\": 0.09467057470000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 204, \"value\": 0.0652943897}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 205, \"value\": -0.11965535880000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 206, \"value\": -0.1738065692}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 207, \"value\": -0.0235560488}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 208, \"value\": 0.0373882445}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 209, \"value\": 0.0382986154}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 210, \"value\": -0.0398592911}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 211, \"value\": -0.08842645800000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 212, \"value\": -0.0195510308}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 213, \"value\": 0.0440167862}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 214, \"value\": 0.07030379889999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 215, \"value\": -0.035302119}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 216, \"value\": -0.1067190544}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 217, \"value\": -0.0629545975}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 218, \"value\": 0.024952434300000003}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 219, \"value\": 0.012098825}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 220, \"value\": 0.0492858109}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 221, \"value\": -0.0249231835}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 222, \"value\": -0.06003227980000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 223, \"value\": -0.0006302596}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 224, \"value\": 0.024140578700000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 225, \"value\": 0.0485212625}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 226, \"value\": 0.11384052230000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 227, \"value\": 0.054605742400000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 228, \"value\": -0.0414909559}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 229, \"value\": -0.0686769532}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 230, \"value\": -0.022231835}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 231, \"value\": 0.056227374299999994}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 232, \"value\": 0.0975873574}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 233, \"value\": 0.0789944251}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 234, \"value\": 0.0034027104}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 235, \"value\": -0.08826950550000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 236, \"value\": -0.0691681237}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 237, \"value\": -0.06265208259999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 238, \"value\": -0.0394275953}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 239, \"value\": -0.0317056837}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 240, \"value\": 0.1493184767}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 241, \"value\": 0.1246110282}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 242, \"value\": 0.09889802439999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 243, \"value\": 0.1143807199}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 244, \"value\": 0.0724322888}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 245, \"value\": -0.0507794737}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 246, \"value\": -0.1030669733}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 247, \"value\": -0.0896816585}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 248, \"value\": -0.041671182}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 249, \"value\": 0.0234386871}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 250, \"value\": -0.0608643593}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 251, \"value\": -0.0482513614}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 252, \"value\": -0.0051072763}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 253, \"value\": 0.0228680908}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 254, \"value\": 0.0084383126}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 255, \"value\": 0.039805313599999996}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 256, \"value\": -0.022240710499999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 257, \"value\": -0.006195109200000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 258, \"value\": -0.0219222969}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 259, \"value\": 0.0073359204}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 260, \"value\": -0.023831962}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 261, \"value\": -0.0452524066}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 262, \"value\": -0.0380799505}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 263, \"value\": -0.026170114700000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 264, \"value\": -0.0354658345}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 265, \"value\": -0.0410410533}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 266, \"value\": -0.0401390498}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 267, \"value\": -0.094055606}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 268, \"value\": -0.0584822595}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 269, \"value\": -0.0249550255}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 270, \"value\": 0.060893318499999995}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 271, \"value\": 0.0805941925}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 272, \"value\": 0.0369799027}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 273, \"value\": 0.08573934789999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 274, \"value\": 0.0848628347}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 275, \"value\": 0.0899941728}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 276, \"value\": 0.050507868600000005}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 277, \"value\": 0.0453112251}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 278, \"value\": -0.01017596}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 279, \"value\": -0.0025704770000000003}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 280, \"value\": -0.0602321438}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 281, \"value\": -0.0267519214}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 282, \"value\": -0.0167326677}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 283, \"value\": -0.010253486899999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 284, \"value\": 0.0417992224}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 285, \"value\": 0.0429072725}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 286, \"value\": 0.018036493}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 287, \"value\": -0.0182917316}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 288, \"value\": -0.0372700247}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 289, \"value\": -0.048044810599999994}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 290, \"value\": 0.0296733709}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 291, \"value\": 0.0262810323}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 292, \"value\": 0.0128570743}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 293, \"value\": -0.0145564279}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 294, \"value\": -0.0625391809}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 295, \"value\": -0.0551078407}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 296, \"value\": 0.0406743567}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 297, \"value\": 0.0280835388}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 298, \"value\": 0.021902245499999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 299, \"value\": -0.08169810870000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 300, \"value\": -0.0395022827}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 301, \"value\": 0.037877706000000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 302, \"value\": 0.0456688061}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 303, \"value\": -0.0754097159}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 304, \"value\": -0.0403062763}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 305, \"value\": 0.09686369310000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 306, \"value\": 0.0262347964}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 307, \"value\": -0.0247173083}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 308, \"value\": -0.06839323309999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 309, \"value\": 0.0684239176}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 310, \"value\": 0.0939062855}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 311, \"value\": -0.0883000713}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 312, \"value\": -0.10685302039999996}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 313, \"value\": 0.0657143723}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 314, \"value\": 0.0469433252}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 315, \"value\": -0.091594545}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 316, \"value\": 0.0866577818}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 317, \"value\": 0.026764941299999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 318, \"value\": -0.06840211759999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 319, \"value\": 0.06427191019999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 320, \"value\": 0.026955926800000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 321, \"value\": -0.0537783292}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 322, \"value\": 0.0540526905}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 323, \"value\": -0.011268748200000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 324, \"value\": -0.0613104458}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 325, \"value\": 0.0680838995}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 326, \"value\": -0.0720820278}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 327, \"value\": -0.05071423269999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 328, \"value\": 0.0996630192}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 329, \"value\": -0.053223025300000004}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 330, \"value\": 0.0038299388}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 331, \"value\": -0.023430482599999997}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 332, \"value\": -0.0558955833}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 333, \"value\": 0.08321989269999999}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 334, \"value\": -0.0020466531}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 335, \"value\": 0.028134134300000002}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 336, \"value\": -0.0242524398}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 337, \"value\": -0.06159184030000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 338, \"value\": 0.0707148782}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 339, \"value\": -0.030176617000000006}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 340, \"value\": 0.0630688106}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 341, \"value\": -0.0158157344}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 342, \"value\": -0.06378715160000001}, {\"regressor\": \"a_comp_cor_02\", \"scan_number\": 343, \"value\": 0.053837980099999995}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 0, \"value\": -0.0621884288}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 1, \"value\": -0.0095241856}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 2, \"value\": 0.14011832800000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 3, \"value\": 0.0508774676}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 4, \"value\": -0.027652220800000002}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 5, \"value\": -0.08672999810000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 6, \"value\": -0.0929927374}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 7, \"value\": 0.015275756399999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 8, \"value\": 0.0675099858}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 9, \"value\": 0.1117850379}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 10, \"value\": 0.0921613308}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 11, \"value\": -0.0450049265}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 12, \"value\": -0.12749376169999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 13, \"value\": -0.0346435957}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 14, \"value\": 0.11576867140000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 15, \"value\": 0.0473039116}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 16, \"value\": -0.0591456308}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 17, \"value\": -0.1033952653}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 18, \"value\": -0.0565379212}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 19, \"value\": 0.0428229871}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 20, \"value\": 0.1241201644}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 21, \"value\": 0.0179391101}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 22, \"value\": -0.11567293390000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 23, \"value\": -0.1321909073}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 24, \"value\": 0.0011399698}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 25, \"value\": 0.0975243241}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 26, \"value\": -0.008261009100000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 27, \"value\": -0.095818835}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 28, \"value\": -0.06137677}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 29, \"value\": 0.08142642580000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 30, \"value\": 0.0750871315}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 31, \"value\": -0.08550026039999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 32, \"value\": 0.0276514344}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 33, \"value\": 0.144284827}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 34, \"value\": -0.0252514}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 35, \"value\": -0.11385825029999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 36, \"value\": 0.0729032556}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 37, \"value\": 0.1238413674}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 38, \"value\": -0.053841882}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 39, \"value\": -0.0951954292}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 40, \"value\": -0.0009277331}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 41, \"value\": 0.0949276228}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 42, \"value\": -0.0487896457}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 43, \"value\": -0.0630221643}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 44, \"value\": 0.1202774107}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 45, \"value\": 0.0038638632}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 46, \"value\": -0.1023941658}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 47, \"value\": 0.0607379242}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 48, \"value\": 0.1152441047}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 49, \"value\": -0.09352379429999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 50, \"value\": 0.017807422}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 51, \"value\": 0.043917121399999995}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 52, \"value\": -0.0674465229}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 53, \"value\": -0.0584858746}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 54, \"value\": 0.1202208565}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 55, \"value\": -0.0492751146}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 56, \"value\": -0.1505406767}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 57, \"value\": 0.0768320407}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 58, \"value\": 0.0302879767}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 59, \"value\": -0.0598116804}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 60, \"value\": 0.062537883}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 61, \"value\": 0.0357987191}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 62, \"value\": -0.10325564460000004}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 63, \"value\": 0.05346836519999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 64, \"value\": -0.0084107023}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 65, \"value\": -0.0220774698}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 66, \"value\": 0.1401432819}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 67, \"value\": -0.17211441370000002}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 68, \"value\": 0.0461912813}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 69, \"value\": 0.0251547729}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 70, \"value\": -0.0317803331}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 71, \"value\": 0.1465039783}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 72, \"value\": -0.12016402890000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 73, \"value\": 0.0696635929}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 74, \"value\": -0.1089385149}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 75, \"value\": 0.0679951343}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 76, \"value\": -0.0079429386}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 77, \"value\": -0.0734851547}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 78, \"value\": 0.0830776489}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 79, \"value\": -0.1207690101}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 80, \"value\": 0.1292424898}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 81, \"value\": -0.1224801023}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 82, \"value\": 0.10060036210000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 83, \"value\": -0.10358544759999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 84, \"value\": 0.06168918740000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 85, \"value\": -0.0688819742}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 86, \"value\": 0.04509459}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 87, \"value\": 0.034743576899999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 88, \"value\": 0.0175564351}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 89, \"value\": -0.0133772729}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 90, \"value\": -0.1285013537}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 91, \"value\": 0.0962940033}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 92, \"value\": -0.0527637979}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 93, \"value\": 0.14552636160000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 94, \"value\": -0.0691718637}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 95, \"value\": 0.0380343771}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 96, \"value\": -0.11414567}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 97, \"value\": 0.114790959}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 98, \"value\": -0.0464958485}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 99, \"value\": 0.0640463044}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 100, \"value\": -0.0251890873}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 101, \"value\": 0.0483172724}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 102, \"value\": -0.0538245058}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 103, \"value\": 0.0714624032}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 104, \"value\": 0.023840048500000002}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 105, \"value\": 0.0168623406}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 106, \"value\": -0.039821810299999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 107, \"value\": -0.0066585478}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 108, \"value\": 0.0028107569}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 109, \"value\": 0.046301691799999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 110, \"value\": -0.006656014599999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 111, \"value\": -0.032198665}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 112, \"value\": -0.0089019272}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 113, \"value\": 0.0123142538}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 114, \"value\": 0.0142751254}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 115, \"value\": -0.049115814800000004}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 116, \"value\": -0.0261930173}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 117, \"value\": 0.0205604966}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 118, \"value\": 0.0049418676}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 119, \"value\": -0.0231044631}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 120, \"value\": -0.0212560616}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 121, \"value\": -0.038756510099999995}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 122, \"value\": -0.0182308642}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 123, \"value\": -0.0334582235}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 124, \"value\": -0.0152045635}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 125, \"value\": -0.0460839332}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 126, \"value\": -0.0206223179}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 127, \"value\": -0.0105299376}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 128, \"value\": 0.0248690581}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 129, \"value\": 0.0064898013000000004}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 130, \"value\": -0.020508099}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 131, \"value\": -0.0059585585}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 132, \"value\": 0.0275020435}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 133, \"value\": 0.0074096177}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 134, \"value\": 0.0062012509}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 135, \"value\": -0.0051466867}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 136, \"value\": -0.0048115386999999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 137, \"value\": 0.0677215072}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 138, \"value\": 0.0032094431}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 139, \"value\": 0.0391863895}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 140, \"value\": -0.0167948775}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 141, \"value\": 0.0019495476999999998}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 142, \"value\": 0.0735417512}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 143, \"value\": 0.0447193671}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 144, \"value\": 0.09058294310000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 145, \"value\": 0.033588747099999997}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 146, \"value\": 0.031495212200000004}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 147, \"value\": 0.0254550766}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 148, \"value\": 0.06559935780000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 149, \"value\": 0.0344726467}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 150, \"value\": 0.016474044099999998}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 151, \"value\": -0.0167113586}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 152, \"value\": -0.0424325151}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 153, \"value\": -0.0605656403}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 154, \"value\": -0.0436181076}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 155, \"value\": -0.0841494154}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 156, \"value\": -0.07964504830000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 157, \"value\": -0.0073258034}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 158, \"value\": -0.0390561827}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 159, \"value\": -0.0775453296}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 160, \"value\": -0.0637860992}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 161, \"value\": -0.0821167191}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 162, \"value\": -0.0380532018}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 163, \"value\": 0.018552906799999998}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 164, \"value\": 0.0131297201}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 165, \"value\": -0.0042438937}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 166, \"value\": -0.0275796804}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 167, \"value\": 0.0080284714}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 168, \"value\": 0.0057937403}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 169, \"value\": 0.0583164284}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 170, \"value\": 0.0002035968}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 171, \"value\": -0.0068200698}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 172, \"value\": 0.0045309370000000005}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 173, \"value\": 0.053524093099999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 174, \"value\": 0.0822418796}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 175, \"value\": 0.0898225277}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 176, \"value\": 0.0415812395}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 177, \"value\": -0.0091970414}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 178, \"value\": 0.0137529984}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 179, \"value\": -0.0028119516}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 180, \"value\": 0.0613552572}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 181, \"value\": 0.0160264754}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 182, \"value\": -0.060572402000000004}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 183, \"value\": 0.0076753386}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 184, \"value\": 0.027766046800000003}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 185, \"value\": 0.0040789629}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 186, \"value\": -0.028949906600000002}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 187, \"value\": -0.0269436003}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 188, \"value\": -0.020899502900000002}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 189, \"value\": -0.0048650941999999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 190, \"value\": 0.0165818833}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 191, \"value\": 0.0111314947}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 192, \"value\": 0.0428824397}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 193, \"value\": -0.0285226936}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 194, \"value\": -0.0188799134}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 195, \"value\": -0.0239755221}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 196, \"value\": -0.0192875781}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 197, \"value\": 0.0476476767}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 198, \"value\": -0.0083693326}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 199, \"value\": -0.0004421874}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 200, \"value\": -0.04444966349999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 201, \"value\": -0.0204579506}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 202, \"value\": -0.018226309}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 203, \"value\": 0.0314917458}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 204, \"value\": -0.0063837548}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 205, \"value\": -0.0169411092}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 206, \"value\": -0.0670460996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 207, \"value\": -0.0066112015}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 208, \"value\": -0.0099081525}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 209, \"value\": -0.003240163}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 210, \"value\": -0.0050215121}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 211, \"value\": -0.0082645397}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 212, \"value\": -0.0209983416}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 213, \"value\": -0.0028063465999999997}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 214, \"value\": 0.059384383}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 215, \"value\": 0.0366827356}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 216, \"value\": -0.012657273500000002}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 217, \"value\": -0.0010523593}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 218, \"value\": 0.0054052043999999995}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 219, \"value\": 0.0035525182000000002}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 220, \"value\": 0.0202743327}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 221, \"value\": -0.0043856244}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 222, \"value\": -0.0053570789}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 223, \"value\": -0.0222392711}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 224, \"value\": 0.010894426899999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 225, \"value\": -0.0183874719}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 226, \"value\": 0.0193141872}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 227, \"value\": 0.0294946731}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 228, \"value\": 0.0163769006}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 229, \"value\": 0.029917065099999997}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 230, \"value\": 0.013004766000000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 231, \"value\": 0.0138750278}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 232, \"value\": 0.0012665525}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 233, \"value\": 0.0062762193}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 234, \"value\": -0.0313542121}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 235, \"value\": 0.0124093573}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 236, \"value\": 0.0319494597}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 237, \"value\": 0.0259093459}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 238, \"value\": -0.0218720533}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 239, \"value\": -0.0263743}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 240, \"value\": -0.0249913508}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 241, \"value\": 0.0180492986}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 242, \"value\": 0.0291537977}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 243, \"value\": 0.0045126637}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 244, \"value\": 0.0323633769}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 245, \"value\": -0.037069207400000005}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 246, \"value\": -0.09178477970000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 247, \"value\": -0.0120666734}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 248, \"value\": 0.0023865760999999997}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 249, \"value\": 0.017936703999999998}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 250, \"value\": -0.0009018838000000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 251, \"value\": -0.0161724798}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 252, \"value\": -0.0017312566}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 253, \"value\": 0.0032144125}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 254, \"value\": 0.029612183900000002}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 255, \"value\": 0.0227346975}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 256, \"value\": -0.0293794582}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 257, \"value\": -0.0094774692}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 258, \"value\": -0.0495011026}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 259, \"value\": 0.0203763243}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 260, \"value\": -0.0315538208}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 261, \"value\": -0.0055556818}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 262, \"value\": -0.0341515587}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 263, \"value\": 0.0060300413}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 264, \"value\": 0.0076830197}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 265, \"value\": 0.0055433587}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 266, \"value\": 0.0210321543}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 267, \"value\": -0.004364574600000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 268, \"value\": -0.048316326}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 269, \"value\": -0.0039806831}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 270, \"value\": 0.0349466364}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 271, \"value\": 0.015621821000000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 272, \"value\": 0.0033213349}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 273, \"value\": -0.0085456483}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 274, \"value\": 0.0347000738}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 275, \"value\": 0.0379040375}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 276, \"value\": -0.0084927919}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 277, \"value\": 0.0630606546}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 278, \"value\": 0.021566963999999997}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 279, \"value\": 0.0065187452}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 280, \"value\": 0.0298506482}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 281, \"value\": 0.029288649500000007}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 282, \"value\": -0.0034534608}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 283, \"value\": -0.0376439971}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 284, \"value\": -0.029716104500000007}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 285, \"value\": -0.023023366}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 286, \"value\": -0.0041843372999999994}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 287, \"value\": 0.0383177448}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 288, \"value\": 0.0350458518}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 289, \"value\": -0.0112236333}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 290, \"value\": -0.0358524496}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 291, \"value\": -0.061200545499999995}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 292, \"value\": 0.0150470654}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 293, \"value\": 0.0526062176}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 294, \"value\": 0.0036559189}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 295, \"value\": -0.0569013008}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 296, \"value\": -0.046448677300000005}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 297, \"value\": 0.003901413}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 298, \"value\": 0.0172583828}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 299, \"value\": 0.008453415}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 300, \"value\": 0.0077439924}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 301, \"value\": -0.0566393244}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 302, \"value\": -0.0025804582}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 303, \"value\": 0.0457236017}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 304, \"value\": 0.0647663651}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 305, \"value\": -0.0451066716}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 306, \"value\": -0.081166773}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 307, \"value\": -0.041688072799999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 308, \"value\": -0.0122863532}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 309, \"value\": 0.028148327200000007}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 310, \"value\": 0.0022555699}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 311, \"value\": -0.036319911499999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 312, \"value\": -0.0752888458}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 313, \"value\": -0.0092597124}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 314, \"value\": 0.0407378548}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 315, \"value\": 0.059224523}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 316, \"value\": -0.0097387849}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 317, \"value\": -0.0195647844}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 318, \"value\": 0.0394990044}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 319, \"value\": 0.0370393606}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 320, \"value\": 0.06059542900000001}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 321, \"value\": 0.0574642111}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 322, \"value\": 0.023885236400000003}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 323, \"value\": -0.003949549}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 324, \"value\": 0.047302008300000004}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 325, \"value\": 0.043007971}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 326, \"value\": 0.0429466497}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 327, \"value\": 0.0040328816}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 328, \"value\": -0.005501127299999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 329, \"value\": -0.039292082799999996}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 330, \"value\": -0.0286277171}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 331, \"value\": -0.0574486684}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 332, \"value\": -0.042660706900000005}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 333, \"value\": -0.0051187285}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 334, \"value\": 0.004945552299999999}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 335, \"value\": -0.0437399283}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 336, \"value\": -0.057211625499999995}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 337, \"value\": -0.0112601425}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 338, \"value\": -0.0020763997}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 339, \"value\": 0.0359428096}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 340, \"value\": 0.012863193}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 341, \"value\": -0.0123974651}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 342, \"value\": 0.018024232299999998}, {\"regressor\": \"a_comp_cor_03\", \"scan_number\": 343, \"value\": 0.0179591517}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 0, \"value\": 0.0260815888}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 1, \"value\": 0.0297164335}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 2, \"value\": -0.0572105541}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 3, \"value\": -0.0096042101}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 4, \"value\": 0.0516517381}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 5, \"value\": 0.051418770999999995}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 6, \"value\": 0.0180726656}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 7, \"value\": -0.0836039688}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 8, \"value\": -0.051810422300000006}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 9, \"value\": -0.008507995899999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 10, \"value\": 0.0691176553}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 11, \"value\": 0.0796450818}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 12, \"value\": 0.0111420473}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 13, \"value\": -0.1031328021}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 14, \"value\": -0.073859465}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 15, \"value\": -0.0165255971}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 16, \"value\": 0.0096505595}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 17, \"value\": 0.0787224316}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 18, \"value\": -0.0010736307000000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 19, \"value\": -0.0482310159}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 20, \"value\": -0.0724072595}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 21, \"value\": 0.060752339100000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 22, \"value\": 0.042630687}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 23, \"value\": 0.0201006331}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 24, \"value\": -0.0703476121}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 25, \"value\": -0.0407908468}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 26, \"value\": 0.056218400599999996}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 27, \"value\": 0.0563984106}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 28, \"value\": -0.0336426197}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 29, \"value\": 0.012916079799999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 30, \"value\": 0.0247176338}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 31, \"value\": 0.0063839817}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 32, \"value\": -0.0683223116}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 33, \"value\": 0.0042604187}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 34, \"value\": 0.0930087567}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 35, \"value\": -0.0569726214}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 36, \"value\": -0.0535376216}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 37, \"value\": 0.0178667076}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 38, \"value\": 0.0853654209}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 39, \"value\": -0.0135164729}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 40, \"value\": -0.066535823}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 41, \"value\": 0.013042833}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 42, \"value\": 0.0602303}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 43, \"value\": -0.0281452377}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 44, \"value\": -0.0118826785}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 45, \"value\": 0.0295640808}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 46, \"value\": 0.0009982933}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 47, \"value\": -0.0661786441}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 48, \"value\": 0.0541110937}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 49, \"value\": 0.06338588769999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 50, \"value\": -0.058829647199999995}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 51, \"value\": -0.0021928606}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 52, \"value\": 0.0004233442}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 53, \"value\": -0.0919643077}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 54, \"value\": -0.0356179881}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 55, \"value\": 0.0625865806}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 56, \"value\": -0.06737348110000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 57, \"value\": -0.0186922718}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 58, \"value\": 0.1084066734}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 59, \"value\": -0.0001403993}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 60, \"value\": -0.056151603700000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 61, \"value\": 0.0726679861}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 62, \"value\": 0.0087299456}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 63, \"value\": -0.019174553400000002}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 64, \"value\": 0.0408851991}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 65, \"value\": -0.0398726919}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 66, \"value\": 0.0189084113}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 67, \"value\": 0.034128509700000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 68, \"value\": -0.078365116}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 69, \"value\": 0.0689257917}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 70, \"value\": -0.049643624299999994}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 71, \"value\": 0.0462856149}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 72, \"value\": 0.0316205871}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 73, \"value\": -0.0286354919}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 74, \"value\": 0.09261703369999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 75, \"value\": -0.12017213410000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 76, \"value\": 0.043756828600000006}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 77, \"value\": -0.0864723387}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 78, \"value\": 0.0358870294}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 79, \"value\": -0.003527062800000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 80, \"value\": -0.0258827669}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 81, \"value\": 0.0172194302}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 82, \"value\": -0.0412114393}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 83, \"value\": 0.0643561653}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 84, \"value\": -0.0629836902}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 85, \"value\": 0.0809217545}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 86, \"value\": -0.0806021921}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 87, \"value\": 0.0639432962}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 88, \"value\": -0.023528577599999996}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 89, \"value\": 0.0692236306}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 90, \"value\": -0.11485811369999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 91, \"value\": 0.0504135057}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 92, \"value\": -0.033623657599999995}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 93, \"value\": 0.0638582525}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 94, \"value\": -0.0473965143}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 95, \"value\": -0.026072727599999998}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 96, \"value\": -0.0200481952}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 97, \"value\": -0.01903245}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 98, \"value\": 0.0238129008}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 99, \"value\": 0.0051901076}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 100, \"value\": 0.0715469906}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 101, \"value\": -0.0412312081}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 102, \"value\": 0.0053141316}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 103, \"value\": 0.0154489252}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 104, \"value\": -0.008075713299999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 105, \"value\": 0.042762953}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 106, \"value\": -0.0293111384}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 107, \"value\": 0.0683884379}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 108, \"value\": -0.0677035358}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 109, \"value\": 0.0800779385}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 110, \"value\": -0.032231349}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 111, \"value\": 0.06484037179999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 112, \"value\": -0.0070813038}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 113, \"value\": -0.0799358898}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 114, \"value\": 0.027025551499999998}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 115, \"value\": -0.0617597696}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 116, \"value\": 0.044419028099999994}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 117, \"value\": 0.0231878128}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 118, \"value\": -0.0070164566}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 119, \"value\": 0.0266099396}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 120, \"value\": -0.11134696150000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 121, \"value\": 0.029443370299999997}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 122, \"value\": -0.032091062999999996}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 123, \"value\": 0.0134958351}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 124, \"value\": 0.024412916899999998}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 125, \"value\": -0.081826919}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 126, \"value\": 0.0178045946}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 127, \"value\": -0.0206431381}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 128, \"value\": 0.0271479206}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 129, \"value\": 0.0534485308}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 130, \"value\": -0.0785349432}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 131, \"value\": 0.0106574378}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 132, \"value\": -0.0033163740000000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 133, \"value\": 0.0018028295}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 134, \"value\": 0.0496220712}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 135, \"value\": -0.0504508614}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 136, \"value\": 0.039484620299999995}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 137, \"value\": -0.0159594509}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 138, \"value\": -0.0350507066}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 139, \"value\": 0.0849490283}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 140, \"value\": 0.0249565869}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 141, \"value\": -0.0846692427}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 142, \"value\": 0.0320472571}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 143, \"value\": -0.005816136800000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 144, \"value\": 0.045027231900000006}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 145, \"value\": 0.10388543089999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 146, \"value\": -0.062034101200000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 147, \"value\": 0.0295916152}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 148, \"value\": 0.0140510527}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 149, \"value\": 0.0029042178999999996}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 150, \"value\": 0.0917532383}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 151, \"value\": 0.0033595596}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 152, \"value\": -0.07963904320000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 153, \"value\": 0.0222757751}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 154, \"value\": -0.038427465}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 155, \"value\": -0.0606558689}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 156, \"value\": 0.0317433471}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 157, \"value\": -0.05829944820000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 158, \"value\": -0.0399171298}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 159, \"value\": 0.008256567}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 160, \"value\": -0.08148097280000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 161, \"value\": -0.0413359622}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 162, \"value\": 0.060899255}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 163, \"value\": -0.06666502889999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 164, \"value\": -0.0204287395}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 165, \"value\": 0.0656156289}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 166, \"value\": 0.0160851589}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 167, \"value\": -0.012634631799999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 168, \"value\": 0.0650764385}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 169, \"value\": -0.0034734084000000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 170, \"value\": -0.075998663}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 171, \"value\": -0.0381171784}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 172, \"value\": 0.09698916910000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 173, \"value\": 0.0132682195}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 174, \"value\": -0.0027250225}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 175, \"value\": 0.0849832776}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 176, \"value\": 0.0252819422}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 177, \"value\": -0.0537951153}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 178, \"value\": 0.011176106299999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 179, \"value\": 0.09887642070000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 180, \"value\": -0.027968251}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 181, \"value\": -0.053404070199999994}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 182, \"value\": 0.025088798}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 183, \"value\": 0.021357562000000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 184, \"value\": -0.0490351584}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 185, \"value\": -0.0351555868}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 186, \"value\": 0.0438341094}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 187, \"value\": -0.0488222254}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 188, \"value\": -0.0316824134}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 189, \"value\": -0.0028430490000000003}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 190, \"value\": 0.0860286943}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 191, \"value\": 0.0688495301}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 192, \"value\": -0.0556947596}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 193, \"value\": -0.0752716013}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 194, \"value\": 0.0186786093}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 195, \"value\": 0.0691555666}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 196, \"value\": 0.0128063039}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 197, \"value\": -0.0862699724}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 198, \"value\": -0.0825750907}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 199, \"value\": 0.0533424426}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 200, \"value\": 0.047798224}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 201, \"value\": -0.0172020502}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 202, \"value\": -0.0769852677}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 203, \"value\": -0.0151488845}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 204, \"value\": 0.0832536161}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 205, \"value\": 0.0269080969}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 206, \"value\": -0.038194132400000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 207, \"value\": -0.049909176}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 208, \"value\": -0.055948571600000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 209, \"value\": 0.0286242302}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 210, \"value\": 0.0824106623}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 211, \"value\": 0.0421620572}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 212, \"value\": -0.0530848973}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 213, \"value\": -0.0415029538}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 214, \"value\": 0.0592811503}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 215, \"value\": 0.08984031880000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 216, \"value\": 0.040499365}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 217, \"value\": -0.04456446730000002}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 218, \"value\": -0.0405287312}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 219, \"value\": -0.0645168067}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 220, \"value\": -0.0394547268}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 221, \"value\": 0.0574162228}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 222, \"value\": 0.04437698019999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 223, \"value\": -0.0159657253}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 224, \"value\": -0.076933076}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 225, \"value\": -0.11397535980000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 226, \"value\": 0.031968691}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 227, \"value\": 0.0747475188}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 228, \"value\": 0.0697610144}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 229, \"value\": 0.0157638184}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 230, \"value\": -0.052996628600000005}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 231, \"value\": -0.0823435538}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 232, \"value\": -0.0251225005}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 233, \"value\": 0.047015645700000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 234, \"value\": 0.1133260116}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 235, \"value\": 0.067167664}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 236, \"value\": 0.008981655}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 237, \"value\": -0.018912468300000002}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 238, \"value\": -0.0329639456}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 239, \"value\": -0.024616305}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 240, \"value\": -0.030860602999999997}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 241, \"value\": -0.0385450588}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 242, \"value\": 0.0038228665}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 243, \"value\": 0.038560456}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 244, \"value\": 0.11331575099999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 245, \"value\": 0.033264704900000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 246, \"value\": 0.0369690735}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 247, \"value\": -0.0244916627}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 248, \"value\": -0.0122504282}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 249, \"value\": 0.0223826612}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 250, \"value\": 0.0186189709}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 251, \"value\": 0.0022209236}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 252, \"value\": -0.0231361308}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 253, \"value\": -0.0692323993}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 254, \"value\": -0.0531128325}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 255, \"value\": -0.0169007179}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 256, \"value\": -0.0288166048}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 257, \"value\": -0.0790379178}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 258, \"value\": -0.1084386401}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 259, \"value\": -0.0707715543}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 260, \"value\": 0.0019943045000000003}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 261, \"value\": 0.0066032399}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 262, \"value\": 0.0003365792}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 263, \"value\": -0.011126351999999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 264, \"value\": -0.0104010922}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 265, \"value\": 0.0289882686}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 266, \"value\": 0.0618779502}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 267, \"value\": 0.0158290795}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 268, \"value\": 0.053494121}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 269, \"value\": 0.036222038399999996}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 270, \"value\": 0.0594023043}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 271, \"value\": 0.0946273781}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 272, \"value\": 0.0587417354}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 273, \"value\": 0.045902064699999995}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 274, \"value\": -0.0187719431}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 275, \"value\": -0.023833211400000002}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 276, \"value\": -0.011359658500000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 277, \"value\": -0.048074368099999994}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 278, \"value\": -0.026282014300000003}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 279, \"value\": 0.0154905672}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 280, \"value\": -0.0030790209000000003}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 281, \"value\": 0.0085060742}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 282, \"value\": 0.0448787844}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 283, \"value\": 0.054245155}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 284, \"value\": 0.0690898205}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 285, \"value\": -0.08298679099999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 286, \"value\": -0.13738624259999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 287, \"value\": -0.0663090041}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 288, \"value\": 0.052593002400000005}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 289, \"value\": 0.1016571059}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 290, \"value\": 0.0469614708}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 291, \"value\": -0.0831084462}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 292, \"value\": -0.1143051252}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 293, \"value\": -0.011954276699999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 294, \"value\": 0.0551982183}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 295, \"value\": 0.0450725189}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 296, \"value\": -0.0496577728}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 297, \"value\": -0.0986198629}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 298, \"value\": -0.0415860505}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 299, \"value\": 0.033763415899999996}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 300, \"value\": 0.0849775846}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 301, \"value\": 0.0048712684999999995}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 302, \"value\": -0.0833733688}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 303, \"value\": -0.047888986900000007}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 304, \"value\": 0.0779888854}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 305, \"value\": 0.0632517809}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 306, \"value\": -0.050898385}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 307, \"value\": -0.0644634948}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 308, \"value\": 0.0307560325}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 309, \"value\": 0.06315245139999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 310, \"value\": -0.021912407400000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 311, \"value\": -0.0309681975}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 312, \"value\": 0.0421940987}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 313, \"value\": -0.000625629}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 314, \"value\": -0.097339994}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 315, \"value\": 0.0636698466}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 316, \"value\": 0.0627491856}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 317, \"value\": -0.050252405300000004}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 318, \"value\": 0.0544062799}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 319, \"value\": 0.0378132783}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 320, \"value\": -0.0682307082}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 321, \"value\": 0.0823838404}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 322, \"value\": 0.0381732252}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 323, \"value\": -0.0298786292}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 324, \"value\": 0.099906472}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 325, \"value\": -0.012320961699999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 326, \"value\": -0.0194409014}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 327, \"value\": 0.0909795933}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 328, \"value\": -0.09236760449999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 329, \"value\": -0.0016826955999999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 330, \"value\": -0.0243763739}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 331, \"value\": -0.09186161970000001}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 332, \"value\": 0.0170085496}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 333, \"value\": -0.0063340311}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 334, \"value\": -0.0157524325}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 335, \"value\": 0.0265486198}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 336, \"value\": -0.0867735201}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 337, \"value\": 0.0365519098}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 338, \"value\": 0.0148216515}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 339, \"value\": 0.0058312103}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 340, \"value\": 0.0788812845}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 341, \"value\": -0.0676010717}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 342, \"value\": -0.010348624399999999}, {\"regressor\": \"a_comp_cor_04\", \"scan_number\": 343, \"value\": 0.0063790254}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 0, \"value\": -0.0751940086}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 1, \"value\": 0.03169054}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 2, \"value\": 0.0710721846}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 3, \"value\": -0.048880774}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 4, \"value\": -0.0020954701}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 5, \"value\": -0.1014494298}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 6, \"value\": -0.0185068845}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 7, \"value\": 0.039012281499999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 8, \"value\": 0.0395804061}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 9, \"value\": 0.0318829589}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 10, \"value\": -0.0175969229}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 11, \"value\": -0.0695754066}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 12, \"value\": -0.041813620499999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 13, \"value\": 0.0801572344}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 14, \"value\": 0.0368692022}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 15, \"value\": 0.0123324755}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 16, \"value\": -0.033315767999999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 17, \"value\": -0.0778017964}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 18, \"value\": 0.0174321923}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 19, \"value\": 0.0645355136}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 20, \"value\": 0.0843704751}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 21, \"value\": 0.0071461899}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 22, \"value\": -0.0143148127}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 23, \"value\": -0.032868947}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 24, \"value\": 0.0624111522}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 25, \"value\": 0.031761952}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 26, \"value\": 0.013443378700000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 27, \"value\": -0.0639719203}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 28, \"value\": 0.0281004926}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 29, \"value\": 0.0288777133}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 30, \"value\": -0.061493367199999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 31, \"value\": -0.049189439}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 32, \"value\": 0.0759521736}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 33, \"value\": -0.0084186314}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 34, \"value\": -0.0295913384}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 35, \"value\": 0.0327555273}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 36, \"value\": 0.0778211389}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 37, \"value\": -0.025091229}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 38, \"value\": -0.0422567367}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 39, \"value\": -0.0068866833999999995}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 40, \"value\": 0.0642231034}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 41, \"value\": 0.0023099249}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 42, \"value\": -0.1281211615}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 43, \"value\": 0.0273969433}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 44, \"value\": 0.0747633065}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 45, \"value\": -0.055163587800000004}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 46, \"value\": -0.0630245897}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 47, \"value\": 0.014005639299999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 48, \"value\": 0.0057920187}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 49, \"value\": -0.0500412839}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 50, \"value\": 0.0228184707}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 51, \"value\": 0.0093394651}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 52, \"value\": -0.0073201312}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 53, \"value\": -0.0120007074}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 54, \"value\": 0.0434031661}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 55, \"value\": -0.0360296514}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 56, \"value\": 0.05828859190000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 57, \"value\": 0.047780706799999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 58, \"value\": -0.0733439818}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 59, \"value\": -0.0604213546}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 60, \"value\": 0.11095903019999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 61, \"value\": -0.056704155}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 62, \"value\": -0.0501372759}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 63, \"value\": 0.09196445}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 64, \"value\": -0.0601799853}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 65, \"value\": 0.0071261841}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 66, \"value\": 0.026812252400000004}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 67, \"value\": -0.029371016899999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 68, \"value\": 0.1143675397}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 69, \"value\": -0.10854978380000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 70, \"value\": -0.0303399258}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 71, \"value\": -0.0355687173}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 72, \"value\": -0.0257821227}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 73, \"value\": 0.0460760264}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 74, \"value\": -0.0938170866}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 75, \"value\": 0.0614814787}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 76, \"value\": 0.0123767478}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 77, \"value\": 0.049211685199999994}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 78, \"value\": -0.0013437796}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 79, \"value\": -0.0354358817}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 80, \"value\": 0.0296633527}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 81, \"value\": -0.0578605585}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 82, \"value\": 0.1410640732}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 83, \"value\": -0.09150366089999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 84, \"value\": 0.0980058645}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 85, \"value\": -0.0342381654}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 86, \"value\": 0.09852115619999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 87, \"value\": -0.0730511376}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 88, \"value\": 0.0743411533}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 89, \"value\": -0.0074671754000000005}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 90, \"value\": 0.093431341}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 91, \"value\": -0.050132404299999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 92, \"value\": -0.0356718232}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 93, \"value\": -0.043637309699999995}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 94, \"value\": 0.0219359476}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 95, \"value\": 0.0263356633}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 96, \"value\": 0.052328540199999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 97, \"value\": -0.040835967}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 98, \"value\": -0.0584107912}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 99, \"value\": -0.0088750274}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 100, \"value\": -0.0135252347}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 101, \"value\": -0.0031133883}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 102, \"value\": 0.0085124196}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 103, \"value\": -0.0264480379}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 104, \"value\": -0.0354641952}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 105, \"value\": -0.0095092317}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 106, \"value\": -0.0332837113}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 107, \"value\": 0.078855411}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 108, \"value\": -0.1153310007}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 109, \"value\": 0.037355402200000005}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 110, \"value\": -0.0985657097}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 111, \"value\": 0.0755658132}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 112, \"value\": -0.1053113566}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 113, \"value\": 0.07723998230000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 114, \"value\": 0.0212560845}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 115, \"value\": -0.0296304839}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 116, \"value\": 0.0248425231}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 117, \"value\": -0.0644510805}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 118, \"value\": -0.0110426459}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 119, \"value\": 0.0417029977}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 120, \"value\": 0.0155057252}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 121, \"value\": 0.0862087272}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 122, \"value\": -0.0653996144}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 123, \"value\": 0.059708453099999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 124, \"value\": -0.0040152949}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 125, \"value\": 0.025872954}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 126, \"value\": 0.04312700480000002}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 127, \"value\": -0.0219858627}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 128, \"value\": 0.0545379734}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 129, \"value\": 0.0031103396999999995}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 130, \"value\": -0.0131161166}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 131, \"value\": 0.08435502060000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 132, \"value\": -0.047672785999999995}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 133, \"value\": 0.040212453599999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 134, \"value\": 0.0127345852}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 135, \"value\": -0.021599177200000003}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 136, \"value\": 0.0506855904}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 137, \"value\": -0.0588926808}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 138, \"value\": -0.053467340099999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 139, \"value\": 0.0501400396}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 140, \"value\": -0.09759812720000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 141, \"value\": 0.022899636400000003}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 142, \"value\": -0.002055923}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 143, \"value\": -0.0863705163}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 144, \"value\": -0.023424467999999997}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 145, \"value\": -0.0347483737}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 146, \"value\": -0.024491585899999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 147, \"value\": 0.035341856899999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 148, \"value\": -0.0351537312}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 149, \"value\": -0.0522502806}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 150, \"value\": 0.0013971882999999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 151, \"value\": -0.0156455022}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 152, \"value\": 0.031180115699999997}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 153, \"value\": 0.0577680151}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 154, \"value\": 0.023843017999999997}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 155, \"value\": 0.0854223995}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 156, \"value\": 0.0584336396}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 157, \"value\": -0.0400831657}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 158, \"value\": 0.0244182839}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 159, \"value\": 0.1086240925}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 160, \"value\": 0.0150365787}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 161, \"value\": 0.026815968}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 162, \"value\": 0.0397056659}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 163, \"value\": -0.07287008190000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 164, \"value\": -0.0357755798}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 165, \"value\": 0.060460886100000014}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 166, \"value\": -0.0583869831}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 167, \"value\": -0.068363828}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 168, \"value\": -0.007740664}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 169, \"value\": -0.0283663827}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 170, \"value\": -0.0317412086}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 171, \"value\": 0.0604075796}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 172, \"value\": 0.0076512247}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 173, \"value\": -0.08449047779999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 174, \"value\": -0.0531781536}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 175, \"value\": -0.0148537253}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 176, \"value\": -0.0504410793}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 177, \"value\": -0.0032934803}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 178, \"value\": 0.0020732858}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 179, \"value\": 0.0085746136}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 180, \"value\": -0.11843407789999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 181, \"value\": 0.0196748374}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 182, \"value\": 0.0868295266}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 183, \"value\": 0.0240304816}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 184, \"value\": -0.0498389866}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 185, \"value\": 0.0007280353}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 186, \"value\": 0.09257576810000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 187, \"value\": 0.0599217372}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 188, \"value\": -0.039463586}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 189, \"value\": 0.0013045777000000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 190, \"value\": 0.0206212786}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 191, \"value\": 0.025641175800000002}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 192, \"value\": -0.0354722185}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 193, \"value\": 0.0309158704}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 194, \"value\": 0.0781216706}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 195, \"value\": 0.0588433096}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 196, \"value\": -0.0400554167}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 197, \"value\": -0.0368792554}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 198, \"value\": 0.0295791462}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 199, \"value\": 0.08881937}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 200, \"value\": 0.062423743899999995}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 201, \"value\": -0.0415443735}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 202, \"value\": -0.0671822237}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 203, \"value\": -0.0094829514}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 204, \"value\": 0.0716323432}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 205, \"value\": 0.0671682017}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 206, \"value\": -0.017443673700000002}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 207, \"value\": -0.09536073869999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 208, \"value\": -0.048123905300000006}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 209, \"value\": 0.0247488963}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 210, \"value\": 0.053919215300000004}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 211, \"value\": -0.07420464660000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 212, \"value\": -0.0861198354}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 213, \"value\": -0.024899304}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 214, \"value\": 0.0075822742}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 215, \"value\": -0.0056115524}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 216, \"value\": -0.0579177432}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 217, \"value\": -0.092320945}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 218, \"value\": -0.1088834389}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 219, \"value\": -0.015526326799999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 220, \"value\": 0.15381790050000002}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 221, \"value\": 0.1003479167}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 222, \"value\": -0.012379859299999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 223, \"value\": -0.0711331054}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 224, \"value\": -0.0126015943}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 225, \"value\": 0.0481190143}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 226, \"value\": 0.0347784516}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 227, \"value\": 0.054273506}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 228, \"value\": 0.0214011192}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 229, \"value\": -0.0388559311}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 230, \"value\": -0.0808188789}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 231, \"value\": -0.021600831400000003}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 232, \"value\": 0.0086208526}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 233, \"value\": 0.0600292248}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 234, \"value\": 0.0213958079}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 235, \"value\": 0.0055461499}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 236, \"value\": 0.0055876216}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 237, \"value\": -0.0123549693}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 238, \"value\": -0.0337524194}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 239, \"value\": -0.0468850342}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 240, \"value\": -0.0226778929}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 241, \"value\": 0.009848711999999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 242, \"value\": 0.034234847400000004}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 243, \"value\": 0.058378625199999985}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 244, \"value\": 0.0766454492}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 245, \"value\": 0.0574080097}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 246, \"value\": 0.0642368934}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 247, \"value\": 0.0044732575}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 248, \"value\": 0.018826637099999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 249, \"value\": 0.005471855699999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 250, \"value\": -0.0085192148}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 251, \"value\": -0.0008603904}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 252, \"value\": -0.0202381791}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 253, \"value\": 0.0066284225}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 254, \"value\": -0.0807393758}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 255, \"value\": -0.0328860537}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 256, \"value\": -0.0312355733}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 257, \"value\": 0.029761133}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 258, \"value\": 0.0115965922}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 259, \"value\": 0.0028369042}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 260, \"value\": -0.0558094472}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 261, \"value\": -0.0064511562}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 262, \"value\": -0.043121506799999994}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 263, \"value\": -0.0412419443}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 264, \"value\": -0.0123886424}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 265, \"value\": -0.0011377463000000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 266, \"value\": -0.0523807483}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 267, \"value\": 0.049102683700000004}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 268, \"value\": 0.055500746100000005}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 269, \"value\": 0.0184095254}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 270, \"value\": 0.0418720863}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 271, \"value\": 0.021605803599999997}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 272, \"value\": 0.0655732154}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 273, \"value\": 0.0035519449}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 274, \"value\": -0.017359335400000002}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 275, \"value\": -0.051322516}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 276, \"value\": -0.0507683562}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 277, \"value\": -0.08789217490000001}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 278, \"value\": -0.0736096872}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 279, \"value\": -0.0361803486}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 280, \"value\": -0.017416286399999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 281, \"value\": -0.0111216225}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 282, \"value\": 0.059878277199999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 283, \"value\": 0.0922037469}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 284, \"value\": 0.027608496099999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 285, \"value\": 0.0019121535999999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 286, \"value\": -0.016674593600000003}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 287, \"value\": -0.0685479846}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 288, \"value\": -0.0093338437}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 289, \"value\": 0.0203626961}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 290, \"value\": 0.0881142237}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 291, \"value\": 0.0327777305}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 292, \"value\": -0.0308772608}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 293, \"value\": -0.034415722}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 294, \"value\": 0.0415103127}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 295, \"value\": 0.0883411376}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 296, \"value\": 0.0634457212}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 297, \"value\": 0.016751523600000002}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 298, \"value\": -0.0958173942}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 299, \"value\": -0.0277304493}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 300, \"value\": 0.0567247427}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 301, \"value\": 0.0658424093}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 302, \"value\": -0.024054779}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 303, \"value\": -0.10446542869999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 304, \"value\": 0.0450204751}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 305, \"value\": 0.062053086699999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 306, \"value\": 0.0028545229}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 307, \"value\": -0.0500080806}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 308, \"value\": 0.0028272966999999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 309, \"value\": 0.0169215934}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 310, \"value\": 0.0072249403000000005}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 311, \"value\": 0.0073958098}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 312, \"value\": 0.07452172809999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 313, \"value\": 0.0496905532}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 314, \"value\": -0.06255985389999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 315, \"value\": -0.0335235087}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 316, \"value\": 0.0753251371}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 317, \"value\": -0.080774942}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 318, \"value\": -0.0732684676}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 319, \"value\": 0.0191719327}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 320, \"value\": -0.11923640529999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 321, \"value\": -0.0769190835}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 322, \"value\": 0.062058417699999986}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 323, \"value\": -0.09827053179999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 324, \"value\": -0.0421302803}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 325, \"value\": -0.0234633769}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 326, \"value\": -0.052345109699999996}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 327, \"value\": -0.0025824436}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 328, \"value\": -0.0378887584}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 329, \"value\": 0.0056502858}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 330, \"value\": 0.16065567949999998}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 331, \"value\": 0.0511613655}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 332, \"value\": 0.05343009940000002}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 333, \"value\": -0.0065360314000000004}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 334, \"value\": -0.0841373337}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 335, \"value\": 0.08325835849999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 336, \"value\": -0.0105862453}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 337, \"value\": 0.0586308665}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 338, \"value\": 0.011260716399999999}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 339, \"value\": -0.0574278513}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 340, \"value\": 0.048979695700000006}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 341, \"value\": -0.0201988797}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 342, \"value\": 0.0363318117}, {\"regressor\": \"a_comp_cor_05\", \"scan_number\": 343, \"value\": -0.0176501523}, {\"regressor\": \"rot_x\", \"scan_number\": 0, \"value\": 0.00165234}, {\"regressor\": \"rot_x\", \"scan_number\": 1, \"value\": 0.0006839319999999999}, {\"regressor\": \"rot_x\", \"scan_number\": 2, \"value\": 0.00273477}, {\"regressor\": \"rot_x\", \"scan_number\": 3, \"value\": 0.00482719}, {\"regressor\": \"rot_x\", \"scan_number\": 4, \"value\": 0.00278328}, {\"regressor\": \"rot_x\", \"scan_number\": 5, \"value\": 0.00330069}, {\"regressor\": \"rot_x\", \"scan_number\": 6, \"value\": 0.00278832}, {\"regressor\": \"rot_x\", \"scan_number\": 7, \"value\": 0.00258923}, {\"regressor\": \"rot_x\", \"scan_number\": 8, \"value\": 0.00213395}, {\"regressor\": \"rot_x\", \"scan_number\": 9, \"value\": 0.00208513}, {\"regressor\": \"rot_x\", \"scan_number\": 10, \"value\": 0.00226022}, {\"regressor\": \"rot_x\", \"scan_number\": 11, \"value\": 0.00337318}, {\"regressor\": \"rot_x\", \"scan_number\": 12, \"value\": 0.00344405}, {\"regressor\": \"rot_x\", \"scan_number\": 13, \"value\": 0.00264987}, {\"regressor\": \"rot_x\", \"scan_number\": 14, \"value\": 0.0046069}, {\"regressor\": \"rot_x\", \"scan_number\": 15, \"value\": 0.00420064}, {\"regressor\": \"rot_x\", \"scan_number\": 16, \"value\": 0.00289768}, {\"regressor\": \"rot_x\", \"scan_number\": 17, \"value\": 0.0008538419999999997}, {\"regressor\": \"rot_x\", \"scan_number\": 18, \"value\": 0.000284642}, {\"regressor\": \"rot_x\", \"scan_number\": 19, \"value\": -0.000254456}, {\"regressor\": \"rot_x\", \"scan_number\": 20, \"value\": 4.79224e-05}, {\"regressor\": \"rot_x\", \"scan_number\": 21, \"value\": -0.000676069}, {\"regressor\": \"rot_x\", \"scan_number\": 22, \"value\": -3.09883e-05}, {\"regressor\": \"rot_x\", \"scan_number\": 23, \"value\": 0.000203044}, {\"regressor\": \"rot_x\", \"scan_number\": 24, \"value\": -0.000512754}, {\"regressor\": \"rot_x\", \"scan_number\": 25, \"value\": -0.00047007}, {\"regressor\": \"rot_x\", \"scan_number\": 26, \"value\": -0.000676069}, {\"regressor\": \"rot_x\", \"scan_number\": 27, \"value\": -0.000491907}, {\"regressor\": \"rot_x\", \"scan_number\": 28, \"value\": -0.000501935}, {\"regressor\": \"rot_x\", \"scan_number\": 29, \"value\": -0.00117749}, {\"regressor\": \"rot_x\", \"scan_number\": 30, \"value\": -0.00145001}, {\"regressor\": \"rot_x\", \"scan_number\": 31, \"value\": -0.00156361}, {\"regressor\": \"rot_x\", \"scan_number\": 32, \"value\": -0.0007706989999999999}, {\"regressor\": \"rot_x\", \"scan_number\": 33, \"value\": -0.000610116}, {\"regressor\": \"rot_x\", \"scan_number\": 34, \"value\": -0.000179396}, {\"regressor\": \"rot_x\", \"scan_number\": 35, \"value\": 9.90895e-06}, {\"regressor\": \"rot_x\", \"scan_number\": 36, \"value\": -0.000139772}, {\"regressor\": \"rot_x\", \"scan_number\": 37, \"value\": 0.000212183}, {\"regressor\": \"rot_x\", \"scan_number\": 38, \"value\": 0.000141019}, {\"regressor\": \"rot_x\", \"scan_number\": 39, \"value\": 0.000193944}, {\"regressor\": \"rot_x\", \"scan_number\": 40, \"value\": 0.000239381}, {\"regressor\": \"rot_x\", \"scan_number\": 41, \"value\": 0.000212734}, {\"regressor\": \"rot_x\", \"scan_number\": 42, \"value\": -0.000318716}, {\"regressor\": \"rot_x\", \"scan_number\": 43, \"value\": 0.000447932}, {\"regressor\": \"rot_x\", \"scan_number\": 44, \"value\": 0.0007368919999999997}, {\"regressor\": \"rot_x\", \"scan_number\": 45, \"value\": 0.00111631}, {\"regressor\": \"rot_x\", \"scan_number\": 46, \"value\": 0.00111631}, {\"regressor\": \"rot_x\", \"scan_number\": 47, \"value\": 0.00124569}, {\"regressor\": \"rot_x\", \"scan_number\": 48, \"value\": 0.000641319}, {\"regressor\": \"rot_x\", \"scan_number\": 49, \"value\": 0.0006926619999999999}, {\"regressor\": \"rot_x\", \"scan_number\": 50, \"value\": 0.00102278}, {\"regressor\": \"rot_x\", \"scan_number\": 51, \"value\": 0.00111631}, {\"regressor\": \"rot_x\", \"scan_number\": 52, \"value\": 0.00117892}, {\"regressor\": \"rot_x\", \"scan_number\": 53, \"value\": 0.00135904}, {\"regressor\": \"rot_x\", \"scan_number\": 54, \"value\": 0.00169676}, {\"regressor\": \"rot_x\", \"scan_number\": 55, \"value\": 0.00111631}, {\"regressor\": \"rot_x\", \"scan_number\": 56, \"value\": 0.00150267}, {\"regressor\": \"rot_x\", \"scan_number\": 57, \"value\": 0.00147852}, {\"regressor\": \"rot_x\", \"scan_number\": 58, \"value\": 0.00122095}, {\"regressor\": \"rot_x\", \"scan_number\": 59, \"value\": 0.00165233}, {\"regressor\": \"rot_x\", \"scan_number\": 60, \"value\": 0.00101087}, {\"regressor\": \"rot_x\", \"scan_number\": 61, \"value\": 0.0007849899999999997}, {\"regressor\": \"rot_x\", \"scan_number\": 62, \"value\": 0.00126017}, {\"regressor\": \"rot_x\", \"scan_number\": 63, \"value\": 0.0019702}, {\"regressor\": \"rot_x\", \"scan_number\": 64, \"value\": 0.001971}, {\"regressor\": \"rot_x\", \"scan_number\": 65, \"value\": 0.00353119}, {\"regressor\": \"rot_x\", \"scan_number\": 66, \"value\": 0.00280583}, {\"regressor\": \"rot_x\", \"scan_number\": 67, \"value\": 0.00300111}, {\"regressor\": \"rot_x\", \"scan_number\": 68, \"value\": 0.00242305}, {\"regressor\": \"rot_x\", \"scan_number\": 69, \"value\": 0.00220667}, {\"regressor\": \"rot_x\", \"scan_number\": 70, \"value\": 0.00173311}, {\"regressor\": \"rot_x\", \"scan_number\": 71, \"value\": -0.000244729}, {\"regressor\": \"rot_x\", \"scan_number\": 72, \"value\": 7.542619999999999e-05}, {\"regressor\": \"rot_x\", \"scan_number\": 73, \"value\": 0.000239741}, {\"regressor\": \"rot_x\", \"scan_number\": 74, \"value\": 0.00130637}, {\"regressor\": \"rot_x\", \"scan_number\": 75, \"value\": 0.00168223}, {\"regressor\": \"rot_x\", \"scan_number\": 76, \"value\": 0.00123222}, {\"regressor\": \"rot_x\", \"scan_number\": 77, \"value\": 0.000939085}, {\"regressor\": \"rot_x\", \"scan_number\": 78, \"value\": 0.0006027119999999999}, {\"regressor\": \"rot_x\", \"scan_number\": 79, \"value\": 0.000972787}, {\"regressor\": \"rot_x\", \"scan_number\": 80, \"value\": 0.000483602}, {\"regressor\": \"rot_x\", \"scan_number\": 81, \"value\": 0.000194425}, {\"regressor\": \"rot_x\", \"scan_number\": 82, \"value\": 0.000551767}, {\"regressor\": \"rot_x\", \"scan_number\": 83, \"value\": 0.00149601}, {\"regressor\": \"rot_x\", \"scan_number\": 84, \"value\": 0.00115003}, {\"regressor\": \"rot_x\", \"scan_number\": 85, \"value\": 0.0012252500000000006}, {\"regressor\": \"rot_x\", \"scan_number\": 86, \"value\": 0.0015615}, {\"regressor\": \"rot_x\", \"scan_number\": 87, \"value\": 0.00209403}, {\"regressor\": \"rot_x\", \"scan_number\": 88, \"value\": 0.00127315}, {\"regressor\": \"rot_x\", \"scan_number\": 89, \"value\": 0.000920135}, {\"regressor\": \"rot_x\", \"scan_number\": 90, \"value\": 0.0016788}, {\"regressor\": \"rot_x\", \"scan_number\": 91, \"value\": 0.00164007}, {\"regressor\": \"rot_x\", \"scan_number\": 92, \"value\": -2.02855e-05}, {\"regressor\": \"rot_x\", \"scan_number\": 93, \"value\": 0.0006242530000000001}, {\"regressor\": \"rot_x\", \"scan_number\": 94, \"value\": 0.00035687}, {\"regressor\": \"rot_x\", \"scan_number\": 95, \"value\": 0.00117068}, {\"regressor\": \"rot_x\", \"scan_number\": 96, \"value\": 0.00133379}, {\"regressor\": \"rot_x\", \"scan_number\": 97, \"value\": 0.0009599640000000002}, {\"regressor\": \"rot_x\", \"scan_number\": 98, \"value\": 0.00145694}, {\"regressor\": \"rot_x\", \"scan_number\": 99, \"value\": 0.0011548900000000006}, {\"regressor\": \"rot_x\", \"scan_number\": 100, \"value\": 0.00112687}, {\"regressor\": \"rot_x\", \"scan_number\": 101, \"value\": 0.000891422}, {\"regressor\": \"rot_x\", \"scan_number\": 102, \"value\": 0.0006827410000000001}, {\"regressor\": \"rot_x\", \"scan_number\": 103, \"value\": 0.000204401}, {\"regressor\": \"rot_x\", \"scan_number\": 104, \"value\": 0.000651751}, {\"regressor\": \"rot_x\", \"scan_number\": 105, \"value\": 0.0013953}, {\"regressor\": \"rot_x\", \"scan_number\": 106, \"value\": 0.00378658}, {\"regressor\": \"rot_x\", \"scan_number\": 107, \"value\": 0.00369298}, {\"regressor\": \"rot_x\", \"scan_number\": 108, \"value\": 0.00294035}, {\"regressor\": \"rot_x\", \"scan_number\": 109, \"value\": 0.0028109000000000003}, {\"regressor\": \"rot_x\", \"scan_number\": 110, \"value\": 0.00281071}, {\"regressor\": \"rot_x\", \"scan_number\": 111, \"value\": 0.00190519}, {\"regressor\": \"rot_x\", \"scan_number\": 112, \"value\": 0.00216138}, {\"regressor\": \"rot_x\", \"scan_number\": 113, \"value\": 0.00332094}, {\"regressor\": \"rot_x\", \"scan_number\": 114, \"value\": 0.00318675}, {\"regressor\": \"rot_x\", \"scan_number\": 115, \"value\": 0.003985}, {\"regressor\": \"rot_x\", \"scan_number\": 116, \"value\": 0.00234754}, {\"regressor\": \"rot_x\", \"scan_number\": 117, \"value\": 0.00313355}, {\"regressor\": \"rot_x\", \"scan_number\": 118, \"value\": 0.00221529}, {\"regressor\": \"rot_x\", \"scan_number\": 119, \"value\": 0.00221529}, {\"regressor\": \"rot_x\", \"scan_number\": 120, \"value\": 0.00280748}, {\"regressor\": \"rot_x\", \"scan_number\": 121, \"value\": 0.00281969}, {\"regressor\": \"rot_x\", \"scan_number\": 122, \"value\": 0.00308444}, {\"regressor\": \"rot_x\", \"scan_number\": 123, \"value\": 0.0031816}, {\"regressor\": \"rot_x\", \"scan_number\": 124, \"value\": 0.00387183}, {\"regressor\": \"rot_x\", \"scan_number\": 125, \"value\": 0.00366035}, {\"regressor\": \"rot_x\", \"scan_number\": 126, \"value\": 0.00500289}, {\"regressor\": \"rot_x\", \"scan_number\": 127, \"value\": 0.00593915}, {\"regressor\": \"rot_x\", \"scan_number\": 128, \"value\": 0.00546054}, {\"regressor\": \"rot_x\", \"scan_number\": 129, \"value\": 0.00617737}, {\"regressor\": \"rot_x\", \"scan_number\": 130, \"value\": 0.00473235}, {\"regressor\": \"rot_x\", \"scan_number\": 131, \"value\": 0.00376562}, {\"regressor\": \"rot_x\", \"scan_number\": 132, \"value\": 0.00370173}, {\"regressor\": \"rot_x\", \"scan_number\": 133, \"value\": 0.00501764}, {\"regressor\": \"rot_x\", \"scan_number\": 134, \"value\": 0.00428554}, {\"regressor\": \"rot_x\", \"scan_number\": 135, \"value\": 0.00432671}, {\"regressor\": \"rot_x\", \"scan_number\": 136, \"value\": 0.00344005}, {\"regressor\": \"rot_x\", \"scan_number\": 137, \"value\": 0.0042471}, {\"regressor\": \"rot_x\", \"scan_number\": 138, \"value\": 0.00270561}, {\"regressor\": \"rot_x\", \"scan_number\": 139, \"value\": 0.00168888}, {\"regressor\": \"rot_x\", \"scan_number\": 140, \"value\": 0.0006747939999999999}, {\"regressor\": \"rot_x\", \"scan_number\": 141, \"value\": 0.001104}, {\"regressor\": \"rot_x\", \"scan_number\": 142, \"value\": 0.00147906}, {\"regressor\": \"rot_x\", \"scan_number\": 143, \"value\": 0.00169769}, {\"regressor\": \"rot_x\", \"scan_number\": 144, \"value\": 0.000604629}, {\"regressor\": \"rot_x\", \"scan_number\": 145, \"value\": 0.00329588}, {\"regressor\": \"rot_x\", \"scan_number\": 146, \"value\": 0.00450766}, {\"regressor\": \"rot_x\", \"scan_number\": 147, \"value\": 0.00174025}, {\"regressor\": \"rot_x\", \"scan_number\": 148, \"value\": 0.00127118}, {\"regressor\": \"rot_x\", \"scan_number\": 149, \"value\": 0.00111996}, {\"regressor\": \"rot_x\", \"scan_number\": 150, \"value\": 0.000379984}, {\"regressor\": \"rot_x\", \"scan_number\": 151, \"value\": -0.00186492}, {\"regressor\": \"rot_x\", \"scan_number\": 152, \"value\": -0.00374176}, {\"regressor\": \"rot_x\", \"scan_number\": 153, \"value\": -0.00607824}, {\"regressor\": \"rot_x\", \"scan_number\": 154, \"value\": -0.00709709}, {\"regressor\": \"rot_x\", \"scan_number\": 155, \"value\": -0.008335979999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 156, \"value\": -0.00807785}, {\"regressor\": \"rot_x\", \"scan_number\": 157, \"value\": -0.00739523}, {\"regressor\": \"rot_x\", \"scan_number\": 158, \"value\": -0.00651781}, {\"regressor\": \"rot_x\", \"scan_number\": 159, \"value\": -0.008051209999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 160, \"value\": -0.00759337}, {\"regressor\": \"rot_x\", \"scan_number\": 161, \"value\": -0.0065907}, {\"regressor\": \"rot_x\", \"scan_number\": 162, \"value\": -0.00526412}, {\"regressor\": \"rot_x\", \"scan_number\": 163, \"value\": -0.00634735}, {\"regressor\": \"rot_x\", \"scan_number\": 164, \"value\": -0.00564507}, {\"regressor\": \"rot_x\", \"scan_number\": 165, \"value\": -0.00532278}, {\"regressor\": \"rot_x\", \"scan_number\": 166, \"value\": -0.00551458}, {\"regressor\": \"rot_x\", \"scan_number\": 167, \"value\": -0.00462052}, {\"regressor\": \"rot_x\", \"scan_number\": 168, \"value\": -0.00545795}, {\"regressor\": \"rot_x\", \"scan_number\": 169, \"value\": -0.00661453}, {\"regressor\": \"rot_x\", \"scan_number\": 170, \"value\": -0.00602689}, {\"regressor\": \"rot_x\", \"scan_number\": 171, \"value\": -0.00531861}, {\"regressor\": \"rot_x\", \"scan_number\": 172, \"value\": -0.00260637}, {\"regressor\": \"rot_x\", \"scan_number\": 173, \"value\": -0.000959257}, {\"regressor\": \"rot_x\", \"scan_number\": 174, \"value\": -0.0011462999999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 175, \"value\": -0.00254759}, {\"regressor\": \"rot_x\", \"scan_number\": 176, \"value\": -0.00268891}, {\"regressor\": \"rot_x\", \"scan_number\": 177, \"value\": -0.00176515}, {\"regressor\": \"rot_x\", \"scan_number\": 178, \"value\": -0.00388128}, {\"regressor\": \"rot_x\", \"scan_number\": 179, \"value\": -0.0036724000000000006}, {\"regressor\": \"rot_x\", \"scan_number\": 180, \"value\": -0.00314985}, {\"regressor\": \"rot_x\", \"scan_number\": 181, \"value\": -0.00381867}, {\"regressor\": \"rot_x\", \"scan_number\": 182, \"value\": -0.00317909}, {\"regressor\": \"rot_x\", \"scan_number\": 183, \"value\": -0.00245757}, {\"regressor\": \"rot_x\", \"scan_number\": 184, \"value\": -0.00342926}, {\"regressor\": \"rot_x\", \"scan_number\": 185, \"value\": -0.00445082}, {\"regressor\": \"rot_x\", \"scan_number\": 186, \"value\": -0.00448878}, {\"regressor\": \"rot_x\", \"scan_number\": 187, \"value\": -0.00452635}, {\"regressor\": \"rot_x\", \"scan_number\": 188, \"value\": -0.00308156}, {\"regressor\": \"rot_x\", \"scan_number\": 189, \"value\": -0.00334303}, {\"regressor\": \"rot_x\", \"scan_number\": 190, \"value\": -0.00414402}, {\"regressor\": \"rot_x\", \"scan_number\": 191, \"value\": -0.00463451}, {\"regressor\": \"rot_x\", \"scan_number\": 192, \"value\": -0.00486588}, {\"regressor\": \"rot_x\", \"scan_number\": 193, \"value\": -0.00466138}, {\"regressor\": \"rot_x\", \"scan_number\": 194, \"value\": -0.00448052}, {\"regressor\": \"rot_x\", \"scan_number\": 195, \"value\": -0.0042294}, {\"regressor\": \"rot_x\", \"scan_number\": 196, \"value\": -0.00428858}, {\"regressor\": \"rot_x\", \"scan_number\": 197, \"value\": -0.00466369}, {\"regressor\": \"rot_x\", \"scan_number\": 198, \"value\": -0.00456032}, {\"regressor\": \"rot_x\", \"scan_number\": 199, \"value\": -0.00522464}, {\"regressor\": \"rot_x\", \"scan_number\": 200, \"value\": -0.00509997}, {\"regressor\": \"rot_x\", \"scan_number\": 201, \"value\": -0.00543543}, {\"regressor\": \"rot_x\", \"scan_number\": 202, \"value\": -0.0052202}, {\"regressor\": \"rot_x\", \"scan_number\": 203, \"value\": -0.00523536}, {\"regressor\": \"rot_x\", \"scan_number\": 204, \"value\": -0.00568265}, {\"regressor\": \"rot_x\", \"scan_number\": 205, \"value\": -0.00507403}, {\"regressor\": \"rot_x\", \"scan_number\": 206, \"value\": -0.00579136}, {\"regressor\": \"rot_x\", \"scan_number\": 207, \"value\": -0.0058155}, {\"regressor\": \"rot_x\", \"scan_number\": 208, \"value\": -0.00628307}, {\"regressor\": \"rot_x\", \"scan_number\": 209, \"value\": -0.0062033}, {\"regressor\": \"rot_x\", \"scan_number\": 210, \"value\": -0.00589258}, {\"regressor\": \"rot_x\", \"scan_number\": 211, \"value\": -0.00589258}, {\"regressor\": \"rot_x\", \"scan_number\": 212, \"value\": -0.00608063}, {\"regressor\": \"rot_x\", \"scan_number\": 213, \"value\": -0.00620539}, {\"regressor\": \"rot_x\", \"scan_number\": 214, \"value\": -0.00700355}, {\"regressor\": \"rot_x\", \"scan_number\": 215, \"value\": -0.007419239999999999}, {\"regressor\": \"rot_x\", \"scan_number\": 216, \"value\": -0.008227099999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 217, \"value\": -0.007486559999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 218, \"value\": -0.00780826}, {\"regressor\": \"rot_x\", \"scan_number\": 219, \"value\": -0.00797972}, {\"regressor\": \"rot_x\", \"scan_number\": 220, \"value\": -0.00782768}, {\"regressor\": \"rot_x\", \"scan_number\": 221, \"value\": -0.00587604}, {\"regressor\": \"rot_x\", \"scan_number\": 222, \"value\": -0.00675864}, {\"regressor\": \"rot_x\", \"scan_number\": 223, \"value\": -0.00645463}, {\"regressor\": \"rot_x\", \"scan_number\": 224, \"value\": -0.006442}, {\"regressor\": \"rot_x\", \"scan_number\": 225, \"value\": -0.00715238}, {\"regressor\": \"rot_x\", \"scan_number\": 226, \"value\": -0.00505549}, {\"regressor\": \"rot_x\", \"scan_number\": 227, \"value\": -0.00402074}, {\"regressor\": \"rot_x\", \"scan_number\": 228, \"value\": -0.00251154}, {\"regressor\": \"rot_x\", \"scan_number\": 229, \"value\": -0.00523322}, {\"regressor\": \"rot_x\", \"scan_number\": 230, \"value\": -0.00622656}, {\"regressor\": \"rot_x\", \"scan_number\": 231, \"value\": -0.00483239}, {\"regressor\": \"rot_x\", \"scan_number\": 232, \"value\": -0.00655076}, {\"regressor\": \"rot_x\", \"scan_number\": 233, \"value\": -0.00691331}, {\"regressor\": \"rot_x\", \"scan_number\": 234, \"value\": -0.007258129999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 235, \"value\": -0.009510190000000005}, {\"regressor\": \"rot_x\", \"scan_number\": 236, \"value\": -0.0101419}, {\"regressor\": \"rot_x\", \"scan_number\": 237, \"value\": -0.010312200000000002}, {\"regressor\": \"rot_x\", \"scan_number\": 238, \"value\": -0.0110985}, {\"regressor\": \"rot_x\", \"scan_number\": 239, \"value\": -0.0103255}, {\"regressor\": \"rot_x\", \"scan_number\": 240, \"value\": -0.00800755}, {\"regressor\": \"rot_x\", \"scan_number\": 241, \"value\": -0.008399719999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 242, \"value\": -0.00901212}, {\"regressor\": \"rot_x\", \"scan_number\": 243, \"value\": -0.00924003}, {\"regressor\": \"rot_x\", \"scan_number\": 244, \"value\": -0.00960271}, {\"regressor\": \"rot_x\", \"scan_number\": 245, \"value\": -0.0100814}, {\"regressor\": \"rot_x\", \"scan_number\": 246, \"value\": -0.011843}, {\"regressor\": \"rot_x\", \"scan_number\": 247, \"value\": -0.0119059}, {\"regressor\": \"rot_x\", \"scan_number\": 248, \"value\": -0.0122403}, {\"regressor\": \"rot_x\", \"scan_number\": 249, \"value\": -0.0126017}, {\"regressor\": \"rot_x\", \"scan_number\": 250, \"value\": -0.0127144}, {\"regressor\": \"rot_x\", \"scan_number\": 251, \"value\": -0.0132563}, {\"regressor\": \"rot_x\", \"scan_number\": 252, \"value\": -0.012775299999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 253, \"value\": -0.0136658}, {\"regressor\": \"rot_x\", \"scan_number\": 254, \"value\": -0.0142237}, {\"regressor\": \"rot_x\", \"scan_number\": 255, \"value\": -0.013786}, {\"regressor\": \"rot_x\", \"scan_number\": 256, \"value\": -0.0158464}, {\"regressor\": \"rot_x\", \"scan_number\": 257, \"value\": -0.0164164}, {\"regressor\": \"rot_x\", \"scan_number\": 258, \"value\": -0.0172541}, {\"regressor\": \"rot_x\", \"scan_number\": 259, \"value\": -0.017619}, {\"regressor\": \"rot_x\", \"scan_number\": 260, \"value\": -0.0171335}, {\"regressor\": \"rot_x\", \"scan_number\": 261, \"value\": -0.016835}, {\"regressor\": \"rot_x\", \"scan_number\": 262, \"value\": -0.016841}, {\"regressor\": \"rot_x\", \"scan_number\": 263, \"value\": -0.017163999999999995}, {\"regressor\": \"rot_x\", \"scan_number\": 264, \"value\": -0.017656799999999997}, {\"regressor\": \"rot_x\", \"scan_number\": 265, \"value\": -0.0190401}, {\"regressor\": \"rot_x\", \"scan_number\": 266, \"value\": -0.0186438}, {\"regressor\": \"rot_x\", \"scan_number\": 267, \"value\": -0.0179329}, {\"regressor\": \"rot_x\", \"scan_number\": 268, \"value\": -0.0185209}, {\"regressor\": \"rot_x\", \"scan_number\": 269, \"value\": -0.0184183}, {\"regressor\": \"rot_x\", \"scan_number\": 270, \"value\": -0.0187134}, {\"regressor\": \"rot_x\", \"scan_number\": 271, \"value\": -0.01926}, {\"regressor\": \"rot_x\", \"scan_number\": 272, \"value\": -0.0184736}, {\"regressor\": \"rot_x\", \"scan_number\": 273, \"value\": -0.0184322}, {\"regressor\": \"rot_x\", \"scan_number\": 274, \"value\": -0.0182886}, {\"regressor\": \"rot_x\", \"scan_number\": 275, \"value\": -0.017788099999999998}, {\"regressor\": \"rot_x\", \"scan_number\": 276, \"value\": -0.0185565}, {\"regressor\": \"rot_x\", \"scan_number\": 277, \"value\": -0.0183432}, {\"regressor\": \"rot_x\", \"scan_number\": 278, \"value\": -0.018489}, {\"regressor\": \"rot_x\", \"scan_number\": 279, \"value\": -0.0197316}, {\"regressor\": \"rot_x\", \"scan_number\": 280, \"value\": -0.020248500000000003}, {\"regressor\": \"rot_x\", \"scan_number\": 281, \"value\": -0.0201234}, {\"regressor\": \"rot_x\", \"scan_number\": 282, \"value\": -0.020248500000000003}, {\"regressor\": \"rot_x\", \"scan_number\": 283, \"value\": -0.0201697}, {\"regressor\": \"rot_x\", \"scan_number\": 284, \"value\": -0.0201531}, {\"regressor\": \"rot_x\", \"scan_number\": 285, \"value\": -0.0198317}, {\"regressor\": \"rot_x\", \"scan_number\": 286, \"value\": -0.0189513}, {\"regressor\": \"rot_x\", \"scan_number\": 287, \"value\": -0.0189143}, {\"regressor\": \"rot_x\", \"scan_number\": 288, \"value\": -0.0198469}, {\"regressor\": \"rot_x\", \"scan_number\": 289, \"value\": -0.0199413}, {\"regressor\": \"rot_x\", \"scan_number\": 290, \"value\": -0.019424}, {\"regressor\": \"rot_x\", \"scan_number\": 291, \"value\": -0.0192533}, {\"regressor\": \"rot_x\", \"scan_number\": 292, \"value\": -0.0196225}, {\"regressor\": \"rot_x\", \"scan_number\": 293, \"value\": -0.0202356}, {\"regressor\": \"rot_x\", \"scan_number\": 294, \"value\": -0.02038}, {\"regressor\": \"rot_x\", \"scan_number\": 295, \"value\": -0.0208761}, {\"regressor\": \"rot_x\", \"scan_number\": 296, \"value\": -0.0203482}, {\"regressor\": \"rot_x\", \"scan_number\": 297, \"value\": -0.0207522}, {\"regressor\": \"rot_x\", \"scan_number\": 298, \"value\": -0.0199151}, {\"regressor\": \"rot_x\", \"scan_number\": 299, \"value\": -0.0193627}, {\"regressor\": \"rot_x\", \"scan_number\": 300, \"value\": -0.0187477}, {\"regressor\": \"rot_x\", \"scan_number\": 301, \"value\": -0.0189587}, {\"regressor\": \"rot_x\", \"scan_number\": 302, \"value\": -0.0189924}, {\"regressor\": \"rot_x\", \"scan_number\": 303, \"value\": -0.0189691}, {\"regressor\": \"rot_x\", \"scan_number\": 304, \"value\": -0.0189835}, {\"regressor\": \"rot_x\", \"scan_number\": 305, \"value\": -0.0193303}, {\"regressor\": \"rot_x\", \"scan_number\": 306, \"value\": -0.017564}, {\"regressor\": \"rot_x\", \"scan_number\": 307, \"value\": -0.0196144}, {\"regressor\": \"rot_x\", \"scan_number\": 308, \"value\": -0.0205412}, {\"regressor\": \"rot_x\", \"scan_number\": 309, \"value\": -0.0191431}, {\"regressor\": \"rot_x\", \"scan_number\": 310, \"value\": -0.017628399999999995}, {\"regressor\": \"rot_x\", \"scan_number\": 311, \"value\": -0.0174364}, {\"regressor\": \"rot_x\", \"scan_number\": 312, \"value\": -0.0179606}, {\"regressor\": \"rot_x\", \"scan_number\": 313, \"value\": -0.0177647}, {\"regressor\": \"rot_x\", \"scan_number\": 314, \"value\": -0.0177043}, {\"regressor\": \"rot_x\", \"scan_number\": 315, \"value\": -0.018125400000000003}, {\"regressor\": \"rot_x\", \"scan_number\": 316, \"value\": -0.0187697}, {\"regressor\": \"rot_x\", \"scan_number\": 317, \"value\": -0.0188895}, {\"regressor\": \"rot_x\", \"scan_number\": 318, \"value\": -0.0180922}, {\"regressor\": \"rot_x\", \"scan_number\": 319, \"value\": -0.0187719}, {\"regressor\": \"rot_x\", \"scan_number\": 320, \"value\": -0.0189246}, {\"regressor\": \"rot_x\", \"scan_number\": 321, \"value\": -0.0189948}, {\"regressor\": \"rot_x\", \"scan_number\": 322, \"value\": -0.0187096}, {\"regressor\": \"rot_x\", \"scan_number\": 323, \"value\": -0.0187983}, {\"regressor\": \"rot_x\", \"scan_number\": 324, \"value\": -0.0180205}, {\"regressor\": \"rot_x\", \"scan_number\": 325, \"value\": -0.0180205}, {\"regressor\": \"rot_x\", \"scan_number\": 326, \"value\": -0.0180205}, {\"regressor\": \"rot_x\", \"scan_number\": 327, \"value\": -0.0187199}, {\"regressor\": \"rot_x\", \"scan_number\": 328, \"value\": -0.017498}, {\"regressor\": \"rot_x\", \"scan_number\": 329, \"value\": -0.019727}, {\"regressor\": \"rot_x\", \"scan_number\": 330, \"value\": -0.0185086}, {\"regressor\": \"rot_x\", \"scan_number\": 331, \"value\": -0.0201025}, {\"regressor\": \"rot_x\", \"scan_number\": 332, \"value\": -0.0203339}, {\"regressor\": \"rot_x\", \"scan_number\": 333, \"value\": -0.0203517}, {\"regressor\": \"rot_x\", \"scan_number\": 334, \"value\": -0.0201961}, {\"regressor\": \"rot_x\", \"scan_number\": 335, \"value\": -0.0203018}, {\"regressor\": \"rot_x\", \"scan_number\": 336, \"value\": -0.0194138}, {\"regressor\": \"rot_x\", \"scan_number\": 337, \"value\": -0.020056}, {\"regressor\": \"rot_x\", \"scan_number\": 338, \"value\": -0.019921900000000003}, {\"regressor\": \"rot_x\", \"scan_number\": 339, \"value\": -0.0201298}, {\"regressor\": \"rot_x\", \"scan_number\": 340, \"value\": -0.020709400000000003}, {\"regressor\": \"rot_x\", \"scan_number\": 341, \"value\": -0.019907}, {\"regressor\": \"rot_x\", \"scan_number\": 342, \"value\": -0.0200593}, {\"regressor\": \"rot_x\", \"scan_number\": 343, \"value\": -0.0205695}, {\"regressor\": \"rot_y\", \"scan_number\": 0, \"value\": 0.000553599}, {\"regressor\": \"rot_y\", \"scan_number\": 1, \"value\": -0.000251714}, {\"regressor\": \"rot_y\", \"scan_number\": 2, \"value\": -0.0005326290000000001}, {\"regressor\": \"rot_y\", \"scan_number\": 3, \"value\": -0.00172359}, {\"regressor\": \"rot_y\", \"scan_number\": 4, \"value\": -0.0007252619999999997}, {\"regressor\": \"rot_y\", \"scan_number\": 5, \"value\": -0.000406836}, {\"regressor\": \"rot_y\", \"scan_number\": 6, \"value\": 2.67789e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 7, \"value\": -0.000213244}, {\"regressor\": \"rot_y\", \"scan_number\": 8, \"value\": -0.000281348}, {\"regressor\": \"rot_y\", \"scan_number\": 9, \"value\": -0.000213244}, {\"regressor\": \"rot_y\", \"scan_number\": 10, \"value\": 7.2873199999999985e-06}, {\"regressor\": \"rot_y\", \"scan_number\": 11, \"value\": -0.000213244}, {\"regressor\": \"rot_y\", \"scan_number\": 12, \"value\": -0.000416872}, {\"regressor\": \"rot_y\", \"scan_number\": 13, \"value\": -0.000213244}, {\"regressor\": \"rot_y\", \"scan_number\": 14, \"value\": -0.000213244}, {\"regressor\": \"rot_y\", \"scan_number\": 15, \"value\": 4.05145e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 16, \"value\": -0.000607976}, {\"regressor\": \"rot_y\", \"scan_number\": 17, \"value\": 0.000166348}, {\"regressor\": \"rot_y\", \"scan_number\": 18, \"value\": 0.000166607}, {\"regressor\": \"rot_y\", \"scan_number\": 19, \"value\": 7.11799e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 20, \"value\": -3.12962e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 21, \"value\": 1.43704e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 22, \"value\": -1.65521e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 23, \"value\": -8.94588e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 24, \"value\": -1.3120100000000005e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 25, \"value\": 8.990669999999997e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 26, \"value\": 8.990669999999997e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 27, \"value\": 8.99068e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 28, \"value\": -1.641e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 29, \"value\": 8.990669999999997e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 30, \"value\": 8.990669999999997e-05}, {\"regressor\": \"rot_y\", \"scan_number\": 31, \"value\": 0.000424392}, {\"regressor\": \"rot_y\", \"scan_number\": 32, \"value\": 0.000653198}, {\"regressor\": \"rot_y\", \"scan_number\": 33, \"value\": 0.00106137}, {\"regressor\": \"rot_y\", \"scan_number\": 34, \"value\": 0.000933967}, {\"regressor\": \"rot_y\", \"scan_number\": 35, \"value\": 0.00123555}, {\"regressor\": \"rot_y\", \"scan_number\": 36, \"value\": 0.00139395}, {\"regressor\": \"rot_y\", \"scan_number\": 37, \"value\": 0.00155235}, {\"regressor\": \"rot_y\", \"scan_number\": 38, \"value\": 0.00153379}, {\"regressor\": \"rot_y\", \"scan_number\": 39, \"value\": 0.00184891}, {\"regressor\": \"rot_y\", \"scan_number\": 40, \"value\": 0.0016367}, {\"regressor\": \"rot_y\", \"scan_number\": 41, \"value\": 0.00184891}, {\"regressor\": \"rot_y\", \"scan_number\": 42, \"value\": 0.00184891}, {\"regressor\": \"rot_y\", \"scan_number\": 43, \"value\": 0.00184891}, {\"regressor\": \"rot_y\", \"scan_number\": 44, \"value\": 0.00184891}, {\"regressor\": \"rot_y\", \"scan_number\": 45, \"value\": 0.00175215}, {\"regressor\": \"rot_y\", \"scan_number\": 46, \"value\": 0.00178107}, {\"regressor\": \"rot_y\", \"scan_number\": 47, \"value\": 0.00184891}, {\"regressor\": \"rot_y\", \"scan_number\": 48, \"value\": 0.00144132}, {\"regressor\": \"rot_y\", \"scan_number\": 49, \"value\": 0.00137299}, {\"regressor\": \"rot_y\", \"scan_number\": 50, \"value\": 0.00137299}, {\"regressor\": \"rot_y\", \"scan_number\": 51, \"value\": 0.00188898}, {\"regressor\": \"rot_y\", \"scan_number\": 52, \"value\": 0.0017372}, {\"regressor\": \"rot_y\", \"scan_number\": 53, \"value\": 0.00137299}, {\"regressor\": \"rot_y\", \"scan_number\": 54, \"value\": 0.00137299}, {\"regressor\": \"rot_y\", \"scan_number\": 55, \"value\": 0.00193024}, {\"regressor\": \"rot_y\", \"scan_number\": 56, \"value\": 0.00210356}, {\"regressor\": \"rot_y\", \"scan_number\": 57, \"value\": 0.00184441}, {\"regressor\": \"rot_y\", \"scan_number\": 58, \"value\": 0.00193449}, {\"regressor\": \"rot_y\", \"scan_number\": 59, \"value\": 0.00214529}, {\"regressor\": \"rot_y\", \"scan_number\": 60, \"value\": 0.00223715}, {\"regressor\": \"rot_y\", \"scan_number\": 61, \"value\": 0.00207982}, {\"regressor\": \"rot_y\", \"scan_number\": 62, \"value\": 0.00235734}, {\"regressor\": \"rot_y\", \"scan_number\": 63, \"value\": 0.00243497}, {\"regressor\": \"rot_y\", \"scan_number\": 64, \"value\": 0.00250202}, {\"regressor\": \"rot_y\", \"scan_number\": 65, \"value\": 0.0025064}, {\"regressor\": \"rot_y\", \"scan_number\": 66, \"value\": 0.00291262}, {\"regressor\": \"rot_y\", \"scan_number\": 67, \"value\": 0.00301048}, {\"regressor\": \"rot_y\", \"scan_number\": 68, \"value\": 0.0026538}, {\"regressor\": \"rot_y\", \"scan_number\": 69, \"value\": 0.00238809}, {\"regressor\": \"rot_y\", \"scan_number\": 70, \"value\": 0.00213796}, {\"regressor\": \"rot_y\", \"scan_number\": 71, \"value\": 0.00213796}, {\"regressor\": \"rot_y\", \"scan_number\": 72, \"value\": 0.00213796}, {\"regressor\": \"rot_y\", \"scan_number\": 73, \"value\": 0.00213796}, {\"regressor\": \"rot_y\", \"scan_number\": 74, \"value\": 0.00253508}, {\"regressor\": \"rot_y\", \"scan_number\": 75, \"value\": 0.00190528}, {\"regressor\": \"rot_y\", \"scan_number\": 76, \"value\": 0.00235169}, {\"regressor\": \"rot_y\", \"scan_number\": 77, \"value\": 0.00328748}, {\"regressor\": \"rot_y\", \"scan_number\": 78, \"value\": 0.00328748}, {\"regressor\": \"rot_y\", \"scan_number\": 79, \"value\": 0.00370326}, {\"regressor\": \"rot_y\", \"scan_number\": 80, \"value\": 0.003876}, {\"regressor\": \"rot_y\", \"scan_number\": 81, \"value\": 0.003876}, {\"regressor\": \"rot_y\", \"scan_number\": 82, \"value\": 0.003876}, {\"regressor\": \"rot_y\", \"scan_number\": 83, \"value\": 0.00381559}, {\"regressor\": \"rot_y\", \"scan_number\": 84, \"value\": 0.00404421}, {\"regressor\": \"rot_y\", \"scan_number\": 85, \"value\": 0.00415604}, {\"regressor\": \"rot_y\", \"scan_number\": 86, \"value\": 0.003876}, {\"regressor\": \"rot_y\", \"scan_number\": 87, \"value\": 0.00401669}, {\"regressor\": \"rot_y\", \"scan_number\": 88, \"value\": 0.00392948}, {\"regressor\": \"rot_y\", \"scan_number\": 89, \"value\": 0.00429619}, {\"regressor\": \"rot_y\", \"scan_number\": 90, \"value\": 0.00429619}, {\"regressor\": \"rot_y\", \"scan_number\": 91, \"value\": 0.00408591}, {\"regressor\": \"rot_y\", \"scan_number\": 92, \"value\": 0.00429619}, {\"regressor\": \"rot_y\", \"scan_number\": 93, \"value\": 0.00410649}, {\"regressor\": \"rot_y\", \"scan_number\": 94, \"value\": 0.0040789}, {\"regressor\": \"rot_y\", \"scan_number\": 95, \"value\": 0.0035911000000000007}, {\"regressor\": \"rot_y\", \"scan_number\": 96, \"value\": 0.0035911000000000007}, {\"regressor\": \"rot_y\", \"scan_number\": 97, \"value\": 0.00375152}, {\"regressor\": \"rot_y\", \"scan_number\": 98, \"value\": 0.00395625}, {\"regressor\": \"rot_y\", \"scan_number\": 99, \"value\": 0.00385507}, {\"regressor\": \"rot_y\", \"scan_number\": 100, \"value\": 0.00363719}, {\"regressor\": \"rot_y\", \"scan_number\": 101, \"value\": 0.00369281}, {\"regressor\": \"rot_y\", \"scan_number\": 102, \"value\": 0.00350276}, {\"regressor\": \"rot_y\", \"scan_number\": 103, \"value\": 0.00349174}, {\"regressor\": \"rot_y\", \"scan_number\": 104, \"value\": 0.00364555}, {\"regressor\": \"rot_y\", \"scan_number\": 105, \"value\": 0.00395104}, {\"regressor\": \"rot_y\", \"scan_number\": 106, \"value\": 0.00365729}, {\"regressor\": \"rot_y\", \"scan_number\": 107, \"value\": 0.00403068}, {\"regressor\": \"rot_y\", \"scan_number\": 108, \"value\": 0.00383242}, {\"regressor\": \"rot_y\", \"scan_number\": 109, \"value\": 0.00387226}, {\"regressor\": \"rot_y\", \"scan_number\": 110, \"value\": 0.00376038}, {\"regressor\": \"rot_y\", \"scan_number\": 111, \"value\": 0.0036325}, {\"regressor\": \"rot_y\", \"scan_number\": 112, \"value\": 0.00396555}, {\"regressor\": \"rot_y\", \"scan_number\": 113, \"value\": 0.00384121}, {\"regressor\": \"rot_y\", \"scan_number\": 114, \"value\": 0.00638834}, {\"regressor\": \"rot_y\", \"scan_number\": 115, \"value\": 0.0071804}, {\"regressor\": \"rot_y\", \"scan_number\": 116, \"value\": 0.008900659999999998}, {\"regressor\": \"rot_y\", \"scan_number\": 117, \"value\": 0.00910051}, {\"regressor\": \"rot_y\", \"scan_number\": 118, \"value\": 0.008378369999999998}, {\"regressor\": \"rot_y\", \"scan_number\": 119, \"value\": 0.008533439999999998}, {\"regressor\": \"rot_y\", \"scan_number\": 120, \"value\": 0.007560899999999998}, {\"regressor\": \"rot_y\", \"scan_number\": 121, \"value\": 0.00703577}, {\"regressor\": \"rot_y\", \"scan_number\": 122, \"value\": 0.00714324}, {\"regressor\": \"rot_y\", \"scan_number\": 123, \"value\": 0.00615788}, {\"regressor\": \"rot_y\", \"scan_number\": 124, \"value\": 0.00596946}, {\"regressor\": \"rot_y\", \"scan_number\": 125, \"value\": 0.0050984}, {\"regressor\": \"rot_y\", \"scan_number\": 126, \"value\": 0.00634514}, {\"regressor\": \"rot_y\", \"scan_number\": 127, \"value\": 0.00624117}, {\"regressor\": \"rot_y\", \"scan_number\": 128, \"value\": 0.006423399999999999}, {\"regressor\": \"rot_y\", \"scan_number\": 129, \"value\": 0.00541408}, {\"regressor\": \"rot_y\", \"scan_number\": 130, \"value\": 0.00533107}, {\"regressor\": \"rot_y\", \"scan_number\": 131, \"value\": 0.00531368}, {\"regressor\": \"rot_y\", \"scan_number\": 132, \"value\": 0.00497199}, {\"regressor\": \"rot_y\", \"scan_number\": 133, \"value\": 0.00516175}, {\"regressor\": \"rot_y\", \"scan_number\": 134, \"value\": 0.00477441}, {\"regressor\": \"rot_y\", \"scan_number\": 135, \"value\": 0.00547644}, {\"regressor\": \"rot_y\", \"scan_number\": 136, \"value\": 0.00594639}, {\"regressor\": \"rot_y\", \"scan_number\": 137, \"value\": 0.0052644}, {\"regressor\": \"rot_y\", \"scan_number\": 138, \"value\": 0.00391877}, {\"regressor\": \"rot_y\", \"scan_number\": 139, \"value\": 0.00324651}, {\"regressor\": \"rot_y\", \"scan_number\": 140, \"value\": 0.00650568}, {\"regressor\": \"rot_y\", \"scan_number\": 141, \"value\": 0.00645585}, {\"regressor\": \"rot_y\", \"scan_number\": 142, \"value\": 0.00488666}, {\"regressor\": \"rot_y\", \"scan_number\": 143, \"value\": 0.00194884}, {\"regressor\": \"rot_y\", \"scan_number\": 144, \"value\": 0.00160455}, {\"regressor\": \"rot_y\", \"scan_number\": 145, \"value\": 0.00322987}, {\"regressor\": \"rot_y\", \"scan_number\": 146, \"value\": 0.00347982}, {\"regressor\": \"rot_y\", \"scan_number\": 147, \"value\": 0.00184805}, {\"regressor\": \"rot_y\", \"scan_number\": 148, \"value\": 0.00106061}, {\"regressor\": \"rot_y\", \"scan_number\": 149, \"value\": 0.00140284}, {\"regressor\": \"rot_y\", \"scan_number\": 150, \"value\": 0.00143723}, {\"regressor\": \"rot_y\", \"scan_number\": 151, \"value\": 0.000981658}, {\"regressor\": \"rot_y\", \"scan_number\": 152, \"value\": 0.000713698}, {\"regressor\": \"rot_y\", \"scan_number\": 153, \"value\": 0.00123211}, {\"regressor\": \"rot_y\", \"scan_number\": 154, \"value\": 0.00156826}, {\"regressor\": \"rot_y\", \"scan_number\": 155, \"value\": 0.00149771}, {\"regressor\": \"rot_y\", \"scan_number\": 156, \"value\": 0.00123138}, {\"regressor\": \"rot_y\", \"scan_number\": 157, \"value\": 0.000587559}, {\"regressor\": \"rot_y\", \"scan_number\": 158, \"value\": 0.0012083}, {\"regressor\": \"rot_y\", \"scan_number\": 159, \"value\": 0.00162968}, {\"regressor\": \"rot_y\", \"scan_number\": 160, \"value\": 0.00131607}, {\"regressor\": \"rot_y\", \"scan_number\": 161, \"value\": 0.00148195}, {\"regressor\": \"rot_y\", \"scan_number\": 162, \"value\": 0.00228365}, {\"regressor\": \"rot_y\", \"scan_number\": 163, \"value\": 0.00272115}, {\"regressor\": \"rot_y\", \"scan_number\": 164, \"value\": 0.0012642}, {\"regressor\": \"rot_y\", \"scan_number\": 165, \"value\": 0.00131056}, {\"regressor\": \"rot_y\", \"scan_number\": 166, \"value\": 0.00200378}, {\"regressor\": \"rot_y\", \"scan_number\": 167, \"value\": 0.00216838}, {\"regressor\": \"rot_y\", \"scan_number\": 168, \"value\": 0.0026598000000000004}, {\"regressor\": \"rot_y\", \"scan_number\": 169, \"value\": 0.00357157}, {\"regressor\": \"rot_y\", \"scan_number\": 170, \"value\": 0.00343039}, {\"regressor\": \"rot_y\", \"scan_number\": 171, \"value\": 0.00304918}, {\"regressor\": \"rot_y\", \"scan_number\": 172, \"value\": 0.0011555300000000005}, {\"regressor\": \"rot_y\", \"scan_number\": 173, \"value\": 0.0017465999999999998}, {\"regressor\": \"rot_y\", \"scan_number\": 174, \"value\": 0.00277195}, {\"regressor\": \"rot_y\", \"scan_number\": 175, \"value\": 0.003003}, {\"regressor\": \"rot_y\", \"scan_number\": 176, \"value\": 0.00298157}, {\"regressor\": \"rot_y\", \"scan_number\": 177, \"value\": 0.00325067}, {\"regressor\": \"rot_y\", \"scan_number\": 178, \"value\": 0.00407548}, {\"regressor\": \"rot_y\", \"scan_number\": 179, \"value\": 0.00453588}, {\"regressor\": \"rot_y\", \"scan_number\": 180, \"value\": 0.00430823}, {\"regressor\": \"rot_y\", \"scan_number\": 181, \"value\": 0.00446482}, {\"regressor\": \"rot_y\", \"scan_number\": 182, \"value\": 0.003213800000000001}, {\"regressor\": \"rot_y\", \"scan_number\": 183, \"value\": 0.00299045}, {\"regressor\": \"rot_y\", \"scan_number\": 184, \"value\": 0.0034048000000000004}, {\"regressor\": \"rot_y\", \"scan_number\": 185, \"value\": 0.00323699}, {\"regressor\": \"rot_y\", \"scan_number\": 186, \"value\": 0.0033816}, {\"regressor\": \"rot_y\", \"scan_number\": 187, \"value\": 0.00346968}, {\"regressor\": \"rot_y\", \"scan_number\": 188, \"value\": 0.0038062}, {\"regressor\": \"rot_y\", \"scan_number\": 189, \"value\": 0.00515817}, {\"regressor\": \"rot_y\", \"scan_number\": 190, \"value\": 0.00551536}, {\"regressor\": \"rot_y\", \"scan_number\": 191, \"value\": 0.00586847}, {\"regressor\": \"rot_y\", \"scan_number\": 192, \"value\": 0.00605632}, {\"regressor\": \"rot_y\", \"scan_number\": 193, \"value\": 0.00580658}, {\"regressor\": \"rot_y\", \"scan_number\": 194, \"value\": 0.00607298}, {\"regressor\": \"rot_y\", \"scan_number\": 195, \"value\": 0.00622166}, {\"regressor\": \"rot_y\", \"scan_number\": 196, \"value\": 0.00579344}, {\"regressor\": \"rot_y\", \"scan_number\": 197, \"value\": 0.0065024}, {\"regressor\": \"rot_y\", \"scan_number\": 198, \"value\": 0.00681672}, {\"regressor\": \"rot_y\", \"scan_number\": 199, \"value\": 0.00653842}, {\"regressor\": \"rot_y\", \"scan_number\": 200, \"value\": 0.00647506}, {\"regressor\": \"rot_y\", \"scan_number\": 201, \"value\": 0.0058998}, {\"regressor\": \"rot_y\", \"scan_number\": 202, \"value\": 0.00621535}, {\"regressor\": \"rot_y\", \"scan_number\": 203, \"value\": 0.00644981}, {\"regressor\": \"rot_y\", \"scan_number\": 204, \"value\": 0.00647541}, {\"regressor\": \"rot_y\", \"scan_number\": 205, \"value\": 0.00653879}, {\"regressor\": \"rot_y\", \"scan_number\": 206, \"value\": 0.00617077}, {\"regressor\": \"rot_y\", \"scan_number\": 207, \"value\": 0.00670285}, {\"regressor\": \"rot_y\", \"scan_number\": 208, \"value\": 0.00678382}, {\"regressor\": \"rot_y\", \"scan_number\": 209, \"value\": 0.007451399999999999}, {\"regressor\": \"rot_y\", \"scan_number\": 210, \"value\": 0.0073813}, {\"regressor\": \"rot_y\", \"scan_number\": 211, \"value\": 0.007737329999999999}, {\"regressor\": \"rot_y\", \"scan_number\": 212, \"value\": 0.00780617}, {\"regressor\": \"rot_y\", \"scan_number\": 213, \"value\": 0.00793773}, {\"regressor\": \"rot_y\", \"scan_number\": 214, \"value\": 0.00759283}, {\"regressor\": \"rot_y\", \"scan_number\": 215, \"value\": 0.00728636}, {\"regressor\": \"rot_y\", \"scan_number\": 216, \"value\": 0.00768552}, {\"regressor\": \"rot_y\", \"scan_number\": 217, \"value\": 0.00812434}, {\"regressor\": \"rot_y\", \"scan_number\": 218, \"value\": 0.00764464}, {\"regressor\": \"rot_y\", \"scan_number\": 219, \"value\": 0.007401439999999999}, {\"regressor\": \"rot_y\", \"scan_number\": 220, \"value\": 0.00769272}, {\"regressor\": \"rot_y\", \"scan_number\": 221, \"value\": 0.0102539}, {\"regressor\": \"rot_y\", \"scan_number\": 222, \"value\": 0.0107392}, {\"regressor\": \"rot_y\", \"scan_number\": 223, \"value\": 0.010741400000000002}, {\"regressor\": \"rot_y\", \"scan_number\": 224, \"value\": 0.0104504}, {\"regressor\": \"rot_y\", \"scan_number\": 225, \"value\": 0.0094575}, {\"regressor\": \"rot_y\", \"scan_number\": 226, \"value\": 0.00965126}, {\"regressor\": \"rot_y\", \"scan_number\": 227, \"value\": 0.00942262}, {\"regressor\": \"rot_y\", \"scan_number\": 228, \"value\": 0.0097581}, {\"regressor\": \"rot_y\", \"scan_number\": 229, \"value\": 0.00939226}, {\"regressor\": \"rot_y\", \"scan_number\": 230, \"value\": 0.00962936}, {\"regressor\": \"rot_y\", \"scan_number\": 231, \"value\": 0.0101302}, {\"regressor\": \"rot_y\", \"scan_number\": 232, \"value\": 0.00955001}, {\"regressor\": \"rot_y\", \"scan_number\": 233, \"value\": 0.00967235}, {\"regressor\": \"rot_y\", \"scan_number\": 234, \"value\": 0.0095434}, {\"regressor\": \"rot_y\", \"scan_number\": 235, \"value\": 0.00910985}, {\"regressor\": \"rot_y\", \"scan_number\": 236, \"value\": 0.0085736}, {\"regressor\": \"rot_y\", \"scan_number\": 237, \"value\": 0.00852161}, {\"regressor\": \"rot_y\", \"scan_number\": 238, \"value\": 0.00824387}, {\"regressor\": \"rot_y\", \"scan_number\": 239, \"value\": 0.0082292}, {\"regressor\": \"rot_y\", \"scan_number\": 240, \"value\": 0.00743537}, {\"regressor\": \"rot_y\", \"scan_number\": 241, \"value\": 0.00835666}, {\"regressor\": \"rot_y\", \"scan_number\": 242, \"value\": 0.00893283}, {\"regressor\": \"rot_y\", \"scan_number\": 243, \"value\": 0.00871613}, {\"regressor\": \"rot_y\", \"scan_number\": 244, \"value\": 0.008440009999999998}, {\"regressor\": \"rot_y\", \"scan_number\": 245, \"value\": 0.00778381}, {\"regressor\": \"rot_y\", \"scan_number\": 246, \"value\": 0.00722446}, {\"regressor\": \"rot_y\", \"scan_number\": 247, \"value\": 0.007213879999999998}, {\"regressor\": \"rot_y\", \"scan_number\": 248, \"value\": 0.00735548}, {\"regressor\": \"rot_y\", \"scan_number\": 249, \"value\": 0.00727761}, {\"regressor\": \"rot_y\", \"scan_number\": 250, \"value\": 0.007433499999999998}, {\"regressor\": \"rot_y\", \"scan_number\": 251, \"value\": 0.00738499}, {\"regressor\": \"rot_y\", \"scan_number\": 252, \"value\": 0.00699799}, {\"regressor\": \"rot_y\", \"scan_number\": 253, \"value\": 0.0068262}, {\"regressor\": \"rot_y\", \"scan_number\": 254, \"value\": 0.00640305}, {\"regressor\": \"rot_y\", \"scan_number\": 255, \"value\": 0.00551679}, {\"regressor\": \"rot_y\", \"scan_number\": 256, \"value\": 0.00434527}, {\"regressor\": \"rot_y\", \"scan_number\": 257, \"value\": 0.00424647}, {\"regressor\": \"rot_y\", \"scan_number\": 258, \"value\": 0.00384055}, {\"regressor\": \"rot_y\", \"scan_number\": 259, \"value\": 0.00415164}, {\"regressor\": \"rot_y\", \"scan_number\": 260, \"value\": 0.00434409}, {\"regressor\": \"rot_y\", \"scan_number\": 261, \"value\": 0.00416581}, {\"regressor\": \"rot_y\", \"scan_number\": 262, \"value\": 0.00456001}, {\"regressor\": \"rot_y\", \"scan_number\": 263, \"value\": 0.00438412}, {\"regressor\": \"rot_y\", \"scan_number\": 264, \"value\": 0.00457159}, {\"regressor\": \"rot_y\", \"scan_number\": 265, \"value\": 0.004560100000000001}, {\"regressor\": \"rot_y\", \"scan_number\": 266, \"value\": 0.0048078}, {\"regressor\": \"rot_y\", \"scan_number\": 267, \"value\": 0.00495242}, {\"regressor\": \"rot_y\", \"scan_number\": 268, \"value\": 0.00509732}, {\"regressor\": \"rot_y\", \"scan_number\": 269, \"value\": 0.00511583}, {\"regressor\": \"rot_y\", \"scan_number\": 270, \"value\": 0.00486048}, {\"regressor\": \"rot_y\", \"scan_number\": 271, \"value\": 0.00434455}, {\"regressor\": \"rot_y\", \"scan_number\": 272, \"value\": 0.0043615}, {\"regressor\": \"rot_y\", \"scan_number\": 273, \"value\": 0.00378239}, {\"regressor\": \"rot_y\", \"scan_number\": 274, \"value\": 0.00442731}, {\"regressor\": \"rot_y\", \"scan_number\": 275, \"value\": 0.00460407}, {\"regressor\": \"rot_y\", \"scan_number\": 276, \"value\": 0.00453098}, {\"regressor\": \"rot_y\", \"scan_number\": 277, \"value\": 0.00447819}, {\"regressor\": \"rot_y\", \"scan_number\": 278, \"value\": 0.00433986}, {\"regressor\": \"rot_y\", \"scan_number\": 279, \"value\": 0.00437998}, {\"regressor\": \"rot_y\", \"scan_number\": 280, \"value\": 0.00396127}, {\"regressor\": \"rot_y\", \"scan_number\": 281, \"value\": 0.00324751}, {\"regressor\": \"rot_y\", \"scan_number\": 282, \"value\": 0.00309714}, {\"regressor\": \"rot_y\", \"scan_number\": 283, \"value\": 0.00331736}, {\"regressor\": \"rot_y\", \"scan_number\": 284, \"value\": 0.00343339}, {\"regressor\": \"rot_y\", \"scan_number\": 285, \"value\": 0.00320145}, {\"regressor\": \"rot_y\", \"scan_number\": 286, \"value\": 0.00288525}, {\"regressor\": \"rot_y\", \"scan_number\": 287, \"value\": 0.00311291}, {\"regressor\": \"rot_y\", \"scan_number\": 288, \"value\": 0.00302142}, {\"regressor\": \"rot_y\", \"scan_number\": 289, \"value\": 0.00338154}, {\"regressor\": \"rot_y\", \"scan_number\": 290, \"value\": 0.00390864}, {\"regressor\": \"rot_y\", \"scan_number\": 291, \"value\": 0.00377227}, {\"regressor\": \"rot_y\", \"scan_number\": 292, \"value\": 0.00347232}, {\"regressor\": \"rot_y\", \"scan_number\": 293, \"value\": 0.00360369}, {\"regressor\": \"rot_y\", \"scan_number\": 294, \"value\": 0.00371007}, {\"regressor\": \"rot_y\", \"scan_number\": 295, \"value\": 0.00416539}, {\"regressor\": \"rot_y\", \"scan_number\": 296, \"value\": 0.00410017}, {\"regressor\": \"rot_y\", \"scan_number\": 297, \"value\": 0.00439938}, {\"regressor\": \"rot_y\", \"scan_number\": 298, \"value\": 0.00372928}, {\"regressor\": \"rot_y\", \"scan_number\": 299, \"value\": 0.00351076}, {\"regressor\": \"rot_y\", \"scan_number\": 300, \"value\": 0.00348136}, {\"regressor\": \"rot_y\", \"scan_number\": 301, \"value\": 0.00346002}, {\"regressor\": \"rot_y\", \"scan_number\": 302, \"value\": 0.00341285}, {\"regressor\": \"rot_y\", \"scan_number\": 303, \"value\": 0.003385}, {\"regressor\": \"rot_y\", \"scan_number\": 304, \"value\": 0.00339374}, {\"regressor\": \"rot_y\", \"scan_number\": 305, \"value\": 0.00381002}, {\"regressor\": \"rot_y\", \"scan_number\": 306, \"value\": 0.0031738000000000005}, {\"regressor\": \"rot_y\", \"scan_number\": 307, \"value\": 0.00337385}, {\"regressor\": \"rot_y\", \"scan_number\": 308, \"value\": 0.00308391}, {\"regressor\": \"rot_y\", \"scan_number\": 309, \"value\": 0.00324346}, {\"regressor\": \"rot_y\", \"scan_number\": 310, \"value\": 0.00279799}, {\"regressor\": \"rot_y\", \"scan_number\": 311, \"value\": 0.00335547}, {\"regressor\": \"rot_y\", \"scan_number\": 312, \"value\": 0.00335516}, {\"regressor\": \"rot_y\", \"scan_number\": 313, \"value\": 0.00308474}, {\"regressor\": \"rot_y\", \"scan_number\": 314, \"value\": 0.00323286}, {\"regressor\": \"rot_y\", \"scan_number\": 315, \"value\": 0.00321255}, {\"regressor\": \"rot_y\", \"scan_number\": 316, \"value\": 0.00324329}, {\"regressor\": \"rot_y\", \"scan_number\": 317, \"value\": 0.00315156}, {\"regressor\": \"rot_y\", \"scan_number\": 318, \"value\": 0.00345985}, {\"regressor\": \"rot_y\", \"scan_number\": 319, \"value\": 0.00352242}, {\"regressor\": \"rot_y\", \"scan_number\": 320, \"value\": 0.00359017}, {\"regressor\": \"rot_y\", \"scan_number\": 321, \"value\": 0.00391139}, {\"regressor\": \"rot_y\", \"scan_number\": 322, \"value\": 0.00397923}, {\"regressor\": \"rot_y\", \"scan_number\": 323, \"value\": 0.00403924}, {\"regressor\": \"rot_y\", \"scan_number\": 324, \"value\": 0.00381924}, {\"regressor\": \"rot_y\", \"scan_number\": 325, \"value\": 0.00413172}, {\"regressor\": \"rot_y\", \"scan_number\": 326, \"value\": 0.00369036}, {\"regressor\": \"rot_y\", \"scan_number\": 327, \"value\": 0.00321286}, {\"regressor\": \"rot_y\", \"scan_number\": 328, \"value\": 0.00295774}, {\"regressor\": \"rot_y\", \"scan_number\": 329, \"value\": 0.00239503}, {\"regressor\": \"rot_y\", \"scan_number\": 330, \"value\": 0.00288826}, {\"regressor\": \"rot_y\", \"scan_number\": 331, \"value\": 0.00373622}, {\"regressor\": \"rot_y\", \"scan_number\": 332, \"value\": 0.00392241}, {\"regressor\": \"rot_y\", \"scan_number\": 333, \"value\": 0.0044001000000000005}, {\"regressor\": \"rot_y\", \"scan_number\": 334, \"value\": 0.00441569}, {\"regressor\": \"rot_y\", \"scan_number\": 335, \"value\": 0.00414423}, {\"regressor\": \"rot_y\", \"scan_number\": 336, \"value\": 0.00457493}, {\"regressor\": \"rot_y\", \"scan_number\": 337, \"value\": 0.00457002}, {\"regressor\": \"rot_y\", \"scan_number\": 338, \"value\": 0.00440496}, {\"regressor\": \"rot_y\", \"scan_number\": 339, \"value\": 0.00465191}, {\"regressor\": \"rot_y\", \"scan_number\": 340, \"value\": 0.00462767}, {\"regressor\": \"rot_y\", \"scan_number\": 341, \"value\": 0.00442985}, {\"regressor\": \"rot_y\", \"scan_number\": 342, \"value\": 0.00455482}, {\"regressor\": \"rot_y\", \"scan_number\": 343, \"value\": 0.00472755}, {\"regressor\": \"rot_z\", \"scan_number\": 0, \"value\": 0.00223066}, {\"regressor\": \"rot_z\", \"scan_number\": 1, \"value\": 0.00178696}, {\"regressor\": \"rot_z\", \"scan_number\": 2, \"value\": 0.00211568}, {\"regressor\": \"rot_z\", \"scan_number\": 3, \"value\": 0.00187752}, {\"regressor\": \"rot_z\", \"scan_number\": 4, \"value\": 0.00181027}, {\"regressor\": \"rot_z\", \"scan_number\": 5, \"value\": 0.00171164}, {\"regressor\": \"rot_z\", \"scan_number\": 6, \"value\": 0.00138265}, {\"regressor\": \"rot_z\", \"scan_number\": 7, \"value\": 0.00121771}, {\"regressor\": \"rot_z\", \"scan_number\": 8, \"value\": 0.000834345}, {\"regressor\": \"rot_z\", \"scan_number\": 9, \"value\": 0.0007685239999999999}, {\"regressor\": \"rot_z\", \"scan_number\": 10, \"value\": 0.0003127}, {\"regressor\": \"rot_z\", \"scan_number\": 11, \"value\": -1.0867e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 12, \"value\": -0.000117787}, {\"regressor\": \"rot_z\", \"scan_number\": 13, \"value\": -0.000215213}, {\"regressor\": \"rot_z\", \"scan_number\": 14, \"value\": -6.31771e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 15, \"value\": 0.000257127}, {\"regressor\": \"rot_z\", \"scan_number\": 16, \"value\": 0.000967283}, {\"regressor\": \"rot_z\", \"scan_number\": 17, \"value\": 0.0003127}, {\"regressor\": \"rot_z\", \"scan_number\": 18, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 19, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 20, \"value\": 2.94148e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 21, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 22, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 23, \"value\": 6.49059e-07}, {\"regressor\": \"rot_z\", \"scan_number\": 24, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 25, \"value\": 0.00017277200000000002}, {\"regressor\": \"rot_z\", \"scan_number\": 26, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 27, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 28, \"value\": 0.000352863}, {\"regressor\": \"rot_z\", \"scan_number\": 29, \"value\": 0.000505231}, {\"regressor\": \"rot_z\", \"scan_number\": 30, \"value\": 0.0005540359999999999}, {\"regressor\": \"rot_z\", \"scan_number\": 31, \"value\": 0.000206718}, {\"regressor\": \"rot_z\", \"scan_number\": 32, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 33, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 34, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 35, \"value\": 0.00035133}, {\"regressor\": \"rot_z\", \"scan_number\": 36, \"value\": 0.000122095}, {\"regressor\": \"rot_z\", \"scan_number\": 37, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 38, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 39, \"value\": -0.000379788}, {\"regressor\": \"rot_z\", \"scan_number\": 40, \"value\": -0.000293839}, {\"regressor\": \"rot_z\", \"scan_number\": 41, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 42, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 43, \"value\": 1.73882e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 44, \"value\": -9.765190000000004e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 45, \"value\": 0.000231278}, {\"regressor\": \"rot_z\", \"scan_number\": 46, \"value\": 0.00045261}, {\"regressor\": \"rot_z\", \"scan_number\": 47, \"value\": 0.000359726}, {\"regressor\": \"rot_z\", \"scan_number\": 48, \"value\": 0.0006860439999999999}, {\"regressor\": \"rot_z\", \"scan_number\": 49, \"value\": 0.000403168}, {\"regressor\": \"rot_z\", \"scan_number\": 50, \"value\": 0.000642077}, {\"regressor\": \"rot_z\", \"scan_number\": 51, \"value\": 0.000642077}, {\"regressor\": \"rot_z\", \"scan_number\": 52, \"value\": 0.000569529}, {\"regressor\": \"rot_z\", \"scan_number\": 53, \"value\": 0.00118185}, {\"regressor\": \"rot_z\", \"scan_number\": 54, \"value\": 0.000770176}, {\"regressor\": \"rot_z\", \"scan_number\": 55, \"value\": 0.000642077}, {\"regressor\": \"rot_z\", \"scan_number\": 56, \"value\": 0.0005275480000000001}, {\"regressor\": \"rot_z\", \"scan_number\": 57, \"value\": 0.000642077}, {\"regressor\": \"rot_z\", \"scan_number\": 58, \"value\": 0.000507573}, {\"regressor\": \"rot_z\", \"scan_number\": 59, \"value\": 0.000199888}, {\"regressor\": \"rot_z\", \"scan_number\": 60, \"value\": 0.000154534}, {\"regressor\": \"rot_z\", \"scan_number\": 61, \"value\": -0.00014855}, {\"regressor\": \"rot_z\", \"scan_number\": 62, \"value\": -0.00032015200000000003}, {\"regressor\": \"rot_z\", \"scan_number\": 63, \"value\": -0.00032015200000000003}, {\"regressor\": \"rot_z\", \"scan_number\": 64, \"value\": -0.000229586}, {\"regressor\": \"rot_z\", \"scan_number\": 65, \"value\": -0.000524046}, {\"regressor\": \"rot_z\", \"scan_number\": 66, \"value\": -0.000670264}, {\"regressor\": \"rot_z\", \"scan_number\": 67, \"value\": -0.000653873}, {\"regressor\": \"rot_z\", \"scan_number\": 68, \"value\": -0.0007708989999999999}, {\"regressor\": \"rot_z\", \"scan_number\": 69, \"value\": -0.000351172}, {\"regressor\": \"rot_z\", \"scan_number\": 70, \"value\": 9.34422e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 71, \"value\": 0.000240232}, {\"regressor\": \"rot_z\", \"scan_number\": 72, \"value\": 0.000308521}, {\"regressor\": \"rot_z\", \"scan_number\": 73, \"value\": 0.000260652}, {\"regressor\": \"rot_z\", \"scan_number\": 74, \"value\": 0.000280835}, {\"regressor\": \"rot_z\", \"scan_number\": 75, \"value\": 0.000640279}, {\"regressor\": \"rot_z\", \"scan_number\": 76, \"value\": 0.00117372}, {\"regressor\": \"rot_z\", \"scan_number\": 77, \"value\": 0.000480185}, {\"regressor\": \"rot_z\", \"scan_number\": 78, \"value\": -9.96767e-05}, {\"regressor\": \"rot_z\", \"scan_number\": 79, \"value\": -0.000484648}, {\"regressor\": \"rot_z\", \"scan_number\": 80, \"value\": -0.0007847079999999997}, {\"regressor\": \"rot_z\", \"scan_number\": 81, \"value\": -0.00071321}, {\"regressor\": \"rot_z\", \"scan_number\": 82, \"value\": -0.00071321}, {\"regressor\": \"rot_z\", \"scan_number\": 83, \"value\": -0.00071321}, {\"regressor\": \"rot_z\", \"scan_number\": 84, \"value\": -0.000262242}, {\"regressor\": \"rot_z\", \"scan_number\": 85, \"value\": -0.000407417}, {\"regressor\": \"rot_z\", \"scan_number\": 86, \"value\": -0.0005805469999999999}, {\"regressor\": \"rot_z\", \"scan_number\": 87, \"value\": -0.000336515}, {\"regressor\": \"rot_z\", \"scan_number\": 88, \"value\": -0.000194425}, {\"regressor\": \"rot_z\", \"scan_number\": 89, \"value\": -0.000194425}, {\"regressor\": \"rot_z\", \"scan_number\": 90, \"value\": -0.000194425}, {\"regressor\": \"rot_z\", \"scan_number\": 91, \"value\": -0.000352969}, {\"regressor\": \"rot_z\", \"scan_number\": 92, \"value\": -0.000249067}, {\"regressor\": \"rot_z\", \"scan_number\": 93, \"value\": -0.000512684}, {\"regressor\": \"rot_z\", \"scan_number\": 94, \"value\": -0.000737371}, {\"regressor\": \"rot_z\", \"scan_number\": 95, \"value\": -0.000420837}, {\"regressor\": \"rot_z\", \"scan_number\": 96, \"value\": -0.000280183}, {\"regressor\": \"rot_z\", \"scan_number\": 97, \"value\": -0.000252454}, {\"regressor\": \"rot_z\", \"scan_number\": 98, \"value\": -0.000194531}, {\"regressor\": \"rot_z\", \"scan_number\": 99, \"value\": -0.000435084}, {\"regressor\": \"rot_z\", \"scan_number\": 100, \"value\": -0.000556969}, {\"regressor\": \"rot_z\", \"scan_number\": 101, \"value\": -0.000598315}, {\"regressor\": \"rot_z\", \"scan_number\": 102, \"value\": -0.0009138420000000002}, {\"regressor\": \"rot_z\", \"scan_number\": 103, \"value\": -0.000352689}, {\"regressor\": \"rot_z\", \"scan_number\": 104, \"value\": -0.0009008690000000002}, {\"regressor\": \"rot_z\", \"scan_number\": 105, \"value\": -0.0009008690000000002}, {\"regressor\": \"rot_z\", \"scan_number\": 106, \"value\": -0.00117257}, {\"regressor\": \"rot_z\", \"scan_number\": 107, \"value\": -0.0015155399999999995}, {\"regressor\": \"rot_z\", \"scan_number\": 108, \"value\": -0.00140989}, {\"regressor\": \"rot_z\", \"scan_number\": 109, \"value\": -0.00203061}, {\"regressor\": \"rot_z\", \"scan_number\": 110, \"value\": -0.00237677}, {\"regressor\": \"rot_z\", \"scan_number\": 111, \"value\": -0.00281348}, {\"regressor\": \"rot_z\", \"scan_number\": 112, \"value\": -0.002141}, {\"regressor\": \"rot_z\", \"scan_number\": 113, \"value\": -0.00108294}, {\"regressor\": \"rot_z\", \"scan_number\": 114, \"value\": -0.000485978}, {\"regressor\": \"rot_z\", \"scan_number\": 115, \"value\": -0.000564791}, {\"regressor\": \"rot_z\", \"scan_number\": 116, \"value\": -0.00149554}, {\"regressor\": \"rot_z\", \"scan_number\": 117, \"value\": -0.0019486}, {\"regressor\": \"rot_z\", \"scan_number\": 118, \"value\": -0.0018616}, {\"regressor\": \"rot_z\", \"scan_number\": 119, \"value\": -0.00208169}, {\"regressor\": \"rot_z\", \"scan_number\": 120, \"value\": -0.00205279}, {\"regressor\": \"rot_z\", \"scan_number\": 121, \"value\": -0.00229611}, {\"regressor\": \"rot_z\", \"scan_number\": 122, \"value\": -0.00178614}, {\"regressor\": \"rot_z\", \"scan_number\": 123, \"value\": -0.00229611}, {\"regressor\": \"rot_z\", \"scan_number\": 124, \"value\": -0.00277247}, {\"regressor\": \"rot_z\", \"scan_number\": 125, \"value\": -0.00249567}, {\"regressor\": \"rot_z\", \"scan_number\": 126, \"value\": -0.00277247}, {\"regressor\": \"rot_z\", \"scan_number\": 127, \"value\": -0.00272088}, {\"regressor\": \"rot_z\", \"scan_number\": 128, \"value\": -0.00292573}, {\"regressor\": \"rot_z\", \"scan_number\": 129, \"value\": -0.00277247}, {\"regressor\": \"rot_z\", \"scan_number\": 130, \"value\": -0.00245521}, {\"regressor\": \"rot_z\", \"scan_number\": 131, \"value\": -0.00271972}, {\"regressor\": \"rot_z\", \"scan_number\": 132, \"value\": -0.00307922}, {\"regressor\": \"rot_z\", \"scan_number\": 133, \"value\": -0.00307922}, {\"regressor\": \"rot_z\", \"scan_number\": 134, \"value\": -0.00338998}, {\"regressor\": \"rot_z\", \"scan_number\": 135, \"value\": -0.00390657}, {\"regressor\": \"rot_z\", \"scan_number\": 136, \"value\": -0.00437349}, {\"regressor\": \"rot_z\", \"scan_number\": 137, \"value\": -0.00394782}, {\"regressor\": \"rot_z\", \"scan_number\": 138, \"value\": -0.00462508}, {\"regressor\": \"rot_z\", \"scan_number\": 139, \"value\": -0.0042656000000000005}, {\"regressor\": \"rot_z\", \"scan_number\": 140, \"value\": -0.00401514}, {\"regressor\": \"rot_z\", \"scan_number\": 141, \"value\": -0.00426302}, {\"regressor\": \"rot_z\", \"scan_number\": 142, \"value\": -0.00365909}, {\"regressor\": \"rot_z\", \"scan_number\": 143, \"value\": -0.00409635}, {\"regressor\": \"rot_z\", \"scan_number\": 144, \"value\": -0.00445283}, {\"regressor\": \"rot_z\", \"scan_number\": 145, \"value\": -0.00409635}, {\"regressor\": \"rot_z\", \"scan_number\": 146, \"value\": -0.0045766}, {\"regressor\": \"rot_z\", \"scan_number\": 147, \"value\": -0.00482413}, {\"regressor\": \"rot_z\", \"scan_number\": 148, \"value\": -0.00427022}, {\"regressor\": \"rot_z\", \"scan_number\": 149, \"value\": -0.00480945}, {\"regressor\": \"rot_z\", \"scan_number\": 150, \"value\": -0.0048588}, {\"regressor\": \"rot_z\", \"scan_number\": 151, \"value\": -0.00478969}, {\"regressor\": \"rot_z\", \"scan_number\": 152, \"value\": -0.00390252}, {\"regressor\": \"rot_z\", \"scan_number\": 153, \"value\": -0.00420291}, {\"regressor\": \"rot_z\", \"scan_number\": 154, \"value\": -0.00420291}, {\"regressor\": \"rot_z\", \"scan_number\": 155, \"value\": -0.00420291}, {\"regressor\": \"rot_z\", \"scan_number\": 156, \"value\": -0.00420291}, {\"regressor\": \"rot_z\", \"scan_number\": 157, \"value\": -0.00410715}, {\"regressor\": \"rot_z\", \"scan_number\": 158, \"value\": -0.00408037}, {\"regressor\": \"rot_z\", \"scan_number\": 159, \"value\": -0.00409736}, {\"regressor\": \"rot_z\", \"scan_number\": 160, \"value\": -0.00388897}, {\"regressor\": \"rot_z\", \"scan_number\": 161, \"value\": -0.00411227}, {\"regressor\": \"rot_z\", \"scan_number\": 162, \"value\": -0.00363208}, {\"regressor\": \"rot_z\", \"scan_number\": 163, \"value\": -0.00449979}, {\"regressor\": \"rot_z\", \"scan_number\": 164, \"value\": -0.00377367}, {\"regressor\": \"rot_z\", \"scan_number\": 165, \"value\": -0.00326097}, {\"regressor\": \"rot_z\", \"scan_number\": 166, \"value\": -0.00393698}, {\"regressor\": \"rot_z\", \"scan_number\": 167, \"value\": -0.00367434}, {\"regressor\": \"rot_z\", \"scan_number\": 168, \"value\": -0.004142}, {\"regressor\": \"rot_z\", \"scan_number\": 169, \"value\": -0.004142}, {\"regressor\": \"rot_z\", \"scan_number\": 170, \"value\": -0.0043207}, {\"regressor\": \"rot_z\", \"scan_number\": 171, \"value\": -0.0043414}, {\"regressor\": \"rot_z\", \"scan_number\": 172, \"value\": -0.00358385}, {\"regressor\": \"rot_z\", \"scan_number\": 173, \"value\": -0.00326828}, {\"regressor\": \"rot_z\", \"scan_number\": 174, \"value\": -0.00434536}, {\"regressor\": \"rot_z\", \"scan_number\": 175, \"value\": -0.00473144}, {\"regressor\": \"rot_z\", \"scan_number\": 176, \"value\": -0.00480473}, {\"regressor\": \"rot_z\", \"scan_number\": 177, \"value\": -0.00482983}, {\"regressor\": \"rot_z\", \"scan_number\": 178, \"value\": -0.00457536}, {\"regressor\": \"rot_z\", \"scan_number\": 179, \"value\": -0.00457536}, {\"regressor\": \"rot_z\", \"scan_number\": 180, \"value\": -0.00473368}, {\"regressor\": \"rot_z\", \"scan_number\": 181, \"value\": -0.00408307}, {\"regressor\": \"rot_z\", \"scan_number\": 182, \"value\": -0.00405375}, {\"regressor\": \"rot_z\", \"scan_number\": 183, \"value\": -0.0041569}, {\"regressor\": \"rot_z\", \"scan_number\": 184, \"value\": -0.00430095}, {\"regressor\": \"rot_z\", \"scan_number\": 185, \"value\": -0.00430095}, {\"regressor\": \"rot_z\", \"scan_number\": 186, \"value\": -0.00430095}, {\"regressor\": \"rot_z\", \"scan_number\": 187, \"value\": -0.0047657}, {\"regressor\": \"rot_z\", \"scan_number\": 188, \"value\": -0.00479169}, {\"regressor\": \"rot_z\", \"scan_number\": 189, \"value\": -0.00512154}, {\"regressor\": \"rot_z\", \"scan_number\": 190, \"value\": -0.00484365}, {\"regressor\": \"rot_z\", \"scan_number\": 191, \"value\": -0.00479993}, {\"regressor\": \"rot_z\", \"scan_number\": 192, \"value\": -0.00484091}, {\"regressor\": \"rot_z\", \"scan_number\": 193, \"value\": -0.0051807}, {\"regressor\": \"rot_z\", \"scan_number\": 194, \"value\": -0.00503344}, {\"regressor\": \"rot_z\", \"scan_number\": 195, \"value\": -0.00522508}, {\"regressor\": \"rot_z\", \"scan_number\": 196, \"value\": -0.00495136}, {\"regressor\": \"rot_z\", \"scan_number\": 197, \"value\": -0.00448077}, {\"regressor\": \"rot_z\", \"scan_number\": 198, \"value\": -0.00496664}, {\"regressor\": \"rot_z\", \"scan_number\": 199, \"value\": -0.00459127}, {\"regressor\": \"rot_z\", \"scan_number\": 200, \"value\": -0.00417784}, {\"regressor\": \"rot_z\", \"scan_number\": 201, \"value\": -0.00403198}, {\"regressor\": \"rot_z\", \"scan_number\": 202, \"value\": -0.00417784}, {\"regressor\": \"rot_z\", \"scan_number\": 203, \"value\": -0.00478461}, {\"regressor\": \"rot_z\", \"scan_number\": 204, \"value\": -0.00478461}, {\"regressor\": \"rot_z\", \"scan_number\": 205, \"value\": -0.00333743}, {\"regressor\": \"rot_z\", \"scan_number\": 206, \"value\": -0.00333743}, {\"regressor\": \"rot_z\", \"scan_number\": 207, \"value\": -0.00406099}, {\"regressor\": \"rot_z\", \"scan_number\": 208, \"value\": -0.00370702}, {\"regressor\": \"rot_z\", \"scan_number\": 209, \"value\": -0.00383578}, {\"regressor\": \"rot_z\", \"scan_number\": 210, \"value\": -0.00412299}, {\"regressor\": \"rot_z\", \"scan_number\": 211, \"value\": -0.00370389}, {\"regressor\": \"rot_z\", \"scan_number\": 212, \"value\": -0.00428366}, {\"regressor\": \"rot_z\", \"scan_number\": 213, \"value\": -0.00408904}, {\"regressor\": \"rot_z\", \"scan_number\": 214, \"value\": -0.00399942}, {\"regressor\": \"rot_z\", \"scan_number\": 215, \"value\": -0.00380594}, {\"regressor\": \"rot_z\", \"scan_number\": 216, \"value\": -0.00420458}, {\"regressor\": \"rot_z\", \"scan_number\": 217, \"value\": -0.00359284}, {\"regressor\": \"rot_z\", \"scan_number\": 218, \"value\": -0.00310358}, {\"regressor\": \"rot_z\", \"scan_number\": 219, \"value\": -0.00240402}, {\"regressor\": \"rot_z\", \"scan_number\": 220, \"value\": -0.00105263}, {\"regressor\": \"rot_z\", \"scan_number\": 221, \"value\": -0.00237901}, {\"regressor\": \"rot_z\", \"scan_number\": 222, \"value\": -0.0029345}, {\"regressor\": \"rot_z\", \"scan_number\": 223, \"value\": -0.00322022}, {\"regressor\": \"rot_z\", \"scan_number\": 224, \"value\": -0.00338392}, {\"regressor\": \"rot_z\", \"scan_number\": 225, \"value\": -0.00291321}, {\"regressor\": \"rot_z\", \"scan_number\": 226, \"value\": -0.00316115}, {\"regressor\": \"rot_z\", \"scan_number\": 227, \"value\": -0.00283946}, {\"regressor\": \"rot_z\", \"scan_number\": 228, \"value\": -0.00283063}, {\"regressor\": \"rot_z\", \"scan_number\": 229, \"value\": -0.00383311}, {\"regressor\": \"rot_z\", \"scan_number\": 230, \"value\": -0.00383311}, {\"regressor\": \"rot_z\", \"scan_number\": 231, \"value\": -0.00321195}, {\"regressor\": \"rot_z\", \"scan_number\": 232, \"value\": -0.00364153}, {\"regressor\": \"rot_z\", \"scan_number\": 233, \"value\": -0.00364153}, {\"regressor\": \"rot_z\", \"scan_number\": 234, \"value\": -0.00414035}, {\"regressor\": \"rot_z\", \"scan_number\": 235, \"value\": -0.00465959}, {\"regressor\": \"rot_z\", \"scan_number\": 236, \"value\": -0.00421613}, {\"regressor\": \"rot_z\", \"scan_number\": 237, \"value\": -0.0035851}, {\"regressor\": \"rot_z\", \"scan_number\": 238, \"value\": -0.00402103}, {\"regressor\": \"rot_z\", \"scan_number\": 239, \"value\": -0.00402102}, {\"regressor\": \"rot_z\", \"scan_number\": 240, \"value\": -0.00295152}, {\"regressor\": \"rot_z\", \"scan_number\": 241, \"value\": -0.00280599}, {\"regressor\": \"rot_z\", \"scan_number\": 242, \"value\": -0.00310897}, {\"regressor\": \"rot_z\", \"scan_number\": 243, \"value\": -0.00356275}, {\"regressor\": \"rot_z\", \"scan_number\": 244, \"value\": -0.00356275}, {\"regressor\": \"rot_z\", \"scan_number\": 245, \"value\": -0.00356275}, {\"regressor\": \"rot_z\", \"scan_number\": 246, \"value\": -0.00356275}, {\"regressor\": \"rot_z\", \"scan_number\": 247, \"value\": -0.00334977}, {\"regressor\": \"rot_z\", \"scan_number\": 248, \"value\": -0.00356275}, {\"regressor\": \"rot_z\", \"scan_number\": 249, \"value\": -0.00356275}, {\"regressor\": \"rot_z\", \"scan_number\": 250, \"value\": -0.00356275}, {\"regressor\": \"rot_z\", \"scan_number\": 251, \"value\": -0.00356275}, {\"regressor\": \"rot_z\", \"scan_number\": 252, \"value\": -0.00268185}, {\"regressor\": \"rot_z\", \"scan_number\": 253, \"value\": -0.0031351}, {\"regressor\": \"rot_z\", \"scan_number\": 254, \"value\": -0.0035134}, {\"regressor\": \"rot_z\", \"scan_number\": 255, \"value\": -0.0036527}, {\"regressor\": \"rot_z\", \"scan_number\": 256, \"value\": -0.00372378}, {\"regressor\": \"rot_z\", \"scan_number\": 257, \"value\": -0.00320577}, {\"regressor\": \"rot_z\", \"scan_number\": 258, \"value\": -0.00286136}, {\"regressor\": \"rot_z\", \"scan_number\": 259, \"value\": -0.00341509}, {\"regressor\": \"rot_z\", \"scan_number\": 260, \"value\": -0.00355561}, {\"regressor\": \"rot_z\", \"scan_number\": 261, \"value\": -0.00387334}, {\"regressor\": \"rot_z\", \"scan_number\": 262, \"value\": -0.00440726}, {\"regressor\": \"rot_z\", \"scan_number\": 263, \"value\": -0.00440726}, {\"regressor\": \"rot_z\", \"scan_number\": 264, \"value\": -0.00440726}, {\"regressor\": \"rot_z\", \"scan_number\": 265, \"value\": -0.00464357}, {\"regressor\": \"rot_z\", \"scan_number\": 266, \"value\": -0.0048618}, {\"regressor\": \"rot_z\", \"scan_number\": 267, \"value\": -0.0048618}, {\"regressor\": \"rot_z\", \"scan_number\": 268, \"value\": -0.00527136}, {\"regressor\": \"rot_z\", \"scan_number\": 269, \"value\": -0.0048618}, {\"regressor\": \"rot_z\", \"scan_number\": 270, \"value\": -0.0048618}, {\"regressor\": \"rot_z\", \"scan_number\": 271, \"value\": -0.0048618}, {\"regressor\": \"rot_z\", \"scan_number\": 272, \"value\": -0.00432918}, {\"regressor\": \"rot_z\", \"scan_number\": 273, \"value\": -0.00381716}, {\"regressor\": \"rot_z\", \"scan_number\": 274, \"value\": -0.00345705}, {\"regressor\": \"rot_z\", \"scan_number\": 275, \"value\": -0.00381716}, {\"regressor\": \"rot_z\", \"scan_number\": 276, \"value\": -0.00333976}, {\"regressor\": \"rot_z\", \"scan_number\": 277, \"value\": -0.00354579}, {\"regressor\": \"rot_z\", \"scan_number\": 278, \"value\": -0.00308851}, {\"regressor\": \"rot_z\", \"scan_number\": 279, \"value\": -0.00327392}, {\"regressor\": \"rot_z\", \"scan_number\": 280, \"value\": -0.00312588}, {\"regressor\": \"rot_z\", \"scan_number\": 281, \"value\": -0.00296194}, {\"regressor\": \"rot_z\", \"scan_number\": 282, \"value\": -0.00316503}, {\"regressor\": \"rot_z\", \"scan_number\": 283, \"value\": -0.00285378}, {\"regressor\": \"rot_z\", \"scan_number\": 284, \"value\": -0.00326661}, {\"regressor\": \"rot_z\", \"scan_number\": 285, \"value\": -0.00326661}, {\"regressor\": \"rot_z\", \"scan_number\": 286, \"value\": -0.00243847}, {\"regressor\": \"rot_z\", \"scan_number\": 287, \"value\": -0.0028474}, {\"regressor\": \"rot_z\", \"scan_number\": 288, \"value\": -0.00291602}, {\"regressor\": \"rot_z\", \"scan_number\": 289, \"value\": -0.00307181}, {\"regressor\": \"rot_z\", \"scan_number\": 290, \"value\": -0.0033221}, {\"regressor\": \"rot_z\", \"scan_number\": 291, \"value\": -0.00356498}, {\"regressor\": \"rot_z\", \"scan_number\": 292, \"value\": -0.0037363}, {\"regressor\": \"rot_z\", \"scan_number\": 293, \"value\": -0.00424572}, {\"regressor\": \"rot_z\", \"scan_number\": 294, \"value\": -0.00455542}, {\"regressor\": \"rot_z\", \"scan_number\": 295, \"value\": -0.00466296}, {\"regressor\": \"rot_z\", \"scan_number\": 296, \"value\": -0.00472599}, {\"regressor\": \"rot_z\", \"scan_number\": 297, \"value\": -0.00477885}, {\"regressor\": \"rot_z\", \"scan_number\": 298, \"value\": -0.00472599}, {\"regressor\": \"rot_z\", \"scan_number\": 299, \"value\": -0.00472598}, {\"regressor\": \"rot_z\", \"scan_number\": 300, \"value\": -0.00479563}, {\"regressor\": \"rot_z\", \"scan_number\": 301, \"value\": -0.00515208}, {\"regressor\": \"rot_z\", \"scan_number\": 302, \"value\": -0.005612600000000001}, {\"regressor\": \"rot_z\", \"scan_number\": 303, \"value\": -0.00564113}, {\"regressor\": \"rot_z\", \"scan_number\": 304, \"value\": -0.00610108}, {\"regressor\": \"rot_z\", \"scan_number\": 305, \"value\": -0.0056627}, {\"regressor\": \"rot_z\", \"scan_number\": 306, \"value\": -0.00538356}, {\"regressor\": \"rot_z\", \"scan_number\": 307, \"value\": -0.005538899999999999}, {\"regressor\": \"rot_z\", \"scan_number\": 308, \"value\": -0.00594299}, {\"regressor\": \"rot_z\", \"scan_number\": 309, \"value\": -0.00594299}, {\"regressor\": \"rot_z\", \"scan_number\": 310, \"value\": -0.00510145}, {\"regressor\": \"rot_z\", \"scan_number\": 311, \"value\": -0.00510145}, {\"regressor\": \"rot_z\", \"scan_number\": 312, \"value\": -0.00510144}, {\"regressor\": \"rot_z\", \"scan_number\": 313, \"value\": -0.00521931}, {\"regressor\": \"rot_z\", \"scan_number\": 314, \"value\": -0.00561987}, {\"regressor\": \"rot_z\", \"scan_number\": 315, \"value\": -0.00561987}, {\"regressor\": \"rot_z\", \"scan_number\": 316, \"value\": -0.00561987}, {\"regressor\": \"rot_z\", \"scan_number\": 317, \"value\": -0.00514045}, {\"regressor\": \"rot_z\", \"scan_number\": 318, \"value\": -0.00554376}, {\"regressor\": \"rot_z\", \"scan_number\": 319, \"value\": -0.00553364}, {\"regressor\": \"rot_z\", \"scan_number\": 320, \"value\": -0.00559525}, {\"regressor\": \"rot_z\", \"scan_number\": 321, \"value\": -0.00604424}, {\"regressor\": \"rot_z\", \"scan_number\": 322, \"value\": -0.00658396}, {\"regressor\": \"rot_z\", \"scan_number\": 323, \"value\": -0.00609371}, {\"regressor\": \"rot_z\", \"scan_number\": 324, \"value\": -0.00584125}, {\"regressor\": \"rot_z\", \"scan_number\": 325, \"value\": -0.00542009}, {\"regressor\": \"rot_z\", \"scan_number\": 326, \"value\": -0.00525191}, {\"regressor\": \"rot_z\", \"scan_number\": 327, \"value\": -0.00513605}, {\"regressor\": \"rot_z\", \"scan_number\": 328, \"value\": -0.00313605}, {\"regressor\": \"rot_z\", \"scan_number\": 329, \"value\": -0.002094}, {\"regressor\": \"rot_z\", \"scan_number\": 330, \"value\": -0.0008604939999999997}, {\"regressor\": \"rot_z\", \"scan_number\": 331, \"value\": -0.00116961}, {\"regressor\": \"rot_z\", \"scan_number\": 332, \"value\": -0.00112216}, {\"regressor\": \"rot_z\", \"scan_number\": 333, \"value\": -0.00209399}, {\"regressor\": \"rot_z\", \"scan_number\": 334, \"value\": -0.0014124}, {\"regressor\": \"rot_z\", \"scan_number\": 335, \"value\": -0.0014469}, {\"regressor\": \"rot_z\", \"scan_number\": 336, \"value\": -0.00128582}, {\"regressor\": \"rot_z\", \"scan_number\": 337, \"value\": -0.00134381}, {\"regressor\": \"rot_z\", \"scan_number\": 338, \"value\": -0.00167568}, {\"regressor\": \"rot_z\", \"scan_number\": 339, \"value\": -0.00151266}, {\"regressor\": \"rot_z\", \"scan_number\": 340, \"value\": -0.00152728}, {\"regressor\": \"rot_z\", \"scan_number\": 341, \"value\": -0.00151927}, {\"regressor\": \"rot_z\", \"scan_number\": 342, \"value\": -0.0014105}, {\"regressor\": \"rot_z\", \"scan_number\": 343, \"value\": -0.0017335199999999995}, {\"regressor\": \"trans_x\", \"scan_number\": 0, \"value\": 0.0959496}, {\"regressor\": \"trans_x\", \"scan_number\": 1, \"value\": 0.096034}, {\"regressor\": \"trans_x\", \"scan_number\": 2, \"value\": 0.0959906}, {\"regressor\": \"trans_x\", \"scan_number\": 3, \"value\": 0.12267}, {\"regressor\": \"trans_x\", \"scan_number\": 4, \"value\": 0.0959974}, {\"regressor\": \"trans_x\", \"scan_number\": 5, \"value\": 0.0960614}, {\"regressor\": \"trans_x\", \"scan_number\": 6, \"value\": 0.0880687}, {\"regressor\": \"trans_x\", \"scan_number\": 7, \"value\": 0.0822783}, {\"regressor\": \"trans_x\", \"scan_number\": 8, \"value\": 0.0752352}, {\"regressor\": \"trans_x\", \"scan_number\": 9, \"value\": 0.0720402}, {\"regressor\": \"trans_x\", \"scan_number\": 10, \"value\": 0.052555099999999993}, {\"regressor\": \"trans_x\", \"scan_number\": 11, \"value\": 0.0429634}, {\"regressor\": \"trans_x\", \"scan_number\": 12, \"value\": 0.0347579}, {\"regressor\": \"trans_x\", \"scan_number\": 13, \"value\": 0.0347719}, {\"regressor\": \"trans_x\", \"scan_number\": 14, \"value\": 0.0420499}, {\"regressor\": \"trans_x\", \"scan_number\": 15, \"value\": 0.0423789}, {\"regressor\": \"trans_x\", \"scan_number\": 16, \"value\": 0.0348397}, {\"regressor\": \"trans_x\", \"scan_number\": 17, \"value\": -0.0008128929999999998}, {\"regressor\": \"trans_x\", \"scan_number\": 18, \"value\": -0.011252}, {\"regressor\": \"trans_x\", \"scan_number\": 19, \"value\": -0.0112369}, {\"regressor\": \"trans_x\", \"scan_number\": 20, \"value\": -0.011225400000000002}, {\"regressor\": \"trans_x\", \"scan_number\": 21, \"value\": -0.0112813}, {\"regressor\": \"trans_x\", \"scan_number\": 22, \"value\": -0.0112832}, {\"regressor\": \"trans_x\", \"scan_number\": 23, \"value\": -0.008905629999999998}, {\"regressor\": \"trans_x\", \"scan_number\": 24, \"value\": 0.00271796}, {\"regressor\": \"trans_x\", \"scan_number\": 25, \"value\": 0.00599656}, {\"regressor\": \"trans_x\", \"scan_number\": 26, \"value\": 0.0059177}, {\"regressor\": \"trans_x\", \"scan_number\": 27, \"value\": 0.0113378}, {\"regressor\": \"trans_x\", \"scan_number\": 28, \"value\": 0.0155607}, {\"regressor\": \"trans_x\", \"scan_number\": 29, \"value\": 0.025935400000000004}, {\"regressor\": \"trans_x\", \"scan_number\": 30, \"value\": 0.02594}, {\"regressor\": \"trans_x\", \"scan_number\": 31, \"value\": 0.0198066}, {\"regressor\": \"trans_x\", \"scan_number\": 32, \"value\": 0.00760825}, {\"regressor\": \"trans_x\", \"scan_number\": 33, \"value\": 0.004689199999999999}, {\"regressor\": \"trans_x\", \"scan_number\": 34, \"value\": 0.00470456}, {\"regressor\": \"trans_x\", \"scan_number\": 35, \"value\": 0.00471955}, {\"regressor\": \"trans_x\", \"scan_number\": 36, \"value\": -0.000886591}, {\"regressor\": \"trans_x\", \"scan_number\": 37, \"value\": 0.00468456}, {\"regressor\": \"trans_x\", \"scan_number\": 38, \"value\": -0.0211693}, {\"regressor\": \"trans_x\", \"scan_number\": 39, \"value\": -0.0254132}, {\"regressor\": \"trans_x\", \"scan_number\": 40, \"value\": -0.0254179}, {\"regressor\": \"trans_x\", \"scan_number\": 41, \"value\": -0.017903799999999997}, {\"regressor\": \"trans_x\", \"scan_number\": 42, \"value\": -0.007302549999999999}, {\"regressor\": \"trans_x\", \"scan_number\": 43, \"value\": -0.0141767}, {\"regressor\": \"trans_x\", \"scan_number\": 44, \"value\": -0.00484307}, {\"regressor\": \"trans_x\", \"scan_number\": 45, \"value\": 0.00262832}, {\"regressor\": \"trans_x\", \"scan_number\": 46, \"value\": 0.0150392}, {\"regressor\": \"trans_x\", \"scan_number\": 47, \"value\": 0.015089600000000003}, {\"regressor\": \"trans_x\", \"scan_number\": 48, \"value\": 0.0151028}, {\"regressor\": \"trans_x\", \"scan_number\": 49, \"value\": 0.0239823}, {\"regressor\": \"trans_x\", \"scan_number\": 50, \"value\": 0.026776}, {\"regressor\": \"trans_x\", \"scan_number\": 51, \"value\": 0.0237202}, {\"regressor\": \"trans_x\", \"scan_number\": 52, \"value\": 0.0265291}, {\"regressor\": \"trans_x\", \"scan_number\": 53, \"value\": 0.040145}, {\"regressor\": \"trans_x\", \"scan_number\": 54, \"value\": 0.0174945}, {\"regressor\": \"trans_x\", \"scan_number\": 55, \"value\": 0.0126645}, {\"regressor\": \"trans_x\", \"scan_number\": 56, \"value\": 0.0151354}, {\"regressor\": \"trans_x\", \"scan_number\": 57, \"value\": 0.0151355}, {\"regressor\": \"trans_x\", \"scan_number\": 58, \"value\": 0.0151571}, {\"regressor\": \"trans_x\", \"scan_number\": 59, \"value\": 0.0151645}, {\"regressor\": \"trans_x\", \"scan_number\": 60, \"value\": -0.00672006}, {\"regressor\": \"trans_x\", \"scan_number\": 61, \"value\": -0.00669614}, {\"regressor\": \"trans_x\", \"scan_number\": 62, \"value\": -0.0268032}, {\"regressor\": \"trans_x\", \"scan_number\": 63, \"value\": -0.026778700000000003}, {\"regressor\": \"trans_x\", \"scan_number\": 64, \"value\": -0.0366333}, {\"regressor\": \"trans_x\", \"scan_number\": 65, \"value\": -0.0442424}, {\"regressor\": \"trans_x\", \"scan_number\": 66, \"value\": -0.0530582}, {\"regressor\": \"trans_x\", \"scan_number\": 67, \"value\": -0.0633735}, {\"regressor\": \"trans_x\", \"scan_number\": 68, \"value\": -0.0799108}, {\"regressor\": \"trans_x\", \"scan_number\": 69, \"value\": -0.047118}, {\"regressor\": \"trans_x\", \"scan_number\": 70, \"value\": -0.0212557}, {\"regressor\": \"trans_x\", \"scan_number\": 71, \"value\": -0.0156362}, {\"regressor\": \"trans_x\", \"scan_number\": 72, \"value\": -0.0213098}, {\"regressor\": \"trans_x\", \"scan_number\": 73, \"value\": -0.0212218}, {\"regressor\": \"trans_x\", \"scan_number\": 74, \"value\": -0.0212248}, {\"regressor\": \"trans_x\", \"scan_number\": 75, \"value\": -0.00873259}, {\"regressor\": \"trans_x\", \"scan_number\": 76, \"value\": 0.016462}, {\"regressor\": \"trans_x\", \"scan_number\": 77, \"value\": -0.00010811900000000004}, {\"regressor\": \"trans_x\", \"scan_number\": 78, \"value\": -0.0346625}, {\"regressor\": \"trans_x\", \"scan_number\": 79, \"value\": -0.0408381}, {\"regressor\": \"trans_x\", \"scan_number\": 80, \"value\": -0.053490599999999985}, {\"regressor\": \"trans_x\", \"scan_number\": 81, \"value\": -0.0510163}, {\"regressor\": \"trans_x\", \"scan_number\": 82, \"value\": -0.0443666}, {\"regressor\": \"trans_x\", \"scan_number\": 83, \"value\": -0.0429872}, {\"regressor\": \"trans_x\", \"scan_number\": 84, \"value\": -0.0361381}, {\"regressor\": \"trans_x\", \"scan_number\": 85, \"value\": -0.0412135}, {\"regressor\": \"trans_x\", \"scan_number\": 86, \"value\": -0.0424326}, {\"regressor\": \"trans_x\", \"scan_number\": 87, \"value\": -0.0318483}, {\"regressor\": \"trans_x\", \"scan_number\": 88, \"value\": -0.0318572}, {\"regressor\": \"trans_x\", \"scan_number\": 89, \"value\": -0.042493300000000005}, {\"regressor\": \"trans_x\", \"scan_number\": 90, \"value\": -0.0319007}, {\"regressor\": \"trans_x\", \"scan_number\": 91, \"value\": -0.0435077}, {\"regressor\": \"trans_x\", \"scan_number\": 92, \"value\": -0.0504242}, {\"regressor\": \"trans_x\", \"scan_number\": 93, \"value\": -0.066334}, {\"regressor\": \"trans_x\", \"scan_number\": 94, \"value\": -0.0901603}, {\"regressor\": \"trans_x\", \"scan_number\": 95, \"value\": -0.08932999999999999}, {\"regressor\": \"trans_x\", \"scan_number\": 96, \"value\": -0.08178889999999997}, {\"regressor\": \"trans_x\", \"scan_number\": 97, \"value\": -0.0943948}, {\"regressor\": \"trans_x\", \"scan_number\": 98, \"value\": -0.104913}, {\"regressor\": \"trans_x\", \"scan_number\": 99, \"value\": -0.104675}, {\"regressor\": \"trans_x\", \"scan_number\": 100, \"value\": -0.102895}, {\"regressor\": \"trans_x\", \"scan_number\": 101, \"value\": -0.112752}, {\"regressor\": \"trans_x\", \"scan_number\": 102, \"value\": -0.139148}, {\"regressor\": \"trans_x\", \"scan_number\": 103, \"value\": -0.06817569999999999}, {\"regressor\": \"trans_x\", \"scan_number\": 104, \"value\": -0.0681727}, {\"regressor\": \"trans_x\", \"scan_number\": 105, \"value\": -0.09244790000000004}, {\"regressor\": \"trans_x\", \"scan_number\": 106, \"value\": -0.099393}, {\"regressor\": \"trans_x\", \"scan_number\": 107, \"value\": -0.101829}, {\"regressor\": \"trans_x\", \"scan_number\": 108, \"value\": -0.122803}, {\"regressor\": \"trans_x\", \"scan_number\": 109, \"value\": -0.142902}, {\"regressor\": \"trans_x\", \"scan_number\": 110, \"value\": -0.17439200000000002}, {\"regressor\": \"trans_x\", \"scan_number\": 111, \"value\": -0.181279}, {\"regressor\": \"trans_x\", \"scan_number\": 112, \"value\": -0.156637}, {\"regressor\": \"trans_x\", \"scan_number\": 113, \"value\": -0.111386}, {\"regressor\": \"trans_x\", \"scan_number\": 114, \"value\": -0.11514}, {\"regressor\": \"trans_x\", \"scan_number\": 115, \"value\": -0.13206099999999998}, {\"regressor\": \"trans_x\", \"scan_number\": 116, \"value\": -0.16458599999999998}, {\"regressor\": \"trans_x\", \"scan_number\": 117, \"value\": -0.184228}, {\"regressor\": \"trans_x\", \"scan_number\": 118, \"value\": -0.182948}, {\"regressor\": \"trans_x\", \"scan_number\": 119, \"value\": -0.182953}, {\"regressor\": \"trans_x\", \"scan_number\": 120, \"value\": -0.16429100000000002}, {\"regressor\": \"trans_x\", \"scan_number\": 121, \"value\": -0.158004}, {\"regressor\": \"trans_x\", \"scan_number\": 122, \"value\": -0.16338}, {\"regressor\": \"trans_x\", \"scan_number\": 123, \"value\": -0.15169000000000002}, {\"regressor\": \"trans_x\", \"scan_number\": 124, \"value\": -0.17108699999999996}, {\"regressor\": \"trans_x\", \"scan_number\": 125, \"value\": -0.15020799999999998}, {\"regressor\": \"trans_x\", \"scan_number\": 126, \"value\": -0.171424}, {\"regressor\": \"trans_x\", \"scan_number\": 127, \"value\": -0.17127}, {\"regressor\": \"trans_x\", \"scan_number\": 128, \"value\": -0.178865}, {\"regressor\": \"trans_x\", \"scan_number\": 129, \"value\": -0.173873}, {\"regressor\": \"trans_x\", \"scan_number\": 130, \"value\": -0.162509}, {\"regressor\": \"trans_x\", \"scan_number\": 131, \"value\": -0.17413999999999996}, {\"regressor\": \"trans_x\", \"scan_number\": 132, \"value\": -0.187298}, {\"regressor\": \"trans_x\", \"scan_number\": 133, \"value\": -0.187421}, {\"regressor\": \"trans_x\", \"scan_number\": 134, \"value\": -0.19563}, {\"regressor\": \"trans_x\", \"scan_number\": 135, \"value\": -0.219429}, {\"regressor\": \"trans_x\", \"scan_number\": 136, \"value\": -0.205547}, {\"regressor\": \"trans_x\", \"scan_number\": 137, \"value\": -0.200738}, {\"regressor\": \"trans_x\", \"scan_number\": 138, \"value\": -0.207355}, {\"regressor\": \"trans_x\", \"scan_number\": 139, \"value\": -0.169903}, {\"regressor\": \"trans_x\", \"scan_number\": 140, \"value\": -0.194176}, {\"regressor\": \"trans_x\", \"scan_number\": 141, \"value\": -0.185076}, {\"regressor\": \"trans_x\", \"scan_number\": 142, \"value\": -0.143225}, {\"regressor\": \"trans_x\", \"scan_number\": 143, \"value\": -0.137115}, {\"regressor\": \"trans_x\", \"scan_number\": 144, \"value\": -0.154942}, {\"regressor\": \"trans_x\", \"scan_number\": 145, \"value\": -0.148909}, {\"regressor\": \"trans_x\", \"scan_number\": 146, \"value\": -0.180383}, {\"regressor\": \"trans_x\", \"scan_number\": 147, \"value\": -0.181521}, {\"regressor\": \"trans_x\", \"scan_number\": 148, \"value\": -0.158667}, {\"regressor\": \"trans_x\", \"scan_number\": 149, \"value\": -0.19613}, {\"regressor\": \"trans_x\", \"scan_number\": 150, \"value\": -0.196221}, {\"regressor\": \"trans_x\", \"scan_number\": 151, \"value\": -0.178674}, {\"regressor\": \"trans_x\", \"scan_number\": 152, \"value\": -0.182088}, {\"regressor\": \"trans_x\", \"scan_number\": 153, \"value\": -0.196401}, {\"regressor\": \"trans_x\", \"scan_number\": 154, \"value\": -0.223562}, {\"regressor\": \"trans_x\", \"scan_number\": 155, \"value\": -0.223488}, {\"regressor\": \"trans_x\", \"scan_number\": 156, \"value\": -0.223183}, {\"regressor\": \"trans_x\", \"scan_number\": 157, \"value\": -0.222294}, {\"regressor\": \"trans_x\", \"scan_number\": 158, \"value\": -0.200314}, {\"regressor\": \"trans_x\", \"scan_number\": 159, \"value\": -0.208846}, {\"regressor\": \"trans_x\", \"scan_number\": 160, \"value\": -0.198993}, {\"regressor\": \"trans_x\", \"scan_number\": 161, \"value\": -0.198677}, {\"regressor\": \"trans_x\", \"scan_number\": 162, \"value\": -0.201431}, {\"regressor\": \"trans_x\", \"scan_number\": 163, \"value\": -0.212597}, {\"regressor\": \"trans_x\", \"scan_number\": 164, \"value\": -0.169324}, {\"regressor\": \"trans_x\", \"scan_number\": 165, \"value\": -0.17040999999999998}, {\"regressor\": \"trans_x\", \"scan_number\": 166, \"value\": -0.171045}, {\"regressor\": \"trans_x\", \"scan_number\": 167, \"value\": -0.180885}, {\"regressor\": \"trans_x\", \"scan_number\": 168, \"value\": -0.18668}, {\"regressor\": \"trans_x\", \"scan_number\": 169, \"value\": -0.201179}, {\"regressor\": \"trans_x\", \"scan_number\": 170, \"value\": -0.205865}, {\"regressor\": \"trans_x\", \"scan_number\": 171, \"value\": -0.200626}, {\"regressor\": \"trans_x\", \"scan_number\": 172, \"value\": -0.147077}, {\"regressor\": \"trans_x\", \"scan_number\": 173, \"value\": -0.1589}, {\"regressor\": \"trans_x\", \"scan_number\": 174, \"value\": -0.191006}, {\"regressor\": \"trans_x\", \"scan_number\": 175, \"value\": -0.208093}, {\"regressor\": \"trans_x\", \"scan_number\": 176, \"value\": -0.208005}, {\"regressor\": \"trans_x\", \"scan_number\": 177, \"value\": -0.217759}, {\"regressor\": \"trans_x\", \"scan_number\": 178, \"value\": -0.224767}, {\"regressor\": \"trans_x\", \"scan_number\": 179, \"value\": -0.222706}, {\"regressor\": \"trans_x\", \"scan_number\": 180, \"value\": -0.221989}, {\"regressor\": \"trans_x\", \"scan_number\": 181, \"value\": -0.2003}, {\"regressor\": \"trans_x\", \"scan_number\": 182, \"value\": -0.189252}, {\"regressor\": \"trans_x\", \"scan_number\": 183, \"value\": -0.189101}, {\"regressor\": \"trans_x\", \"scan_number\": 184, \"value\": -0.200725}, {\"regressor\": \"trans_x\", \"scan_number\": 185, \"value\": -0.220806}, {\"regressor\": \"trans_x\", \"scan_number\": 186, \"value\": -0.229331}, {\"regressor\": \"trans_x\", \"scan_number\": 187, \"value\": -0.238242}, {\"regressor\": \"trans_x\", \"scan_number\": 188, \"value\": -0.255774}, {\"regressor\": \"trans_x\", \"scan_number\": 189, \"value\": -0.273417}, {\"regressor\": \"trans_x\", \"scan_number\": 190, \"value\": -0.273713}, {\"regressor\": \"trans_x\", \"scan_number\": 191, \"value\": -0.274048}, {\"regressor\": \"trans_x\", \"scan_number\": 192, \"value\": -0.27628800000000003}, {\"regressor\": \"trans_x\", \"scan_number\": 193, \"value\": -0.263315}, {\"regressor\": \"trans_x\", \"scan_number\": 194, \"value\": -0.26210100000000003}, {\"regressor\": \"trans_x\", \"scan_number\": 195, \"value\": -0.25721900000000003}, {\"regressor\": \"trans_x\", \"scan_number\": 196, \"value\": -0.255573}, {\"regressor\": \"trans_x\", \"scan_number\": 197, \"value\": -0.27838}, {\"regressor\": \"trans_x\", \"scan_number\": 198, \"value\": -0.28205}, {\"regressor\": \"trans_x\", \"scan_number\": 199, \"value\": -0.261778}, {\"regressor\": \"trans_x\", \"scan_number\": 200, \"value\": -0.240171}, {\"regressor\": \"trans_x\", \"scan_number\": 201, \"value\": -0.238609}, {\"regressor\": \"trans_x\", \"scan_number\": 202, \"value\": -0.25263}, {\"regressor\": \"trans_x\", \"scan_number\": 203, \"value\": -0.258274}, {\"regressor\": \"trans_x\", \"scan_number\": 204, \"value\": -0.26210100000000003}, {\"regressor\": \"trans_x\", \"scan_number\": 205, \"value\": -0.234255}, {\"regressor\": \"trans_x\", \"scan_number\": 206, \"value\": -0.224724}, {\"regressor\": \"trans_x\", \"scan_number\": 207, \"value\": -0.240761}, {\"regressor\": \"trans_x\", \"scan_number\": 208, \"value\": -0.224463}, {\"regressor\": \"trans_x\", \"scan_number\": 209, \"value\": -0.244328}, {\"regressor\": \"trans_x\", \"scan_number\": 210, \"value\": -0.258384}, {\"regressor\": \"trans_x\", \"scan_number\": 211, \"value\": -0.268447}, {\"regressor\": \"trans_x\", \"scan_number\": 212, \"value\": -0.296709}, {\"regressor\": \"trans_x\", \"scan_number\": 213, \"value\": -0.28241}, {\"regressor\": \"trans_x\", \"scan_number\": 214, \"value\": -0.27021}, {\"regressor\": \"trans_x\", \"scan_number\": 215, \"value\": -0.282467}, {\"regressor\": \"trans_x\", \"scan_number\": 216, \"value\": -0.310385}, {\"regressor\": \"trans_x\", \"scan_number\": 217, \"value\": -0.277515}, {\"regressor\": \"trans_x\", \"scan_number\": 218, \"value\": -0.243368}, {\"regressor\": \"trans_x\", \"scan_number\": 219, \"value\": -0.226758}, {\"regressor\": \"trans_x\", \"scan_number\": 220, \"value\": -0.13596200000000006}, {\"regressor\": \"trans_x\", \"scan_number\": 221, \"value\": -0.16482}, {\"regressor\": \"trans_x\", \"scan_number\": 222, \"value\": -0.200066}, {\"regressor\": \"trans_x\", \"scan_number\": 223, \"value\": -0.21833400000000006}, {\"regressor\": \"trans_x\", \"scan_number\": 224, \"value\": -0.219445}, {\"regressor\": \"trans_x\", \"scan_number\": 225, \"value\": -0.203458}, {\"regressor\": \"trans_x\", \"scan_number\": 226, \"value\": -0.203539}, {\"regressor\": \"trans_x\", \"scan_number\": 227, \"value\": -0.203333}, {\"regressor\": \"trans_x\", \"scan_number\": 228, \"value\": -0.209685}, {\"regressor\": \"trans_x\", \"scan_number\": 229, \"value\": -0.251233}, {\"regressor\": \"trans_x\", \"scan_number\": 230, \"value\": -0.253356}, {\"regressor\": \"trans_x\", \"scan_number\": 231, \"value\": -0.240141}, {\"regressor\": \"trans_x\", \"scan_number\": 232, \"value\": -0.239931}, {\"regressor\": \"trans_x\", \"scan_number\": 233, \"value\": -0.25006}, {\"regressor\": \"trans_x\", \"scan_number\": 234, \"value\": -0.263947}, {\"regressor\": \"trans_x\", \"scan_number\": 235, \"value\": -0.271514}, {\"regressor\": \"trans_x\", \"scan_number\": 236, \"value\": -0.264529}, {\"regressor\": \"trans_x\", \"scan_number\": 237, \"value\": -0.246712}, {\"regressor\": \"trans_x\", \"scan_number\": 238, \"value\": -0.241016}, {\"regressor\": \"trans_x\", \"scan_number\": 239, \"value\": -0.232786}, {\"regressor\": \"trans_x\", \"scan_number\": 240, \"value\": -0.200985}, {\"regressor\": \"trans_x\", \"scan_number\": 241, \"value\": -0.187271}, {\"regressor\": \"trans_x\", \"scan_number\": 242, \"value\": -0.210547}, {\"regressor\": \"trans_x\", \"scan_number\": 243, \"value\": -0.221681}, {\"regressor\": \"trans_x\", \"scan_number\": 244, \"value\": -0.216236}, {\"regressor\": \"trans_x\", \"scan_number\": 245, \"value\": -0.210161}, {\"regressor\": \"trans_x\", \"scan_number\": 246, \"value\": -0.193817}, {\"regressor\": \"trans_x\", \"scan_number\": 247, \"value\": -0.19393}, {\"regressor\": \"trans_x\", \"scan_number\": 248, \"value\": -0.196304}, {\"regressor\": \"trans_x\", \"scan_number\": 249, \"value\": -0.198144}, {\"regressor\": \"trans_x\", \"scan_number\": 250, \"value\": -0.196432}, {\"regressor\": \"trans_x\", \"scan_number\": 251, \"value\": -0.197704}, {\"regressor\": \"trans_x\", \"scan_number\": 252, \"value\": -0.169975}, {\"regressor\": \"trans_x\", \"scan_number\": 253, \"value\": -0.162968}, {\"regressor\": \"trans_x\", \"scan_number\": 254, \"value\": -0.184368}, {\"regressor\": \"trans_x\", \"scan_number\": 255, \"value\": -0.173555}, {\"regressor\": \"trans_x\", \"scan_number\": 256, \"value\": -0.16769}, {\"regressor\": \"trans_x\", \"scan_number\": 257, \"value\": -0.16126600000000002}, {\"regressor\": \"trans_x\", \"scan_number\": 258, \"value\": -0.154504}, {\"regressor\": \"trans_x\", \"scan_number\": 259, \"value\": -0.165027}, {\"regressor\": \"trans_x\", \"scan_number\": 260, \"value\": -0.165939}, {\"regressor\": \"trans_x\", \"scan_number\": 261, \"value\": -0.183411}, {\"regressor\": \"trans_x\", \"scan_number\": 262, \"value\": -0.201501}, {\"regressor\": \"trans_x\", \"scan_number\": 263, \"value\": -0.20411}, {\"regressor\": \"trans_x\", \"scan_number\": 264, \"value\": -0.204304}, {\"regressor\": \"trans_x\", \"scan_number\": 265, \"value\": -0.206596}, {\"regressor\": \"trans_x\", \"scan_number\": 266, \"value\": -0.210556}, {\"regressor\": \"trans_x\", \"scan_number\": 267, \"value\": -0.22976}, {\"regressor\": \"trans_x\", \"scan_number\": 268, \"value\": -0.238987}, {\"regressor\": \"trans_x\", \"scan_number\": 269, \"value\": -0.238682}, {\"regressor\": \"trans_x\", \"scan_number\": 270, \"value\": -0.237307}, {\"regressor\": \"trans_x\", \"scan_number\": 271, \"value\": -0.220605}, {\"regressor\": \"trans_x\", \"scan_number\": 272, \"value\": -0.2177}, {\"regressor\": \"trans_x\", \"scan_number\": 273, \"value\": -0.19118}, {\"regressor\": \"trans_x\", \"scan_number\": 274, \"value\": -0.200882}, {\"regressor\": \"trans_x\", \"scan_number\": 275, \"value\": -0.208342}, {\"regressor\": \"trans_x\", \"scan_number\": 276, \"value\": -0.209235}, {\"regressor\": \"trans_x\", \"scan_number\": 277, \"value\": -0.210078}, {\"regressor\": \"trans_x\", \"scan_number\": 278, \"value\": -0.204239}, {\"regressor\": \"trans_x\", \"scan_number\": 279, \"value\": -0.201017}, {\"regressor\": \"trans_x\", \"scan_number\": 280, \"value\": -0.20071}, {\"regressor\": \"trans_x\", \"scan_number\": 281, \"value\": -0.183861}, {\"regressor\": \"trans_x\", \"scan_number\": 282, \"value\": -0.17350199999999996}, {\"regressor\": \"trans_x\", \"scan_number\": 283, \"value\": -0.14617}, {\"regressor\": \"trans_x\", \"scan_number\": 284, \"value\": -0.152615}, {\"regressor\": \"trans_x\", \"scan_number\": 285, \"value\": -0.167743}, {\"regressor\": \"trans_x\", \"scan_number\": 286, \"value\": -0.147245}, {\"regressor\": \"trans_x\", \"scan_number\": 287, \"value\": -0.147293}, {\"regressor\": \"trans_x\", \"scan_number\": 288, \"value\": -0.149619}, {\"regressor\": \"trans_x\", \"scan_number\": 289, \"value\": -0.163655}, {\"regressor\": \"trans_x\", \"scan_number\": 290, \"value\": -0.164458}, {\"regressor\": \"trans_x\", \"scan_number\": 291, \"value\": -0.17034100000000002}, {\"regressor\": \"trans_x\", \"scan_number\": 292, \"value\": -0.181742}, {\"regressor\": \"trans_x\", \"scan_number\": 293, \"value\": -0.188659}, {\"regressor\": \"trans_x\", \"scan_number\": 294, \"value\": -0.190921}, {\"regressor\": \"trans_x\", \"scan_number\": 295, \"value\": -0.204426}, {\"regressor\": \"trans_x\", \"scan_number\": 296, \"value\": -0.217765}, {\"regressor\": \"trans_x\", \"scan_number\": 297, \"value\": -0.218838}, {\"regressor\": \"trans_x\", \"scan_number\": 298, \"value\": -0.211789}, {\"regressor\": \"trans_x\", \"scan_number\": 299, \"value\": -0.205171}, {\"regressor\": \"trans_x\", \"scan_number\": 300, \"value\": -0.219077}, {\"regressor\": \"trans_x\", \"scan_number\": 301, \"value\": -0.222768}, {\"regressor\": \"trans_x\", \"scan_number\": 302, \"value\": -0.226963}, {\"regressor\": \"trans_x\", \"scan_number\": 303, \"value\": -0.241154}, {\"regressor\": \"trans_x\", \"scan_number\": 304, \"value\": -0.246326}, {\"regressor\": \"trans_x\", \"scan_number\": 305, \"value\": -0.246009}, {\"regressor\": \"trans_x\", \"scan_number\": 306, \"value\": -0.22737}, {\"regressor\": \"trans_x\", \"scan_number\": 307, \"value\": -0.245641}, {\"regressor\": \"trans_x\", \"scan_number\": 308, \"value\": -0.24462}, {\"regressor\": \"trans_x\", \"scan_number\": 309, \"value\": -0.245294}, {\"regressor\": \"trans_x\", \"scan_number\": 310, \"value\": -0.246923}, {\"regressor\": \"trans_x\", \"scan_number\": 311, \"value\": -0.25600700000000004}, {\"regressor\": \"trans_x\", \"scan_number\": 312, \"value\": -0.257168}, {\"regressor\": \"trans_x\", \"scan_number\": 313, \"value\": -0.246711}, {\"regressor\": \"trans_x\", \"scan_number\": 314, \"value\": -0.265455}, {\"regressor\": \"trans_x\", \"scan_number\": 315, \"value\": -0.265149}, {\"regressor\": \"trans_x\", \"scan_number\": 316, \"value\": -0.264292}, {\"regressor\": \"trans_x\", \"scan_number\": 317, \"value\": -0.255857}, {\"regressor\": \"trans_x\", \"scan_number\": 318, \"value\": -0.255888}, {\"regressor\": \"trans_x\", \"scan_number\": 319, \"value\": -0.270791}, {\"regressor\": \"trans_x\", \"scan_number\": 320, \"value\": -0.273046}, {\"regressor\": \"trans_x\", \"scan_number\": 321, \"value\": -0.285145}, {\"regressor\": \"trans_x\", \"scan_number\": 322, \"value\": -0.287065}, {\"regressor\": \"trans_x\", \"scan_number\": 323, \"value\": -0.283274}, {\"regressor\": \"trans_x\", \"scan_number\": 324, \"value\": -0.270008}, {\"regressor\": \"trans_x\", \"scan_number\": 325, \"value\": -0.256496}, {\"regressor\": \"trans_x\", \"scan_number\": 326, \"value\": -0.251587}, {\"regressor\": \"trans_x\", \"scan_number\": 327, \"value\": -0.240842}, {\"regressor\": \"trans_x\", \"scan_number\": 328, \"value\": -0.155563}, {\"regressor\": \"trans_x\", \"scan_number\": 329, \"value\": -0.10243499999999997}, {\"regressor\": \"trans_x\", \"scan_number\": 330, \"value\": -0.05774840000000001}, {\"regressor\": \"trans_x\", \"scan_number\": 331, \"value\": -0.0622023}, {\"regressor\": \"trans_x\", \"scan_number\": 332, \"value\": -0.07635029999999997}, {\"regressor\": \"trans_x\", \"scan_number\": 333, \"value\": -0.08753689999999999}, {\"regressor\": \"trans_x\", \"scan_number\": 334, \"value\": -0.0768552}, {\"regressor\": \"trans_x\", \"scan_number\": 335, \"value\": -0.07635839999999999}, {\"regressor\": \"trans_x\", \"scan_number\": 336, \"value\": -0.07686599999999999}, {\"regressor\": \"trans_x\", \"scan_number\": 337, \"value\": -0.07689}, {\"regressor\": \"trans_x\", \"scan_number\": 338, \"value\": -0.0766285}, {\"regressor\": \"trans_x\", \"scan_number\": 339, \"value\": -0.098462}, {\"regressor\": \"trans_x\", \"scan_number\": 340, \"value\": -0.0998084}, {\"regressor\": \"trans_x\", \"scan_number\": 341, \"value\": -0.08495819999999997}, {\"regressor\": \"trans_x\", \"scan_number\": 342, \"value\": -0.10028}, {\"regressor\": \"trans_x\", \"scan_number\": 343, \"value\": -0.0945703}, {\"regressor\": \"trans_y\", \"scan_number\": 0, \"value\": 0.0307721}, {\"regressor\": \"trans_y\", \"scan_number\": 1, \"value\": 0.0365419}, {\"regressor\": \"trans_y\", \"scan_number\": 2, \"value\": -3.81876e-05}, {\"regressor\": \"trans_y\", \"scan_number\": 3, \"value\": -2.74752e-05}, {\"regressor\": \"trans_y\", \"scan_number\": 4, \"value\": 0.0161649}, {\"regressor\": \"trans_y\", \"scan_number\": 5, \"value\": -0.0143655}, {\"regressor\": \"trans_y\", \"scan_number\": 6, \"value\": 0.0454096}, {\"regressor\": \"trans_y\", \"scan_number\": 7, \"value\": 0.00593651}, {\"regressor\": \"trans_y\", \"scan_number\": 8, \"value\": -0.013320600000000002}, {\"regressor\": \"trans_y\", \"scan_number\": 9, \"value\": -0.0326035}, {\"regressor\": \"trans_y\", \"scan_number\": 10, \"value\": -0.07549409999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 11, \"value\": -0.0377186}, {\"regressor\": \"trans_y\", \"scan_number\": 12, \"value\": 0.0105835}, {\"regressor\": \"trans_y\", \"scan_number\": 13, \"value\": 0.010669}, {\"regressor\": \"trans_y\", \"scan_number\": 14, \"value\": -0.0109129}, {\"regressor\": \"trans_y\", \"scan_number\": 15, \"value\": -0.0682309}, {\"regressor\": \"trans_y\", \"scan_number\": 16, \"value\": -0.0439575}, {\"regressor\": \"trans_y\", \"scan_number\": 17, \"value\": 0.0358424}, {\"regressor\": \"trans_y\", \"scan_number\": 18, \"value\": 0.0357937}, {\"regressor\": \"trans_y\", \"scan_number\": 19, \"value\": -0.008727749999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 20, \"value\": -0.00873642}, {\"regressor\": \"trans_y\", \"scan_number\": 21, \"value\": -0.0246467}, {\"regressor\": \"trans_y\", \"scan_number\": 22, \"value\": -0.0398982}, {\"regressor\": \"trans_y\", \"scan_number\": 23, \"value\": 0.0307677}, {\"regressor\": \"trans_y\", \"scan_number\": 24, \"value\": 0.00188663}, {\"regressor\": \"trans_y\", \"scan_number\": 25, \"value\": 0.0170418}, {\"regressor\": \"trans_y\", \"scan_number\": 26, \"value\": -0.012072200000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 27, \"value\": -0.0142833}, {\"regressor\": \"trans_y\", \"scan_number\": 28, \"value\": -0.0142692}, {\"regressor\": \"trans_y\", \"scan_number\": 29, \"value\": 0.0417402}, {\"regressor\": \"trans_y\", \"scan_number\": 30, \"value\": -0.0359423}, {\"regressor\": \"trans_y\", \"scan_number\": 31, \"value\": -0.0359351}, {\"regressor\": \"trans_y\", \"scan_number\": 32, \"value\": -0.0136529}, {\"regressor\": \"trans_y\", \"scan_number\": 33, \"value\": 0.007714269999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 34, \"value\": -0.037562800000000014}, {\"regressor\": \"trans_y\", \"scan_number\": 35, \"value\": 0.0151943}, {\"regressor\": \"trans_y\", \"scan_number\": 36, \"value\": 0.0465415}, {\"regressor\": \"trans_y\", \"scan_number\": 37, \"value\": -0.027715}, {\"regressor\": \"trans_y\", \"scan_number\": 38, \"value\": -0.0530855}, {\"regressor\": \"trans_y\", \"scan_number\": 39, \"value\": -0.0168687}, {\"regressor\": \"trans_y\", \"scan_number\": 40, \"value\": 0.0193996}, {\"regressor\": \"trans_y\", \"scan_number\": 41, \"value\": -0.00417359}, {\"regressor\": \"trans_y\", \"scan_number\": 42, \"value\": 0.00662756}, {\"regressor\": \"trans_y\", \"scan_number\": 43, \"value\": -0.00418184}, {\"regressor\": \"trans_y\", \"scan_number\": 44, \"value\": 0.0217377}, {\"regressor\": \"trans_y\", \"scan_number\": 45, \"value\": -0.0169042}, {\"regressor\": \"trans_y\", \"scan_number\": 46, \"value\": -0.035062300000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 47, \"value\": 0.060862699999999985}, {\"regressor\": \"trans_y\", \"scan_number\": 48, \"value\": 0.0735356}, {\"regressor\": \"trans_y\", \"scan_number\": 49, \"value\": -0.0397249}, {\"regressor\": \"trans_y\", \"scan_number\": 50, \"value\": 0.0293011}, {\"regressor\": \"trans_y\", \"scan_number\": 51, \"value\": 0.00816215}, {\"regressor\": \"trans_y\", \"scan_number\": 52, \"value\": 0.008162489999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 53, \"value\": -0.00813142}, {\"regressor\": \"trans_y\", \"scan_number\": 54, \"value\": 0.013987}, {\"regressor\": \"trans_y\", \"scan_number\": 55, \"value\": -0.00811116}, {\"regressor\": \"trans_y\", \"scan_number\": 56, \"value\": -0.05844019999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 57, \"value\": 0.0375353}, {\"regressor\": \"trans_y\", \"scan_number\": 58, \"value\": 0.0118899}, {\"regressor\": \"trans_y\", \"scan_number\": 59, \"value\": -0.0287703}, {\"regressor\": \"trans_y\", \"scan_number\": 60, \"value\": 0.0438805}, {\"regressor\": \"trans_y\", \"scan_number\": 61, \"value\": 0.0105126}, {\"regressor\": \"trans_y\", \"scan_number\": 62, \"value\": -0.0734883}, {\"regressor\": \"trans_y\", \"scan_number\": 63, \"value\": 0.0298001}, {\"regressor\": \"trans_y\", \"scan_number\": 64, \"value\": -0.00678238}, {\"regressor\": \"trans_y\", \"scan_number\": 65, \"value\": -0.0318633}, {\"regressor\": \"trans_y\", \"scan_number\": 66, \"value\": 0.0440784}, {\"regressor\": \"trans_y\", \"scan_number\": 67, \"value\": -0.0281189}, {\"regressor\": \"trans_y\", \"scan_number\": 68, \"value\": -0.0200174}, {\"regressor\": \"trans_y\", \"scan_number\": 69, \"value\": -0.00989017}, {\"regressor\": \"trans_y\", \"scan_number\": 70, \"value\": -0.0632177}, {\"regressor\": \"trans_y\", \"scan_number\": 71, \"value\": -0.0517526}, {\"regressor\": \"trans_y\", \"scan_number\": 72, \"value\": -0.103929}, {\"regressor\": \"trans_y\", \"scan_number\": 73, \"value\": -0.000420171}, {\"regressor\": \"trans_y\", \"scan_number\": 74, \"value\": -0.036730300000000014}, {\"regressor\": \"trans_y\", \"scan_number\": 75, \"value\": -0.0760705}, {\"regressor\": \"trans_y\", \"scan_number\": 76, \"value\": 0.0307014}, {\"regressor\": \"trans_y\", \"scan_number\": 77, \"value\": -0.0060006}, {\"regressor\": \"trans_y\", \"scan_number\": 78, \"value\": 0.0454091}, {\"regressor\": \"trans_y\", \"scan_number\": 79, \"value\": -0.0741685}, {\"regressor\": \"trans_y\", \"scan_number\": 80, \"value\": 0.0288775}, {\"regressor\": \"trans_y\", \"scan_number\": 81, \"value\": -0.0863932}, {\"regressor\": \"trans_y\", \"scan_number\": 82, \"value\": -0.0175364}, {\"regressor\": \"trans_y\", \"scan_number\": 83, \"value\": -0.041349800000000006}, {\"regressor\": \"trans_y\", \"scan_number\": 84, \"value\": -0.0413326}, {\"regressor\": \"trans_y\", \"scan_number\": 85, \"value\": 0.0336518}, {\"regressor\": \"trans_y\", \"scan_number\": 86, \"value\": -0.0190551}, {\"regressor\": \"trans_y\", \"scan_number\": 87, \"value\": 0.042980800000000006}, {\"regressor\": \"trans_y\", \"scan_number\": 88, \"value\": -0.0391109}, {\"regressor\": \"trans_y\", \"scan_number\": 89, \"value\": 0.075744}, {\"regressor\": \"trans_y\", \"scan_number\": 90, \"value\": -0.0643798}, {\"regressor\": \"trans_y\", \"scan_number\": 91, \"value\": 0.0311968}, {\"regressor\": \"trans_y\", \"scan_number\": 92, \"value\": -0.0488135}, {\"regressor\": \"trans_y\", \"scan_number\": 93, \"value\": 0.026351}, {\"regressor\": \"trans_y\", \"scan_number\": 94, \"value\": -0.0391841}, {\"regressor\": \"trans_y\", \"scan_number\": 95, \"value\": 0.0375812}, {\"regressor\": \"trans_y\", \"scan_number\": 96, \"value\": -0.054826199999999985}, {\"regressor\": \"trans_y\", \"scan_number\": 97, \"value\": 0.030251}, {\"regressor\": \"trans_y\", \"scan_number\": 98, \"value\": -0.0263739}, {\"regressor\": \"trans_y\", \"scan_number\": 99, \"value\": 0.00439899}, {\"regressor\": \"trans_y\", \"scan_number\": 100, \"value\": -0.0274201}, {\"regressor\": \"trans_y\", \"scan_number\": 101, \"value\": -0.0444329}, {\"regressor\": \"trans_y\", \"scan_number\": 102, \"value\": -0.06957560000000003}, {\"regressor\": \"trans_y\", \"scan_number\": 103, \"value\": 0.0315953}, {\"regressor\": \"trans_y\", \"scan_number\": 104, \"value\": 0.022697400000000003}, {\"regressor\": \"trans_y\", \"scan_number\": 105, \"value\": 0.012571}, {\"regressor\": \"trans_y\", \"scan_number\": 106, \"value\": -0.0382649}, {\"regressor\": \"trans_y\", \"scan_number\": 107, \"value\": 0.025662200000000003}, {\"regressor\": \"trans_y\", \"scan_number\": 108, \"value\": -0.0390846}, {\"regressor\": \"trans_y\", \"scan_number\": 109, \"value\": -0.0211816}, {\"regressor\": \"trans_y\", \"scan_number\": 110, \"value\": -0.048127}, {\"regressor\": \"trans_y\", \"scan_number\": 111, \"value\": 0.0357966}, {\"regressor\": \"trans_y\", \"scan_number\": 112, \"value\": -0.00271256}, {\"regressor\": \"trans_y\", \"scan_number\": 113, \"value\": -0.00418463}, {\"regressor\": \"trans_y\", \"scan_number\": 114, \"value\": 0.047024300000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 115, \"value\": -0.0154051}, {\"regressor\": \"trans_y\", \"scan_number\": 116, \"value\": 0.0852556}, {\"regressor\": \"trans_y\", \"scan_number\": 117, \"value\": -0.0576886}, {\"regressor\": \"trans_y\", \"scan_number\": 118, \"value\": 0.034242800000000004}, {\"regressor\": \"trans_y\", \"scan_number\": 119, \"value\": 0.09933860000000004}, {\"regressor\": \"trans_y\", \"scan_number\": 120, \"value\": 0.0156931}, {\"regressor\": \"trans_y\", \"scan_number\": 121, \"value\": 0.0578146}, {\"regressor\": \"trans_y\", \"scan_number\": 122, \"value\": -0.0118845}, {\"regressor\": \"trans_y\", \"scan_number\": 123, \"value\": 0.0290462}, {\"regressor\": \"trans_y\", \"scan_number\": 124, \"value\": 0.0972855}, {\"regressor\": \"trans_y\", \"scan_number\": 125, \"value\": 0.033466300000000004}, {\"regressor\": \"trans_y\", \"scan_number\": 126, \"value\": 0.08066210000000001}, {\"regressor\": \"trans_y\", \"scan_number\": 127, \"value\": 0.0496578}, {\"regressor\": \"trans_y\", \"scan_number\": 128, \"value\": 0.0902468}, {\"regressor\": \"trans_y\", \"scan_number\": 129, \"value\": 0.0190729}, {\"regressor\": \"trans_y\", \"scan_number\": 130, \"value\": 0.0126177}, {\"regressor\": \"trans_y\", \"scan_number\": 131, \"value\": 0.0966448}, {\"regressor\": \"trans_y\", \"scan_number\": 132, \"value\": -0.0006574939999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 133, \"value\": 0.0308612}, {\"regressor\": \"trans_y\", \"scan_number\": 134, \"value\": 0.107014}, {\"regressor\": \"trans_y\", \"scan_number\": 135, \"value\": 0.0373522}, {\"regressor\": \"trans_y\", \"scan_number\": 136, \"value\": 0.0917287}, {\"regressor\": \"trans_y\", \"scan_number\": 137, \"value\": -0.0125377}, {\"regressor\": \"trans_y\", \"scan_number\": 138, \"value\": -0.037404900000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 139, \"value\": 0.06231340000000001}, {\"regressor\": \"trans_y\", \"scan_number\": 140, \"value\": 0.0267906}, {\"regressor\": \"trans_y\", \"scan_number\": 141, \"value\": 0.0151638}, {\"regressor\": \"trans_y\", \"scan_number\": 142, \"value\": 0.05289830000000001}, {\"regressor\": \"trans_y\", \"scan_number\": 143, \"value\": 0.0259152}, {\"regressor\": \"trans_y\", \"scan_number\": 144, \"value\": 0.06469209999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 145, \"value\": 0.0671408}, {\"regressor\": \"trans_y\", \"scan_number\": 146, \"value\": 0.0551619}, {\"regressor\": \"trans_y\", \"scan_number\": 147, \"value\": 0.0819031}, {\"regressor\": \"trans_y\", \"scan_number\": 148, \"value\": 0.000434076}, {\"regressor\": \"trans_y\", \"scan_number\": 149, \"value\": -0.05912000000000001}, {\"regressor\": \"trans_y\", \"scan_number\": 150, \"value\": 0.07190919999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 151, \"value\": -0.037054}, {\"regressor\": \"trans_y\", \"scan_number\": 152, \"value\": -0.138449}, {\"regressor\": \"trans_y\", \"scan_number\": 153, \"value\": -0.0476121}, {\"regressor\": \"trans_y\", \"scan_number\": 154, \"value\": -0.110226}, {\"regressor\": \"trans_y\", \"scan_number\": 155, \"value\": -0.11524400000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 156, \"value\": -0.06386019999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 157, \"value\": -0.117234}, {\"regressor\": \"trans_y\", \"scan_number\": 158, \"value\": -0.0542394}, {\"regressor\": \"trans_y\", \"scan_number\": 159, \"value\": -0.0646355}, {\"regressor\": \"trans_y\", \"scan_number\": 160, \"value\": -0.153635}, {\"regressor\": \"trans_y\", \"scan_number\": 161, \"value\": -0.0894702}, {\"regressor\": \"trans_y\", \"scan_number\": 162, \"value\": -0.0553852}, {\"regressor\": \"trans_y\", \"scan_number\": 163, \"value\": -0.0433314}, {\"regressor\": \"trans_y\", \"scan_number\": 164, \"value\": -0.0206479}, {\"regressor\": \"trans_y\", \"scan_number\": 165, \"value\": 0.0446447}, {\"regressor\": \"trans_y\", \"scan_number\": 166, \"value\": -0.052047}, {\"regressor\": \"trans_y\", \"scan_number\": 167, \"value\": 0.00307704}, {\"regressor\": \"trans_y\", \"scan_number\": 168, \"value\": 0.022952700000000003}, {\"regressor\": \"trans_y\", \"scan_number\": 169, \"value\": -0.0468711}, {\"regressor\": \"trans_y\", \"scan_number\": 170, \"value\": -0.0453897}, {\"regressor\": \"trans_y\", \"scan_number\": 171, \"value\": 0.0182466}, {\"regressor\": \"trans_y\", \"scan_number\": 172, \"value\": 0.0131414}, {\"regressor\": \"trans_y\", \"scan_number\": 173, \"value\": 0.0885564}, {\"regressor\": \"trans_y\", \"scan_number\": 174, \"value\": 0.0698104}, {\"regressor\": \"trans_y\", \"scan_number\": 175, \"value\": 0.06537190000000001}, {\"regressor\": \"trans_y\", \"scan_number\": 176, \"value\": -0.0174527}, {\"regressor\": \"trans_y\", \"scan_number\": 177, \"value\": 0.00345641}, {\"regressor\": \"trans_y\", \"scan_number\": 178, \"value\": 0.0484582}, {\"regressor\": \"trans_y\", \"scan_number\": 179, \"value\": -0.0116444}, {\"regressor\": \"trans_y\", \"scan_number\": 180, \"value\": -0.0467833}, {\"regressor\": \"trans_y\", \"scan_number\": 181, \"value\": 0.033228}, {\"regressor\": \"trans_y\", \"scan_number\": 182, \"value\": 0.0346727}, {\"regressor\": \"trans_y\", \"scan_number\": 183, \"value\": -0.0408736}, {\"regressor\": \"trans_y\", \"scan_number\": 184, \"value\": -0.017197099999999996}, {\"regressor\": \"trans_y\", \"scan_number\": 185, \"value\": 0.024416}, {\"regressor\": \"trans_y\", \"scan_number\": 186, \"value\": 0.0220026}, {\"regressor\": \"trans_y\", \"scan_number\": 187, \"value\": -0.0182126}, {\"regressor\": \"trans_y\", \"scan_number\": 188, \"value\": -0.0298323}, {\"regressor\": \"trans_y\", \"scan_number\": 189, \"value\": 0.0712347}, {\"regressor\": \"trans_y\", \"scan_number\": 190, \"value\": 0.0566311}, {\"regressor\": \"trans_y\", \"scan_number\": 191, \"value\": 0.008559739999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 192, \"value\": 0.00541913}, {\"regressor\": \"trans_y\", \"scan_number\": 193, \"value\": 0.0420291}, {\"regressor\": \"trans_y\", \"scan_number\": 194, \"value\": 0.0305083}, {\"regressor\": \"trans_y\", \"scan_number\": 195, \"value\": -0.0126381}, {\"regressor\": \"trans_y\", \"scan_number\": 196, \"value\": -0.0153784}, {\"regressor\": \"trans_y\", \"scan_number\": 197, \"value\": 0.00462823}, {\"regressor\": \"trans_y\", \"scan_number\": 198, \"value\": 0.06008930000000001}, {\"regressor\": \"trans_y\", \"scan_number\": 199, \"value\": 0.06511990000000001}, {\"regressor\": \"trans_y\", \"scan_number\": 200, \"value\": 0.00546689}, {\"regressor\": \"trans_y\", \"scan_number\": 201, \"value\": -0.014411000000000004}, {\"regressor\": \"trans_y\", \"scan_number\": 202, \"value\": 0.033037800000000006}, {\"regressor\": \"trans_y\", \"scan_number\": 203, \"value\": 0.08348619999999997}, {\"regressor\": \"trans_y\", \"scan_number\": 204, \"value\": 0.042303}, {\"regressor\": \"trans_y\", \"scan_number\": 205, \"value\": 0.013736300000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 206, \"value\": -0.00338812}, {\"regressor\": \"trans_y\", \"scan_number\": 207, \"value\": 0.0453286}, {\"regressor\": \"trans_y\", \"scan_number\": 208, \"value\": 0.06296669999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 209, \"value\": 0.07399709999999997}, {\"regressor\": \"trans_y\", \"scan_number\": 210, \"value\": 0.0201157}, {\"regressor\": \"trans_y\", \"scan_number\": 211, \"value\": -0.0139985}, {\"regressor\": \"trans_y\", \"scan_number\": 212, \"value\": -0.00858041}, {\"regressor\": \"trans_y\", \"scan_number\": 213, \"value\": 0.0248816}, {\"regressor\": \"trans_y\", \"scan_number\": 214, \"value\": 0.055236900000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 215, \"value\": 0.00841132}, {\"regressor\": \"trans_y\", \"scan_number\": 216, \"value\": -0.0353712}, {\"regressor\": \"trans_y\", \"scan_number\": 217, \"value\": 0.0363122}, {\"regressor\": \"trans_y\", \"scan_number\": 218, \"value\": 0.102968}, {\"regressor\": \"trans_y\", \"scan_number\": 219, \"value\": 0.0841728}, {\"regressor\": \"trans_y\", \"scan_number\": 220, \"value\": -0.0458336}, {\"regressor\": \"trans_y\", \"scan_number\": 221, \"value\": 0.0689488}, {\"regressor\": \"trans_y\", \"scan_number\": 222, \"value\": -0.030241700000000007}, {\"regressor\": \"trans_y\", \"scan_number\": 223, \"value\": -0.0016049599999999995}, {\"regressor\": \"trans_y\", \"scan_number\": 224, \"value\": 0.0300242}, {\"regressor\": \"trans_y\", \"scan_number\": 225, \"value\": -0.0166845}, {\"regressor\": \"trans_y\", \"scan_number\": 226, \"value\": -0.015985}, {\"regressor\": \"trans_y\", \"scan_number\": 227, \"value\": -0.015694899999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 228, \"value\": -0.00866834}, {\"regressor\": \"trans_y\", \"scan_number\": 229, \"value\": -0.0516904}, {\"regressor\": \"trans_y\", \"scan_number\": 230, \"value\": 0.017393900000000004}, {\"regressor\": \"trans_y\", \"scan_number\": 231, \"value\": -0.0123876}, {\"regressor\": \"trans_y\", \"scan_number\": 232, \"value\": -0.0117772}, {\"regressor\": \"trans_y\", \"scan_number\": 233, \"value\": -0.0502305}, {\"regressor\": \"trans_y\", \"scan_number\": 234, \"value\": -0.137465}, {\"regressor\": \"trans_y\", \"scan_number\": 235, \"value\": -0.106528}, {\"regressor\": \"trans_y\", \"scan_number\": 236, \"value\": -0.107272}, {\"regressor\": \"trans_y\", \"scan_number\": 237, \"value\": -0.0721498}, {\"regressor\": \"trans_y\", \"scan_number\": 238, \"value\": -0.033154199999999995}, {\"regressor\": \"trans_y\", \"scan_number\": 239, \"value\": 0.00149056}, {\"regressor\": \"trans_y\", \"scan_number\": 240, \"value\": 0.00992796}, {\"regressor\": \"trans_y\", \"scan_number\": 241, \"value\": -0.000129232}, {\"regressor\": \"trans_y\", \"scan_number\": 242, \"value\": -0.072354}, {\"regressor\": \"trans_y\", \"scan_number\": 243, \"value\": -0.07336389999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 244, \"value\": -0.0678936}, {\"regressor\": \"trans_y\", \"scan_number\": 245, \"value\": -0.102583}, {\"regressor\": \"trans_y\", \"scan_number\": 246, \"value\": -0.108642}, {\"regressor\": \"trans_y\", \"scan_number\": 247, \"value\": -0.10627}, {\"regressor\": \"trans_y\", \"scan_number\": 248, \"value\": -0.07872959999999997}, {\"regressor\": \"trans_y\", \"scan_number\": 249, \"value\": -0.07214819999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 250, \"value\": -0.07337489999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 251, \"value\": -0.0805951}, {\"regressor\": \"trans_y\", \"scan_number\": 252, \"value\": -0.0785735}, {\"regressor\": \"trans_y\", \"scan_number\": 253, \"value\": -0.06775679999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 254, \"value\": -0.108126}, {\"regressor\": \"trans_y\", \"scan_number\": 255, \"value\": -0.0793067}, {\"regressor\": \"trans_y\", \"scan_number\": 256, \"value\": -0.0810832}, {\"regressor\": \"trans_y\", \"scan_number\": 257, \"value\": -0.0999484}, {\"regressor\": \"trans_y\", \"scan_number\": 258, \"value\": -0.114624}, {\"regressor\": \"trans_y\", \"scan_number\": 259, \"value\": -0.155081}, {\"regressor\": \"trans_y\", \"scan_number\": 260, \"value\": -0.15117}, {\"regressor\": \"trans_y\", \"scan_number\": 261, \"value\": -0.115544}, {\"regressor\": \"trans_y\", \"scan_number\": 262, \"value\": -0.113719}, {\"regressor\": \"trans_y\", \"scan_number\": 263, \"value\": -0.097162}, {\"regressor\": \"trans_y\", \"scan_number\": 264, \"value\": -0.118373}, {\"regressor\": \"trans_y\", \"scan_number\": 265, \"value\": -0.12886}, {\"regressor\": \"trans_y\", \"scan_number\": 266, \"value\": -0.213457}, {\"regressor\": \"trans_y\", \"scan_number\": 267, \"value\": -0.137207}, {\"regressor\": \"trans_y\", \"scan_number\": 268, \"value\": -0.113735}, {\"regressor\": \"trans_y\", \"scan_number\": 269, \"value\": -0.189738}, {\"regressor\": \"trans_y\", \"scan_number\": 270, \"value\": -0.226687}, {\"regressor\": \"trans_y\", \"scan_number\": 271, \"value\": -0.256268}, {\"regressor\": \"trans_y\", \"scan_number\": 272, \"value\": -0.207037}, {\"regressor\": \"trans_y\", \"scan_number\": 273, \"value\": -0.250573}, {\"regressor\": \"trans_y\", \"scan_number\": 274, \"value\": -0.223471}, {\"regressor\": \"trans_y\", \"scan_number\": 275, \"value\": -0.253373}, {\"regressor\": \"trans_y\", \"scan_number\": 276, \"value\": -0.276619}, {\"regressor\": \"trans_y\", \"scan_number\": 277, \"value\": -0.187512}, {\"regressor\": \"trans_y\", \"scan_number\": 278, \"value\": -0.12558}, {\"regressor\": \"trans_y\", \"scan_number\": 279, \"value\": -0.185292}, {\"regressor\": \"trans_y\", \"scan_number\": 280, \"value\": -0.209046}, {\"regressor\": \"trans_y\", \"scan_number\": 281, \"value\": -0.200406}, {\"regressor\": \"trans_y\", \"scan_number\": 282, \"value\": -0.230321}, {\"regressor\": \"trans_y\", \"scan_number\": 283, \"value\": -0.22291100000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 284, \"value\": -0.225978}, {\"regressor\": \"trans_y\", \"scan_number\": 285, \"value\": -0.24534}, {\"regressor\": \"trans_y\", \"scan_number\": 286, \"value\": -0.211595}, {\"regressor\": \"trans_y\", \"scan_number\": 287, \"value\": -0.176076}, {\"regressor\": \"trans_y\", \"scan_number\": 288, \"value\": -0.119717}, {\"regressor\": \"trans_y\", \"scan_number\": 289, \"value\": -0.150619}, {\"regressor\": \"trans_y\", \"scan_number\": 290, \"value\": -0.15041300000000002}, {\"regressor\": \"trans_y\", \"scan_number\": 291, \"value\": -0.187141}, {\"regressor\": \"trans_y\", \"scan_number\": 292, \"value\": -0.20923000000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 293, \"value\": -0.168457}, {\"regressor\": \"trans_y\", \"scan_number\": 294, \"value\": -0.15349000000000002}, {\"regressor\": \"trans_y\", \"scan_number\": 295, \"value\": -0.14507}, {\"regressor\": \"trans_y\", \"scan_number\": 296, \"value\": -0.165187}, {\"regressor\": \"trans_y\", \"scan_number\": 297, \"value\": -0.192339}, {\"regressor\": \"trans_y\", \"scan_number\": 298, \"value\": -0.230824}, {\"regressor\": \"trans_y\", \"scan_number\": 299, \"value\": -0.166899}, {\"regressor\": \"trans_y\", \"scan_number\": 300, \"value\": -0.119451}, {\"regressor\": \"trans_y\", \"scan_number\": 301, \"value\": -0.175058}, {\"regressor\": \"trans_y\", \"scan_number\": 302, \"value\": -0.244916}, {\"regressor\": \"trans_y\", \"scan_number\": 303, \"value\": -0.237451}, {\"regressor\": \"trans_y\", \"scan_number\": 304, \"value\": -0.139699}, {\"regressor\": \"trans_y\", \"scan_number\": 305, \"value\": -0.14955}, {\"regressor\": \"trans_y\", \"scan_number\": 306, \"value\": -0.13834200000000002}, {\"regressor\": \"trans_y\", \"scan_number\": 307, \"value\": -0.216097}, {\"regressor\": \"trans_y\", \"scan_number\": 308, \"value\": -0.153319}, {\"regressor\": \"trans_y\", \"scan_number\": 309, \"value\": -0.148329}, {\"regressor\": \"trans_y\", \"scan_number\": 310, \"value\": -0.14693599999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 311, \"value\": -0.101425}, {\"regressor\": \"trans_y\", \"scan_number\": 312, \"value\": -0.08912619999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 313, \"value\": -0.12627}, {\"regressor\": \"trans_y\", \"scan_number\": 314, \"value\": -0.16008599999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 315, \"value\": -0.155692}, {\"regressor\": \"trans_y\", \"scan_number\": 316, \"value\": -0.06401359999999999}, {\"regressor\": \"trans_y\", \"scan_number\": 317, \"value\": -0.14175}, {\"regressor\": \"trans_y\", \"scan_number\": 318, \"value\": -0.152043}, {\"regressor\": \"trans_y\", \"scan_number\": 319, \"value\": -0.0980725}, {\"regressor\": \"trans_y\", \"scan_number\": 320, \"value\": -0.182406}, {\"regressor\": \"trans_y\", \"scan_number\": 321, \"value\": -0.184765}, {\"regressor\": \"trans_y\", \"scan_number\": 322, \"value\": -0.13360999999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 323, \"value\": -0.202267}, {\"regressor\": \"trans_y\", \"scan_number\": 324, \"value\": -0.131536}, {\"regressor\": \"trans_y\", \"scan_number\": 325, \"value\": -0.13506400000000002}, {\"regressor\": \"trans_y\", \"scan_number\": 326, \"value\": -0.16188699999999998}, {\"regressor\": \"trans_y\", \"scan_number\": 327, \"value\": -0.13815400000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 328, \"value\": -0.108191}, {\"regressor\": \"trans_y\", \"scan_number\": 329, \"value\": -0.185142}, {\"regressor\": \"trans_y\", \"scan_number\": 330, \"value\": -0.111536}, {\"regressor\": \"trans_y\", \"scan_number\": 331, \"value\": -0.120543}, {\"regressor\": \"trans_y\", \"scan_number\": 332, \"value\": -0.14166700000000002}, {\"regressor\": \"trans_y\", \"scan_number\": 333, \"value\": -0.08468660000000001}, {\"regressor\": \"trans_y\", \"scan_number\": 334, \"value\": -0.159552}, {\"regressor\": \"trans_y\", \"scan_number\": 335, \"value\": -0.0448659}, {\"regressor\": \"trans_y\", \"scan_number\": 336, \"value\": -0.104371}, {\"regressor\": \"trans_y\", \"scan_number\": 337, \"value\": -0.12064200000000005}, {\"regressor\": \"trans_y\", \"scan_number\": 338, \"value\": -0.0753853}, {\"regressor\": \"trans_y\", \"scan_number\": 339, \"value\": -0.197091}, {\"regressor\": \"trans_y\", \"scan_number\": 340, \"value\": -0.0882707}, {\"regressor\": \"trans_y\", \"scan_number\": 341, \"value\": -0.0986524}, {\"regressor\": \"trans_y\", \"scan_number\": 342, \"value\": -0.122951}, {\"regressor\": \"trans_y\", \"scan_number\": 343, \"value\": -0.0810682}, {\"regressor\": \"trans_z\", \"scan_number\": 0, \"value\": 0.0567853}, {\"regressor\": \"trans_z\", \"scan_number\": 1, \"value\": 0.10202}, {\"regressor\": \"trans_z\", \"scan_number\": 2, \"value\": 0.053744500000000014}, {\"regressor\": \"trans_z\", \"scan_number\": 3, \"value\": 0.0115611}, {\"regressor\": \"trans_z\", \"scan_number\": 4, \"value\": 0.0393458}, {\"regressor\": \"trans_z\", \"scan_number\": 5, \"value\": -0.0136073}, {\"regressor\": \"trans_z\", \"scan_number\": 6, \"value\": 0.00475126}, {\"regressor\": \"trans_z\", \"scan_number\": 7, \"value\": 0.00218633}, {\"regressor\": \"trans_z\", \"scan_number\": 8, \"value\": -0.0106431}, {\"regressor\": \"trans_z\", \"scan_number\": 9, \"value\": -0.00431552}, {\"regressor\": \"trans_z\", \"scan_number\": 10, \"value\": -0.0242923}, {\"regressor\": \"trans_z\", \"scan_number\": 11, \"value\": -0.0655986}, {\"regressor\": \"trans_z\", \"scan_number\": 12, \"value\": -0.0716657}, {\"regressor\": \"trans_z\", \"scan_number\": 13, \"value\": -0.0662983}, {\"regressor\": \"trans_z\", \"scan_number\": 14, \"value\": -0.07689539999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 15, \"value\": -0.07386439999999997}, {\"regressor\": \"trans_z\", \"scan_number\": 16, \"value\": -0.038739}, {\"regressor\": \"trans_z\", \"scan_number\": 17, \"value\": -0.00209931}, {\"regressor\": \"trans_z\", \"scan_number\": 18, \"value\": 0.0108292}, {\"regressor\": \"trans_z\", \"scan_number\": 19, \"value\": 0.0104026}, {\"regressor\": \"trans_z\", \"scan_number\": 20, \"value\": -0.00522646}, {\"regressor\": \"trans_z\", \"scan_number\": 21, \"value\": 0.00881076}, {\"regressor\": \"trans_z\", \"scan_number\": 22, \"value\": 0.035061}, {\"regressor\": \"trans_z\", \"scan_number\": 23, \"value\": 0.0172603}, {\"regressor\": \"trans_z\", \"scan_number\": 24, \"value\": 0.034188}, {\"regressor\": \"trans_z\", \"scan_number\": 25, \"value\": 0.0220182}, {\"regressor\": \"trans_z\", \"scan_number\": 26, \"value\": 0.0417382}, {\"regressor\": \"trans_z\", \"scan_number\": 27, \"value\": 0.0668297}, {\"regressor\": \"trans_z\", \"scan_number\": 28, \"value\": 0.07341359999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 29, \"value\": 0.0924342}, {\"regressor\": \"trans_z\", \"scan_number\": 30, \"value\": 0.0807939}, {\"regressor\": \"trans_z\", \"scan_number\": 31, \"value\": 0.0904669}, {\"regressor\": \"trans_z\", \"scan_number\": 32, \"value\": 0.0803247}, {\"regressor\": \"trans_z\", \"scan_number\": 33, \"value\": 0.0841549}, {\"regressor\": \"trans_z\", \"scan_number\": 34, \"value\": 0.06670889999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 35, \"value\": 0.0140169}, {\"regressor\": \"trans_z\", \"scan_number\": 36, \"value\": 0.016910599999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 37, \"value\": 0.0387728}, {\"regressor\": \"trans_z\", \"scan_number\": 38, \"value\": 0.0418122}, {\"regressor\": \"trans_z\", \"scan_number\": 39, \"value\": 0.0140345}, {\"regressor\": \"trans_z\", \"scan_number\": 40, \"value\": 0.0230421}, {\"regressor\": \"trans_z\", \"scan_number\": 41, \"value\": 0.0165474}, {\"regressor\": \"trans_z\", \"scan_number\": 42, \"value\": 0.0140063}, {\"regressor\": \"trans_z\", \"scan_number\": 43, \"value\": 0.0140214}, {\"regressor\": \"trans_z\", \"scan_number\": 44, \"value\": 0.00193075}, {\"regressor\": \"trans_z\", \"scan_number\": 45, \"value\": -0.0256293}, {\"regressor\": \"trans_z\", \"scan_number\": 46, \"value\": -0.0256288}, {\"regressor\": \"trans_z\", \"scan_number\": 47, \"value\": -0.0436083}, {\"regressor\": \"trans_z\", \"scan_number\": 48, \"value\": -0.042235900000000014}, {\"regressor\": \"trans_z\", \"scan_number\": 49, \"value\": -0.0188611}, {\"regressor\": \"trans_z\", \"scan_number\": 50, \"value\": -0.029334}, {\"regressor\": \"trans_z\", \"scan_number\": 51, \"value\": -0.052639}, {\"regressor\": \"trans_z\", \"scan_number\": 52, \"value\": -0.0210638}, {\"regressor\": \"trans_z\", \"scan_number\": 53, \"value\": -0.0284885}, {\"regressor\": \"trans_z\", \"scan_number\": 54, \"value\": 0.000654389}, {\"regressor\": \"trans_z\", \"scan_number\": 55, \"value\": 0.00275855}, {\"regressor\": \"trans_z\", \"scan_number\": 56, \"value\": 0.013981}, {\"regressor\": \"trans_z\", \"scan_number\": 57, \"value\": 0.0274397}, {\"regressor\": \"trans_z\", \"scan_number\": 58, \"value\": 0.0139748}, {\"regressor\": \"trans_z\", \"scan_number\": 59, \"value\": 0.0139839}, {\"regressor\": \"trans_z\", \"scan_number\": 60, \"value\": 0.0267702}, {\"regressor\": \"trans_z\", \"scan_number\": 61, \"value\": 0.0223291}, {\"regressor\": \"trans_z\", \"scan_number\": 62, \"value\": 0.0359131}, {\"regressor\": \"trans_z\", \"scan_number\": 63, \"value\": 0.0283349}, {\"regressor\": \"trans_z\", \"scan_number\": 64, \"value\": 0.032242}, {\"regressor\": \"trans_z\", \"scan_number\": 65, \"value\": 0.00901559}, {\"regressor\": \"trans_z\", \"scan_number\": 66, \"value\": 0.0407677}, {\"regressor\": \"trans_z\", \"scan_number\": 67, \"value\": 0.102901}, {\"regressor\": \"trans_z\", \"scan_number\": 68, \"value\": 0.113154}, {\"regressor\": \"trans_z\", \"scan_number\": 69, \"value\": 0.125352}, {\"regressor\": \"trans_z\", \"scan_number\": 70, \"value\": 0.112231}, {\"regressor\": \"trans_z\", \"scan_number\": 71, \"value\": 0.149784}, {\"regressor\": \"trans_z\", \"scan_number\": 72, \"value\": 0.115681}, {\"regressor\": \"trans_z\", \"scan_number\": 73, \"value\": 0.105474}, {\"regressor\": \"trans_z\", \"scan_number\": 74, \"value\": 0.0494037}, {\"regressor\": \"trans_z\", \"scan_number\": 75, \"value\": -0.00484068}, {\"regressor\": \"trans_z\", \"scan_number\": 76, \"value\": 0.093539}, {\"regressor\": \"trans_z\", \"scan_number\": 77, \"value\": 0.0940535}, {\"regressor\": \"trans_z\", \"scan_number\": 78, \"value\": 0.138795}, {\"regressor\": \"trans_z\", \"scan_number\": 79, \"value\": 0.155388}, {\"regressor\": \"trans_z\", \"scan_number\": 80, \"value\": 0.184997}, {\"regressor\": \"trans_z\", \"scan_number\": 81, \"value\": 0.186441}, {\"regressor\": \"trans_z\", \"scan_number\": 82, \"value\": 0.15573499999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 83, \"value\": 0.13890999999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 84, \"value\": 0.111795}, {\"regressor\": \"trans_z\", \"scan_number\": 85, \"value\": 0.111841}, {\"regressor\": \"trans_z\", \"scan_number\": 86, \"value\": 0.130228}, {\"regressor\": \"trans_z\", \"scan_number\": 87, \"value\": 0.115955}, {\"regressor\": \"trans_z\", \"scan_number\": 88, \"value\": 0.123602}, {\"regressor\": \"trans_z\", \"scan_number\": 89, \"value\": 0.148869}, {\"regressor\": \"trans_z\", \"scan_number\": 90, \"value\": 0.167019}, {\"regressor\": \"trans_z\", \"scan_number\": 91, \"value\": 0.206006}, {\"regressor\": \"trans_z\", \"scan_number\": 92, \"value\": 0.244788}, {\"regressor\": \"trans_z\", \"scan_number\": 93, \"value\": 0.257046}, {\"regressor\": \"trans_z\", \"scan_number\": 94, \"value\": 0.273318}, {\"regressor\": \"trans_z\", \"scan_number\": 95, \"value\": 0.287198}, {\"regressor\": \"trans_z\", \"scan_number\": 96, \"value\": 0.339881}, {\"regressor\": \"trans_z\", \"scan_number\": 97, \"value\": 0.363786}, {\"regressor\": \"trans_z\", \"scan_number\": 98, \"value\": 0.398096}, {\"regressor\": \"trans_z\", \"scan_number\": 99, \"value\": 0.398104}, {\"regressor\": \"trans_z\", \"scan_number\": 100, \"value\": 0.426999}, {\"regressor\": \"trans_z\", \"scan_number\": 101, \"value\": 0.426914}, {\"regressor\": \"trans_z\", \"scan_number\": 102, \"value\": 0.48102}, {\"regressor\": \"trans_z\", \"scan_number\": 103, \"value\": 0.372534}, {\"regressor\": \"trans_z\", \"scan_number\": 104, \"value\": 0.366223}, {\"regressor\": \"trans_z\", \"scan_number\": 105, \"value\": 0.382443}, {\"regressor\": \"trans_z\", \"scan_number\": 106, \"value\": 0.383844}, {\"regressor\": \"trans_z\", \"scan_number\": 107, \"value\": 0.447241}, {\"regressor\": \"trans_z\", \"scan_number\": 108, \"value\": 0.484969}, {\"regressor\": \"trans_z\", \"scan_number\": 109, \"value\": 0.49669}, {\"regressor\": \"trans_z\", \"scan_number\": 110, \"value\": 0.539967}, {\"regressor\": \"trans_z\", \"scan_number\": 111, \"value\": 0.592119}, {\"regressor\": \"trans_z\", \"scan_number\": 112, \"value\": 0.552375}, {\"regressor\": \"trans_z\", \"scan_number\": 113, \"value\": 0.674299}, {\"regressor\": \"trans_z\", \"scan_number\": 114, \"value\": 0.7956489999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 115, \"value\": 0.8241459999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 116, \"value\": 0.953113}, {\"regressor\": \"trans_z\", \"scan_number\": 117, \"value\": 1.04862}, {\"regressor\": \"trans_z\", \"scan_number\": 118, \"value\": 1.04129}, {\"regressor\": \"trans_z\", \"scan_number\": 119, \"value\": 1.05496}, {\"regressor\": \"trans_z\", \"scan_number\": 120, \"value\": 1.1182}, {\"regressor\": \"trans_z\", \"scan_number\": 121, \"value\": 1.1415799999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 122, \"value\": 1.11224}, {\"regressor\": \"trans_z\", \"scan_number\": 123, \"value\": 1.18421}, {\"regressor\": \"trans_z\", \"scan_number\": 124, \"value\": 1.16671}, {\"regressor\": \"trans_z\", \"scan_number\": 125, \"value\": 1.21728}, {\"regressor\": \"trans_z\", \"scan_number\": 126, \"value\": 1.14066}, {\"regressor\": \"trans_z\", \"scan_number\": 127, \"value\": 1.05835}, {\"regressor\": \"trans_z\", \"scan_number\": 128, \"value\": 1.09248}, {\"regressor\": \"trans_z\", \"scan_number\": 129, \"value\": 1.11453}, {\"regressor\": \"trans_z\", \"scan_number\": 130, \"value\": 1.17629}, {\"regressor\": \"trans_z\", \"scan_number\": 131, \"value\": 1.21668}, {\"regressor\": \"trans_z\", \"scan_number\": 132, \"value\": 1.26196}, {\"regressor\": \"trans_z\", \"scan_number\": 133, \"value\": 1.188}, {\"regressor\": \"trans_z\", \"scan_number\": 134, \"value\": 1.20119}, {\"regressor\": \"trans_z\", \"scan_number\": 135, \"value\": 1.17271}, {\"regressor\": \"trans_z\", \"scan_number\": 136, \"value\": 1.17247}, {\"regressor\": \"trans_z\", \"scan_number\": 137, \"value\": 1.21317}, {\"regressor\": \"trans_z\", \"scan_number\": 138, \"value\": 1.31489}, {\"regressor\": \"trans_z\", \"scan_number\": 139, \"value\": 1.28269}, {\"regressor\": \"trans_z\", \"scan_number\": 140, \"value\": 0.987956}, {\"regressor\": \"trans_z\", \"scan_number\": 141, \"value\": 1.0361}, {\"regressor\": \"trans_z\", \"scan_number\": 142, \"value\": 1.1646}, {\"regressor\": \"trans_z\", \"scan_number\": 143, \"value\": 1.22025}, {\"regressor\": \"trans_z\", \"scan_number\": 144, \"value\": 1.22009}, {\"regressor\": \"trans_z\", \"scan_number\": 145, \"value\": 1.1397700000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 146, \"value\": 1.1666299999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 147, \"value\": 1.29593}, {\"regressor\": \"trans_z\", \"scan_number\": 148, \"value\": 1.3732}, {\"regressor\": \"trans_z\", \"scan_number\": 149, \"value\": 1.41676}, {\"regressor\": \"trans_z\", \"scan_number\": 150, \"value\": 1.43389}, {\"regressor\": \"trans_z\", \"scan_number\": 151, \"value\": 1.53434}, {\"regressor\": \"trans_z\", \"scan_number\": 152, \"value\": 1.62997}, {\"regressor\": \"trans_z\", \"scan_number\": 153, \"value\": 1.70344}, {\"regressor\": \"trans_z\", \"scan_number\": 154, \"value\": 1.73436}, {\"regressor\": \"trans_z\", \"scan_number\": 155, \"value\": 1.76636}, {\"regressor\": \"trans_z\", \"scan_number\": 156, \"value\": 1.8058}, {\"regressor\": \"trans_z\", \"scan_number\": 157, \"value\": 1.73557}, {\"regressor\": \"trans_z\", \"scan_number\": 158, \"value\": 1.61476}, {\"regressor\": \"trans_z\", \"scan_number\": 159, \"value\": 1.67348}, {\"regressor\": \"trans_z\", \"scan_number\": 160, \"value\": 1.63694}, {\"regressor\": \"trans_z\", \"scan_number\": 161, \"value\": 1.62885}, {\"regressor\": \"trans_z\", \"scan_number\": 162, \"value\": 1.53923}, {\"regressor\": \"trans_z\", \"scan_number\": 163, \"value\": 1.5001799999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 164, \"value\": 1.47677}, {\"regressor\": \"trans_z\", \"scan_number\": 165, \"value\": 1.39369}, {\"regressor\": \"trans_z\", \"scan_number\": 166, \"value\": 1.39244}, {\"regressor\": \"trans_z\", \"scan_number\": 167, \"value\": 1.39028}, {\"regressor\": \"trans_z\", \"scan_number\": 168, \"value\": 1.40614}, {\"regressor\": \"trans_z\", \"scan_number\": 169, \"value\": 1.3637800000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 170, \"value\": 1.35806}, {\"regressor\": \"trans_z\", \"scan_number\": 171, \"value\": 1.35361}, {\"regressor\": \"trans_z\", \"scan_number\": 172, \"value\": 1.25778}, {\"regressor\": \"trans_z\", \"scan_number\": 173, \"value\": 1.2933}, {\"regressor\": \"trans_z\", \"scan_number\": 174, \"value\": 1.29442}, {\"regressor\": \"trans_z\", \"scan_number\": 175, \"value\": 1.29926}, {\"regressor\": \"trans_z\", \"scan_number\": 176, \"value\": 1.28416}, {\"regressor\": \"trans_z\", \"scan_number\": 177, \"value\": 1.28207}, {\"regressor\": \"trans_z\", \"scan_number\": 178, \"value\": 1.25035}, {\"regressor\": \"trans_z\", \"scan_number\": 179, \"value\": 1.27278}, {\"regressor\": \"trans_z\", \"scan_number\": 180, \"value\": 1.27303}, {\"regressor\": \"trans_z\", \"scan_number\": 181, \"value\": 1.27292}, {\"regressor\": \"trans_z\", \"scan_number\": 182, \"value\": 1.3055}, {\"regressor\": \"trans_z\", \"scan_number\": 183, \"value\": 1.30825}, {\"regressor\": \"trans_z\", \"scan_number\": 184, \"value\": 1.34184}, {\"regressor\": \"trans_z\", \"scan_number\": 185, \"value\": 1.39627}, {\"regressor\": \"trans_z\", \"scan_number\": 186, \"value\": 1.38764}, {\"regressor\": \"trans_z\", \"scan_number\": 187, \"value\": 1.38839}, {\"regressor\": \"trans_z\", \"scan_number\": 188, \"value\": 1.33617}, {\"regressor\": \"trans_z\", \"scan_number\": 189, \"value\": 1.25696}, {\"regressor\": \"trans_z\", \"scan_number\": 190, \"value\": 1.2093200000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 191, \"value\": 1.17181}, {\"regressor\": \"trans_z\", \"scan_number\": 192, \"value\": 1.15214}, {\"regressor\": \"trans_z\", \"scan_number\": 193, \"value\": 1.14374}, {\"regressor\": \"trans_z\", \"scan_number\": 194, \"value\": 1.16693}, {\"regressor\": \"trans_z\", \"scan_number\": 195, \"value\": 1.10818}, {\"regressor\": \"trans_z\", \"scan_number\": 196, \"value\": 1.11092}, {\"regressor\": \"trans_z\", \"scan_number\": 197, \"value\": 1.12799}, {\"regressor\": \"trans_z\", \"scan_number\": 198, \"value\": 1.12785}, {\"regressor\": \"trans_z\", \"scan_number\": 199, \"value\": 1.05074}, {\"regressor\": \"trans_z\", \"scan_number\": 200, \"value\": 1.01469}, {\"regressor\": \"trans_z\", \"scan_number\": 201, \"value\": 1.0374}, {\"regressor\": \"trans_z\", \"scan_number\": 202, \"value\": 1.0809}, {\"regressor\": \"trans_z\", \"scan_number\": 203, \"value\": 1.07784}, {\"regressor\": \"trans_z\", \"scan_number\": 204, \"value\": 1.06133}, {\"regressor\": \"trans_z\", \"scan_number\": 205, \"value\": 0.944439}, {\"regressor\": \"trans_z\", \"scan_number\": 206, \"value\": 0.955862}, {\"regressor\": \"trans_z\", \"scan_number\": 207, \"value\": 1.00989}, {\"regressor\": \"trans_z\", \"scan_number\": 208, \"value\": 0.934827}, {\"regressor\": \"trans_z\", \"scan_number\": 209, \"value\": 0.971456}, {\"regressor\": \"trans_z\", \"scan_number\": 210, \"value\": 1.0173299999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 211, \"value\": 0.974501}, {\"regressor\": \"trans_z\", \"scan_number\": 212, \"value\": 0.958397}, {\"regressor\": \"trans_z\", \"scan_number\": 213, \"value\": 0.974343}, {\"regressor\": \"trans_z\", \"scan_number\": 214, \"value\": 0.983329}, {\"regressor\": \"trans_z\", \"scan_number\": 215, \"value\": 1.0044}, {\"regressor\": \"trans_z\", \"scan_number\": 216, \"value\": 1.07423}, {\"regressor\": \"trans_z\", \"scan_number\": 217, \"value\": 1.00724}, {\"regressor\": \"trans_z\", \"scan_number\": 218, \"value\": 0.906014}, {\"regressor\": \"trans_z\", \"scan_number\": 219, \"value\": 0.9837920000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 220, \"value\": 1.27008}, {\"regressor\": \"trans_z\", \"scan_number\": 221, \"value\": 1.22738}, {\"regressor\": \"trans_z\", \"scan_number\": 222, \"value\": 1.21995}, {\"regressor\": \"trans_z\", \"scan_number\": 223, \"value\": 1.20977}, {\"regressor\": \"trans_z\", \"scan_number\": 224, \"value\": 1.22649}, {\"regressor\": \"trans_z\", \"scan_number\": 225, \"value\": 1.26665}, {\"regressor\": \"trans_z\", \"scan_number\": 226, \"value\": 1.24003}, {\"regressor\": \"trans_z\", \"scan_number\": 227, \"value\": 1.16448}, {\"regressor\": \"trans_z\", \"scan_number\": 228, \"value\": 1.14307}, {\"regressor\": \"trans_z\", \"scan_number\": 229, \"value\": 1.14141}, {\"regressor\": \"trans_z\", \"scan_number\": 230, \"value\": 1.1278700000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 231, \"value\": 1.0845200000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 232, \"value\": 1.09163}, {\"regressor\": \"trans_z\", \"scan_number\": 233, \"value\": 1.12084}, {\"regressor\": \"trans_z\", \"scan_number\": 234, \"value\": 1.07837}, {\"regressor\": \"trans_z\", \"scan_number\": 235, \"value\": 1.1171799999999998}, {\"regressor\": \"trans_z\", \"scan_number\": 236, \"value\": 1.1470200000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 237, \"value\": 1.09984}, {\"regressor\": \"trans_z\", \"scan_number\": 238, \"value\": 1.10595}, {\"regressor\": \"trans_z\", \"scan_number\": 239, \"value\": 1.07732}, {\"regressor\": \"trans_z\", \"scan_number\": 240, \"value\": 0.973075}, {\"regressor\": \"trans_z\", \"scan_number\": 241, \"value\": 1.02968}, {\"regressor\": \"trans_z\", \"scan_number\": 242, \"value\": 0.9936140000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 243, \"value\": 0.98244}, {\"regressor\": \"trans_z\", \"scan_number\": 244, \"value\": 0.950303}, {\"regressor\": \"trans_z\", \"scan_number\": 245, \"value\": 0.903638}, {\"regressor\": \"trans_z\", \"scan_number\": 246, \"value\": 0.9585070000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 247, \"value\": 0.980466}, {\"regressor\": \"trans_z\", \"scan_number\": 248, \"value\": 1.01409}, {\"regressor\": \"trans_z\", \"scan_number\": 249, \"value\": 1.03001}, {\"regressor\": \"trans_z\", \"scan_number\": 250, \"value\": 1.07099}, {\"regressor\": \"trans_z\", \"scan_number\": 251, \"value\": 1.0714}, {\"regressor\": \"trans_z\", \"scan_number\": 252, \"value\": 1.10441}, {\"regressor\": \"trans_z\", \"scan_number\": 253, \"value\": 1.10713}, {\"regressor\": \"trans_z\", \"scan_number\": 254, \"value\": 1.06455}, {\"regressor\": \"trans_z\", \"scan_number\": 255, \"value\": 1.05144}, {\"regressor\": \"trans_z\", \"scan_number\": 256, \"value\": 1.0737}, {\"regressor\": \"trans_z\", \"scan_number\": 257, \"value\": 1.09519}, {\"regressor\": \"trans_z\", \"scan_number\": 258, \"value\": 1.06699}, {\"regressor\": \"trans_z\", \"scan_number\": 259, \"value\": 1.05331}, {\"regressor\": \"trans_z\", \"scan_number\": 260, \"value\": 0.994461}, {\"regressor\": \"trans_z\", \"scan_number\": 261, \"value\": 0.957591}, {\"regressor\": \"trans_z\", \"scan_number\": 262, \"value\": 0.970649}, {\"regressor\": \"trans_z\", \"scan_number\": 263, \"value\": 0.970596}, {\"regressor\": \"trans_z\", \"scan_number\": 264, \"value\": 1.00066}, {\"regressor\": \"trans_z\", \"scan_number\": 265, \"value\": 1.01445}, {\"regressor\": \"trans_z\", \"scan_number\": 266, \"value\": 0.987461}, {\"regressor\": \"trans_z\", \"scan_number\": 267, \"value\": 0.963226}, {\"regressor\": \"trans_z\", \"scan_number\": 268, \"value\": 0.939414}, {\"regressor\": \"trans_z\", \"scan_number\": 269, \"value\": 0.950748}, {\"regressor\": \"trans_z\", \"scan_number\": 270, \"value\": 0.929451}, {\"regressor\": \"trans_z\", \"scan_number\": 271, \"value\": 0.931931}, {\"regressor\": \"trans_z\", \"scan_number\": 272, \"value\": 0.905689}, {\"regressor\": \"trans_z\", \"scan_number\": 273, \"value\": 0.905317}, {\"regressor\": \"trans_z\", \"scan_number\": 274, \"value\": 0.8971979999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 275, \"value\": 0.8911020000000001}, {\"regressor\": \"trans_z\", \"scan_number\": 276, \"value\": 0.929764}, {\"regressor\": \"trans_z\", \"scan_number\": 277, \"value\": 0.916235}, {\"regressor\": \"trans_z\", \"scan_number\": 278, \"value\": 0.97017}, {\"regressor\": \"trans_z\", \"scan_number\": 279, \"value\": 1.0297}, {\"regressor\": \"trans_z\", \"scan_number\": 280, \"value\": 1.06131}, {\"regressor\": \"trans_z\", \"scan_number\": 281, \"value\": 1.05491}, {\"regressor\": \"trans_z\", \"scan_number\": 282, \"value\": 1.05716}, {\"regressor\": \"trans_z\", \"scan_number\": 283, \"value\": 1.10454}, {\"regressor\": \"trans_z\", \"scan_number\": 284, \"value\": 1.05749}, {\"regressor\": \"trans_z\", \"scan_number\": 285, \"value\": 1.03079}, {\"regressor\": \"trans_z\", \"scan_number\": 286, \"value\": 1.0189700000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 287, \"value\": 0.99004}, {\"regressor\": \"trans_z\", \"scan_number\": 288, \"value\": 0.967216}, {\"regressor\": \"trans_z\", \"scan_number\": 289, \"value\": 0.974733}, {\"regressor\": \"trans_z\", \"scan_number\": 290, \"value\": 0.936447}, {\"regressor\": \"trans_z\", \"scan_number\": 291, \"value\": 0.930068}, {\"regressor\": \"trans_z\", \"scan_number\": 292, \"value\": 0.969527}, {\"regressor\": \"trans_z\", \"scan_number\": 293, \"value\": 0.990504}, {\"regressor\": \"trans_z\", \"scan_number\": 294, \"value\": 1.02427}, {\"regressor\": \"trans_z\", \"scan_number\": 295, \"value\": 0.998283}, {\"regressor\": \"trans_z\", \"scan_number\": 296, \"value\": 0.98891}, {\"regressor\": \"trans_z\", \"scan_number\": 297, \"value\": 0.986922}, {\"regressor\": \"trans_z\", \"scan_number\": 298, \"value\": 0.9822900000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 299, \"value\": 0.965403}, {\"regressor\": \"trans_z\", \"scan_number\": 300, \"value\": 0.934109}, {\"regressor\": \"trans_z\", \"scan_number\": 301, \"value\": 0.921443}, {\"regressor\": \"trans_z\", \"scan_number\": 302, \"value\": 0.929288}, {\"regressor\": \"trans_z\", \"scan_number\": 303, \"value\": 0.9152}, {\"regressor\": \"trans_z\", \"scan_number\": 304, \"value\": 0.9430170000000002}, {\"regressor\": \"trans_z\", \"scan_number\": 305, \"value\": 0.929021}, {\"regressor\": \"trans_z\", \"scan_number\": 306, \"value\": 0.913595}, {\"regressor\": \"trans_z\", \"scan_number\": 307, \"value\": 0.959618}, {\"regressor\": \"trans_z\", \"scan_number\": 308, \"value\": 0.954377}, {\"regressor\": \"trans_z\", \"scan_number\": 309, \"value\": 0.8972649999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 310, \"value\": 0.855009}, {\"regressor\": \"trans_z\", \"scan_number\": 311, \"value\": 0.834593}, {\"regressor\": \"trans_z\", \"scan_number\": 312, \"value\": 0.877333}, {\"regressor\": \"trans_z\", \"scan_number\": 313, \"value\": 0.8689379999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 314, \"value\": 0.853547}, {\"regressor\": \"trans_z\", \"scan_number\": 315, \"value\": 0.861333}, {\"regressor\": \"trans_z\", \"scan_number\": 316, \"value\": 0.8892559999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 317, \"value\": 0.8955219999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 318, \"value\": 0.8998669999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 319, \"value\": 0.8852270000000001}, {\"regressor\": \"trans_z\", \"scan_number\": 320, \"value\": 0.8815719999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 321, \"value\": 0.887051}, {\"regressor\": \"trans_z\", \"scan_number\": 322, \"value\": 0.8958229999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 323, \"value\": 0.869848}, {\"regressor\": \"trans_z\", \"scan_number\": 324, \"value\": 0.853626}, {\"regressor\": \"trans_z\", \"scan_number\": 325, \"value\": 0.873144}, {\"regressor\": \"trans_z\", \"scan_number\": 326, \"value\": 0.8734469999999999}, {\"regressor\": \"trans_z\", \"scan_number\": 327, \"value\": 0.927017}, {\"regressor\": \"trans_z\", \"scan_number\": 328, \"value\": 1.083}, {\"regressor\": \"trans_z\", \"scan_number\": 329, \"value\": 1.23778}, {\"regressor\": \"trans_z\", \"scan_number\": 330, \"value\": 1.27453}, {\"regressor\": \"trans_z\", \"scan_number\": 331, \"value\": 1.27381}, {\"regressor\": \"trans_z\", \"scan_number\": 332, \"value\": 1.30133}, {\"regressor\": \"trans_z\", \"scan_number\": 333, \"value\": 1.33826}, {\"regressor\": \"trans_z\", \"scan_number\": 334, \"value\": 1.32105}, {\"regressor\": \"trans_z\", \"scan_number\": 335, \"value\": 1.33368}, {\"regressor\": \"trans_z\", \"scan_number\": 336, \"value\": 1.31334}, {\"regressor\": \"trans_z\", \"scan_number\": 337, \"value\": 1.30436}, {\"regressor\": \"trans_z\", \"scan_number\": 338, \"value\": 1.35616}, {\"regressor\": \"trans_z\", \"scan_number\": 339, \"value\": 1.35175}, {\"regressor\": \"trans_z\", \"scan_number\": 340, \"value\": 1.34673}, {\"regressor\": \"trans_z\", \"scan_number\": 341, \"value\": 1.35987}, {\"regressor\": \"trans_z\", \"scan_number\": 342, \"value\": 1.35602}, {\"regressor\": \"trans_z\", \"scan_number\": 343, \"value\": 1.3968600000000002}]}, \"resolve\": {\"scale\": {\"color\": \"independent\"}}, \"vconcat\": [{\"encoding\": {\"fill\": {\"field\": \"value\", \"legend\": null, \"scale\": {\"scheme\": \"viridis\"}, \"sort\": \"ascending\", \"type\": \"quantitative\"}, \"stroke\": {\"field\": \"value\", \"legend\": null, \"scale\": {\"scheme\": \"viridis\"}, \"sort\": \"ascending\", \"type\": \"quantitative\"}, \"x\": {\"axis\": {\"labelAngle\": -45, \"ticks\": false, \"title\": null}, \"field\": \"regressor\", \"sort\": null, \"type\": \"nominal\"}, \"y\": {\"axis\": {\"labels\": true, \"ticks\": false, \"title\": \"Time (TRs)\", \"values\": [0, 50, 100, 150, 200, 250, 300]}, \"field\": \"scan_number\", \"type\": \"ordinal\"}}, \"height\": 450, \"mark\": \"rect\", \"width\": 750}, {\"hconcat\": [{\"encoding\": {\"color\": {\"field\": \"regressor\", \"legend\": null, \"type\": \"nominal\"}, \"x\": {\"axis\": {\"ticks\": false, \"title\": \"Time (TRs)\", \"values\": [0, 50, 100, 150, 200, 250, 300]}, \"field\": \"scan_number\", \"scale\": {\"domain\": [0, 343]}, \"type\": \"quantitative\"}, \"y\": {\"axis\": {\"title\": \"Amplitude (scaled for visualization)\"}, \"field\": \"value\", \"type\": \"quantitative\"}}, \"height\": 225, \"mark\": {\"clip\": true, \"type\": \"line\"}, \"title\": \"Timecourse (shift-click legend to select)\", \"transform\": [{\"filter\": {\"selection\": \"selector083\"}}], \"width\": 650}, {\"encoding\": {\"color\": {\"field\": \"regressor\", \"legend\": null, \"type\": \"nominal\"}, \"y\": {\"axis\": {\"orient\": \"right\"}, \"field\": \"regressor\", \"type\": \"nominal\"}}, \"mark\": {\"size\": 200, \"type\": \"square\"}, \"selection\": {\"selector083\": {\"fields\": [\"regressor\"], \"type\": \"multi\"}}}]}]}, {\"mode\": \"vega-lite\"});\n",
       "</script>"
      ],
      "text/plain": [
       "<altair.vegalite.v4.display.VegaLite at 0x7f72e6580f28>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "analysis = language_models[name][0]['analysis']\n",
    "analysis.generate_report(run_id=analysis.runs[0]) \n",
    "analysis.plot_report(plot_type='design_matrix_plot')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 31,
   "metadata": {},
   "outputs": [],
   "source": [
    "# dump_collection(language_models, filename)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Compile models"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 36,
   "metadata": {
    "jupyter": {
     "outputs_hidden": true
    },
    "scrolled": false,
    "tags": []
   },
   "outputs": [],
   "source": [
    "# Compile analyses\n",
    "# for analysis_dict in language_models[name]:\n",
    "#     analysis = analysis_dict['analysis']\n",
    "#     if analysis.get_status()['status'] in 'DRAFT':\n",
    "#         analysis.compile()"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "Python 3",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.7.3"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 4
}
